@@ -45,8 +45,8 @@
 class GovernmentForms {
 	var $objs = NULL;
 
-	var $tcpdf_dir = '.'; //TCPDF class directory.
-	var $fpdi_dir = '.'; //FPDI class directory.
+	var $tcpdf_dir = '../tcpdf/'; //TCPDF class directory.
+	var $fpdi_dir = '../fpdi/'; //FPDI class directory.
 
 	function __construct() {
 		return TRUE;
@@ -98,6 +98,35 @@ class GovernmentForms {
 		return FALSE;
 	}
 
+	function validateXML( $xml, $schema_file ) {
+		Debug::text('Schema File: '. $schema_file, __FILE__, __LINE__, __METHOD__, 10);
+		if ( class_exists( 'DomDocument' ) AND file_exists($schema_file) ) {
+			libxml_use_internal_errors( TRUE );
+
+			$dom = new DomDocument;
+			$dom->loadXML( $xml );
+
+			if ( $dom->schemaValidate( $schema_file ) ) {
+				Debug::Text('Schema is valid!', __FILE__, __LINE__, __METHOD__,10);
+				return TRUE;
+			} else {
+				Debug::Text('Schema is NOT valid!', __FILE__, __LINE__, __METHOD__,10);
+
+				$errors = libxml_get_errors();
+				foreach ( $errors as $error) {
+					Debug::Text('XML Error (Line: '. $error->line.'): '. $error->message, __FILE__, __LINE__, __METHOD__,10);
+				}
+
+				return FALSE;
+			}
+		} else {
+			Debug::Text('DomDocument not available!', __FILE__, __LINE__, __METHOD__,10);
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
 	function Output( $type ) {
 		$type = strtolower($type);
 
@@ -115,6 +144,7 @@ class GovernmentForms {
 			$pdf = new FPDI( 'P', 'pt' );
 			$pdf->setMargins(0,0,0,0);
 			$pdf->SetAutoPageBreak(FALSE);
+			$pdf->setFontSubsetting(FALSE);
 
 			foreach( $this->objs as $obj ) {
 				$obj->setPDFObject( $pdf );
@@ -122,6 +152,40 @@ class GovernmentForms {
 			}
 
 			return $pdf->Output('','S');
+		} elseif ( $type == 'xml' ) {
+			//Since multiple XML sections may need to be joined together,
+			//We must pass the XML object between each form and  build the entire XML object completely
+			//then output it all at once at the end.
+			$xml = NULL;
+			$xml_schema = NULL;
+			foreach( $this->objs as $obj ) {
+				if ( is_object( $xml ) ) {
+					$obj->setXMLObject($xml);
+				}
+
+				$obj->Output( $type );
+				if ( isset($obj->xml_schema) ) {
+					$xml_schema = $obj->getClassDirectory() . DIRECTORY_SEPARATOR . 'schema' . DIRECTORY_SEPARATOR . $obj->xml_schema;
+				}
+
+				if ( $xml == NULL AND is_object( $obj->getXMLObject() ) ) {
+					$xml = $obj->getXMLObject();
+				}
+			}
+
+			if ( is_object( $xml ) ) {
+				$output = $xml->asXML();
+
+				if ( $this->validateXML( $output, $xml_schema ) == FALSE ) {
+					Debug::text('XML Schema is invalid! Malformed XML!', __FILE__, __LINE__, __METHOD__, 10);
+					$output = FALSE;
+				}
+			} else {
+				Debug::text('No XML object!', __FILE__, __LINE__, __METHOD__, 10);
+				$output = FALSE;
+			}
+
+			return $output;
 		}
 	}
 }
