@@ -45,9 +45,10 @@
 include_once( 'US.class.php' );
 class GovernmentForms_US_941 extends GovernmentForms_US {
 	public $pdf_template = '941.pdf';
-	//public $template_offsets = array( 0, -33 ); //x, y
+	//public $template_offsets = array( -2, +35 ); //x, y
+	public $page_offsets = array( 0, -35 ); //x, y
 
-	public $social_security_rate = 0.124; //Line: 5a2, 5b2
+	public $social_security_rate = 0.104; //Line: 5a2, 5b2
 
 	public $medicare_rate = 0.029; //Line: 5c2
 
@@ -89,9 +90,9 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 										'value' => 'Form',
 										'on_background' => TRUE,
 										'coordinates' => array(
-															'x' => 36,
-															'y' => 74,
-															'h' => 20,
+															'x' => 35,
+															'y' => 71,
+															'h' => 23,
 															'w' => 22,
 															'halign' => 'L',
 															'fill_color' => array( 255, 255, 255 ),
@@ -108,7 +109,7 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 															'x' => 57,
 															'y' => 66,
 															'h' => 28,
-															'w' => 99,
+															'w' => 97,
 															'halign' => 'C',
 															'fill_color' => array( 255, 255, 255 ),
 															),
@@ -118,13 +119,13 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 									),
 
 								array(
-										'value' => $this->year,
+										'value' => $this->year, //Top left, in quarter checkbox section.
 										'on_background' => TRUE,
 										'coordinates' => array(
-															'x' => 527,
+															'x' => 532,
 															'y' => 107,
 															'h' => 8,
-															'w' => 20,
+															'w' => 21,
 															'halign' => 'C',
 															'text_color' => array( 255, 255, 255 ),
 															'fill_color' => array( 30, 30, 30 ),
@@ -135,11 +136,11 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 									),
 
 								array(
-										'value' => '('. $this->year .')',
+										'value' => '('. $this->year .')', //Bottom right of first page.
 										'on_background' => TRUE,
 										'coordinates' => array(
-															'x' => 519,
-															'y' => 766,
+															'x' => 533,
+															'y' => 756,
 															'h' => 11,
 															'w' => 45,
 															'halign' => 'C',
@@ -163,56 +164,56 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 																		'halign' => 'C',
 																		),
 																	   array(
-																		'x' => 176,
+																		'x' => 178,
 																		'y' => 102,
 																		'h' => 17,
 																		'w' => 19,
 																		'halign' => 'C',
 																		),
 																	   array(
-																		'x' => 213,
+																		'x' => 216,
 																		'y' => 102,
 																		'h' => 17,
 																		'w' => 19,
 																		'halign' => 'C',
 																		),
 																	   array(
-																		'x' => 238,
+																		'x' => 242,
 																		'y' => 102,
 																		'h' => 17,
 																		'w' => 19,
 																		'halign' => 'C',
 																		),
 																	   array(
-																		'x' => 262,
+																		'x' => 267,
 																		'y' => 102,
 																		'h' => 17,
 																		'w' => 19,
 																		'halign' => 'C',
 																		),
 																	   array(
-																		'x' => 287,
+																		'x' => 292,
 																		'y' => 102,
 																		'h' => 17,
 																		'w' => 19,
 																		'halign' => 'C',
 																		),
 																	   array(
-																		'x' => 312,
+																		'x' => 318,
 																		'y' => 102,
 																		'h' => 17,
 																		'w' => 19,
 																		'halign' => 'C',
 																		),
 																	   array(
-																		'x' => 336,
+																		'x' => 343,
 																		'y' => 102,
 																		'h' => 17,
 																		'w' => 19,
 																		'halign' => 'C',
 																		),
 																	   array(
-																		'x' => 361,
+																		'x' => 369,
 																		'y' => 102,
 																		'h' => 17,
 																		'w' => 19,
@@ -228,7 +229,7 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'page' => 1,
 												'template_page' => 1,
 												'coordinates' => array(
-																		'x' => 134,
+																		'x' => 139,
 																		'y' => 125,
 																		'h' => 18,
 																		'w' => 246,
@@ -240,7 +241,7 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'page' => 1,
 												'template_page' => 1,
 												'coordinates' => array(
-																		'x' => 113,
+																		'x' => 118,
 																		'y' => 149,
 																		'h' => 18,
 																		'w' => 267,
@@ -252,7 +253,7 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'page' => 1,
 												'template_page' => 1,
 												'coordinates' => array(
-																		'x' => 78,
+																		'x' => 83,
 																		'y' => 172,
 																		'h' => 18,
 																		'w' => 302,
@@ -264,8 +265,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'page' => 1,
 												'template_page' => 1,
 												'coordinates' => array(
-																		'x' => 78,
-																		'y' => 198,
+																		'x' => 83,
+																		'y' => 199,
 																		'h' => 18,
 																		'w' => 182,
 																		'halign' => 'L',
@@ -275,8 +276,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'page' => 1,
 												'template_page' => 1,
 												'coordinates' => array(
-																		'x' => 268,
-																		'y' => 198,
+																		'x' => 273,
+																		'y' => 199,
 																		'h' => 18,
 																		'w' => 35,
 																		'halign' => 'C',
@@ -286,8 +287,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'page' => 1,
 												'template_page' => 1,
 												'coordinates' => array(
-																		'x' => 310,
-																		'y' => 198,
+																		'x' => 317,
+																		'y' => 199,
 																		'h' => 18,
 																		'w' => 70,
 																		'halign' => 'C',
@@ -301,29 +302,29 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'function' => 'drawCheckBox',
 												'coordinates' => array(
 																		1 => array(
-																			'x' => 414,
-																			'y' => 136,
+																			'x' => 420,
+																			'y' => 134,
 																			'h' => 10,
 																			'w' => 11,
 																			'halign' => 'C',
 																			),
 																		2 => array(
-																			'x' => 414,
-																			'y' => 153,
+																			'x' => 420,
+																			'y' => 151,
 																			'h' => 10,
 																			'w' => 11,
 																			'halign' => 'C',
 																			),
 																		3 => array(
-																			'x' => 414,
-																			'y' => 171,
+																			'x' => 420,
+																			'y' => 169,
 																			'h' => 10,
 																			'w' => 11,
 																			'halign' => 'C',
 																			),
 																		4 => array(
-																			'x' => 414,
-																			'y' => 188,
+																			'x' => 420,
+																			'y' => 186,
 																			'h' => 10,
 																			'w' => 11,
 																			'halign' => 'C',
@@ -338,8 +339,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'page' => 1,
 												'template_page' => 1,
 												'coordinates' => array(
-																		'x' => 431,
-																		'y' => 257,
+																		'x' => 447, //431
+																		'y' => 262, //257
 																		'h' => 15,
 																		'w' => 128,
 																		'halign' => 'C',
@@ -352,15 +353,15 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'function' => 'drawSplitDecimalFloat',
 												'coordinates' => array(
 																	array(
-																		'x' => 431,
-																		'y' => 275,
+																		'x' => 447,
+																		'y' => 281,
 																		'h' => 14,
 																		'w' => 99,
 																		'halign' => 'R',
 																		),
 																	array(
-																		'x' => 533,
-																		'y' => 275,
+																		'x' => 549,
+																		'y' => 281,
 																		'h' => 14,
 																		'w' => 26,
 																		'halign' => 'C',
@@ -373,15 +374,15 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'function' => 'drawSplitDecimalFloat',
 												'coordinates' => array(
 																	array(
-																		'x' => 431,
-																		'y' => 292,
+																		'x' => 447,
+																		'y' => 300,
 																		'h' => 14,
 																		'w' => 99,
 																		'halign' => 'R',
 																		),
 																	array(
-																		'x' => 533,
-																		'y' => 292,
+																		'x' => 549,
+																		'y' => 300,
 																		'h' => 14,
 																		'w' => 26,
 																		'halign' => 'C',
@@ -394,8 +395,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'function' => 'drawCheckbox',
 												'coordinates' => array(
 																	array(
-																		'x' => 431,
-																		'y' => 314,
+																		'x' => 449,
+																		'y' => 319,
 																		'h' => 6,
 																		'w' => 10,
 																		'halign' => 'C',
@@ -411,15 +412,15 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'function' => 'drawSplitDecimalFloat',
 												'coordinates' => array(
 																	array(
-																		'x' => 190,
-																		'y' => 351,
+																		'x' => 200, //190
+																		'y' => 348, //351
 																		'h' => 14,
-																		'w' => 75,
+																		'w' => 65, //75
 																		'halign' => 'R',
 																		),
 																	array(
-																		'x' => 269,
-																		'y' => 351,
+																		'x' => 275,
+																		'y' => 348,
 																		'h' => 14,
 																		'w' => 20,
 																		'halign' => 'C',
@@ -432,15 +433,15 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'function' => 'drawSplitDecimalFloat',
 												'coordinates' => array(
 																	array(
-																		'x' => 190,
-																		'y' => 369,
+																		'x' => 200,
+																		'y' => 366,
 																		'h' => 14,
-																		'w' => 75,
+																		'w' => 65,
 																		'halign' => 'R',
 																		),
 																	array(
-																		'x' => 269,
-																		'y' => 369,
+																		'x' => 275,
+																		'y' => 366,
 																		'h' => 14,
 																		'w' => 20,
 																		'halign' => 'C',
@@ -453,15 +454,15 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'function' => 'drawSplitDecimalFloat',
 												'coordinates' => array(
 																	array(
-																		'x' => 190,
-																		'y' => 386,
+																		'x' => 200,
+																		'y' => 384,
 																		'h' => 14,
-																		'w' => 75,
+																		'w' => 65,
 																		'halign' => 'R',
 																		),
 																	array(
-																		'x' => 269,
-																		'y' => 386,
+																		'x' => 275,
+																		'y' => 384,
 																		'h' => 14,
 																		'w' => 20,
 																		'halign' => 'C',
@@ -475,14 +476,14 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'coordinates' => array(
 																	array(
 																		'x' => 331,
-																		'y' => 351,
+																		'y' => 348,
 																		'h' => 14,
 																		'w' => 75,
 																		'halign' => 'R',
 																		),
 																	array(
 																		'x' => 410,
-																		'y' => 351,
+																		'y' => 348,
 																		'h' => 14,
 																		'w' => 19,
 																		'halign' => 'C',
@@ -496,14 +497,14 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'coordinates' => array(
 																	array(
 																		'x' => 331,
-																		'y' => 369,
+																		'y' => 366,
 																		'h' => 14,
 																		'w' => 75,
 																		'halign' => 'R',
 																		),
 																	array(
 																		'x' => 410,
-																		'y' => 369,
+																		'y' => 366,
 																		'h' => 14,
 																		'w' => 19,
 																		'halign' => 'C',
@@ -517,14 +518,14 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'coordinates' => array(
 																	array(
 																		'x' => 331,
-																		'y' => 386,
+																		'y' => 384,
 																		'h' => 14,
 																		'w' => 75,
 																		'halign' => 'R',
 																		),
 																	array(
 																		'x' => 410,
-																		'y' => 386,
+																		'y' => 384,
 																		'h' => 14,
 																		'w' => 19,
 																		'halign' => 'C',
@@ -537,183 +538,145 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'function' => array('calcL5D', 'drawSplitDecimalFloat'),
 												'coordinates' => array(
 																	array(
-																		'x' => 431,
-																		'y' => 409,
+																		'x' => 446,
+																		'y' => 413,
 																		'h' => 14,
 																		'w' => 99,
 																		'halign' => 'R',
 																		),
 																	array(
-																		'x' => 533,
-																		'y' => 409,
+																		'x' => 549,
+																		'y' => 413,
 																		'h' => 14,
 																		'w' => 26,
 																		'halign' => 'C',
 																		),
 																	),
 											),
-								'l6' => array(
+								'l5e' => array(
 												'page' => 1,
 												'template_page' => 1,
-												'function' => array('calcL6', 'drawSplitDecimalFloat'),
+												'function' => array( 'drawSplitDecimalFloat'),
 												'coordinates' => array(
 																	array(
-																		'x' => 431,
-																		'y' => 426,
+																		'x' => 446,
+																		'y' => 437,
 																		'h' => 14,
 																		'w' => 99,
 																		'halign' => 'R',
 																		),
 																	array(
-																		'x' => 533,
-																		'y' => 426,
+																		'x' => 549,
+																		'y' => 437,
 																		'h' => 14,
 																		'w' => 26,
 																		'halign' => 'C',
 																		),
 																	),
 											),
-								'l7a' => array(
+
+								'l6e' => array(
 												'page' => 1,
 												'template_page' => 1,
-												'function' => array('calcL7A', 'drawSplitDecimalFloat'),
+												'function' => array('calcL6E', 'drawSplitDecimalFloat'),
 												'coordinates' => array(
 																	array(
-																		'x' => 331,
-																		'y' => 462,
-																		'h' => 14,
-																		'w' => 75,
-																		'halign' => 'R',
-																		),
-																	array(
-																		'x' => 410,
-																		'y' => 462,
-																		'h' => 14,
-																		'w' => 19,
-																		'halign' => 'C',
-																		),
-																	),
-											),
-								'l7b' => array(
-												'page' => 1,
-												'template_page' => 1,
-												'function' => 'drawSplitDecimalFloat',
-												'coordinates' => array(
-																	array(
-																		'x' => 331,
-																		'y' => 480,
-																		'h' => 14,
-																		'w' => 75,
-																		'halign' => 'R',
-																		),
-																	array(
-																		'x' => 410,
-																		'y' => 480,
-																		'h' => 14,
-																		'w' => 19,
-																		'halign' => 'C',
-																		),
-																	),
-											),
-								'l7c' => array(
-												'page' => 1,
-												'template_page' => 1,
-												'function' => 'drawSplitDecimalFloat',
-												'coordinates' => array(
-																	array(
-																		'x' => 331,
-																		'y' => 497,
-																		'h' => 14,
-																		'w' => 75,
-																		'halign' => 'R',
-																		),
-																	array(
-																		'x' => 410,
-																		'y' => 497,
-																		'h' => 14,
-																		'w' => 19,
-																		'halign' => 'C',
-																		),
-																	),
-											),
-								'l7d' => array(
-												'page' => 1,
-												'template_page' => 1,
-												'function' => array('calcL7D', 'drawSplitDecimalFloat'),
-												'coordinates' => array(
-																	array(
-																		'x' => 431,
-																		'y' => 520,
+																		'x' => 446,
+																		'y' => 528,
 																		'h' => 14,
 																		'w' => 99,
 																		'halign' => 'R',
 																		),
 																	array(
-																		'x' => 533,
-																		'y' => 520,
+																		'x' => 549,
+																		'y' => 528,
 																		'h' => 14,
 																		'w' => 26,
 																		'halign' => 'C',
 																		),
 																	),
 											),
+								'l7' => array(
+												'page' => 1,
+												'template_page' => 1,
+												'function' => array('calcL7', 'drawSplitDecimalFloat'),
+												'coordinates' => array(
+																	array(
+																		'x' => 446,
+																		'y' => 546,
+																		'h' => 14,
+																		'w' => 99,
+																		'halign' => 'R',
+																		),
+																	array(
+																		'x' => 549,
+																		'y' => 546,
+																		'h' => 14,
+																		'w' => 26,
+																		'halign' => 'C',
+																		),
+																	),
+											),
+
 								'l8' => array(
 												'page' => 1,
 												'template_page' => 1,
-												'function' => array('calcL8', 'drawSplitDecimalFloat'),
+												'function' => 'drawSplitDecimalFloat',
 												'coordinates' => array(
 																	array(
-																		'x' => 431,
-																		'y' => 538,
+																		'x' => 446,
+																		'y' => 563,
 																		'h' => 14,
 																		'w' => 99,
 																		'halign' => 'R',
 																		),
 																	array(
-																		'x' => 533,
-																		'y' => 538,
+																		'x' => 549,
+																		'y' => 563,
 																		'h' => 14,
 																		'w' => 26,
 																		'halign' => 'C',
 																		),
 																	),
 											),
+
 								'l9' => array(
 												'page' => 1,
 												'template_page' => 1,
 												'function' => 'drawSplitDecimalFloat',
 												'coordinates' => array(
 																	array(
-																		'x' => 431,
-																		'y' => 555,
+																		'x' => 446,
+																		'y' => 582,
 																		'h' => 14,
 																		'w' => 99,
 																		'halign' => 'R',
 																		),
 																	array(
-																		'x' => 533,
-																		'y' => 555,
+																		'x' => 549,
+																		'y' => 582,
 																		'h' => 14,
 																		'w' => 26,
 																		'halign' => 'C',
 																		),
 																	),
 											),
+
 								'l10' => array(
 												'page' => 1,
 												'template_page' => 1,
 												'function' => array('calcL10', 'drawSplitDecimalFloat'),
 												'coordinates' => array(
 																	array(
-																		'x' => 431,
-																		'y' => 573,
+																		'x' => 446,
+																		'y' => 600,
 																		'h' => 14,
 																		'w' => 99,
 																		'halign' => 'R',
 																		),
 																	array(
-																		'x' => 533,
-																		'y' => 573,
+																		'x' => 549,
+																		'y' => 600,
 																		'h' => 14,
 																		'w' => 26,
 																		'halign' => 'C',
@@ -726,17 +689,17 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'function' => 'drawSplitDecimalFloat',
 												'coordinates' => array(
 																	array(
-																		'x' => 331,
-																		'y' => 608,
+																		'x' => 446,
+																		'y' => 617,
 																		'h' => 14,
-																		'w' => 75,
+																		'w' => 99,
 																		'halign' => 'R',
 																		),
 																	array(
-																		'x' => 410,
-																		'y' => 608,
+																		'x' => 549,
+																		'y' => 617,
 																		'h' => 14,
-																		'w' => 19,
+																		'w' => 26,
 																		'halign' => 'C',
 																		),
 																	),
@@ -747,17 +710,17 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'function' => 'drawSplitDecimalFloat',
 												'coordinates' => array(
 																	array(
-																		'x' => 331,
-																		'y' => 631,
+																		'x' => 446,
+																		'y' => 635,
 																		'h' => 14,
-																		'w' => 75,
+																		'w' => 99,
 																		'halign' => 'R',
 																		),
 																	array(
-																		'x' => 410,
-																		'y' => 631,
+																		'x' => 549,
+																		'y' => 635,
 																		'h' => 14,
-																		'w' => 19,
+																		'w' => 26,
 																		'halign' => 'C',
 																		),
 																	),
@@ -766,8 +729,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'page' => 1,
 												'template_page' => 1,
 												'coordinates' => array(
-																	'x' => 254,
-																	'y' => 655,
+																	'x' => 350,
+																	'y' => 654,
 																	'h' => 14,
 																	'w' => 76,
 																	'halign' => 'C',
@@ -780,15 +743,15 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'function' => array('calcL13', 'drawSplitDecimalFloat'),
 												'coordinates' => array(
 																	array(
-																		'x' => 431,
-																		'y' => 678,
+																		'x' => 446,
+																		'y' => 672,
 																		'h' => 14,
 																		'w' => 99,
 																		'halign' => 'R',
 																		),
 																	array(
-																		'x' => 533,
-																		'y' => 678,
+																		'x' => 549,
+																		'y' => 672,
 																		'h' => 14,
 																		'w' => 26,
 																		'halign' => 'C',
@@ -801,15 +764,15 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'function' => array('calcL14', 'drawSplitDecimalFloat'),
 												'coordinates' => array(
 																	array(
-																		'x' => 431,
-																		'y' => 702,
+																		'x' => 446,
+																		'y' => 689,
 																		'h' => 14,
 																		'w' => 99,
 																		'halign' => 'R',
 																		),
 																	array(
-																		'x' => 533,
-																		'y' => 702,
+																		'x' => 549,
+																		'y' => 689,
 																		'h' => 14,
 																		'w' => 26,
 																		'halign' => 'C',
@@ -822,15 +785,15 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'function' => array('calcL15', 'drawSplitDecimalFloat'),
 												'coordinates' => array(
 																	array(
-																		'x' => 331,
-																		'y' => 725,
+																		'x' => 295,
+																		'y' => 707,
 																		'h' => 14,
 																		'w' => 75,
 																		'halign' => 'R',
 																		),
 																	array(
-																		'x' => 410,
-																		'y' => 725,
+																		'x' => 375,
+																		'y' => 707,
 																		'h' => 14,
 																		'w' => 19,
 																		'halign' => 'C',
@@ -843,8 +806,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'function' => array('filterL15A', 'drawCheckbox'),
 												'coordinates' => array(
 																	array(
-																		'x' => 478,
-																		'y' => 718,
+																		'x' => 444,
+																		'y' => 710,
 																		'h' => 6,
 																		'w' => 10,
 																		'halign' => 'C',
@@ -860,8 +823,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'function' => array('filterL15B', 'drawCheckbox'),
 												'coordinates' => array(
 																	array(
-																		'x' => 478,
-																		'y' => 729,
+																		'x' => 515,
+																		'y' => 710,
 																		'h' => 6,
 																		'w' => 10,
 																		'halign' => 'C',
@@ -879,7 +842,7 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'value' => $this->name,
 												'coordinates' => array(
 																		'x' => 36,
-																		'y' => 88,
+																		'y' => 89,
 																		'h' => 15,
 																		'w' => 350,
 																		'halign' => 'L',
@@ -888,8 +851,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 								array(
 												'value' => $this->ein,
 												'coordinates' => array(
-																		'x' => 388,
-																		'y' => 88,
+																		'x' => 398,
+																		'y' => 89,
 																		'h' => 15,
 																		'w' => 175,
 																		'halign' => 'C',
@@ -899,8 +862,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 										'value' => '('. $this->year .')',
 										'on_background' => TRUE,
 										'coordinates' => array(
-															'x' => 519,
-															'y' => 766,
+															'x' => 534,
+															'y' => 792,
 															'h' => 11,
 															'w' => 45,
 															'halign' => 'C',
@@ -918,14 +881,14 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'coordinates' => array(
 																		array(
 																			'x' => 64,
-																			'y' => 144,
+																			'y' => 154,
 																			'h' => 18,
 																			'w' => 18,
 																			'halign' => 'C',
 																			),
 																		array(
-																			'x' => 85,
-																			'y' => 144,
+																			'x' => 86,
+																			'y' => 154,
 																			'h' => 18,
 																			'w' => 18,
 																			'halign' => 'C',
@@ -938,15 +901,15 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'function' => 'drawSplitDecimalFloat',
 												'coordinates' => array(
 																	array(
-																		'x' => 232,
-																		'y' => 223,
+																		'x' => 237,
+																		'y' => 244,
 																		'h' => 14,
 																		'w' => 99,
 																		'halign' => 'R',
 																		),
 																	array(
-																		'x' => 334,
-																		'y' => 223,
+																		'x' => 339,
+																		'y' => 244,
 																		'h' => 14,
 																		'w' => 26,
 																		'halign' => 'C',
@@ -959,15 +922,15 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'function' => 'drawSplitDecimalFloat',
 												'coordinates' => array(
 																	array(
-																		'x' => 232,
-																		'y' => 246,
+																		'x' => 237,
+																		'y' => 266,
 																		'h' => 14,
 																		'w' => 99,
 																		'halign' => 'R',
 																		),
 																	array(
-																		'x' => 334,
-																		'y' => 246,
+																		'x' => 339,
+																		'y' => 266,
 																		'h' => 14,
 																		'w' => 26,
 																		'halign' => 'C',
@@ -980,15 +943,15 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'function' => 'drawSplitDecimalFloat',
 												'coordinates' => array(
 																	array(
-																		'x' => 232,
-																		'y' => 270,
+																		'x' => 237,
+																		'y' => 288,
 																		'h' => 14,
 																		'w' => 99,
 																		'halign' => 'R',
 																		),
 																	array(
-																		'x' => 334,
-																		'y' => 270,
+																		'x' => 339,
+																		'y' => 288,
 																		'h' => 14,
 																		'w' => 26,
 																		'halign' => 'C',
@@ -1001,15 +964,15 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'function' => array('calcL17MonthTotal', 'drawSplitDecimalFloat'),
 												'coordinates' => array(
 																	array(
-																		'x' => 232,
-																		'y' => 293,
+																		'x' => 237,
+																		'y' => 310,
 																		'h' => 14,
 																		'w' => 99,
 																		'halign' => 'R',
 																		),
 																	array(
-																		'x' => 334,
-																		'y' => 293,
+																		'x' => 339,
+																		'y' => 310,
 																		'h' => 14,
 																		'w' => 26,
 																		'halign' => 'C',
@@ -1023,22 +986,22 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'function' => array( 'filterL17', 'drawCheckbox'),
 												'coordinates' => array(
 																	'a' => array(
-																		'x' => 113,
-																		'y' => 169,
+																		'x' => 117,
+																		'y' => 177,
 																		'h' => 6,
 																		'w' => 10,
 																		'halign' => 'C',
 																		),
 																	'b' => array(
-																		'x' => 113,
-																		'y' => 192,
+																		'x' => 117,
+																		'y' => 215,
 																		'h' => 6,
 																		'w' => 10,
 																		'halign' => 'C',
 																		),
 																	'c' => array(
-																		'x' => 113,
-																		'y' => 313,
+																		'x' => 117,
+																		'y' => 328,
 																		'h' => 6,
 																		'w' => 10,
 																		'halign' => 'C',
@@ -1057,8 +1020,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'value' => substr( $this->year, 2, 2),
 												'on_background' => TRUE,
 												'coordinates' => array(
-																		'x' => 504,
-																		'y' => 608,
+																		'x' => 536,
+																		'y' => 602,
 																		'h' => 0,
 																		'w' => 30,
 																		'halign' => 'L',
@@ -1077,14 +1040,14 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'coordinates' => array(
 																	array(
 																		'x' => 54,
-																		'y' => 653,
+																		'y' => 648,
 																		'h' => 15,
 																		'w' => 30,
 																		'halign' => 'C',
 																		),
 																	array(
 																		'x' => 87,
-																		'y' => 653,
+																		'y' => 648,
 																		'h' => 15,
 																		'w' => 50,
 																		'halign' => 'C',
@@ -1100,14 +1063,14 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'function' => array( 'calcL14', 'drawSplitDecimalFloat'),
 												'coordinates' => array(
 																	array(
-																		'x' => 417,
+																		'x' => 444,
 																		'y' => 642,
 																		'h' => 17,
 																		'w' => 95,
 																		'halign' => 'R',
 																		),
 																	array(
-																		'x' => 515,
+																		'x' => 542,
 																		'y' => 642,
 																		'h' => 17,
 																		'w' => 32,
@@ -1123,8 +1086,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'template_page' => 3,
 												'value' => $this->trade_name,
 												'coordinates' => array(
-																		'x' => 219,
-																		'y' => 677,
+																		'x' => 229,
+																		'y' => 676,
 																		'h' => 15,
 																		'w' => 250,
 																		'halign' => 'L',
@@ -1137,8 +1100,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'template_page' => 3,
 												'value' => $this->address,
 												'coordinates' => array(
-																		'x' => 219,
-																		'y' => 701,
+																		'x' => 229,
+																		'y' => 700,
 																		'h' => 15,
 																		'w' => 250,
 																		'halign' => 'L',
@@ -1151,8 +1114,8 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'template_page' => 3,
 												'value' => $this->city . ', ' . $this->state . ', ' . $this->zip_code,
 												'coordinates' => array(
-																		'x' => 219,
-																		'y' => 724,
+																		'x' => 229,
+																		'y' => 723,
 																		'h' => 15,
 																		'w' => 250,
 																		'halign' => 'L',
@@ -1166,29 +1129,29 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 												'function' => array('drawPage3Quarter', 'drawCheckBox'),
 												'coordinates' => array(
 																		1 => array(
-																			'x' => 56,
-																			'y' => 690,
+																			'x' => 51,
+																			'y' => 687,
 																			'h' => 10,
 																			'w' => 11,
 																			'halign' => 'C',
 																			),
 																		2 => array(
-																			'x' => 56,
-																			'y' => 719,
+																			'x' => 51,
+																			'y' => 718,
 																			'h' => 10,
 																			'w' => 11,
 																			'halign' => 'C',
 																			),
 																		3 => array(
-																			'x' => 144,
-																			'y' => 690,
+																			'x' => 138,
+																			'y' => 688,
 																			'h' => 10,
 																			'w' => 11,
 																			'halign' => 'C',
 																			),
 																		4 => array(
-																			'x' => 144,
-																			'y' => 719,
+																			'x' => 138,
+																			'y' => 718,
 																			'h' => 10,
 																			'w' => 11,
 																			'halign' => 'C',
@@ -1270,11 +1233,11 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 
 		return $this->l5d;
 	}
-	function calcL6( $value, $schema ) {
-		$this->l6 = $this->l3 + $this->l5d;
-		return $this->l6;
+	function calcL6E( $value, $schema ) {
+		$this->l6e = $this->l3 + $this->l5d + $this->l5e;
+		return $this->l6e;
 	}
-	function calcL7A( $value, $schema ) {
+	function calcL7( $value, $schema ) {
 		/*
 		$this->l7a = ( $this->MoneyFormat( $this->l5d, FALSE ) - ( $this->l5a2 + $this->l5b2 + $this->l5c2 ) );
 
@@ -1283,16 +1246,13 @@ class GovernmentForms_US_941 extends GovernmentForms_US {
 		return $value;
 	}
 
-	function calcL7D( $value, $schema ) {
-		$this->l7d = $this->l7a + $this->l7b + $this->l7c;
-		return $this->l7d;
-	}
 	function calcL8( $value, $schema ) {
 		$this->l8 = $this->l6 + $this->l7d;
 		return $this->l8;
 	}
+
 	function calcL10( $value, $schema ) {
-		$this->l10 = $this->l8 - $this->l9;
+		$this->l10 = $this->l6e + $this->l7 + $this->l8 + $this->l9;
 		return $this->l10;
 	}
 	function calcL13( $value, $schema ) {
