@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3526 $
- * $Id: AccrualBalanceFactory.class.php 3526 2010-04-26 22:03:24Z ipso $
- * $Date: 2010-04-26 15:03:24 -0700 (Mon, 26 Apr 2010) $
+ * $Revision: 4265 $
+ * $Id: AccrualBalanceFactory.class.php 4265 2011-02-18 00:49:20Z ipso $
+ * $Date: 2011-02-17 16:49:20 -0800 (Thu, 17 Feb 2011) $
  */
 
 /**
@@ -70,6 +70,9 @@ class AccrualBalanceFactory extends Factory {
 										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
 							);
 				break;
+			case 'list_columns':
+				$retval = Misc::arrayIntersectByKey( array('accrual_policy','balance'), Misc::trimSortPrefix( $this->getOptions('columns') ) );
+				break;
 			case 'default_display_columns': //Columns that are displayed by default.
 				$retval = array(
 								'first_name',
@@ -112,7 +115,7 @@ class AccrualBalanceFactory extends Factory {
 	function setUser($id) {
 		$id = trim($id);
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 
 		if ( $this->Validator->isResultSetWithRows(	'user',
 															$ulf->getByID($id),
@@ -140,7 +143,7 @@ class AccrualBalanceFactory extends Factory {
 			$id = NULL;
 		}
 
-		$aplf = new AccrualPolicyListFactory();
+		$aplf = TTnew( 'AccrualPolicyListFactory' );
 
 		if ( $id == NULL
 				OR
@@ -221,11 +224,11 @@ class AccrualBalanceFactory extends Factory {
 
 		$profiler->startTimer( "AccrualBalanceFactory::calcBalance()");
 
-		$alf = new AccrualListFactory();
+		$alf = TTnew( 'AccrualListFactory' );
 		$balance = $alf->getSumByUserIdAndAccrualPolicyId($user_id, $accrual_policy_id);
 		Debug::text('Balance for User ID: '. $user_id .' Accrual Policy ID: '. $accrual_policy_id .' Balance: '. $balance, __FILE__, __LINE__, __METHOD__, 10);
 
-		$ablf = new AccrualBalanceListFactory();
+		$ablf = TTnew( 'AccrualBalanceListFactory' );
 		$ablf->getByUserIdAndAccrualPolicyId( $user_id, $accrual_policy_id);
 		Debug::text('Found balance records to delete: '. $ablf->getRecordCount(), __FILE__, __LINE__, __METHOD__, 10);
 		if ( $ablf->getRecordCount() > 0) {
@@ -235,7 +238,7 @@ class AccrualBalanceFactory extends Factory {
 		}
 
 		Debug::text('Setting new balance to: '. $balance, __FILE__, __LINE__, __METHOD__, 10);
-		$ab = new AccrualBalanceFactory();
+		$ab = TTnew( 'AccrualBalanceFactory' );
 		$ab->setUser( $user_id );
 		$ab->setAccrualPolicyId( $accrual_policy_id );
 		$ab->setBalance( $balance );
@@ -262,10 +265,10 @@ class AccrualBalanceFactory extends Factory {
 		return TRUE;
 	}
 
-	function getObjectAsArray( $include_columns = NULL ) {
+	function getObjectAsArray( $include_columns = NULL, $permission_children_ids = FALSE  ) {
 		$variable_function_map = $this->getVariableToFunctionMap();
 		if ( is_array( $variable_function_map ) ) {
-			$apf = new AccrualPolicyFactory();
+			$apf = TTnew( 'AccrualPolicyFactory' );
 
 			foreach( $variable_function_map as $variable => $function_stub ) {
 				if ( $include_columns == NULL OR ( isset($include_columns[$variable]) AND $include_columns[$variable] == TRUE ) ) {
@@ -294,6 +297,7 @@ class AccrualBalanceFactory extends Factory {
 
 				}
 			}
+			$this->getPermissionColumns( &$data, $this->getUser(), FALSE, $permission_children_ids, $include_columns );
 			//Accrual Balances are only created/modified by the system.
 			//$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
 		}
