@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3508 $
- * $Id: AccrualBalanceListFactory.class.php 3508 2010-04-19 19:46:03Z ipso $
- * $Date: 2010-04-19 12:46:03 -0700 (Mon, 19 Apr 2010) $
+ * $Revision: 4265 $
+ * $Id: AccrualBalanceListFactory.class.php 4265 2011-02-18 00:49:20Z ipso $
+ * $Date: 2011-02-17 16:49:20 -0800 (Thu, 17 Feb 2011) $
  */
 
 /**
@@ -131,6 +131,7 @@ class AccrualBalanceListFactory extends AccrualBalanceFactory implements Iterato
 
 		$uf = new UserFactory();
 		$apf = new AccrualPolicyFactory();
+		$af = new AccrualFactory();
 
 		$ph = array(
 					'company_id' => $company_id,
@@ -145,6 +146,7 @@ class AccrualBalanceListFactory extends AccrualBalanceFactory implements Iterato
 						AND a.accrual_policy_id = c.id
 						AND b.company_id = ?
 						AND a.user_id in ('. $this->getListSQL( $user_id, $ph ) .')
+						AND EXISTS ( select 1 from '. $af->getTable() .' as af WHERE af.accrual_policy_id = a.accrual_policy_id AND a.user_id = af.user_id AND af.deleted = 0 )
 						AND ( a.deleted = 0 AND b.deleted = 0 AND c.deleted = 0 )';
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
@@ -247,7 +249,12 @@ class AccrualBalanceListFactory extends AccrualBalanceFactory implements Iterato
 			}
 		}
 
-		$additional_order_fields = array();
+		$additional_order_fields = array( 'accrual_policy','accrual_policy_type_id' );
+		$sort_column_aliases = array(
+									 'accrual_policy_type' => 'accrual_policy_type_id',
+									 );
+		$order = $this->getColumnsFromAliases( $order, $sort_column_aliases );
+
 		if ( $order == NULL ) {
 			$order = array( 'accrual_policy_id' => 'asc', );
 			$strict = FALSE;
@@ -269,6 +276,7 @@ class AccrualBalanceListFactory extends AccrualBalanceFactory implements Iterato
 		$ugf = new UserGroupFactory();
 		$utf = new UserTitleFactory();
 		$apf = new AccrualPolicyFactory();
+		$af = new AccrualFactory();
 
 		$ph = array(
 					'company_id' => $company_id,
@@ -301,6 +309,7 @@ class AccrualBalanceListFactory extends AccrualBalanceFactory implements Iterato
 						LEFT JOIN '. $utf->getTable() .' as f ON ( b.title_id = f.id AND f.deleted = 0 )
 
 					where	b.company_id = ?
+						AND EXISTS ( select 1 from '. $af->getTable() .' as af WHERE af.accrual_policy_id = a.accrual_policy_id AND a.user_id = af.user_id AND af.deleted = 0 )
 					';
 
 		if ( isset($filter_data['permission_children_ids']) AND isset($filter_data['permission_children_ids'][0]) AND !in_array(-1, (array)$filter_data['permission_children_ids']) ) {
