@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3819 $
- * $Id: AccrualFactory.class.php 3819 2010-08-26 20:28:06Z ipso $
- * $Date: 2010-08-26 13:28:06 -0700 (Thu, 26 Aug 2010) $
+ * $Revision: 4401 $
+ * $Id: AccrualFactory.class.php 4401 2011-03-19 20:29:26Z ipso $
+ * $Date: 2011-03-19 13:29:26 -0700 (Sat, 19 Mar 2011) $
  */
 
 /**
@@ -81,8 +81,8 @@ class AccrualFactory extends Factory {
 
 										'-1030-accrual_policy' => TTi18n::gettext('Accrual Policy'),
 										'-1040-type' => TTi18n::gettext('Type'),
-										'-1050-amount' => TTi18n::gettext('Amount'),
-										'-1060-time_stamp' => TTi18n::gettext('Date'),
+										'-1050-time_stamp' => TTi18n::gettext('Date'),
+										'-1060-amount' => TTi18n::gettext('Amount'),
 
 										'-1090-title' => TTi18n::gettext('Title'),
 										'-1099-group' => TTi18n::gettext('Group'),
@@ -95,6 +95,9 @@ class AccrualFactory extends Factory {
 										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
 							);
 				break;
+			case 'list_columns':
+				$retval = Misc::arrayIntersectByKey( array('accrual_policy', 'type', 'time_stamp', 'amount'), Misc::trimSortPrefix( $this->getOptions('columns') ) );
+				break;
 			case 'default_display_columns': //Columns that are displayed by default.
 				$retval = array(
 								'first_name',
@@ -139,7 +142,7 @@ class AccrualFactory extends Factory {
 		if ( is_object($this->user_obj) ) {
 			return $this->user_obj;
 		} else {
-			$ulf = new UserListFactory();
+			$ulf = TTnew( 'UserListFactory' );
 			$ulf->getById( $this->getUser() );
 			if ( $ulf->getRecordCount() == 1 ) {
 				$this->user_obj = $ulf->getCurrent();
@@ -157,9 +160,9 @@ class AccrualFactory extends Factory {
 	function setUser($id) {
 		$id = trim($id);
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 
-		if ( $this->Validator->isResultSetWithRows(	'user',
+		if ( $this->Validator->isResultSetWithRows(	'user_id',
 															$ulf->getByID($id),
 															TTi18n::gettext('Invalid Employee')
 															) ) {
@@ -185,7 +188,7 @@ class AccrualFactory extends Factory {
 			$id = NULL;
 		}
 
-		$aplf = new AccrualPolicyListFactory();
+		$aplf = TTnew( 'AccrualPolicyListFactory' );
 
 		if ( $id == NULL
 				OR
@@ -246,7 +249,7 @@ class AccrualFactory extends Factory {
 	function setUserDateTotalID($id) {
 		$id = trim($id);
 
-		$udtlf = new UserDateTotalListFactory();
+		$udtlf = TTnew( 'UserDateTotalListFactory' );
 
 		if ( $id == 0
 				OR
@@ -380,7 +383,7 @@ class AccrualFactory extends Factory {
 		//Or orphaned entries on Sum'ing?
 		//Would have to do it on view as well though.
 		if ( $this->getUserDateTotalID() !== FALSE AND $this->getUserDateTotalID() !== 0 ) {
-			$alf = new AccrualListFactory();
+			$alf = TTnew( 'AccrualListFactory' );
 			$alf->getByUserIdAndAccrualPolicyIDAndUserDateTotalID( $this->getUser(), $this->getAccrualPolicyID(), $this->getUserDateTotalID() );
 			Debug::text('Found Duplicate Records: '. (int)$alf->getRecordCount(), __FILE__, __LINE__, __METHOD__, 10);
 			if ( $alf->getRecordCount() > 0 ) {
@@ -406,7 +409,7 @@ class AccrualFactory extends Factory {
 	static function deleteOrphans($user_id) {
 		Debug::text('Attempting to delete Orphaned Records for User ID: '. $user_id, __FILE__, __LINE__, __METHOD__, 10);
 		//Remove orphaned entries
-		$alf = new AccrualListFactory();
+		$alf = TTnew( 'AccrualListFactory' );
 		$alf->getOrphansByUserId( $user_id );
 		Debug::text('Found Orphaned Records: '. $alf->getRecordCount(), __FILE__, __LINE__, __METHOD__, 10);
 		if ( $alf->getRecordCount() > 0 ) {
@@ -458,7 +461,7 @@ class AccrualFactory extends Factory {
 		return FALSE;
 	}
 
-	function getObjectAsArray( $include_columns = NULL ) {
+	function getObjectAsArray( $include_columns = NULL, $permission_children_ids = FALSE  ) {
 		$variable_function_map = $this->getVariableToFunctionMap();
 		if ( is_array( $variable_function_map ) ) {
 			foreach( $variable_function_map as $variable => $function_stub ) {
@@ -495,6 +498,7 @@ class AccrualFactory extends Factory {
 
 				}
 			}
+			$this->getPermissionColumns( &$data, $this->getUser(), $this->getCreatedBy(), $permission_children_ids, $include_columns );
 			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
 		}
 
