@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3508 $
- * $Id: AccrualListFactory.class.php 3508 2010-04-19 19:46:03Z ipso $
- * $Date: 2010-04-19 12:46:03 -0700 (Mon, 19 Apr 2010) $
+ * $Revision: 4265 $
+ * $Id: AccrualListFactory.class.php 4265 2011-02-18 00:49:20Z ipso $
+ * $Date: 2011-02-17 16:49:20 -0800 (Thu, 17 Feb 2011) $
  */
 
 /**
@@ -494,7 +494,12 @@ class AccrualListFactory extends AccrualFactory implements IteratorAggregate {
 			}
 		}
 
-		$additional_order_fields = array();
+		$additional_order_fields = array( 'accrual_policy','accrual_policy_type_id' );
+		$sort_column_aliases = array(
+									 'accrual_policy_type' => 'accrual_policy_type_id',
+									 'type' => 'type_id',
+									 );
+		$order = $this->getColumnsFromAliases( $order, $sort_column_aliases );
 		if ( $order == NULL ) {
 			$order = array( 'accrual_policy_id' => 'asc', );
 			$strict = FALSE;
