@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: BranchFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4845 $
+ * $Id: BranchFactory.class.php 4845 2011-06-21 16:23:18Z ipso $
+ * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
  */
 
 /**
@@ -80,6 +80,9 @@ class BranchFactory extends Factory {
 										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
 							);
 				break;
+			case 'list_columns':
+				$retval = Misc::arrayIntersectByKey( $this->getOptions('default_display_columns'), Misc::trimSortPrefix( $this->getOptions('columns') ) );
+				break;
 			case 'default_display_columns': //Columns that are displayed by default.
 				$retval = array(
 								'manual_id',
@@ -137,7 +140,7 @@ class BranchFactory extends Factory {
 	function setCompany($id) {
 		$id = trim($id);
 
-		$clf = new CompanyListFactory();
+		$clf = TTnew( 'CompanyListFactory' );
 
 		if ( $id == 0
 				OR $this->Validator->isResultSetWithRows(	'company',
@@ -213,7 +216,7 @@ class BranchFactory extends Factory {
 			$company_id = $this->getCompany();
 		}
 
-		$blf = new BranchListFactory();
+		$blf = TTnew( 'BranchListFactory' );
 		$blf->getHighestManualIDByCompanyId( $company_id );
 		if ( $blf->getRecordCount() > 0 ) {
 			$next_available_manual_id = $blf->getCurrent()->getManualId()+1;
@@ -419,7 +422,7 @@ class BranchFactory extends Factory {
 
 		Debug::Text('Country: '. $this->getCountry() .' Province: '. $province, __FILE__, __LINE__, __METHOD__,10);
 
-		$cf = new CompanyFactory();
+		$cf = TTnew( 'CompanyFactory' );
 
 		$options_arr = $cf->getOptions('province');
 		if ( isset($options_arr[$this->getCountry()]) ) {
@@ -454,7 +457,7 @@ class BranchFactory extends Factory {
 	function setCountry($country) {
 		$country = trim($country);
 
-		$cf = new CompanyFactory();
+		$cf = TTnew( 'CompanyFactory' );
 
 		if ( $this->Validator->inArrayKey(		'country',
 												$country,
@@ -573,45 +576,45 @@ class BranchFactory extends Factory {
 		if ( $this->getDeleted() == TRUE ) {
 			Debug::Text('UnAssign Hours from Branch: '. $this->getId(), __FILE__, __LINE__, __METHOD__,10);
 			//Unassign hours from this branch.
-			$pcf = new PunchControlFactory();
-			$udtf = new UserDateTotalFactory();
-			$uf = new UserFactory();
-			$sf = new StationFactory();
-			$sbf = new StationBranchFactory();
-			$sf_b = new ScheduleFactory();
-			$udf = new UserDefaultFactory();
-			$rstf = new RecurringScheduleTemplateFactory();
+			$pcf = TTnew( 'PunchControlFactory' );
+			$udtf = TTnew( 'UserDateTotalFactory' );
+			$uf = TTnew( 'UserFactory' );
+			$sf = TTnew( 'StationFactory' );
+			$sbf = TTnew( 'StationBranchFactory' );
+			$sf_b = TTnew( 'ScheduleFactory' );
+			$udf = TTnew( 'UserDefaultFactory' );
+			$rstf = TTnew( 'RecurringScheduleTemplateFactory' );
 
-			$query = 'update '. $pcf->getTable() .' set branch_id = 0 where branch_id = '. $this->getId();
+			$query = 'update '. $pcf->getTable() .' set branch_id = 0 where branch_id = '. (int)$this->getId();
 			$this->db->Execute($query);
 
-			$query = 'update '. $udtf->getTable() .' set branch_id = 0 where branch_id = '. $this->getId();
+			$query = 'update '. $udtf->getTable() .' set branch_id = 0 where branch_id = '. (int)$this->getId();
 			$this->db->Execute($query);
 
-			$query = 'update '. $sf_b->getTable() .' set branch_id = 0 where branch_id = '. $this->getId();
+			$query = 'update '. $sf_b->getTable() .' set branch_id = 0 where branch_id = '. (int)$this->getId();
 			$this->db->Execute($query);
 
-			$query = 'update '. $uf->getTable() .' set default_branch_id = 0 where company_id = '. $this->getCompany() .' AND default_branch_id = '. $this->getId();
+			$query = 'update '. $uf->getTable() .' set default_branch_id = 0 where company_id = '. (int)$this->getCompany() .' AND default_branch_id = '. (int)$this->getId();
 			$this->db->Execute($query);
 
-			$query = 'update '. $udf->getTable() .' set default_branch_id = 0 where company_id = '. $this->getCompany() .' AND default_branch_id = '. $this->getId();
+			$query = 'update '. $udf->getTable() .' set default_branch_id = 0 where company_id = '. (int)$this->getCompany() .' AND default_branch_id = '. (int)$this->getId();
 			$this->db->Execute($query);
 
-			$query = 'update '. $sf->getTable() .' set branch_id = 0 where company_id = '. $this->getCompany() .' AND branch_id = '. $this->getId();
+			$query = 'update '. $sf->getTable() .' set branch_id = 0 where company_id = '. (int)$this->getCompany() .' AND branch_id = '. (int)$this->getId();
 			$this->db->Execute($query);
 
-			$query = 'delete from '. $sbf->getTable() .' where branch_id = '. $this->getId();
+			$query = 'delete from '. $sbf->getTable() .' where branch_id = '. (int)$this->getId();
 			$this->db->Execute($query);
 
-			$query = 'update '. $rstf->getTable() .' set branch_id = 0 where branch_id = '. $this->getId();
+			$query = 'update '. $rstf->getTable() .' set branch_id = 0 where branch_id = '. (int)$this->getId();
 			$this->db->Execute($query);
 
 			//Job employee criteria
-			$cgmlf = new CompanyGenericMapListFactory();
+			$cgmlf = TTnew( 'CompanyGenericMapListFactory' );
 			$cgmlf->getByCompanyIDAndObjectTypeAndMapID( $this->getCompany(), 1010, $this->getID() );
 			if ( $cgmlf->getRecordCount() > 0 ) {
 				foreach( $cgmlf as $cgm_obj ) {
-					Debug::text('Deleteing from Company Generic Map: '. $cgm_obj->getID(), __FILE__, __LINE__, __METHOD__, 10);
+					Debug::text('Deleting from Company Generic Map: '. $cgm_obj->getID(), __FILE__, __LINE__, __METHOD__, 10);
 					$cgm_obj->Delete();
 				}
 			}
@@ -621,6 +624,10 @@ class BranchFactory extends Factory {
 		return TRUE;
 	}
 
+	function getMapURL() {
+		return Misc::getMapURL( $this->getAddress1(), $this->getAddress2(), $this->getCity(), $this->getProvince(), $this->getPostalCode(), $this->getCountry() );
+	}
+
 	function setObjectFromArray( $data ) {
 		if ( is_array( $data ) ) {
 			$variable_function_map = $this->getVariableToFunctionMap();
@@ -676,7 +683,7 @@ class BranchFactory extends Factory {
 	}
 
 	function addLog( $log_action ) {
-		return TTLog::addEntry( $this->getId(), $log_action, TTi18n::getText('Branch'), NULL, $this->getTable(), $this );
+		return TTLog::addEntry( $this->getId(), $log_action, TTi18n::getText('Branch') .': '. $this->getName() , NULL, $this->getTable(), $this );
 	}
 
 }
