@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3764 $
- * $Id: BranchListFactory.class.php 3764 2010-08-13 18:07:55Z ipso $
- * $Date: 2010-08-13 11:07:55 -0700 (Fri, 13 Aug 2010) $
+ * $Revision: 4265 $
+ * $Id: BranchListFactory.class.php 4265 2011-02-18 00:49:20Z ipso $
+ * $Date: 2011-02-17 16:49:20 -0800 (Thu, 17 Feb 2011) $
  */
 
 /**
@@ -344,7 +344,6 @@ class BranchListFactory extends BranchFactory implements IteratorAggregate {
 									 );
 
 		$order = $this->getColumnsFromAliases( $order, $sort_column_aliases );
-
 		if ( $order == NULL ) {
 			$order = array( 'status_id' => 'asc', 'name' => 'asc');
 			$strict = FALSE;
@@ -379,9 +378,10 @@ class BranchListFactory extends BranchFactory implements IteratorAggregate {
 					from 	'. $this->getTable() .' as a
 						LEFT JOIN '. $uf->getTable() .' as y ON ( a.created_by = y.id AND y.deleted = 0 )
 						LEFT JOIN '. $uf->getTable() .' as z ON ( a.updated_by = z.id AND z.deleted = 0 )
-					where	a.company_id = ?
-					';
-
+					where	a.company_id = ?';
+		if ( isset($filter_data['permission_children_ids']) AND isset($filter_data['permission_children_ids'][0]) AND !in_array(-1, (array)$filter_data['permission_children_ids']) ) {
+			$query  .=	' AND a.created_by in ('. $this->getListSQL($filter_data['permission_children_ids'], $ph) .') ';
+		}
 		if ( isset($filter_data['id']) AND isset($filter_data['id'][0]) AND !in_array(-1, (array)$filter_data['id']) ) {
 			$query  .=	' AND a.id in ('. $this->getListSQL($filter_data['id'], $ph) .') ';
 		}
