@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3725 $
- * $Id: CompanyDeductionListFactory.class.php 3725 2010-07-28 21:16:05Z ipso $
- * $Date: 2010-07-28 14:16:05 -0700 (Wed, 28 Jul 2010) $
+ * $Revision: 4265 $
+ * $Id: CompanyDeductionListFactory.class.php 4265 2011-02-18 00:49:20Z ipso $
+ * $Date: 2011-02-17 16:49:20 -0800 (Thu, 17 Feb 2011) $
  */
 
 /**
@@ -402,8 +402,10 @@ class CompanyDeductionListFactory extends CompanyDeductionFactory implements Ite
 		$additional_order_fields = array('status_id');
 
 		$sort_column_aliases = array(
-									 'status' => 'status_id',
-									 );
+									'status' => 'status_id',
+									'type' => 'type_id',
+									'calculation' => 'calculation_id',
+									);
 
 		$order = $this->getColumnsFromAliases( $order, $sort_column_aliases );
 
@@ -448,6 +450,9 @@ class CompanyDeductionListFactory extends CompanyDeductionFactory implements Ite
 					where	a.company_id = ?
 					';
 
+		if ( isset($filter_data['permission_children_ids']) AND isset($filter_data['permission_children_ids'][0]) AND !in_array(-1, (array)$filter_data['permission_children_ids']) ) {
+			$query  .=	' AND a.created_by in ('. $this->getListSQL($filter_data['permission_children_ids'], $ph) .') ';
+		}
 		if ( isset($filter_data['id']) AND isset($filter_data['id'][0]) AND !in_array(-1, (array)$filter_data['id']) ) {
 			$query  .=	' AND a.id in ('. $this->getListSQL($filter_data['id'], $ph) .') ';
 		}
