@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: CompanyDeductionPayStubEntryAccountFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4104 $
+ * $Id: CompanyDeductionPayStubEntryAccountFactory.class.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 
 /**
@@ -68,7 +68,7 @@ class CompanyDeductionPayStubEntryAccountFactory extends Factory {
 		if ( is_object($this->pay_stub_entry_account_obj) ) {
 			return $this->pay_stub_entry_account_obj;
 		} else {
-			$psealf = new PayStubEntryAccountListFactory();
+			$psealf = TTnew( 'PayStubEntryAccountListFactory' );
 			$psealf->getById( $this->getPayStubEntryAccount() );
 			if ( $psealf->getRecordCount() > 0 ) {
 				$this->pay_stub_entry_account_obj = $psealf->getCurrent();
@@ -90,7 +90,7 @@ class CompanyDeductionPayStubEntryAccountFactory extends Factory {
 		$id = trim($id);
 
 		Debug::Text('ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
-		$cdlf = new CompanyDeductionListFactory();
+		$cdlf = TTnew( 'CompanyDeductionListFactory' );
 
 		if (	$id != 0
 				OR
@@ -147,7 +147,7 @@ class CompanyDeductionPayStubEntryAccountFactory extends Factory {
 		$id = trim($id);
 
 		Debug::Text('ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
-		$psealf = new PayStubEntryAccountListFactory();
+		$psealf = TTnew( 'PayStubEntryAccountListFactory' );
 
 		if (
 				$this->Validator->isResultSetWithRows(	'pay_stub_entry_account',
