@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3939 $
- * $Id: CompanyFactory.class.php 3939 2010-11-19 22:41:24Z ipso $
- * $Date: 2010-11-19 14:41:24 -0800 (Fri, 19 Nov 2010) $
+ * $Revision: 4845 $
+ * $Id: CompanyFactory.class.php 4845 2011-06-21 16:23:18Z ipso $
+ * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
  */
 
 /**
@@ -49,6 +49,9 @@ class CompanyFactory extends Factory {
 	protected $address_validator_regex = '/^[a-zA-Z0-9-,_\/\.\'#\ |\x{0080}-\x{FFFF}]{1,250}$/iu';
 	protected $city_validator_regex = '/^[a-zA-Z0-9-\.\ |\x{0080}-\x{FFFF}]{1,250}$/iu';
 
+	var $user_default_obj = NULL;
+	var $user_obj = NULL;
+
 	function _getFactoryOptions( $name ) {
 
 		$retval = NULL;
@@ -1043,6 +1046,37 @@ class CompanyFactory extends Factory {
 													),
 										);
 				break;
+			case 'industry':
+				//2007 NAICS
+				$retval = array(
+										0  => TTi18n::gettext('- Please Choose -'),
+										72  => TTi18n::gettext('Accommodation and Food Services'),
+										561 => TTi18n::gettext('Administrative and Support Services'),
+										11  => TTi18n::gettext('Agriculture, Forestry, Fishing and Hunting'),
+										71  => TTi18n::gettext('Arts, Entertainment and Recreation'),
+										23  => TTi18n::gettext('Construction'),
+										518 => TTi18n::gettext('Data Processing, Hosting and Related Services'),
+										61  => TTi18n::gettext('Educational Services'),
+										52  => TTi18n::gettext('Finance and Insurance'),
+										91  => TTi18n::gettext('Government/Public Administration'),
+										62  => TTi18n::gettext('Health Care and Social Assistance'),
+										51  => TTi18n::gettext('Information and Cultural Industries'),
+										55  => TTi18n::gettext('Management of Companies and Enterprises'),
+										31  => TTi18n::gettext('Manufacturing'),
+										21  => TTi18n::gettext('Mining and Oil and Gas Extraction'),
+										512 => TTi18n::gettext('Motion Picture and Sound Recording Industries'),
+										54  => TTi18n::gettext('Professional, Scientific and Technical Services'),
+										511 => TTi18n::gettext('Publishing Industries (except Internet'),
+										53  => TTi18n::gettext('Real Estate and Rental and Leasing'),
+										44  => TTi18n::gettext('Retail Trade'),
+										517 => TTi18n::gettext('Telecommunications'),
+										48  => TTi18n::gettext('Transportation and Warehousing'),
+										22  => TTi18n::gettext('Utilities'),
+										562 => TTi18n::gettext('Waste Management and Remediation Services'),
+										41  => TTi18n::gettext('Wholesale Trade'),
+										99  => TTi18n::gettext('Other'),
+									);
+				break;
 			case 'ldap_authentication_type':
 				$retval = array(
 										0 => TTi18n::gettext('Disabled'),
@@ -1073,6 +1107,9 @@ class CompanyFactory extends Factory {
 										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
 							);
 				break;
+			case 'list_columns':
+				$retval = Misc::arrayIntersectByKey( $this->getOptions('default_display_columns'), Misc::trimSortPrefix( $this->getOptions('columns') ) );
+				break;
 			case 'default_display_columns': //Columns that are displayed by default.
 				$retval = array(
 								'status',
@@ -1105,6 +1142,8 @@ class CompanyFactory extends Factory {
 											'status' => FALSE,
 											'product_edition_id' => 'ProductEdition',
 											'product_edition' => FALSE,
+											'industry_id' => 'Industry',
+											'industry' => FALSE,
 											'name' => 'Name',
 											'business_number' => 'BusinessNumber',
 											'originator_id' => 'OriginatorID',
@@ -1136,13 +1175,48 @@ class CompanyFactory extends Factory {
 			return $variable_function_map;
 	}
 
+	function getUserDefaultObject() {
+		if ( is_object($this->user_default_obj) ) {
+			return $this->user_default_obj;
+		} else {
+			$udlf = TTnew( 'UserDefaultListFactory' );
+			$udlf->getById( $this->getID() );
+			if ( $udlf->getRecordCount() == 1 ) {
+				$this->user_default_obj = $udlf->getCurrent();
+				return $this->user_default_obj;
+			}
+
+			return FALSE;
+		}
+	}
+
+	function getUserObject( $user_id ) {
+		if ( $user_id == '' AND $user_id <= 0 ) {
+			return FALSE;
+		}
+
+		if ( isset($this->user_obj[$user_id]) AND is_object($this->user_obj[$user_id]) ) {
+			return $this->user_obj[$user_id];
+		} else {
+			$ulf = TTnew( 'UserListFactory' );
+			$ulf->getById( $user_id );
+			if ( $ulf->getRecordCount() == 1 ) {
+				$this->user_obj[$user_id] = $ulf->getCurrent();
+
+				return $this->user_obj[$user_id];
+			}
+		}
+
+		return FALSE;
+	}
+
 	function getParent() {
 		return $this->data['parent_id'];
 	}
 	function setParent($id) {
 		$id = trim($id);
 
-		$clf = new CompanyListFactory();
+		$clf = TTnew( 'CompanyListFactory' );
 
 		if ( $id == 0
 				OR $this->Validator->isResultSetWithRows(	'parent',
@@ -1238,6 +1312,30 @@ class CompanyFactory extends Factory {
 		return FALSE;
 	}
 
+	function getIndustry() {
+		if ( isset($this->data['industry_id']) ) {
+			return $this->data['industry_id'];
+		}
+
+		return FALSE;
+	}
+	function setIndustry($value) {
+		$value = trim($value);
+
+		if ( $value == 0
+				OR $this->Validator->inArrayKey(	'industry_id',
+													$value,
+													TTi18n::gettext('Incorrect Industry'),
+													$this->getOptions('industry')) ) {
+
+			$this->data['industry_id'] = $value;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
 	function getBusinessNumber() {
 		if ( isset($this->data['business_number']) ) {
 			return $this->data['business_number'];
@@ -1578,7 +1676,7 @@ class CompanyFactory extends Factory {
 	function setAdminContact($id) {
 		$id = trim($id);
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 
 		if ( !empty($id)
 				AND 	$this->Validator->isResultSetWithRows(	'admin_contact',
@@ -1605,7 +1703,7 @@ class CompanyFactory extends Factory {
 	function setBillingContact($id) {
 		$id = trim($id);
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 
 		if ( !empty($id)
 				AND $this->Validator->isResultSetWithRows(	'billing_contact',
@@ -1631,7 +1729,7 @@ class CompanyFactory extends Factory {
 	function setSupportContact($id) {
 		$id = trim($id);
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 
 		if ( !empty($id)
 				AND $this->Validator->isResultSetWithRows(	'support_contact',
@@ -1648,7 +1746,7 @@ class CompanyFactory extends Factory {
 	}
 
 	function getDefaultCurrency() {
-		$culf = new CurrencyListFactory();
+		$culf = TTnew( 'CurrencyListFactory' );
 		$culf->getByCompanyIdAndDefault( $this->getId(), TRUE );
 		if ($culf->getRecordCount() == 1 ) {
 			return $culf->getCurrent()->getId();
@@ -1776,13 +1874,18 @@ class CompanyFactory extends Factory {
 			$logo_file_name = $base_name.'.png';
 		} else {
 			if ( $include_default_logo == TRUE ) {
-				$logo_file_name = Environment::getImagesPath().'timetrex_logo_wbg_small2.jpg';
+				//Check for primary company logo first, so branding gets carried over automatically.
+				if ( $company_id != PRIMARY_COMPANY_ID ) {
+					$logo_file_name = $this->getLogoFileName( PRIMARY_COMPANY_ID );
+				} else {
+					$logo_file_name = Environment::getImagesPath().'timetrex_logo_wbg_small2.jpg';
+				}
 			} else {
 				return FALSE;
 			}
 		}
 
-		Debug::Text('Logo File Name: '. $logo_file_name, __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Text('Logo File Name: '. $logo_file_name, __FILE__, __LINE__, __METHOD__,10);
 		return $logo_file_name;
 	}
 
@@ -2075,6 +2178,10 @@ class CompanyFactory extends Factory {
 			$this->is_new = TRUE;
 		}
 
+		if ( $this->getIndustry() == FALSE ) {
+			$this->setIndustry(0);
+		}
+
 		return TRUE;
 	}
 	function postSave() {
@@ -2085,12 +2192,12 @@ class CompanyFactory extends Factory {
 		if ( $this->getDeleted() == FALSE ) {
 			//Add base currency for this new company.
 			if ( $this->getEnableAddCurrency() == TRUE ) {
-				$clf = new CurrencyListFactory();
+				$clf = TTnew( 'CurrencyListFactory' );
 				$clf->getByCompanyId( $this->getId() );
 				if ( $clf->getRecordCount() == 0 ) {
 					Debug::text('Adding Default Currency', __FILE__, __LINE__, __METHOD__,9);
 
-					$cf = new CurrencyFactory();
+					$cf = TTnew( 'CurrencyFactory' );
 					$country_to_currency_map_arr = $cf->getOptions('country_currency');
 
 					if ( isset($country_to_currency_map_arr[$this->getCountry()]) ) {
@@ -2120,7 +2227,7 @@ class CompanyFactory extends Factory {
 			if ( $this->getEnableAddPermissionGroupPreset() == TRUE ) {
 				Debug::text('Adding Preset Permission Groups', __FILE__, __LINE__, __METHOD__,9);
 
-				$pf = new PermissionFactory();
+				$pf = TTnew( 'PermissionFactory' );
 				$pf->StartTransaction();
 
 				if ( $this->getProductEdition() == 20 ) {
@@ -2137,7 +2244,7 @@ class CompanyFactory extends Factory {
 				$preset_level_options = $pf->getOptions('preset_level');
 				$i=0;
 				foreach( $preset_options as $preset_id => $preset_name ) {
-					$pcf = new PermissionControlFactory();
+					$pcf = TTnew( 'PermissionControlFactory' );
 					$pcf->setCompany( $this->getId() );
 					$pcf->setName( $preset_name );
 					$pcf->setDescription( '' );
@@ -2161,7 +2268,7 @@ class CompanyFactory extends Factory {
 				Debug::text('Adding Default Station', __FILE__, __LINE__, __METHOD__,9);
 
 				//Enable punching in from all stations
-				$sf = new StationFactory();
+				$sf = TTnew( 'StationFactory' );
 				$sf->setCompany( $this->getId() );
 
 				$sf->setStatus( 20 );
@@ -2196,7 +2303,7 @@ class CompanyFactory extends Factory {
 
 			if ( $this->getEnableAddUserDefaultPreset() == TRUE ) {
 				//User Default settings, always do this last.
-				$udf = new UserDefaultFactory();
+				$udf = TTnew( 'UserDefaultFactory' );
 				$udf->setCompany( $this->getID() );
 				$udf->setCity( $this->getCity() );
 				$udf->setCountry( $this->getCountry() );
@@ -2220,13 +2327,8 @@ class CompanyFactory extends Factory {
 					$udf->setCurrency( $currency_id );
 				}
 
-				$uf = new UserPreferenceFactory();
-				$location_time_zones = $uf->getOptions('location_timezone');
-				if ( isset($location_time_zones[$this->getCountry()][$this->getProvince()]) ) {
-					$udf->setTimeZone( $location_time_zones[$this->getCountry()][$this->getProvince()] );
-				} else {
-					$udf->setTimeZone( 'GMT' );
-				}
+				$upf = TTnew( 'UserPreferenceFactory' );
+				$udf->setTimeZone( $upf->getLocationTimeZone( $this->getCountry(), $this->getProvince(), $this->getWorkPhone() ) );
 				Debug::text('Time Zone: '. $udf->getTimeZone(), __FILE__, __LINE__, __METHOD__,9);
 
 				$udf->setEnableEmailNotificationException( TRUE );
@@ -2242,7 +2344,7 @@ class CompanyFactory extends Factory {
 		}
 
 		if ( $this->getDeleted() == TRUE ) {
-			$ulf = new UserListFactory();
+			$ulf = TTnew( 'UserListFactory' );
 			$ulf->getByCompanyId( $this->getID() );
 			if ( $ulf->getRecordCount() > 0 ) {
 				$ulf->StartTransaction();
@@ -2303,6 +2405,9 @@ class CompanyFactory extends Factory {
 						case 'product_edition':
 							$data[$variable] = Option::getByKey( $this->getProductEdition(), $this->getOptions( $variable ) );
 							break;
+						case 'industry':
+							$data[$variable] = Option::getByKey( $this->getIndustry(), $this->getOptions( $variable ) );
+							break;
 						default:
 							if ( method_exists( $this, $function ) ) {
 								$data[$variable] = $this->$function();
