@@ -87,10 +87,15 @@ class CompanyGenericMapFactory extends Factory {
 										1030 => 'job_user_group',
 										1040 => 'job_include_user',
 										1050 => 'job_exclude_user',
+
 										//Job task mapping
 										1060 => 'job_job_item_group',
 										1070 => 'job_include_job_item',
 										1080 => 'job_exclude_job_item',
+
+										//Invoice Payment Gateway mapping
+										3010 => 'payment_gateway_credit_card_type',
+										3020 => 'payment_gateway_bank_account_type',
 									);
 				break;
 		}
@@ -108,7 +113,7 @@ class CompanyGenericMapFactory extends Factory {
 	function setCompany($id) {
 		$id = trim($id);
 
-		$clf = new CompanyListFactory();
+		$clf = TTnew( 'CompanyListFactory' );
 
 		if ( $id == 0
 				OR $this->Validator->isResultSetWithRows(	'company',
@@ -156,7 +161,7 @@ class CompanyGenericMapFactory extends Factory {
 	function setObjectID($id) {
 		$id = trim($id);
 
-		$pglf = new PolicyGroupListFactory();
+		$pglf = TTnew( 'PolicyGroupListFactory' );
 
 		if ( $this->Validator->isNumeric(	'object_id',
 										$id,
@@ -180,7 +185,7 @@ class CompanyGenericMapFactory extends Factory {
 	function setMapID($id) {
 		$id = trim($id);
 
-		$pglf = new PolicyGroupListFactory();
+		$pglf = TTnew( 'PolicyGroupListFactory' );
 
 		if ( $this->Validator->isNumeric(	'map_id',
 										$id,
@@ -222,7 +227,7 @@ class CompanyGenericMapFactory extends Factory {
 		if ( is_array($ids) ) {
 			if ( $is_new == FALSE ) {
 				//If needed, delete mappings first.
-				$cgmlf = new CompanyGenericMapListFactory();
+				$cgmlf = TTnew( 'CompanyGenericMapListFactory' );
 				$cgmlf->getByCompanyIDAndObjectTypeAndObjectID( $company_id, $object_type_id, $object_id );
 
 				$tmp_ids = array();
@@ -245,7 +250,7 @@ class CompanyGenericMapFactory extends Factory {
 
 			foreach ($ids as $id) {
 				if ( isset($ids) AND $id > 0 AND !in_array($id, $tmp_ids) ) {
-					$cgmf = new CompanyGenericMapFactory();
+					$cgmf = TTnew( 'CompanyGenericMapFactory' );
 					$cgmf->setCompany( $company_id );
 					$cgmf->setObjectType( $object_type_id );
 					$cgmf->setObjectID( $object_id );
@@ -324,51 +329,67 @@ class CompanyGenericMapFactory extends Factory {
 				case 190:
 					switch( $this->getObjectType() )  {
 						case 110:
-							$lf = new OverTimePolicyListFactory();
+							$lf = TTnew( 'OverTimePolicyListFactory' );
 							$lf->getById( $this->getMapId() );
 							if ( $lf->getRecordCount() > 0 ) {
 								$description = TTi18n::getText('Overtime Policy').': '. $lf->getCurrent()->getName();
 							}
 							break;
 						case 120:
-							$lf = new PremiumPolicyListFactory();
+							$lf = TTnew( 'PremiumPolicyListFactory' );
 							$lf->getById( $this->getMapId() );
 							if ( $lf->getRecordCount() > 0 ) {
 								$description = TTi18n::getText('Premium Policy').': '. $lf->getCurrent()->getName();
 							}
 							break;
 						case 130:
-							$lf = new RoundIntervalPolicyListFactory();
+							$lf = TTnew( 'RoundIntervalPolicyListFactory' );
 							$lf->getById( $this->getMapId() );
 							if ( $lf->getRecordCount() > 0 ) {
 								$description = TTi18n::getText('Rounding Policy').': '. $lf->getCurrent()->getName();
 							}
 							break;
 						case 140:
-							$lf = new AccrualPolicyListFactory();
+							$lf = TTnew( 'AccrualPolicyListFactory' );
 							$lf->getById( $this->getMapId() );
 							if ( $lf->getRecordCount() > 0 ) {
 								$description = TTi18n::getText('Accrual Policy').': '. $lf->getCurrent()->getName();
 							}
 							break;
 						case 150:
-							$lf = new MealPolicyListFactory();
+							$lf = TTnew( 'MealPolicyListFactory' );
 							$lf->getById( $this->getMapId() );
 							if ( $lf->getRecordCount() > 0 ) {
 								$description = TTi18n::getText('Meal Policy').': '. $lf->getCurrent()->getName();
 							}
 							break;
 						case 160:
+							$lf = TTnew( 'BreakPolicyListFactory' );
+							$lf->getById( $this->getMapId() );
+							if ( $lf->getRecordCount() > 0 ) {
+								$description = TTi18n::getText('Break Policy').': '. $lf->getCurrent()->getName();
+							}
+							break;
 						case 170:
+							$lf = TTnew( 'AbsencePolicyListFactory' );
+							$lf->getById( $this->getMapId() );
+							if ( $lf->getRecordCount() > 0 ) {
+								$description = TTi18n::getText('Absence Policy').': '. $lf->getCurrent()->getName();
+							}
 							break;
 						case 180:
-							$lf = new HolidayPolicyListFactory();
+							$lf = TTnew( 'HolidayPolicyListFactory' );
 							$lf->getById( $this->getMapId() );
 							if ( $lf->getRecordCount() > 0 ) {
 								$description = TTi18n::getText('Holiday Policy').': '. $lf->getCurrent()->getName();
 							}
 							break;
-						case 190:
+						case 190: //Not handled with generic mapping currently.
+							$lf = TTnew( 'ExceptionPolicyListFactory' );
+							$lf->getById( $this->getMapId() );
+							if ( $lf->getRecordCount() > 0 ) {
+								$description = TTi18n::getText('Exception Policy').': '. $lf->getCurrent()->getName();
+							}
 							break;
 					}
 
@@ -376,7 +397,7 @@ class CompanyGenericMapFactory extends Factory {
 					$retval = TTLog::addEntry( $this->getObjectId(), $log_action, $description, NULL, 'policy_group' );
 					break;
 				case 165:
-					$lf = new BreakPolicyListFactory();
+					$lf = TTnew( 'BreakPolicyListFactory' );
 					$lf->getById( $this->getMapId() );
 					if ( $lf->getRecordCount() > 0 ) {
 						$description = TTi18n::getText('Break Policy').': '. $lf->getCurrent()->getName();
@@ -387,7 +408,7 @@ class CompanyGenericMapFactory extends Factory {
 					break;
 				//Job user mapping
 				case 1010: //'job_user_branch',
-					$lf = new BranchListFactory();
+					$lf = TTnew( 'BranchListFactory' );
 					$lf->getById( $this->getMapId() );
 					if ( $lf->getRecordCount() > 0 ) {
 						$description = TTi18n::getText('Branch').': '. $lf->getCurrent()->getName();
@@ -397,7 +418,7 @@ class CompanyGenericMapFactory extends Factory {
 					$retval = TTLog::addEntry( $this->getObjectId(), $log_action, $description, NULL, 'job_user_branch' );
 					break;
 				case 1020: // => 'job_user_department',
-					$lf = new DepartmentListFactory();
+					$lf = TTnew( 'DepartmentListFactory' );
 					$lf->getById( $this->getMapId() );
 					if ( $lf->getRecordCount() > 0 ) {
 						$description = TTi18n::getText('Department').': '. $lf->getCurrent()->getName();
@@ -407,7 +428,7 @@ class CompanyGenericMapFactory extends Factory {
 					$retval = TTLog::addEntry( $this->getObjectId(), $log_action, $description, NULL, 'job_user_department' );
 					break;
 				case 1030: // => 'job_user_group',
-					$lf = new UserGroupListFactory();
+					$lf = TTnew( 'UserGroupListFactory' );
 					$lf->getById( $this->getMapId() );
 					if ( $lf->getRecordCount() > 0 ) {
 						$description = TTi18n::getText('Employee Group').': '. $lf->getCurrent()->getName();
@@ -429,7 +450,7 @@ class CompanyGenericMapFactory extends Factory {
 							break;
 					}
 
-					$lf = new UserListFactory();
+					$lf = TTnew( 'UserListFactory' );
 					$lf->getById( $this->getMapId() );
 					if ( $lf->getRecordCount() > 0 ) {
 						$description = $type.' '. TTi18n::getText('Employee').': '. $lf->getCurrent()->getFullName();
@@ -440,7 +461,7 @@ class CompanyGenericMapFactory extends Factory {
 					break;
 				//Job task mapping
 				case 1060: // => 'job_job_item_group',
-					$lf = new JobItemGroupListFactory();
+					$lf = TTnew( 'JobItemGroupListFactory' );
 					$lf->getById( $this->getMapId() );
 					if ( $lf->getRecordCount() > 0 ) {
 						$description = TTi18n::getText('Task Group').': '. $lf->getCurrent()->getName();
@@ -462,7 +483,7 @@ class CompanyGenericMapFactory extends Factory {
 							break;
 					}
 
-					$lf = new JobItemListFactory();
+					$lf = TTnew( 'JobItemListFactory' );
 					$lf->getById( $this->getMapId() );
 					if ( $lf->getRecordCount() > 0 ) {
 						$description = $type.' '. TTi18n::getText('Task').': '. $lf->getCurrent()->getName();
@@ -471,6 +492,27 @@ class CompanyGenericMapFactory extends Factory {
 					Debug::text('Action: '. $log_action .' MapID: '. $this->getMapID() .' ObjectID: '. $this->getObjectID() .' Description: '. $description .' Record Count: '. $lf->getRecordCount(), __FILE__, __LINE__, __METHOD__, 10);
 					$retval = TTLog::addEntry( $this->getObjectId(), $log_action, $description, NULL, $table_name );
 					break;
+				case 3010: // => 'payment_gateway_credit_card_type',
+					$table_name = 'payment_gateway_credit_card_type';
+
+					$cpf = TTnew( 'ClientPaymentFactory' );
+					$description = TTi18n::getText('Credit Card Type').': '. Option::getByKey( $this->getMapId(), $cpf->getOptions('credit_card_type') );
+
+					Debug::text('Action: '. $log_action .' MapID: '. $this->getMapID() .' ObjectID: '. $this->getObjectID() .' Description: '. $description, __FILE__, __LINE__, __METHOD__, 10);
+					$retval = TTLog::addEntry( $this->getObjectId(), $log_action, $description, NULL, $table_name );
+
+					break;
+				case 3020: // => 'payment_gateway_bank_account_type',
+					$table_name = 'payment_gateway_bank_account_type';
+
+					$cpf = TTnew( 'ClientPaymentFactory' );
+					$description = TTi18n::getText('Bank Account Type').': '. Option::getByKey( $this->getMapId(), $cpf->getOptions('bank_account_type') );
+
+					Debug::text('Action: '. $log_action .' MapID: '. $this->getMapID() .' ObjectID: '. $this->getObjectID() .' Description: '. $description, __FILE__, __LINE__, __METHOD__, 10);
+					$retval = TTLog::addEntry( $this->getObjectId(), $log_action, $description, NULL, $table_name );
+
+					break;
+					break;
 			}
 		}
 
