@@ -65,6 +65,9 @@ class WageGroupFactory extends Factory {
 								'name',
 								);
 				break;
+			case 'list_columns':
+				$retval = Misc::arrayIntersectByKey( $this->getOptions('default_display_columns'), Misc::trimSortPrefix( $this->getOptions('columns') ) );
+				break;
 			case 'default_display_columns': //Columns that are displayed by default.
 				$retval = array(
 								'name',
@@ -91,7 +94,7 @@ class WageGroupFactory extends Factory {
 	function setCompany($id) {
 		$id = trim($id);
 
-		$clf = new CompanyListFactory();
+		$clf = TTnew( 'CompanyListFactory' );
 
 		if ( $id == 0
 				OR $this->Validator->isResultSetWithRows(	'company',
@@ -156,22 +159,26 @@ class WageGroupFactory extends Factory {
 		return FALSE;
 	}
 
-	function postSave() {
-		//Don't delete wage groups that are in use by users, or policies.
-		/*
+	function Validate() {
+		Debug::Text('Validate...', __FILE__, __LINE__, __METHOD__,10);
+
 		if ( $this->getDeleted() == TRUE ) {
-			Debug::Text('UnAssign title from employees: '. $this->getId(), __FILE__, __LINE__, __METHOD__,10);
-			//Unassign hours from this job.
-			$uf = new UserFactory();
-			$udf = new UserDefaultFactory();
+			//Check to make sure there are no hours using this OT policy.
+			$uwlf = TTnew( 'UserWageListFactory' );
+			$uwlf->getByWageGroupIDAndCompanyId( $this->getID(), $this->getCompany() );
+			if ( $uwlf->getRecordCount() > 0 ) {
+				$this->Validator->isTRUE(	'in_use',
+											FALSE,
+											TTi18n::gettext('This wage group is in use'));
 
-			$query = 'update '. $uf->getTable() .' set title_id = 0 where company_id = '. $this->getCompany() .' AND title_id = '. $this->getId();
-			$this->db->Execute($query);
-
-			$query = 'update '. $udf->getTable() .' set title_id = 0 where company_id = '. $this->getCompany() .' AND title_id = '. $this->getId();
-			$this->db->Execute($query);
+			}
 		}
-		*/
+
+		return TRUE;
+	}
+
+	function postSave() {
+		return TRUE;
 	}
 
 	function setObjectFromArray( $data ) {
