@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3123 $
- * $Id: AJAX_Server.class.php 3123 2009-11-26 00:47:08Z ipso $
- * $Date: 2009-11-25 16:47:08 -0800 (Wed, 25 Nov 2009) $
+ * $Revision: 4104 $
+ * $Id: AJAX_Server.class.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 
 /**
@@ -69,7 +69,7 @@ class AJAX_Server {
 
 		Debug::Arr($country, 'bCountry: ', __FILE__, __LINE__, __METHOD__, 10);
 
-		$cf = new CompanyFactory();
+		$cf = TTnew( 'CompanyFactory' );
 
 		$province_arr = $cf->getOptions('province');
 
@@ -101,7 +101,7 @@ class AJAX_Server {
 		}
 		Debug::text('Country: '. $country .' Province: '. $province, __FILE__, __LINE__, __METHOD__, 10);
 
-		$cf = new CompanyFactory();
+		$cf = TTnew( 'CompanyFactory' );
 
 		$district_arr = $cf->getOptions('district');
 
@@ -138,7 +138,7 @@ class AJAX_Server {
 
 		Debug::text('Country: '. $country .' Province: '. $province, __FILE__, __LINE__, __METHOD__, 10);
 
-		$idlf = new InvoiceDistrictListFactory();
+		$idlf = TTnew( 'InvoiceDistrictListFactory' );
 		$idlf->getByCompanyIdAndProvinceAndCountry( $current_company->getId(), $province, $country);
 
 		$district_arr = $idlf->getArrayByListFactory($idlf, FALSE);
@@ -164,7 +164,7 @@ class AJAX_Server {
 			return '0.00';
 		}
 
-		$uwf = new UserWageFactory();
+		$uwf = TTnew( 'UserWageFactory' );
 		$uwf->setType( $wage_type_id );
 		$uwf->setWage( $wage );
 		$uwf->setWeeklyTime( TTDate::parseTimeUnit($weekly_hours) );
@@ -185,7 +185,7 @@ class AJAX_Server {
 
 		$epoch = TTDate::parseDateTime($date);
 
-		$uwlf = new UserWageListFactory();
+		$uwlf = TTnew( 'UserWageListFactory' );
 		$uwlf->getByUserIdAndDate( $user_id, $epoch);
 		if ( $uwlf->getRecordCount() > 0 ) {
 			$hourly_rate = $uwlf->getCurrent()->getHourlyRate();
@@ -225,7 +225,7 @@ class AJAX_Server {
 
 		Debug::text('User ID: '. $user_id .' Company ID: '. $current_company->getId(), __FILE__, __LINE__, __METHOD__, 10);
 
-		$jlf = new JobListFactory();
+		$jlf = TTnew( 'JobListFactory' );
 		return $jlf->getByCompanyIdAndUserIdAndStatusArray( $current_company->getId(),  $user_id, array(10,20,30,40), TRUE );
 	}
 
@@ -241,7 +241,7 @@ class AJAX_Server {
 
 		Debug::text('Job ID: '. $job_id .' Include Disabled: '. (int)$include_disabled, __FILE__, __LINE__, __METHOD__, 10);
 
-		$jilf = new JobItemListFactory();
+		$jilf = TTnew( 'JobItemListFactory' );
 		//$jilf->getByCompanyIdAndJobId( $current_company->getId(), $job_id );
 		$jilf->getByJobId( $job_id );
 		$job_item_options = $jilf->getArrayByListFactory( $jilf, TRUE, $include_disabled );
@@ -273,7 +273,7 @@ class AJAX_Server {
 			return FALSE;
 		}
 
-		$jilf = new JobItemListFactory();
+		$jilf = TTnew( 'JobItemListFactory' );
 		$jilf->getByIdAndCompanyId( $job_item_id, $current_company->getId() );
 		if ( $jilf->getRecordCount() > 0 ) {
 			foreach( $jilf as $item_obj ) {
@@ -322,7 +322,7 @@ class AJAX_Server {
 			return FALSE;
 		}
 
-		$plf = new ProductListFactory();
+		$plf = TTnew( 'ProductListFactory' );
 		$plf->getByIdAndCompanyId($product_id, $current_company->getId() );
 		if ( $plf->getRecordCount() > 0 ) {
 			$p_obj = $plf->getCurrent();
@@ -355,7 +355,7 @@ class AJAX_Server {
 			return FALSE;
 		}
 
-		$plf = new ProductListFactory();
+		$plf = TTnew( 'ProductListFactory' );
 
 		if ( $product_id != '' ) {
 			$plf->getByIdAndCompanyId($product_id, $current_company->getId() );
@@ -439,7 +439,7 @@ class AJAX_Server {
 		//Debug::Arr($data, 'Input Transaction Data...', __FILE__, __LINE__, __METHOD__, 10);
 		//Debug::Arr($invoice_data, 'Input Invoice Data...', __FILE__, __LINE__, __METHOD__, 10);
 
-		$ilf = new InvoiceListFactory();
+		$ilf = TTnew( 'InvoiceListFactory' );
 
 		$transaction_arr = FALSE;
 		if ( is_array($data) ) {
@@ -491,7 +491,7 @@ class AJAX_Server {
 	}
 
 	function getShippingOptions( $data, $invoice_data ) {
-		$if = new InvoiceFactory();
+		$if = TTnew( 'InvoiceFactory' );
 
 		$transaction_arr = FALSE;
 		if ( is_array($data) ) {
@@ -514,7 +514,7 @@ class AJAX_Server {
 	function getCurrencyData( $currency_id ) {
 		Debug::Text('Getting Currency Data for ID: '. $currency_id, __FILE__, __LINE__, __METHOD__, 10);
 
-		$clf = new CurrencyListFactory();
+		$clf = TTnew( 'CurrencyListFactory' );
 		$clf->getById( $currency_id );
 		if ( $clf->getRecordCount() > 0 ) {
 			$c_obj = $clf->getCurrent();
@@ -536,7 +536,7 @@ class AJAX_Server {
 	}
 
 	function getScheduleTotalTime( $start, $end, $schedule_policy_id ) {
-		$sf = new ScheduleFactory();
+		$sf = TTnew( 'ScheduleFactory' );
 		$sf->setStartTime( TTDate::parseDateTime($start) );
 		$sf->setEndTime( TTDate::parseDateTime($end) );
 		$sf->setSchedulePolicyId( $schedule_policy_id );
@@ -552,14 +552,14 @@ class AJAX_Server {
 			return FALSE;
 		}
 
-		$aplf = new AbsencePolicyListFactory();
+		$aplf = TTnew( 'AbsencePolicyListFactory' );
 		$aplf->getByIdAndCompanyId( $absence_policy_id, $current_company->getId() );
 		if ( $aplf->getRecordCount() > 0 ) {
 			$ap_obj = $aplf->getCurrent();
 
 			$ap_data = $ap_obj->getObjectAsArray();
 
-			$aplf = new AccrualPolicyListFactory();
+			$aplf = TTnew( 'AccrualPolicyListFactory' );
 			$aplf->getByIdAndCompanyId( $ap_obj->getAccrualPolicyID(), $current_company->getId() );
 			if ( $aplf->getRecordCount() > 0 ) {
 				$ap_data['accrual_policy_name'] = $aplf->getCurrent()->getName();
@@ -580,7 +580,7 @@ class AJAX_Server {
 			return FALSE;
 		}
 
-		$aplf = new AbsencePolicyListFactory();
+		$aplf = TTnew( 'AbsencePolicyListFactory' );
 		$aplf->getByIdAndCompanyId( $absence_policy_id, $current_company->getId() );
 		if ( $aplf->getRecordCount() > 0 ) {
 			$ap_obj = $aplf->getCurrent();
@@ -600,7 +600,7 @@ class AJAX_Server {
 			return FALSE;
 		}
 
-		$ablf = new AccrualBalanceListFactory();
+		$ablf = TTnew( 'AccrualBalanceListFactory' );
 		$ablf->getByUserIdAndAccrualPolicyId($user_id, $accrual_policy_id );
 		if ( $ablf->getRecordCount() > 0 ) {
 			$accrual_balance = $ablf->getCurrent()->getBalance();
@@ -624,7 +624,7 @@ class AJAX_Server {
 			return FALSE;
 		}
 
-		$psealf = new PayStubEntryAccountListFactory();
+		$psealf = TTnew( 'PayStubEntryAccountListFactory' );
 		$psealf->getHighestOrderByCompanyIdAndTypeId( $current_company->getId(), $type_id );
 		if ( $psealf->getRecordCount() > 0 ) {
 			foreach( $psealf as $psea_obj ) {
