@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2937 $
- * $Id: CalculatePayStub.class.php 2937 2009-10-27 22:07:04Z ipso $
- * $Date: 2009-10-27 15:07:04 -0700 (Tue, 27 Oct 2009) $
+ * $Revision: 4104 $
+ * $Id: CalculatePayStub.class.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 
 /**
@@ -61,7 +61,7 @@ class CalculatePayStub extends PayStubFactory {
 	function setUser($id) {
 		$id = trim($id);
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 
 		if ( $id == 0
 				OR $this->Validator->isResultSetWithRows(	'user',
@@ -86,7 +86,7 @@ class CalculatePayStub extends PayStubFactory {
 	function setPayPeriod($id) {
 		$id = trim($id);
 
-		$pplf = new PayPeriodListFactory();
+		$pplf = TTnew( 'PayPeriodListFactory' );
 
 		if (  $this->Validator->isResultSetWithRows(	'pay_period',
 														$pplf->getByID($id),
@@ -117,7 +117,7 @@ class CalculatePayStub extends PayStubFactory {
 		if ( is_object($this->user_obj) ) {
 			return $this->user_obj;
 		} else {
-			$ulf = new UserListFactory();
+			$ulf = TTnew( 'UserListFactory' );
 			//$this->user_obj = $ulf->getById( $this->getUser() )->getCurrent();
 			$ulf->getById( $this->getUser() );
 			if ( $ulf->getRecordCount() > 0 ) {
@@ -134,7 +134,7 @@ class CalculatePayStub extends PayStubFactory {
 		if ( is_object($this->pay_stub_entry_account_link_obj) ) {
 			return $this->pay_stub_entry_account_link_obj;
 		} else {
-			$pseallf = new PayStubEntryAccountLinkListFactory();
+			$pseallf = TTnew( 'PayStubEntryAccountLinkListFactory' );
 			$pseallf->getByCompanyId( $this->getUserObject()->getCompany() );
 			if ( $pseallf->getRecordCount() > 0 ) {
 				$this->pay_stub_entry_account_link_obj = $pseallf->getCurrent();
@@ -149,7 +149,7 @@ class CalculatePayStub extends PayStubFactory {
 		if ( is_object($this->pay_period_obj) ) {
 			return $this->pay_period_obj;
 		} else {
-			$pplf = new PayPeriodListFactory();
+			$pplf = TTnew( 'PayPeriodListFactory' );
 			//$this->pay_period_obj = $pplf->getById( $this->getPayPeriod() )->getCurrent();
 			$pplf->getById( $this->getPayPeriod() );
 			if ( $pplf->getRecordCount() > 0 ) {
@@ -166,7 +166,7 @@ class CalculatePayStub extends PayStubFactory {
 		if ( is_object($this->pay_period_schedule_obj) ) {
 			return $this->pay_period_schedule_obj;
 		} else {
-			$ppslf = new PayPeriodScheduleListFactory();
+			$ppslf = TTnew( 'PayPeriodScheduleListFactory' );
 			$this->pay_period_schedule_obj = $ppslf->getById( $this->getPayPeriodObject()->getPayPeriodSchedule() )->getCurrent();
 
 			return $this->pay_period_schedule_obj;
@@ -189,7 +189,7 @@ class CalculatePayStub extends PayStubFactory {
 			//Debug::text('Returning Cached data...' , __FILE__, __LINE__, __METHOD__,10);
 			return $this->pay_stub_entry_accounts_type_obj;
 		} else {
-			$psealf = new PayStubEntryAccountListFactory();
+			$psealf = TTnew( 'PayStubEntryAccountListFactory' );
 			$this->pay_stub_entry_accounts_type_obj = $psealf->getByTypeArrayByCompanyIdAndStatusId( $this->getUserObject()->getCompany(), 10 );
 
 			if ( is_array( $this->pay_stub_entry_accounts_type_obj ) ) {
@@ -202,7 +202,7 @@ class CalculatePayStub extends PayStubFactory {
 	}
 
 	function getDeductionObjectArrayForSorting( $obj ) {
-		//$psealf = new PayStubEntryAccountListFactory();
+		//$psealf = TTnew( 'PayStubEntryAccountListFactory' );
 		//$type_map_arr = $psealf->getByTypeArrayByCompanyIdAndStatusId( $this->getUserObject()->getCompany(), 10 );
 		$type_map_arr = $this->getPayStubEntryAccountsTypeArray();
 
@@ -365,7 +365,7 @@ class CalculatePayStub extends PayStubFactory {
 
 		Debug::text('bbUser Id: '. $this->getUser() .' Pay Period End Date: '. TTDate::getDate('DATE+TIME', $this->getPayPeriodObject()->getEndDate() ), __FILE__, __LINE__, __METHOD__,10);
 
-		$pay_stub = new PayStubFactory();
+		$pay_stub = TTnew( 'PayStubFactory' );
 		$pay_stub->StartTransaction();
 
 		$old_pay_stub_id = NULL;
@@ -374,7 +374,7 @@ class CalculatePayStub extends PayStubFactory {
 			$pay_stub->setTemp(TRUE);
 
 			//Check for current pay stub ID so we can compare against it.
-			$pslf = new PayStubListFactory();
+			$pslf = TTnew( 'PayStubListFactory' );
 			$pslf->getByUserIdAndPayPeriodId( $this->getUser(), $this->getPayPeriod() );
 			if ( $pslf->getRecordCount() > 0 ) {
 				$old_pay_stub_id = $pslf->getCurrent()->getId();
@@ -411,7 +411,14 @@ class CalculatePayStub extends PayStubFactory {
 			//Use the end of the current date for the transaction date, as if the employee is terminated
 			//on the same day they are generating the pay stub, the transaction date could be before the end date
 			//as the end date is at 11:59PM
-			$pay_stub->setTransactionDate( TTDate::getEndDayEpoch( TTDate::getTime() ) );
+			
+			//For now make sure that the transaction date for a terminated employee is never before their termination date.
+			if ( TTDate::getEndDayEpoch( TTDate::getTime() ) < $this->getUserObject()->getTerminationDate() ) {
+				$pay_stub->setTransactionDate( $this->getUserObject()->getTerminationDate() );
+			} else {
+				$pay_stub->setTransactionDate( TTDate::getEndDayEpoch( TTDate::getTime() ) );
+			}
+
 		} else {
 			Debug::text('User Termination Date is NOT set, assuming normal pay.', __FILE__, __LINE__, __METHOD__,10);
 			$pay_stub->setDefaultDates();
@@ -460,10 +467,10 @@ class CalculatePayStub extends PayStubFactory {
 		}
 
 		//Get all PS amendments and Tax / Deductions so we can determine the proper order to calculate them in.
-		$psalf = new PayStubAmendmentListFactory();
+		$psalf = TTnew( 'PayStubAmendmentListFactory' );
 		$psalf->getByUserIdAndAuthorizedAndStartDateAndEndDate( $this->getUser(), TRUE, $this->getPayPeriodObject()->getStartDate(), $this->getPayPeriodObject()->getEndDate() );
 
-		$udlf = new UserDeductionListFactory();
+		$udlf = TTnew( 'UserDeductionListFactory' );
 		$udlf->getByCompanyIdAndUserId( $this->getUserObject()->getCompany(), $this->getUserObject()->getId() );
 
 		$deduction_order_arr = $this->getOrderedDeductionAndPSAmendment( $udlf, $psalf );
@@ -542,7 +549,7 @@ class CalculatePayStub extends PayStubFactory {
 				//TimeTrex wouldn't delete these temporary pay stubs.
 				//Moving this code outside that IF statement so it only depends on EnableCorrection()
 				//to be TRUE should fix that issue.
-				$pslf = new PayStubListFactory();
+				$pslf = TTnew( 'PayStubListFactory' );
 				$pslf->getById( $pay_stub_id );
 				if ( $pslf->getRecordCount() > 0 ) {
 					$tmp_ps_obj = $pslf->getCurrent();
