@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: CurrencyFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4265 $
+ * $Id: CurrencyFactory.class.php 4265 2011-02-18 00:49:20Z ipso $
+ * $Date: 2011-02-17 16:49:20 -0800 (Thu, 17 Feb 2011) $
  */
 
 /**
@@ -322,6 +322,9 @@ class CurrencyFactory extends Factory {
 										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
 							);
 				break;
+			case 'list_columns':
+				$retval = Misc::arrayIntersectByKey( array('name','iso_code','status'), Misc::trimSortPrefix( $this->getOptions('columns') ) );
+				break;
 			case 'default_display_columns': //Columns that are displayed by default.
 				$retval = array(
 								'status',
@@ -330,10 +333,6 @@ class CurrencyFactory extends Factory {
 								'conversion_rate',
 								'is_default',
 								'is_base',
-								'created_by',
-								'created_date',
-								'updated_by',
-								'updated_date',
 								);
 				break;
 			case 'unique_columns': //Columns that are unique, and disabled for mass editing.
@@ -384,7 +383,7 @@ class CurrencyFactory extends Factory {
 	function setCompany($id) {
 		$id = trim($id);
 
-		$clf = new CompanyListFactory();
+		$clf = TTnew( 'CompanyListFactory' );
 
 		if ( $id == 0
 				OR $this->Validator->isResultSetWithRows(	'company',
@@ -742,7 +741,7 @@ class CurrencyFactory extends Factory {
 			return $amount;
 		}
 
-		$clf = new CurrencyListFactory();
+		$clf = TTnew( 'CurrencyListFactory' );
 		$clf->getById( $src_currency_id );
 		if ( $clf->getRecordCount() > 0 ) {
 			$src_currency_obj = $clf->getCurrent();
@@ -782,7 +781,7 @@ class CurrencyFactory extends Factory {
 		*/
 		$base_currency = FALSE;
 
-		$clf = new CurrencyListFactory();
+		$clf = TTnew( 'CurrencyListFactory' );
 		$clf->getByCompanyId( $company_id );
 		if ( $clf->getRecordCount() > 0 ) {
 			foreach( $clf as $c_obj) {
@@ -810,7 +809,7 @@ class CurrencyFactory extends Factory {
 		if ( isset($currency_rates) AND is_array($currency_rates) AND count($currency_rates) > 0 ) {
 			foreach( $currency_rates as $currency => $rate ) {
 				if ( is_numeric($rate) ) {
-					$clf = new CurrencyListFactory();
+					$clf = TTnew( 'CurrencyListFactory' );
 					$clf->getByCompanyIdAndISOCode( $company_id, $currency);
 					if ( $clf->getRecordCount() == 1 ) {
 						$c_obj = $clf->getCurrent();
@@ -843,14 +842,14 @@ class CurrencyFactory extends Factory {
 			//CHeck to make sure currency isnt in-use by paystubs/employees/wages, if so, don't delete.
 			$invalid = FALSE;
 
-			$pslf = new PayStubListFactory();
+			$pslf = TTnew( 'PayStubListFactory' );
 			$pslf->getByCurrencyId( $this->getId() );
 			if ( $pslf->getRecordCount() > 0 ) {
 				$invalid = TRUE;
 			}
 
 			if ( $invalid == FALSE ) {
-				$ulf = new UserListFactory();
+				$ulf = TTnew( 'UserListFactory' );
 				$ulf->getByCurrencyId( $this->getId() );
 				if ( $ulf->getRecordCount() > 0 ) {
 					$invalid = TRUE;
