@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3508 $
- * $Id: ExceptionFactory.class.php 3508 2010-04-19 19:46:03Z ipso $
- * $Date: 2010-04-19 12:46:03 -0700 (Mon, 19 Apr 2010) $
+ * $Revision: 4265 $
+ * $Id: ExceptionFactory.class.php 4265 2011-02-18 00:49:20Z ipso $
+ * $Date: 2011-02-17 16:49:20 -0800 (Thu, 17 Feb 2011) $
  */
 
 /**
@@ -94,6 +94,9 @@ class ExceptionFactory extends Factory {
 										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
 							);
 				break;
+			case 'list_columns':
+				$retval = Misc::arrayIntersectByKey( array('date_stamp','severity', 'exception_policy_type', 'exception_policy_type_id'), Misc::trimSortPrefix( $this->getOptions('columns') ) );
+				break;
 			case 'default_display_columns': //Columns that are displayed by default.
 				$retval = array(
 								'first_name',
@@ -158,7 +161,7 @@ class ExceptionFactory extends Factory {
 		if ( is_object($this->user_date_obj) ) {
 			return $this->user_date_obj;
 		} else {
-			$udlf = new UserDateListFactory();
+			$udlf = TTnew( 'UserDateListFactory' );
 			$this->user_date_obj = $udlf->getById( $this->getUserDateID() )->getCurrent();
 
 			return $this->user_date_obj;
@@ -169,7 +172,7 @@ class ExceptionFactory extends Factory {
 		if ( is_object($this->exception_policy_obj) ) {
 			return $this->exception_policy_obj;
 		} else {
-			$eplf = new ExceptionPolicyListFactory();
+			$eplf = TTnew( 'ExceptionPolicyListFactory' );
 			$this->exception_policy_obj = $eplf->getById( $this->getExceptionPolicyID() )->getCurrent();
 
 			return $this->exception_policy_obj;
@@ -186,7 +189,7 @@ class ExceptionFactory extends Factory {
 	function setUserDateID($id = NULL) {
 		$id = trim($id);
 
-		$udlf = new UserDateListFactory();
+		$udlf = TTnew( 'UserDateListFactory' );
 
 		if (  $this->Validator->isResultSetWithRows(	'user_date',
 														$udlf->getByID($id),
@@ -214,7 +217,7 @@ class ExceptionFactory extends Factory {
 			$id = NULL;
 		}
 
-		$eplf = new ExceptionPolicyListFactory();
+		$eplf = TTnew( 'ExceptionPolicyListFactory' );
 
 		if (	$id == NULL
 				OR
@@ -244,7 +247,7 @@ class ExceptionFactory extends Factory {
 			$id = NULL;
 		}
 
-		$pclf = new PunchControlListFactory();
+		$pclf = TTnew( 'PunchControlListFactory' );
 
 		if (
 				$id == NULL
@@ -275,7 +278,7 @@ class ExceptionFactory extends Factory {
 			$id = NULL;
 		}
 
-		$plf = new PunchListFactory();
+		$plf = TTnew( 'PunchListFactory' );
 
 		if (	$id == NULL
 				OR
@@ -413,11 +416,11 @@ class ExceptionFactory extends Factory {
 				//Make sure supervisor email notifcations are enabled
 				if ( $ep_obj->getEmailNotification() == 20 OR $ep_obj->getEmailNotification() == 100 ) {
 					//Find supervisor(s)
-					$hlf = new HierarchyListFactory();
+					$hlf = TTnew( 'HierarchyListFactory' );
 					$parent_user_id = $hlf->getHierarchyParentByCompanyIdAndUserIdAndObjectTypeID( $u_obj->getCompany(), $u_obj->getId(), 80 );
 					if ( $parent_user_id != FALSE ) {
 						//Parent could be multiple supervisors, make sure we email them all.
-						$ulf = new UserListFactory();
+						$ulf = TTnew( 'UserListFactory' );
 						$ulf->getByIdAndCompanyId( $parent_user_id, $u_obj->getCompany() );
 						if ( $ulf->getRecordCount() > 0 ) {
 							foreach( $ulf as $parent_user_obj ) {
@@ -598,7 +601,7 @@ class ExceptionFactory extends Factory {
 	function getObjectAsArray( $include_columns = NULL ) {
 		$variable_function_map = $this->getVariableToFunctionMap();
 
-		$epf = new ExceptionPolicyFactory();
+		$epf = TTnew( 'ExceptionPolicyFactory' );
 		$exception_policy_type_options = $epf->getOptions('type');
 		$exception_policy_severity_options = $epf->getOptions('severity');
 
