@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3478 $
- * $Id: ExceptionListFactory.class.php 3478 2010-04-01 23:43:06Z ipso $
- * $Date: 2010-04-01 16:43:06 -0700 (Thu, 01 Apr 2010) $
+ * $Revision: 4265 $
+ * $Id: ExceptionListFactory.class.php 4265 2011-02-18 00:49:20Z ipso $
+ * $Date: 2011-02-17 16:49:20 -0800 (Thu, 17 Feb 2011) $
  */
 
 /**
@@ -847,6 +847,12 @@ class ExceptionListFactory extends ExceptionFactory implements IteratorAggregate
 		}
 
 		$additional_order_fields = array('d.name', 'e.name', 'f.name', 'g.name', 'h.status_id','i.severity_id','i.type_id','c.first_name','c.last_name', 'b.date_stamp');
+		$sort_column_aliases = array(
+									 'status' => 'status_id',
+									 'type' => 'type_id',
+									 );
+		$order = $this->getColumnsFromAliases( $order, $sort_column_aliases );
+
 		if ( $order == NULL ) {
 			//$order = array( 'status_id' => 'asc', 'last_name' => 'asc', 'first_name' => 'asc', 'middle_name' => 'asc');
 			$order = array( 'i.severity_id' => 'desc', 'c.last_name' => 'asc', 'b.date_stamp' => 'asc', 'i.type_id' => 'asc' );
@@ -971,7 +977,6 @@ class ExceptionListFactory extends ExceptionFactory implements IteratorAggregate
 						LEFT JOIN '. $utf->getTable() .' as g ON c.title_id = g.id
 						LEFT JOIN '. $ppf->getTable() .' as h ON b.pay_period_id = h.id
 						LEFT JOIN '. $epf->getTable() .' as i ON a.exception_policy_id = i.id
-
 						LEFT JOIN '. $uf->getTable() .' as y ON ( a.created_by = y.id AND y.deleted = 0 )
 						LEFT JOIN '. $uf->getTable() .' as z ON ( a.updated_by = z.id AND z.deleted = 0 )
 					where	c.company_id = ?
@@ -1030,9 +1035,9 @@ class ExceptionListFactory extends ExceptionFactory implements IteratorAggregate
 			$query  .=	' AND b.date_stamp <= ?';
 		}
 
-
+		//Make sure we accept exception rows assign to pay_period_id = 0 (no pay period), as this can happen when punches exist in the future.
 		$query .= 	'
-						AND ( a.deleted = 0 AND b.deleted = 0 AND c.deleted = 0 AND h.deleted = 0 )
+						AND ( a.deleted = 0 AND b.deleted = 0 AND c.deleted = 0 AND ( h.deleted = 0 OR h.deleted is NULL ) )
 					';
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
