@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3928 $
- * $Id: Factory.class.php 3928 2010-11-11 20:29:54Z ipso $
- * $Date: 2010-11-11 12:29:54 -0800 (Thu, 11 Nov 2010) $
+ * $Revision: 4845 $
+ * $Id: Factory.class.php 4845 2011-06-21 16:23:18Z ipso $
+ * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
  */
 
 /**
@@ -50,6 +50,7 @@ abstract class Factory {
 
 	protected $next_insert_id = NULL;
 	protected $progress_bar_obj = NULL;
+	protected $AMF_message_id = NULL;
 
 	function __construct() {
 		global $db, $cache;
@@ -69,6 +70,21 @@ abstract class Factory {
 	/*
 	 * Used for updating progress bar for API calls.
 	 */
+	function getAMFMessageID() {
+		if ( $this->AMF_message_id != NULL ) {
+			return $this->AMF_message_id;
+		}
+		return FALSE;
+	}
+	function setAMFMessageID( $id ) {
+		if ( $id != '' ) {
+			$this->AMF_message_id = $id;
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
 	function setProgressBarObject( $obj ) {
 		if  ( is_object( $obj ) ) {
 			$this->progress_bar_obj = $obj;
@@ -89,20 +105,27 @@ abstract class Factory {
 	 * Cache functions
 	 */
 	function getCache($cache_id) {
-		if ( is_object($this->cache) AND is_string( $this->cache->get($cache_id, $this->getTable(TRUE) ) ) ) {
-			return unserialize( $this->cache->get($cache_id, $this->getTable(TRUE) ) );
+		if ( is_object($this->cache) ) {
+			return $this->cache->get($cache_id, $this->getTable(TRUE) );
 		}
 
 		return FALSE;
 	}
 	function saveCache($data, $cache_id) {
+		//Cache_ID can't have ':' in it, otherwise it fails on Windows.
 		if ( is_object($this->cache) ) {
-			return $this->cache->save(serialize($data), $cache_id, $this->getTable(TRUE) );
+			$retval = $this->cache->save( $data, $cache_id, $this->getTable(TRUE) );
+			if ( $retval === FALSE ) {
+				//Due to locking, its common that cache files may fail writing once in a while.
+				Debug::text('WARNING: Unable to write cache file, likely due to permissions or locking! Cache ID: '. $cache_id .' Table: '. $this->getTable(TRUE) .' File: '. $this->cache->_file, __FILE__, __LINE__, __METHOD__,10);
+			}
+
+			return $retval;
 		}
 		return FALSE;
 	}
 	function removeCache($cache_id = NULL, $group_id = NULL ) {
-		Debug::text('Attempting to remove cache: '. $cache_id , __FILE__, __LINE__, __METHOD__,10);
+		Debug::text('Attempting to remove cache: '. $cache_id, __FILE__, __LINE__, __METHOD__,10);
 		if ( is_object($this->cache) ) {
 			if ( $group_id == '' ) {
 				$group_id = $this->getTable(TRUE);
@@ -151,6 +174,29 @@ abstract class Factory {
 		return FALSE;
 	}
 
+	//Print primary columns from object.
+	function __toString() {
+		if ( method_exists( $this, 'getObjectAsArray' ) ) {
+			$columns = Misc::trimSortPrefix( $this->getOptions('columns') );
+			$data = $this->getObjectAsArray( $columns );
+
+			if ( is_array($columns) AND is_array($data) ) {
+				$retarr = array();
+				foreach( $columns as $column => $name ) {
+					if ( isset($data[$column]) ) {
+						$retarr[] = $name .': '. $data[$column];
+					}
+				}
+
+				if ( count($retarr) > 0 ) {
+					return implode( "\n", $retarr );
+				}
+			}
+		}
+
+		return FALSE;
+	}
+
 	function toBool($value) {
 		$value = strtolower(trim($value));
 
@@ -245,9 +291,12 @@ abstract class Factory {
 			$this->data['id'] = $id; //Allow ID to be set as FALSE. Essentially making a new entry.
 		}
 		*/
-		$this->data['id'] = $id; //Allow ID to be set as FALSE. Essentially making a new entry.
+		if ( is_numeric( $id ) OR is_bool( $id ) ) {
+			$this->data['id'] = $id; //Allow ID to be set as FALSE. Essentially making a new entry.
+			return TRUE;
+		}
 
-		return true;
+		return FALSE;
 	}
 
 	function getEnableSystemLogDetail() {
@@ -271,7 +320,7 @@ abstract class Factory {
 		return FALSE;
 	}
 	function setDeleted($bool) {
-		$value = $this->toBool($bool);
+		$value = (bool)$bool;
 
 		//Handle Postgres's boolean values.
 		if ($value === TRUE) {
@@ -334,7 +383,7 @@ abstract class Factory {
 		//Its possible that these are incorrect, especially if the user was created by a system or master administrator.
 		//Skip strict checks for now.
 		/*
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		if ( $this->Validator->isResultSetWithRows(	'created_by',
 													$ulf->getByID($id),
 													TTi18n::gettext('Incorrect User')
@@ -404,7 +453,7 @@ abstract class Factory {
 		//Its possible that these are incorrect, especially if the user was created by a system or master administrator.
 		//Skip strict checks for now.
 		/*
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		if ( $this->Validator->isResultSetWithRows(	'updated_by',
 													$ulf->getByID($id),
 													TTi18n::gettext('Incorrect User')
@@ -470,7 +519,7 @@ abstract class Factory {
 			}
 		}
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 
 		if ( $this->Validator->isResultSetWithRows(	'updated_by',
 													$ulf->getByID($id),
@@ -486,6 +535,7 @@ abstract class Factory {
 	}
 
 	function setCreatedAndUpdatedColumns( $data ) {
+		Debug::text(' Set created/updated columns...', __FILE__, __LINE__, __METHOD__,10);
 		//Update array in-place.
 		if ( isset($data['created_by']) AND is_numeric($data['created_by']) AND $data['created_by'] > 0 ) {
 			$this->setCreatedBy( $data['created_by'] );
@@ -533,16 +583,17 @@ abstract class Factory {
 		return TRUE;
 	}
 
-	function getPermissionColumns( &$data, $object_id, $created_by_id, $permission_children_ids, $include_columns = NULL ) {
+	function getPermissionColumns( &$data, $object_user_id, $created_by_id, $permission_children_ids = NULL, $include_columns = NULL ) {
 		$permission = new Permission();
 
 		if( $include_columns == NULL OR ( isset($include_columns['is_owner']) AND $include_columns['is_owner'] == TRUE) ) {
-			$data['is_owner'] = $permission->isOwner( $created_by_id, $object_id );
+			$data['is_owner'] = $permission->isOwner( $created_by_id, $object_user_id );
 		}
 
 		if ( $include_columns == NULL OR ( isset($include_columns['is_child']) AND $include_columns['is_child'] == TRUE) ) {
 			if ( is_array($permission_children_ids) ) {
-				$data['is_child'] = $permission->isChild( $object_id, $permission_children_ids );
+				//ObjectID should always be a user_id.
+				$data['is_child'] = $permission->isChild( $object_user_id, $permission_children_ids );
 			} else {
 				$data['is_child'] = FALSE;
 			}
@@ -907,10 +958,11 @@ abstract class Factory {
 		if ( is_array($this->data) AND count($this->data) > 0) {
 			$column_list = array_keys($this->data);
 
-			if ( $this->setUpdatedDate() !== FALSE ) {
+			//Don't set updated_date when deleting records, we use deleted_date/deleted_by for that.
+			if ( $this->getDeleted() == FALSE AND $this->setUpdatedDate() !== FALSE ) {
 				$column_list[] = 'updated_date';
 			}
-			if ( $this->setUpdatedBy() !== FALSE ) {
+			if ( $this->getDeleted() == FALSE AND $this->setUpdatedBy() !== FALSE ) {
 				$column_list[] = 'updated_by';
 			}
 
@@ -926,16 +978,20 @@ abstract class Factory {
 	}
 
 	public function getEmptyRecordSet($id = NULL) {
-		global $profiler;
+		global $profiler, $config_vars;
 		$profiler->startTimer( 'getEmptyRecordSet()' );
 
 		if ($id == NULL) {
 			$id = -1;
 		}
 
+		$id = (int)$id;
+
 		//Possible errors can happen if $this->data[<invalid_column>] is passed, like what happens with APIPunch when attempting to delete a punch.
 		//Why are we not using '*' for all empty record set queries? Will using * cause more fields to be updated then necessary?
 		//Yes, it will, as well the updated_by/updated_date fields aren't controllable by getColumnList() then either.
+		//Therefore any ListFactory queries used to potentially delete data should only include columns from its own table,
+		//Or collect the IDs and use bulkDelete instead.
 		$column_list = $this->getColumnList();
 		if ( is_array($column_list) ) {
 			//Implode columns.
@@ -945,11 +1001,37 @@ abstract class Factory {
 		}
 
 		try {
-			$query = 'select '. $column_str .' from '. $this->table .' where id = '. (int)$id;
-			//Debug::text('Query: '. $query , __FILE__, __LINE__, __METHOD__,9);
+			$query = 'select '. $column_str .' from '. $this->table .' where id = '. $id;
 
-			if ( $id == -1 ) {
-				$rs = $this->db->CacheExecute(86400, $query);
+			if ( $id == -1 AND isset($config_vars['cache']['enable']) AND $config_vars['cache']['enable'] == TRUE ) {
+
+				/*
+				//Try to use Cache Lite instead of ADODB, to avoid cache write errors from causing a transaction rollback. It should be faster too.
+				//However I think there is some issues with storing the record set, as ADODB goes to great lengths to avoid straight serialize/unserialize.
+				$cache_id = 'empty_rs_'. $this->table .'_'. $id;
+				$rs = $this->getCache($cache_id);
+				if ( $rs === FALSE ) {
+					$rs = $this->db->Execute($query);
+					$this->saveCache($rs,$cache_id);
+				}
+				*/
+				$save_error_handlers = $this->db->IgnoreErrors(); //Prevent a cache write error from causing a transaction rollback.
+				try {
+					$rs = $this->db->CacheExecute(604800, $query);
+				} catch (Exception $e) {
+					if ( $e->getCode() == -32000 OR $e->getCode() == -32001 ) { //Cache write error/cache file lock error.
+						//Likely a cache write error occurred, fall back to non-cached query and log this error.
+						Debug::Text('ERROR: Unable to write cache file, likely due to permissions or locking! Code: '. $e->getCode() .' Msg: '. $e->getMessage(), __FILE__, __LINE__, __METHOD__,10);
+					}
+
+					//Execute non-cached query
+					try {
+						$rs = $this->db->Execute($query);
+					} catch (Exception $e) {
+						throw new DBError($e);
+					}
+				}
+				$this->db->IgnoreErrors( $save_error_handlers ); //Prevent a cache write error from causing a transaction rollback.
 			} else {
 				$rs = $this->db->Execute($query);
 			}
