@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2321 $
- * $Id: FormVariables.class.php 2321 2009-01-03 00:58:17Z ipso $
- * $Date: 2009-01-02 16:58:17 -0800 (Fri, 02 Jan 2009) $
+ * $Revision: 4364 $
+ * $Id: FormVariables.class.php 4364 2011-03-14 20:05:49Z ipso $
+ * $Date: 2011-03-14 13:05:49 -0700 (Mon, 14 Mar 2011) $
  */
 
 /**
@@ -73,7 +73,7 @@ class FormVariables {
 				if ( $filter_input == TRUE AND is_string($retarr[$variable_name]) AND $retarr[$variable_name] != ''
 						AND ( !is_array($filter_ignore_name_arr) OR ( is_array($filter_ignore_name_arr) AND !in_array( $variable_name, $filter_ignore_name_arr) ) ) ) {
 					//Remove "javascript:" from all inputs, and run htmlspecialchars over them to help prevent XSS attacks.
-					$retarr[$variable_name] = htmlspecialchars( str_ireplace('javascript:', '', $retarr[$variable_name] ), ENT_QUOTES, 'UTF-8' );
+					$retarr[$variable_name] = @htmlspecialchars( str_ireplace('javascript:', '', $retarr[$variable_name] ), ENT_QUOTES, 'UTF-8' ); //Supress warnings due to invalid multibyte sequences
 				} elseif ( strtolower($filter_input) == 'recurse' AND is_array($retarr[$variable_name])
 								AND ( !is_array($filter_ignore_name_arr) OR ( is_array($filter_ignore_name_arr) AND !in_array( $variable_name, $filter_ignore_name_arr) ) ) ) {
 					self::RecurseFilterArray($retarr[$variable_name]);
@@ -98,7 +98,7 @@ class FormVariables {
 			if ( is_array($val) ) {
 				self::RecurseFilterArray($arr[$key]);
 			} else {
-				$arr[$key] = htmlspecialchars( str_ireplace('javascript:', '', $val ), ENT_QUOTES, 'UTF-8' );
+				$arr[$key] = @htmlspecialchars( str_ireplace('javascript:', '', $val ), ENT_QUOTES, 'UTF-8' ); //Supress warnings due to invalid multibyte sequences
 			}
 		}
 
