@@ -57,7 +57,7 @@ class LogDetailFactory extends Factory {
 			$id = 0;
 		}
 
-		$llf = new LogListFactory();
+		$llf = TTnew( 'LogListFactory' );
 
 		if ( $id == 0
 				OR $this->Validator->isResultSetWithRows(	'user',
@@ -164,6 +164,7 @@ class LogDetailFactory extends Factory {
 							'currency_id' => TTi18n::getText('Currency'),
 							'branch_id' => TTi18n::getText('Branch'),
 							'department_id' => TTi18n::getText('Department'),
+							'group_id' => TTi18n::getText('Group'),
 							'job_id' => TTi18n::getText('Job'),
 							'job_item_id' => TTi18n::getText('Task'),
 							'exception_policy_control_id' => TTi18n::getText('Exception Policy'),
@@ -178,6 +179,12 @@ class LogDetailFactory extends Factory {
 							'product_id' => TTi18n::getText('Product'),
 							'invoice_district_id' => TTi18n::getText('District'),
 							'total_time' => TTi18n::getText('Total Time'),
+
+							'other_id1' => TTi18n::getText('Other ID1'), //Need to find the proper names for these eventually.
+							'other_id2' => TTi18n::getText('Other ID2'),
+							'other_id3' => TTi18n::getText('Other ID3'),
+							'other_id4' => TTi18n::getText('Other ID4'),
+							'other_id5' => TTi18n::getText('Other ID5'),
 							);
 
 			//Handle class specific fields.
@@ -310,6 +317,12 @@ class LogDetailFactory extends Factory {
 									'secondary_transaction_day_of_month' => TTi18n::getText('Secondary Transaction Day'),
 									);
 					break;
+				case 'RequestFactory':
+				case 'RequestListFactory':
+					$columns = array(
+									'authorization_level' => TTi18n::getText('Authorization Level'),
+									);
+					break;
 				case 'PayStubAmendmentFactory':
 				case 'PayStubAmendmentListFactory':
 				case 'RecurringPayStubAmendmentFactory':
@@ -340,6 +353,13 @@ class LogDetailFactory extends Factory {
 									'sun' => TTi18n::getText('Sunday'),
 									);
 					break;
+				case 'UserFactory':
+				case 'UserListFactory':
+					$columns = array(
+									'sex' => TTi18n::gettext('Sex'),
+									'second_last_name' => TTi18n::gettext('Second Surname'),
+									);
+					break;
 				case 'UserPreferenceFactory':
 				case 'UserPreferenceListFactory':
 					$columns = array(
@@ -402,7 +422,7 @@ class LogDetailFactory extends Factory {
 									);
 					break;
 				case 'ClientPaymentFactory':
-				case 'ClientPaymentFactory':
+				case 'ClientPaymentListFactory':
 					$columns = array(
 									'cc_bank_phone' => TTi18n::gettext('Issuing Bank Phone Number'),
 									'cc_expire' => TTi18n::gettext('Expiry Date'),
@@ -415,7 +435,7 @@ class LogDetailFactory extends Factory {
 									);
 					break;
 				case 'ProductFactory':
-				case 'ProductFactory':
+				case 'ProductListFactory':
 					$columns = array(
 									'group_id' => TTi18n::gettext('Group'),
 									'minimum_purchase_quantity' => TTi18n::gettext('Minimum Purchase Quantity'),
@@ -467,7 +487,7 @@ class LogDetailFactory extends Factory {
 			//Global variables, like branches,departments,titles,jobs,tasks,status_id,type_id etc...
 			case 'branch_id':
 			case 'default_branch_id':
-				$lf = new BranchListFactory();
+				$lf = TTnew( 'BranchListFactory' );
 				$lf->getById( $value );
 				if ( $lf->getRecordCount() > 0 ) {
 					$retval = $lf->getCurrent()->getName();
@@ -477,7 +497,7 @@ class LogDetailFactory extends Factory {
 				break;
 			case 'department_id':
 			case 'default_department_id':
-				$lf = new DepartmentListFactory();
+				$lf = TTnew( 'DepartmentListFactory' );
 				$lf->getById( $value );
 				if ( $lf->getRecordCount() > 0 ) {
 					$retval = $lf->getCurrent()->getName();
@@ -486,7 +506,7 @@ class LogDetailFactory extends Factory {
 				}
 				break;
 			case 'title_id':
-				$lf = new UserTitleListFactory();
+				$lf = TTnew( 'UserTitleListFactory' );
 				$lf->getById( $value );
 				if ( $lf->getRecordCount() > 0 ) {
 					$retval = $lf->getCurrent()->getName();
@@ -495,7 +515,7 @@ class LogDetailFactory extends Factory {
 				}
 				break;
 			case 'currency_id':
-				$lf = new CurrencyListFactory();
+				$lf = TTnew( 'CurrencyListFactory' );
 				$lf->getById( $value );
 				if ( $lf->getRecordCount() > 0 ) {
 					$retval = $lf->getCurrent()->getName();
@@ -504,7 +524,7 @@ class LogDetailFactory extends Factory {
 				}
 				break;
 			case 'group_id':
-				$lf = new UserGroupListFactory();
+				$lf = TTnew( 'UserGroupListFactory' );
 				$lf->getById( $value );
 				if ( $lf->getRecordCount() > 0 ) {
 					$retval = $lf->getCurrent()->getName();
@@ -516,7 +536,7 @@ class LogDetailFactory extends Factory {
 			case 'support_contact':
 			case 'sales_contact':
 			case 'user_id':
-				$lf = new UserListFactory();
+				$lf = TTnew( 'UserListFactory' );
 				$lf->getById( $value );
 				if ( $lf->getRecordCount() > 0 ) {
 					$retval = $lf->getCurrent()->getFullName();
@@ -525,7 +545,7 @@ class LogDetailFactory extends Factory {
 				}
 				break;
 			case 'accrual_policy_id':
-				$lf = new AccrualPolicyListFactory();
+				$lf = TTnew( 'AccrualPolicyListFactory' );
 				$lf->getById( $value );
 				if ( $lf->getRecordCount() > 0 ) {
 					$retval = $lf->getCurrent()->getName();
@@ -534,7 +554,7 @@ class LogDetailFactory extends Factory {
 				}
 				break;
 			case 'schedule_policy_id':
-				$lf = new SchedulePolicyListFactory();
+				$lf = TTnew( 'SchedulePolicyListFactory' );
 				$lf->getById( $value );
 				if ( $lf->getRecordCount() > 0 ) {
 					$retval = $lf->getCurrent()->getName();
@@ -543,7 +563,7 @@ class LogDetailFactory extends Factory {
 				}
 				break;
 			case 'exception_policy_control_id':
-				$lf = new ExceptionPolicyListFactory();
+				$lf = TTnew( 'ExceptionPolicyListFactory' );
 				$lf->getById( $value );
 				if ( $lf->getRecordCount() > 0 ) {
 					$retval = $lf->getCurrent()->getName();
@@ -552,7 +572,7 @@ class LogDetailFactory extends Factory {
 				}
 				break;
 			case 'meal_policy_id':
-				$lf = new MealPolicyListFactory();
+				$lf = TTnew( 'MealPolicyListFactory' );
 				$lf->getById( $value );
 				if ( $lf->getRecordCount() > 0 ) {
 					$retval = $lf->getCurrent()->getName();
@@ -561,7 +581,7 @@ class LogDetailFactory extends Factory {
 				}
 				break;
 			case 'break_policy_id':
-				$lf = new BreakPolicyListFactory();
+				$lf = TTnew( 'BreakPolicyListFactory' );
 				$lf->getById( $value );
 				if ( $lf->getRecordCount() > 0 ) {
 					$retval = $lf->getCurrent()->getName();
@@ -570,7 +590,7 @@ class LogDetailFactory extends Factory {
 				}
 				break;
 			case 'absence_policy_id':
-				$lf = new AbsencePolicyListFactory();
+				$lf = TTnew( 'AbsencePolicyListFactory' );
 				$lf->getById( $value );
 				if ( $lf->getRecordCount() > 0 ) {
 					$retval = $lf->getCurrent()->getName();
@@ -579,7 +599,7 @@ class LogDetailFactory extends Factory {
 				}
 				break;
 			case 'over_time_policy_id':
-				$lf = new OverTimePolicyListFactory();
+				$lf = TTnew( 'OverTimePolicyListFactory' );
 				$lf->getById( $value );
 				if ( $lf->getRecordCount() > 0 ) {
 					$retval = $lf->getCurrent()->getName();
@@ -588,7 +608,7 @@ class LogDetailFactory extends Factory {
 				}
 				break;
 			case 'holiday_policy_id':
-				$lf = new HolidayPolicyListFactory();
+				$lf = TTnew( 'HolidayPolicyListFactory' );
 				$lf->getById( $value );
 				if ( $lf->getRecordCount() > 0 ) {
 					$retval = $lf->getCurrent()->getName();
@@ -597,7 +617,7 @@ class LogDetailFactory extends Factory {
 				}
 				break;
 			case 'round_interval_policy_id':
-				$lf = new RoundIntervalPolicyListFactory();
+				$lf = TTnew( 'RoundIntervalPolicyListFactory' );
 				$lf->getById( $value );
 				if ( $lf->getRecordCount() > 0 ) {
 					$retval = $lf->getCurrent()->getName();
@@ -606,7 +626,7 @@ class LogDetailFactory extends Factory {
 				}
 				break;
 			case 'wage_group_id':
-				$lf = new WageGroupListFactory();
+				$lf = TTnew( 'WageGroupListFactory' );
 				$lf->getById( $value );
 				if ( $lf->getRecordCount() > 0 ) {
 					$retval = $lf->getCurrent()->getName();
@@ -615,7 +635,7 @@ class LogDetailFactory extends Factory {
 				}
 				break;
 			case 'company_deduction_id':
-				$lf = new CompanyDeductionListFactory();
+				$lf = TTnew( 'CompanyDeductionListFactory' );
 				$lf->getById( $value );
 				if ( $lf->getRecordCount() > 0 ) {
 					$retval = $lf->getCurrent()->getName();
@@ -627,7 +647,7 @@ class LogDetailFactory extends Factory {
 			case 'pay_stub_entry_name_id':
 			case 'accrual_pay_stub_entry_account_id':
 			case 'percent_amount_entry_name_id':
-				$lf = new PayStubEntryAccountListFactory();
+				$lf = TTnew( 'PayStubEntryAccountListFactory' );
 				$lf->getById( $value );
 				if ( $lf->getRecordCount() > 0 ) {
 					$type_options  = $lf->getOptions('type');
@@ -637,7 +657,7 @@ class LogDetailFactory extends Factory {
 				}
 				break;
 			case 'recurring_schedule_template_control_id':
-				$lf = new RecurringScheduleTemplateControlListFactory();
+				$lf = TTnew( 'RecurringScheduleTemplateControlListFactory' );
 				$lf->getById( $value );
 				if ( $lf->getRecordCount() > 0 ) {
 					$retval = $lf->getCurrent()->getName();
@@ -651,7 +671,7 @@ class LogDetailFactory extends Factory {
 			//
 			case 'job_id':
 				if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
-					$lf = new JobListFactory();
+					$lf = TTnew( 'JobListFactory' );
 					$lf->getById( $value );
 					if ( $lf->getRecordCount() > 0 ) {
 						$retval = $lf->getCurrent()->getName();
@@ -663,7 +683,7 @@ class LogDetailFactory extends Factory {
 			case 'default_item_id':
 			case 'job_item_id':
 				if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
-					$lf = new JobItemListFactory();
+					$lf = TTnew( 'JobItemListFactory' );
 					$lf->getById( $value );
 					if ( $lf->getRecordCount() > 0 ) {
 						$retval = $lf->getCurrent()->getName();
@@ -674,7 +694,7 @@ class LogDetailFactory extends Factory {
 				break;
 			case 'client_id':
 				if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
-					$lf = new ClientListFactory();
+					$lf = TTnew( 'ClientListFactory' );
 					$lf->getById( $value );
 					if ( $lf->getRecordCount() > 0 ) {
 						$retval = $lf->getCurrent()->getCompanyName();
@@ -685,7 +705,7 @@ class LogDetailFactory extends Factory {
 				break;
 			case 'product_id':
 				if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
-					$lf = new ProductListFactory();
+					$lf = TTnew( 'ProductListFactory' );
 					$lf->getById( $value );
 					if ( $lf->getRecordCount() > 0 ) {
 						$retval = $lf->getCurrent()->getName();
@@ -696,7 +716,7 @@ class LogDetailFactory extends Factory {
 				break;
 			case 'document_id':
 				if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
-					$lf = new DocumentListFactory();
+					$lf = TTnew( 'DocumentListFactory' );
 					$lf->getById( $value );
 					if ( $lf->getRecordCount() > 0 ) {
 						$retval = $lf->getCurrent()->getName();
@@ -707,7 +727,7 @@ class LogDetailFactory extends Factory {
 				break;
 			case 'invoice_district_id':
 				if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
-					$lf = new InvoiceDistrictListFactory();
+					$lf = TTnew( 'InvoiceDistrictListFactory' );
 					$lf->getById( $value );
 					if ( $lf->getRecordCount() > 0 ) {
 						$retval = $lf->getCurrent()->getName();
@@ -727,13 +747,13 @@ class LogDetailFactory extends Factory {
 				break;
 			case 'origin_country':
 			case 'country':
-				$cf = new CompanyFactory();
+				$cf = TTnew( 'CompanyFactory' );
 				$retval = Option::getByKey($value, $cf->getOptions( 'country') );
 				break;
 			case 'province': //Cant do this one, as it requires the country value too.
 				break;
 			case 'time_zone':
-				$upf = new UserPreferenceFactory();
+				$upf = TTnew( 'UserPreferenceFactory' );
 				$retval = Option::getByKey($value, Misc::TrimSortPrefix( $upf->getOptions( $field ) ) );
 				break;
 			case 'time_stamp':
@@ -773,6 +793,10 @@ class LogDetailFactory extends Factory {
 					case 'termination_date':
 						$retval = TTDate::getDate('DATE', $value );
 						break;
+					case 'sex_id':
+						$options = $obj->getOptions( $this->normalizeField( $obj, $field) );
+						$retval = Option::getByKey($value, $options );
+						break;
 				}
 				break;
 			case 'CurrencyFactory':
@@ -1148,7 +1172,7 @@ class LogDetailFactory extends Factory {
 			case 'JobListFactory':
 				switch ( $field ) {
 					case 'group_id':
-						$lf = new JobGroupListFactory();
+						$lf = TTnew( 'JobGroupListFactory' );
 						$lf->getById( $value );
 						if ( $lf->getRecordCount() > 0 ) {
 							$retval = $lf->getCurrent()->getName();
@@ -1179,7 +1203,7 @@ class LogDetailFactory extends Factory {
 			case 'JobItemListFactory':
 				switch ( $field ) {
 					case 'group_id':
-						$lf = new JobItemGroupListFactory();
+						$lf = TTnew( 'JobItemGroupListFactory' );
 						$lf->getById( $value );
 						if ( $lf->getRecordCount() > 0 ) {
 							$retval = $lf->getCurrent()->getName();
@@ -1197,7 +1221,7 @@ class LogDetailFactory extends Factory {
 			case 'DocumentListFactory':
 				switch ( $field ) {
 					case 'group_id':
-						$lf = new DocumentGroupListFactory();
+						$lf = TTnew( 'DocumentGroupListFactory' );
 						$lf->getById( $value );
 						if ( $lf->getRecordCount() > 0 ) {
 							$retval = $lf->getCurrent()->getName();
@@ -1215,7 +1239,7 @@ class LogDetailFactory extends Factory {
 			case 'ClientListFactory':
 				switch ( $field ) {
 					case 'group_id':
-						$lf = new ClientGroupListFactory();
+						$lf = TTnew( 'ClientGroupListFactory' );
 						$lf->getById( $value );
 						if ( $lf->getRecordCount() > 0 ) {
 							$retval = $lf->getCurrent()->getName();
@@ -1237,7 +1261,7 @@ class LogDetailFactory extends Factory {
 			case 'ProductListFactory':
 				switch ( $field ) {
 					case 'group_id':
-						$lf = new ProductGroupListFactory();
+						$lf = TTnew( 'ProductGroupListFactory' );
 						$lf->getById( $value );
 						if ( $lf->getRecordCount() > 0 ) {
 							$retval = $lf->getCurrent()->getName();
@@ -1259,6 +1283,14 @@ class LogDetailFactory extends Factory {
 						break;
 				}
 				break;
+			case 'TransactionFactory':
+			case 'TransactionListFactory':
+				switch ( $field ) {
+					case 'effective_date':
+						$retval = TTDate::getDate('DATE', $value );
+						break;
+				}
+				break;
 		}
 
 		Debug::text('  Converting: '. $value .' to Display Value for Class: '. $class .' Field: '. $field .' Retval: '. $retval, __FILE__, __LINE__, __METHOD__, 10);
@@ -1351,9 +1383,19 @@ class LogDetailFactory extends Factory {
 				case 'UserFactory':
 				case 'UserListFactory':
 					unset(
+							$diff_arr['labor_standard_industry'],
 							$diff_arr['password'],
 							$diff_arr['phone_password'],
-							$diff_arr['full_name']
+							$diff_arr['password_reset_key'],
+							$diff_arr['full_name'],
+							$diff_arr['finger_print_1'],
+							$diff_arr['finger_print_2'],
+							$diff_arr['finger_print_3'],
+							$diff_arr['finger_print_4'],
+							$diff_arr['finger_print_1_updated_date'],
+							$diff_arr['finger_print_2_updated_date'],
+							$diff_arr['finger_print_3_updated_date'],
+							$diff_arr['finger_print_4_updated_date']
 							);
 					break;
 				case 'StationFactory':
@@ -1404,18 +1446,18 @@ class LogDetailFactory extends Factory {
 					if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
 						//Only log secure values.
 						if ( isset($diff_arr['cc_number']) ) {
-							$old_data['cc_number'] = $object->getSecureCreditCardNumber( Misc::decrypt( $old_data['cc_number'] ) );
-							$new_data['cc_number'] = $object->getSecureCreditCardNumber( Misc::decrypt( $new_data['cc_number'] ) );
+							$old_data['cc_number'] = ( isset($old_data['cc_number']) ) ? $object->getSecureCreditCardNumber( Misc::decrypt( $old_data['cc_number'] ) ) : '';
+							$new_data['cc_number'] = ( isset($new_data['cc_number']) ) ? $object->getSecureCreditCardNumber( Misc::decrypt( $new_data['cc_number'] ) ) : '';
 						}
 
 						if ( isset($diff_arr['bank_account']) ) {
-							$old_data['bank_account'] = $object->getSecureAccount( $old_data['bank_account'] );
-							$new_data['bank_account'] = $object->getSecureAccount( $new_data['bank_account'] );
+							$old_data['bank_account'] = ( isset($old_data['bank_account']) ) ? $object->getSecureAccount( $old_data['bank_account'] ) : '';
+							$new_data['bank_account'] = ( isset($old_data['bank_account']) ) ? $object->getSecureAccount( $new_data['bank_account'] ) : '';
 						}
 
 						if ( isset($diff_arr['cc_check']) ) {
-							$old_data['cc_check'] = $object->getSecureCreditCardCheck( $old_data['cc_check'] );
-							$new_data['cc_check'] = $object->getSecureCreditCardCheck( $new_data['cc_check'] );
+							$old_data['cc_check'] = ( isset($old_data['cc_check']) ) ? $object->getSecureCreditCardCheck( $old_data['cc_check'] ) : '';
+							$new_data['cc_check'] = ( isset($old_data['cc_check']) ) ? $object->getSecureCreditCardCheck( $new_data['cc_check'] ) : '';
 						}
 					}
 					break;
