@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: LogFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4265 $
+ * $Id: LogFactory.class.php 4265 2011-02-18 00:49:20Z ipso $
+ * $Date: 2011-02-17 16:49:20 -0800 (Thu, 17 Feb 2011) $
  */
 
 /**
@@ -185,6 +185,9 @@ class LogFactory extends Factory {
 										'-1130-description' => TTi18n::gettext('Description'),
 							);
 				break;
+			case 'list_columns':
+				$retval = Misc::arrayIntersectByKey( $this->getOptions('default_display_columns'), Misc::trimSortPrefix( $this->getOptions('columns') ) );
+				break;
 			case 'default_display_columns': //Columns that are displayed by default.
 				$retval = array(
 								'first_name',
@@ -233,7 +236,7 @@ class LogFactory extends Factory {
 		if ( is_object($this->user_obj) ) {
 			return $this->user_obj;
 		} else {
-			$ulf = new UserListFactory();
+			$ulf = TTnew( 'UserListFactory' );
 			$this->user_obj = $ulf->getById( $this->getUser() )->getCurrent();
 
 			return $this->user_obj;
@@ -438,7 +441,7 @@ class LogFactory extends Factory {
 			$id = 0;
 		}
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 
 		if ( $id == 0
 				OR $this->Validator->isResultSetWithRows(	'user',
@@ -622,7 +625,7 @@ class LogFactory extends Factory {
 				$class = new $table_class;
 				Debug::Text( 'Table Class: '. $table_class, __FILE__, __LINE__, __METHOD__,10);
 
-				$ldlf = new LogDetailListFactory();
+				$ldlf = TTnew( 'LogDetailListFactory' );
 				$ldlf->getBySystemLogIdAndCompanyId( $this->getID(), $this->getUserObject()->getCompany() );
 				if ( $ldlf->getRecordCount() > 0 ) {
 					foreach( $ldlf as $ld_obj ) {
@@ -635,7 +638,7 @@ class LogFactory extends Factory {
 					}
 
 					$detail_row = Sort::multiSort( $detail_row, 'display_field' ) ;
-					Debug::Arr( $detail_row, 'Detail Row: ', __FILE__, __LINE__, __METHOD__,10);
+					//Debug::Arr( $detail_row, 'Detail Row: ', __FILE__, __LINE__, __METHOD__,10);
 
 					return $detail_row;
 				}
