@@ -108,7 +108,8 @@ class LogRotate {
 	function getRotatedHistoryFiles( $files, $primary_file ) {
 		if ( is_array($files) ) {
 			foreach( $files as $key => $filename ) {
-				$pattern = '/'. str_replace( array('/','\\'), array('\\/','\\\\'), $primary_file) .'\.[0-9]{1,2}/i';
+				$pattern = '/'. str_replace( array('/','\\'), array('\/','\\'), $primary_file) .'\.[0-9]{1,2}/i';
+				//Debug::Text(' Pattern: '. $pattern, __FILE__, __LINE__, __METHOD__, 10);
 				if ( preg_match( $pattern, $filename) == 1 ) {
 					$retarr[] = $filename;
 				}
@@ -166,7 +167,7 @@ class LogRotate {
 				if ( $this->isFileRotatable( $filename ) == TRUE ) {
 					Debug::Text(' File IS a primary log file: '. $filename, __FILE__, __LINE__, __METHOD__, 10);
 
-					if( $this->isFileReadyToRotate( $filename, $rotate_config['frequency']) == TRUE ) {
+					if ( $this->isFileReadyToRotate( $filename, $rotate_config['frequency']) == TRUE ) {
 						Debug::Text(' File is old enough to be rotated: '. $filename , __FILE__, __LINE__, __METHOD__, 10);
 
 						$this->handleHistoryFiles( $this->getRotatedHistoryFiles( $files, $filename ), $rotate_config['history'] );
