@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3928 $
- * $Id: Misc.class.php 3928 2010-11-11 20:29:54Z ipso $
- * $Date: 2010-11-11 12:29:54 -0800 (Thu, 11 Nov 2010) $
+ * $Revision: 4845 $
+ * $Id: Misc.class.php 4845 2011-06-21 16:23:18Z ipso $
+ * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
  */
 
 /**
@@ -888,18 +888,19 @@ class Misc {
 			$server_port = ':'.$_SERVER['SERVER_PORT'];
 		}
 
-		if ( DEPLOYMENT_ON_DEMAND == TRUE AND isset($config_vars['other']['hostname']) AND $config_vars['other']['hostname'] != '' ) {
+		if ( defined('DEPLOYMENT_ON_DEMAND') AND DEPLOYMENT_ON_DEMAND == TRUE AND isset($config_vars['other']['hostname']) AND $config_vars['other']['hostname'] != '' ) {
 			$server_domain = $config_vars['other']['hostname'];
 		} else {
 			//Try server hostname/servername first, than fallback on .ini hostname setting.
-			if ( isset( $_SERVER['HTTP_HOST'] ) ) { //Use HTTP_HOST instead of SERVER_NAME first so it includes any custom ports.
+			//If the admin sets the hostname in the .ini file, always use that, as the servers hostname from the CLI could be incorrect.
+			if ( isset($config_vars['other']['hostname']) AND $config_vars['other']['hostname'] != '' ) {
+				$server_domain = $config_vars['other']['hostname'];
+			} elseif ( isset( $_SERVER['HTTP_HOST'] ) ) { //Use HTTP_HOST instead of SERVER_NAME first so it includes any custom ports.
 				$server_domain = $_SERVER['HTTP_HOST'];
 			} elseif ( isset( $_SERVER['SERVER_NAME'] ) ) {
 				$server_domain = $_SERVER['SERVER_NAME'].$server_port;
 			} elseif ( isset( $_SERVER['HOSTNAME'] ) ) {
 				$server_domain = $_SERVER['HOSTNAME'].$server_port;
-			} elseif ( isset($config_vars['other']['hostname']) AND $config_vars['other']['hostname'] != '' ) {
-				$server_domain = $config_vars['other']['hostname'];
 			} else {
 				$server_domain = 'localhost'.$server_port;
 			}
@@ -1004,6 +1005,45 @@ class Misc {
 		}
 	}
 
+	/** Delete all files in directory
+	* @param $path directory to clean
+	* @param $recursive delete files in subdirs
+	* @param $delDirs delete subdirs
+	* @param $delRoot delete root directory
+	* @access public
+	* @return success
+	*/
+	static function cleanDir( $path, $recursive = FALSE, $del_dirs = FALSE, $del_root = FALSE ) {
+		$result = TRUE;
+
+		if( !$dir = @dir($path) ) {
+			return FALSE;
+		}
+
+		while( $file = $dir->read() ) {
+			if( $file === '.' OR $file === '..' ) {
+				continue;
+			}
+
+			$full = $dir->path.DIRECTORY_SEPARATOR.$file;
+			if ( is_dir($full) AND $recursive == TRUE ) {
+				$result = self::cleanDir( $full, $recursive, $del_dirs, $del_dirs );
+			} elseif( is_file($full) ) {
+				$result = unlink($full);
+				//Debug::Text('Deleting: '. $full , __FILE__, __LINE__, __METHOD__, 10);
+			}
+
+		}
+		$dir->close();
+
+		if ( $del_root == TRUE ) {
+			//Debug::Text('Deleting Dir: '. $dir->path , __FILE__, __LINE__, __METHOD__, 10);
+			$result = rmdir($dir->path);
+		}
+
+		return $result;
+	}
+
 	static function getFileList( $start_dir, $regex_filter = NULL, $recurse = FALSE ) {
 		$files = array();
 		if ( is_dir($start_dir) AND is_readable( $start_dir ) ) {
@@ -1096,5 +1136,112 @@ class Misc {
 		return FALSE;
 	}
 
+	static function sendSystemMail( $subject, $body ) {
+		if ( $subject == '' OR $body == '' ) {
+			return FALSE;
+		}
+
+		//Email notification.
+		$cc = array('admin@'.Misc::getHostName(FALSE) );
+
+		//Get admin contacts for primary company.
+		$clf = new CompanyListFactory();
+		$clf->getById( PRIMARY_COMPANY_ID );
+		if ( $clf->getRecordCount() > 0 ) {
+			$c_obj = $clf->getCurrent();
+			$admin_user_obj = $c_obj->getUserObject( $c_obj->getAdminContact() );
+			if ( is_object( $admin_user_obj ) ) {
+				$cc[] = $admin_user_obj->getWorkEmail();
+			}
+
+			$support_user_obj = $c_obj->getUserObject( $c_obj->getSupportContact() );
+			if ( is_object($support_user_obj) ) {
+				$cc[] = $support_user_obj->getWorkEmail();
+			}
+
+			$cc = implode(',', array_unique($cc) );
+		}
+		Debug::Text('CC: '. $cc , __FILE__, __LINE__, __METHOD__, 10);
+
+		unset($clf, $c_obj, $admin_user_obj, $support_user_obj );
+
+		$to = 'root@'.Misc::getHostName(FALSE);
+		$from = APPLICATION_NAME.'@'.Misc::getHostName( FALSE );
+
+		$headers = array(
+							'From'    => $from,
+							'Subject' => $subject,
+							'cc'	  => $cc,
+							'Reply-To' => $to,
+							'Return-Path' => $to,
+							'Errors-To' => $to,
+						 );
+
+		$mail = new TTMail();
+		$mail->setTo( $to );
+		$mail->setHeaders( $headers );
+		$mail->setBody( $body );
+		$retval = $mail->Send();
+
+		return $retval;
+	}
+
+	static function disableCaching( $email_notification = TRUE ) {
+		//In case the cache directory does not exist, disabling caching can prevent errors from occurring or punches to be missed.
+		//So this should be enabled even for ON-DEMAND services just in case.
+		if ( PRODUCTION == TRUE ) {
+			//Disable caching to prevent stale cache data from being read, and further cache errors.
+			$install_obj = new Install();
+			$tmp_config_vars['cache']['enable'] = FALSE;
+			$write_config_result = $install_obj->writeConfigFile( $tmp_config_vars );
+			unset($install_obj, $tmp_config_vars);
+
+			if ( $email_notification == TRUE ) {
+				if ( $write_config_result == TRUE ) {
+					$subject = APPLICATION_NAME. ' - Error!';
+					$body = 'ERROR writing cache file, likely due to incorrect operating system permissions, disabling caching to prevent data corruption. This may result in '. APPLICATION_NAME .' performing slowly.'."\n\n";
+					$body .= Debug::getOutput();
+				} else {
+					$subject = APPLICATION_NAME. ' - Error!';
+					$body = 'ERROR writing config file, likely due to incorrect operating system permissions conflicts. Please correction permissions so '. APPLICATION_NAME .' can operate correctly.'."\n\n";
+					$body .= Debug::getOutput();
+				}
+				return self::sendSystemMail( $subject, $body );
+			}
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	static function getMapURL( $address1, $address2, $city, $province, $postal_code, $country, $service = 'google', $service_params = array() ) {
+		if ( $address1 == '' AND $address2 == '' ) {
+			return FALSE;
+		}
+
+		$url = NULL;
+
+		//Expand the country code to the full country name?
+		if ( strlen($country) == 2 ) {
+			$cf = TTnew('CompanyFactory');
+
+			$long_country = Option::getByKey($country, $cf->getOptions('country') );
+			if ( $long_country != '' ) {
+				$country = $long_country;
+			}
+		}
+
+		if ( $service == 'google' ) {
+			$base_url = 'maps.google.com/?z=16&q=';
+			$url = $base_url. urlencode($address1.' '. $city .' '. $province .' '. $postal_code .' '. $country);
+		}
+
+		if ( $url != '' ) {
+			return 'http://'.$url;
+		}
+
+		return FALSE;
+	}
 }
 ?>
\ No newline at end of file
