@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: Permission.class.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4308 $
+ * $Id: Permission.class.php 4308 2011-02-27 22:02:30Z ipso $
+ * $Date: 2011-02-27 14:02:30 -0800 (Sun, 27 Feb 2011) $
  */
 
 /**
@@ -45,9 +45,9 @@
 class Permission {
 	function getPermissions( $user_id, $company_id ) {
 
-		$plf = new PermissionListFactory();
+		$plf = TTnew( 'PermissionListFactory' );
 
-		$cache_id = 'permission::all'.$user_id.$company_id;
+		$cache_id = 'permission_all'.$user_id.$company_id;
 		$perm_arr = $plf->getCache($cache_id);
 		//Debug::Arr($perm_arr, 'Cached Perm Arr:', __FILE__, __LINE__, __METHOD__,9);
 		if ( $perm_arr === FALSE ) {
@@ -162,7 +162,7 @@ class Permission {
 			$company_id = $current_company->getId();
 		}
 
-		$plf = new PermissionListFactory();
+		$plf = TTnew( 'PermissionListFactory' );
 
 		return $plf->getBySectionAndNameAndUserIdAndCompanyId($section, $name, $user_id, $company_id)->getCurrent();
 	}
@@ -187,11 +187,24 @@ class Permission {
 	}
 
 	//Checks if the row_object_id is in the src_object_list array,
-	function isChild( $row_object_id, $src_object_list ) {
+	function isChild( $row_object_id, $src_object_list, $current_user_id = NULL ) {
 		if ( !is_numeric($row_object_id) ) {
 			return FALSE;
 		}
 
+		if ( $current_user_id == NULL OR $current_user_id == '') {
+			global $current_user;
+			if ( is_object( $current_user ) ) {
+				$current_user_id = $current_user->getId();
+			} else {
+				return FALSE;
+			}
+		}
+		//Can never be a child of themselves, so remove the current user from the child list.
+		if ( $row_object_id == $current_user_id ) {
+			return FALSE;
+		}
+
 		if ( !is_array($src_object_list) AND $src_object_list != '' ) {
 			$src_object_list = array( $src_object_list );
 		}
@@ -203,6 +216,56 @@ class Permission {
 		return FALSE;
 	}
 
+	function getPermissionHierarchyChildren( $company_id, $user_id ) {
+		$hlf = TTnew( 'HierarchyListFactory' );
+		$permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $company_id, $user_id, 100 );
+		//Debug::Arr($permission_children_ids, 'Permission Child IDs: ', __FILE__, __LINE__, __METHOD__, 10);
+
+		return $permission_children_ids;
+	}
+
+	function getPermissionChildren($section, $name, $user_id = NULL, $company_id = NULL) {
+		//Use Cache_Lite class once we need performance.
+		if ( $user_id == NULL OR $user_id == '') {
+			global $current_user;
+			if ( is_object( $current_user ) ) {
+				$user_id = $current_user->getId();
+			} else {
+				return FALSE;
+			}
+		}
+
+		if ( $company_id == NULL OR $company_id == '') {
+			global $current_company;
+			$company_id = $current_company->getId();
+		}
+
+		$permission_children_ids = $this->getPermissionHierarchyChildren( $company_id, $user_id );
+		if ( $this->Check( $section, $name ) == FALSE ) {
+			if ( $this->Check( $section, $name.'_child') ) {
+				$retarr = $permission_children_ids;
+			}
+			//Why are we including the current user in the "child" list, if they can view their own records.
+			//This essentially makes edit_child permissions include edit_own as well. Which for the editing punches
+			//there may be cases where they can edit subordinates but not themselves.
+			//Because in the SQL query, we restrict to just the child_ids.
+			//Its different view view_own/view_child as compared to edit_own/edit_child.
+			//  So we need to include the current user if they can only view their own, but exclude the current user when doing is_child checks above.
+			//Another way we could handle this is to return an array of children and owner separately, then in SQL queries combine them together.
+			if ( $this->Check( $section, $name.'_own') ) {
+				$retarr[] = $user_id;
+			}
+		} else {
+			$retarr = NULL;
+		}
+
+		if ( isset($retarr) ) {
+			return $retarr;
+		}
+
+		return NULL;
+	}
+
 	function getLastUpdatedDate( $user_id = NULL, $company_id = NULL ) {
 		//Use Cache_Lite class once we need performance.
 		if ( $user_id == NULL OR $user_id == '') {
