@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3928 $
- * $Id: PermissionControlFactory.class.php 3928 2010-11-11 20:29:54Z ipso $
- * $Date: 2010-11-11 12:29:54 -0800 (Thu, 11 Nov 2010) $
+ * $Revision: 4360 $
+ * $Id: PermissionControlFactory.class.php 4360 2011-03-14 18:30:42Z ipso $
+ * $Date: 2011-03-14 11:30:42 -0700 (Mon, 14 Mar 2011) $
  */
 
 /**
@@ -54,7 +54,7 @@ class PermissionControlFactory extends Factory {
 		$retval = NULL;
 		switch( $name ) {
 			case 'preset':
-				$pf = new PermissionFactory();
+				$pf = TTnew( 'PermissionFactory' );
 				$retval = $pf->getOptions('preset');
 				break;
 			case 'level':
@@ -98,6 +98,9 @@ class PermissionControlFactory extends Factory {
 										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
 							);
 				break;
+			case 'list_columns':
+				$retval = Misc::arrayIntersectByKey( array('name','description','level'), Misc::trimSortPrefix( $this->getOptions('columns') ) );
+				break;
 			case 'default_display_columns': //Columns that are displayed by default.
 				$retval = array(
 								'name',
@@ -137,7 +140,7 @@ class PermissionControlFactory extends Factory {
 		if ( is_object($this->company_obj) ) {
 			return $this->company_obj;
 		} else {
-			$clf = new CompanyListFactory();
+			$clf = TTnew( 'CompanyListFactory' );
 			$clf->getById( $this->getCompany() );
 			if ( $clf->getRecordCount() > 0 ) {
 				$this->company_obj = $clf->getCurrent();
@@ -158,7 +161,7 @@ class PermissionControlFactory extends Factory {
 	function setCompany($id) {
 		$id = trim($id);
 
-		$clf = new CompanyListFactory();
+		$clf = TTnew( 'CompanyListFactory' );
 
 		if ( $this->Validator->isResultSetWithRows(	'company',
 													$clf->getByID($id),
@@ -262,7 +265,7 @@ class PermissionControlFactory extends Factory {
 	}
 
 	function getUser() {
-		$pulf = new PermissionUserListFactory();
+		$pulf = TTnew( 'PermissionUserListFactory' );
 		$pulf->getByPermissionControlId( $this->getId() );
 		foreach ($pulf as $obj) {
 			$list[] = $obj->getUser();
@@ -279,7 +282,7 @@ class PermissionControlFactory extends Factory {
 		if (is_array($ids) and count($ids) > 0) {
 			//Remove any of the selected employees from other permission control objects first.
 			//So there we can switch employees from one group to another in a single action.
-			$pulf = new PermissionUserListFactory();
+			$pulf = TTnew( 'PermissionUserListFactory' );
 			//$pculf->getByCompanyIdAndUserId( $this->getCompany(), $ids );
 			$pulf->getByCompanyIdAndUserIdAndNotPermissionControlId( $this->getCompany(), $ids, (int)$this->getId() );
 			if ( $pulf->getRecordCount() > 0 ) {
@@ -292,10 +295,10 @@ class PermissionControlFactory extends Factory {
 
 			$tmp_ids = array();
 
-			$pf = new PermissionFactory();
+			$pf = TTnew( 'PermissionFactory' );
 			if ( !$this->isNew() ) {
 				//If needed, delete mappings first.
-				$pulf = new PermissionUserListFactory();
+				$pulf = TTnew( 'PermissionUserListFactory' );
 				$pulf->getByPermissionControlId( $this->getId() );
 
 				$tmp_ids = array();
@@ -318,7 +321,7 @@ class PermissionControlFactory extends Factory {
 			}
 
 			//Insert new mappings.
-			$ulf = new UserListFactory();
+			$ulf = TTnew( 'UserListFactory' );
 
 			foreach ($ids as $id) {
 				if ( isset($ids) AND !in_array($id, $tmp_ids) ) {
@@ -326,7 +329,7 @@ class PermissionControlFactory extends Factory {
 					//first, otherwise there is a gab where an employee has
 					//no permissions, this is especially bad for administrators
 					//who are currently logged in.
-					$puf = new PermissionUserFactory();
+					$puf = TTnew( 'PermissionUserFactory' );
 					$puf->setPermissionControl( $this->getId() );
 					$puf->setUser( $id );
 
@@ -352,7 +355,7 @@ class PermissionControlFactory extends Factory {
 
 		$retval = array();
 
-		$pf = new PermissionFactory();
+		$pf = TTnew( 'PermissionFactory' );
 		$sections = $pf->getOptions('section');
 		$names = $pf->getOptions('name');
 		if ( is_array($names) ) {
@@ -373,7 +376,7 @@ class PermissionControlFactory extends Factory {
 	}
 
 	function getPermission() {
-		$plf = new PermissionListFactory();
+		$plf = TTnew( 'PermissionListFactory' );
 		$plf->getByCompanyIdAndPermissionControlId( $this->getCompany(), $this->getId() );
 		if ( $plf->getRecordCount() > 0 ) {
 			Debug::Text('Found Permissions: '. $plf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
@@ -406,7 +409,7 @@ class PermissionControlFactory extends Factory {
 			//Debug::Arr($permission_arr, ' Final Permissions: '. count($permission_arr), __FILE__, __LINE__, __METHOD__,10);
 		}
 
-		$pf = new PermissionFactory();
+		$pf = TTnew( 'PermissionFactory' );
 
 		//Don't Delete all previous permissions, do that in the Permission class.
 		if ( isset($permission_arr) AND is_array($permission_arr) AND count($permission_arr) > 0 ) {
@@ -424,7 +427,7 @@ class PermissionControlFactory extends Factory {
 
 						if ( $value == 0 OR $value == 1 ) {
 							Debug::Text('    Modifying/Adding Permission: '. $name .' - Value: '. $value, __FILE__, __LINE__, __METHOD__,10);
-							$tmp_pf = new PermissionFactory();
+							$tmp_pf = TTnew( 'PermissionFactory' );
 							$tmp_pf->setCompany( $this->getCompanyObject()->getId() );
 							$tmp_pf->setPermissionControl( $this->getId() );
 							$tmp_pf->setSection( $section );
@@ -454,7 +457,7 @@ class PermissionControlFactory extends Factory {
 	}
 
 	function postSave() {
-		$pf = new PermissionFactory();
+		$pf = TTnew( 'PermissionFactory' );
 
 		$clear_cache_user_ids = array_merge( (array)$this->getUser(), (array)$this->tmp_previous_user_ids);
 		foreach( $clear_cache_user_ids as $user_id ) {
