@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: PermissionFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4671 $
+ * $Id: PermissionFactory.class.php 4671 2011-05-13 21:16:31Z ipso $
+ * $Date: 2011-05-13 14:16:31 -0700 (Fri, 13 May 2011) $
  */
 
 /**
@@ -72,7 +72,6 @@ class PermissionFactory extends Factory {
 										40 => 25,
 									);
 				break;
-
 			case 'section_group':
 				$retval = array(
 											0 => TTi18n::gettext('-- Please Choose --'),
@@ -103,7 +102,8 @@ class PermissionFactory extends Factory {
 															'other_field',
 															'document',
 															'help',
-															'permission'
+															'permission',
+															'pay_period_schedule',
 															),
 										'user' 	=> array(
 															'user',
@@ -157,7 +157,6 @@ class PermissionFactory extends Factory {
 															'pay_stub',
 															'pay_stub_amendment',
 															'wage',
-															'pay_period_schedule',
 															'roe',
 															'company_tax_deduction',
 														),
@@ -954,7 +953,7 @@ class PermissionFactory extends Factory {
 			return $this->permission_control_obj;
 		} else {
 
-			$pclf = new PermissionControlListFactory();
+			$pclf = TTnew( 'PermissionControlListFactory' );
 			$pclf->getById( $this->getPermissionControl() );
 
 			if ( $pclf->getRecordCount() == 1 ) {
@@ -977,7 +976,7 @@ class PermissionFactory extends Factory {
 	function setPermissionControl($id) {
 		$id = trim($id);
 
-		$pclf = new PermissionControlListFactory();
+		$pclf = TTnew( 'PermissionControlListFactory' );
 
 		if ( $id != 0
 				OR
@@ -1003,12 +1002,7 @@ class PermissionFactory extends Factory {
 	}
 	function setSection($section) {
 		$section = trim($section);
-/*
-		$key = Option::getByValue($section, $this->getOptions('section') );
-		if ($key !== FALSE) {
-			$section = $key;
-		}
-*/
+		
 		if ( $this->Validator->inArrayKey(	'section',
 											$section,
 											TTi18n::gettext('Incorrect section'),
@@ -1031,12 +1025,7 @@ class PermissionFactory extends Factory {
 	}
 	function setName($name) {
 		$name = trim($name);
-/*
-		$key = Option::getByValue($name, $this->getOptions('name', $this->getSection() ) );
-		if ($key !== FALSE) {
-			$name = $key;
-		}
-*/
+
 		if ( $this->Validator->inArrayKey(	'name',
 											$name,
 											TTi18n::gettext('Incorrect permission name'),
@@ -1056,7 +1045,6 @@ class PermissionFactory extends Factory {
 		} else {
 			return FALSE;
 		}
-		//return $this->data['value'];
 	}
 	function setValue($value) {
 		$value = trim($value);
@@ -1086,12 +1074,6 @@ class PermissionFactory extends Factory {
 		if ( getTTProductEdition() != TT_PRODUCT_PROFESSIONAL ) {
 			$preset_flags = array();
 		}
-/*
-										10 => 'Regular Employee',
-										20 => 'Supervisor',
-										30 => 'Payroll Administrator',
-										40 => 'Administrator'
-*/
 
 		Debug::Text('Preset: '. $preset, __FILE__, __LINE__, __METHOD__,10);
 		Debug::Arr($preset_flags, 'Preset Flags... ', __FILE__, __LINE__, __METHOD__,10);
@@ -1776,7 +1758,7 @@ class PermissionFactory extends Factory {
 
 		$this->setPermissionControl( $permission_control_id );
 
-		$pf = new PermissionFactory();
+		$pf = TTnew( 'PermissionFactory' );
 		$pf->StartTransaction();
 
 		//Delete all previous permissions for this user.
@@ -1798,7 +1780,7 @@ class PermissionFactory extends Factory {
 		}
 
 		//Clear cache for all users assigned to this permission_control_id
-		$pclf = new PermissionControlListFactory();
+		$pclf = TTnew( 'PermissionControlListFactory' );
 		$pclf->getById( $permission_control_id );
 		if ( $pclf->getRecordCount() > 0 ) {
 			$pc_obj = $pclf->getCurrent();
@@ -1826,7 +1808,7 @@ class PermissionFactory extends Factory {
 			return FALSE;
 		}
 
-		$plf = new PermissionListFactory();
+		$plf = TTnew( 'PermissionListFactory' );
 		$plf->getByCompanyIDAndPermissionControlId( $company_id, $permission_control_id );
 		foreach($plf as $permission_obj) {
 			$permission_obj->delete(TRUE);
@@ -1903,7 +1885,7 @@ class PermissionFactory extends Factory {
 
 	function preSave() {
 		//Just update any existing permissions. It would probably be faster to delete them all and re-insert though.
-		$plf = new PermissionListFactory();
+		$plf = TTnew( 'PermissionListFactory' );
 		$obj = $plf->getByCompanyIdAndPermissionControlIdAndSectionAndName( $this->getCompany(), $this->getPermissionControl(), $this->getSection(), $this->getName() )->getCurrent();
 		$this->setId( $obj->getId() );
 
@@ -1911,7 +1893,7 @@ class PermissionFactory extends Factory {
 	}
 
 	function getCacheID() {
-		$cache_id = 'permission::query_'.$this->getSection().$this->getName().$this->getPermissionControl().$this->getCompany();
+		$cache_id = 'permission_query_'.$this->getSection().$this->getName().$this->getPermissionControl().$this->getCompany();
 
 		return $cache_id;
 	}
@@ -1919,12 +1901,12 @@ class PermissionFactory extends Factory {
 	function clearCache( $user_id, $company_id ) {
 		Debug::Text(' Clearing Cache for User ID: '. $user_id, __FILE__, __LINE__, __METHOD__,10);
 
-		$cache_id = 'permission::all'.$user_id.$company_id;
+		$cache_id = 'permission_all'.$user_id.$company_id;
 		return $this->removeCache( $cache_id );
 	}
 
 	function postSave() {
-		//$cache_id = 'permission::query_'.$this->getSection().$this->getName().$this->getUser().$this->getCompany();
+		//$cache_id = 'permission_query_'.$this->getSection().$this->getName().$this->getUser().$this->getCompany();
 		//$this->removeCache( $this->getCacheID() );
 
 		return TRUE;
