@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: StationFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4453 $
+ * $Id: StationFactory.class.php 4453 2011-03-28 18:15:14Z ipso $
+ * $Date: 2011-03-28 11:15:14 -0700 (Mon, 28 Mar 2011) $
  */
 include_once('Net/IPv4.php');
 
@@ -72,7 +72,7 @@ class StationFactory extends Factory {
 					$retval[40]	= TTi18n::gettext('Barcode');
 					$retval[50]	= TTi18n::gettext('FingerPrint');
 					$retval[100] = TTi18n::gettext('TimeClock: TT-A8');
-					$retval[120] = TTi18n::gettext('TimeClock: TT-S300');
+					//$retval[120] = TTi18n::gettext('TimeClock: TT-S300');
 					$retval[150] = TTi18n::gettext('TimeClock: TT-US100');
 					//$retval[200] = TTi18n::gettext('TimeClock: ACTAtek');
 				}
@@ -173,6 +173,10 @@ class StationFactory extends Factory {
 										65536  	=> TTi18n::gettext('Authentication: Fingerprint & Proximity Card'),
 										131072 	=> TTi18n::gettext('Authentication: PIN & Fingerprint'),
 										262144	=> TTi18n::gettext('Authentication: Proximity Card & Password'),
+
+										1048576	=> TTi18n::gettext('Enable: External Proximity Card Reader'),
+										2097152 => TTi18n::gettext('Enable: Pre-Punch Message'),
+										4194304	=> TTi18n::gettext('Enable: Post-Punch Message'),
 									);
 				if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
 					$retval[128]  = TTi18n::gettext('Enable: Job');
@@ -197,13 +201,16 @@ class StationFactory extends Factory {
 										'-1160-branch_selection_type' => TTi18n::gettext('Branch Selection Type'),
 										'-1160-department_selection_type' => TTi18n::gettext('Department Selection Type'),
 										'-1160-group_selection_type' => TTi18n::gettext('Group Selection Type'),
-										
+
 										'-2000-created_by' => TTi18n::gettext('Created By'),
 										'-2010-created_date' => TTi18n::gettext('Created Date'),
 										'-2020-updated_by' => TTi18n::gettext('Updated By'),
 										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
 							);
 				break;
+			case 'list_columns':
+				$retval = Misc::arrayIntersectByKey( $this->getOptions('default_display_columns'), Misc::trimSortPrefix( $this->getOptions('columns') ) );
+				break;
 			case 'default_display_columns': //Columns that are displayed by default.
 				$retval = array(
 								'status',
@@ -283,7 +290,7 @@ class StationFactory extends Factory {
 		if ( is_object($this->company_obj) ) {
 			return $this->company_obj;
 		} else {
-			$clf = new CompanyListFactory();
+			$clf = TTnew( 'CompanyListFactory' );
 			$this->company_obj = $clf->getById( $this->getCompany() )->getCurrent();
 
 			return $this->company_obj;
@@ -296,7 +303,7 @@ class StationFactory extends Factory {
 	function setCompany($id) {
 		$id = trim($id);
 
-		$clf = new CompanyListFactory();
+		$clf = TTnew( 'CompanyListFactory' );
 
 		if ( $this->Validator->isResultSetWithRows(	'company',
 													$clf->getByID($id),
@@ -487,7 +494,7 @@ class StationFactory extends Factory {
 	function setDefaultBranch($id) {
 		$id = trim($id);
 
-		$blf = new BranchListFactory();
+		$blf = TTnew( 'BranchListFactory' );
 
 		if (
 				$id == 0
@@ -515,7 +522,7 @@ class StationFactory extends Factory {
 	function setDefaultDepartment($id) {
 		$id = trim($id);
 
-		$dlf = new DepartmentListFactory();
+		$dlf = TTnew( 'DepartmentListFactory' );
 
 		if (
 				$id == 0
@@ -549,7 +556,7 @@ class StationFactory extends Factory {
 
 		Debug::Text('Job ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
 		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
-			$jlf = new JobListFactory();
+			$jlf = TTnew( 'JobListFactory' );
 		}
 
 		if (
@@ -584,7 +591,7 @@ class StationFactory extends Factory {
 
 		Debug::Text('Job Item ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
 		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
-			$jilf = new JobItemListFactory();
+			$jilf = TTnew( 'JobItemListFactory' );
 		}
 
 		if (
@@ -613,7 +620,7 @@ class StationFactory extends Factory {
 	function setTimeZone($time_zone) {
 		$time_zone = trim($time_zone);
 
-		$upf = new UserPreferenceFactory();
+		$upf = TTnew( 'UserPreferenceFactory' );
 
 		$key = Option::getByValue($time_zone, $upf->getOptions('time_zone') );
 		if ($key !== FALSE) {
@@ -659,7 +666,7 @@ class StationFactory extends Factory {
 	}
 
 	function getGroup() {
-		$lf = new StationUserGroupListFactory();
+		$lf = TTnew( 'StationUserGroupListFactory' );
 		$lf->getByStationId( $this->getId() );
 		foreach ($lf as $obj) {
 			$list[] = $obj->getGroup();
@@ -678,7 +685,7 @@ class StationFactory extends Factory {
 
 			if ( !$this->isNew() ) {
 				//If needed, delete mappings first.
-				$lf_a = new StationUserGroupListFactory();
+				$lf_a = TTnew( 'StationUserGroupListFactory' );
 				$lf_a->getByStationId( $this->getId() );
 
 				foreach ($lf_a as $obj) {
@@ -699,11 +706,11 @@ class StationFactory extends Factory {
 			}
 
 			//Insert new mappings.
-			$lf_b = new UserGroupListFactory();
+			$lf_b = TTnew( 'UserGroupListFactory' );
 
 			foreach ($ids as $id) {
 				if ( isset($ids) AND !in_array($id, $tmp_ids) ) {
-					$f = new StationUserGroupFactory();
+					$f = TTnew( 'StationUserGroupFactory' );
 					$f->setStation( $this->getId() );
 					$f->setGroup( $id );
 
@@ -748,7 +755,7 @@ class StationFactory extends Factory {
 	}
 
 	function getBranch() {
-		$lf = new StationBranchListFactory();
+		$lf = TTnew( 'StationBranchListFactory' );
 		$lf->getByStationId( $this->getId() );
 		foreach ($lf as $obj) {
 			$list[] = $obj->getBranch();
@@ -768,7 +775,7 @@ class StationFactory extends Factory {
 
 			if ( !$this->isNew() ) {
 				//If needed, delete mappings first.
-				$lf_a = new StationBranchListFactory();
+				$lf_a = TTnew( 'StationBranchListFactory' );
 				$lf_a->getByStationId( $this->getId() );
 
 				foreach ($lf_a as $obj) {
@@ -789,11 +796,11 @@ class StationFactory extends Factory {
 			}
 
 			//Insert new mappings.
-			$lf_b = new BranchListFactory();
+			$lf_b = TTnew( 'BranchListFactory' );
 
 			foreach ($ids as $id) {
 				if ( isset($ids) AND !in_array($id, $tmp_ids) ) {
-					$f = new StationBranchFactory();
+					$f = TTnew( 'StationBranchFactory' );
 					$f->setStation( $this->getId() );
 					$f->setBranch( $id );
 
@@ -838,7 +845,7 @@ class StationFactory extends Factory {
 	}
 
 	function getDepartment() {
-		$lf = new StationDepartmentListFactory();
+		$lf = TTnew( 'StationDepartmentListFactory' );
 		$lf->getByStationId( $this->getId() );
 		foreach ($lf as $obj) {
 			$list[] = $obj->getDepartment();
@@ -857,7 +864,7 @@ class StationFactory extends Factory {
 
 			if ( !$this->isNew() ) {
 				//If needed, delete mappings first.
-				$lf_a = new StationDepartmentListFactory();
+				$lf_a = TTnew( 'StationDepartmentListFactory' );
 				$lf_a->getByStationId( $this->getId() );
 
 				foreach ($lf_a as $obj) {
@@ -878,11 +885,11 @@ class StationFactory extends Factory {
 			}
 
 			//Insert new mappings.
-			$lf_b = new DepartmentListFactory();
+			$lf_b = TTnew( 'DepartmentListFactory' );
 
 			foreach ($ids as $id) {
 				if ( isset($ids) AND !in_array($id, $tmp_ids) ) {
-					$f = new StationDepartmentFactory();
+					$f = TTnew( 'StationDepartmentFactory' );
 					$f->setStation( $this->getId() );
 					$f->setDepartment( $id );
 
@@ -904,7 +911,7 @@ class StationFactory extends Factory {
 	}
 
 	function getIncludeUser() {
-		$lf = new StationIncludeUserListFactory();
+		$lf = TTnew( 'StationIncludeUserListFactory' );
 		$lf->getByStationId( $this->getId() );
 		foreach ($lf as $obj) {
 			$list[] = $obj->getIncludeUser();
@@ -923,7 +930,7 @@ class StationFactory extends Factory {
 
 			if ( !$this->isNew() ) {
 				//If needed, delete mappings first.
-				$lf_a = new StationIncludeUserListFactory();
+				$lf_a = TTnew( 'StationIncludeUserListFactory' );
 				$lf_a->getByStationId( $this->getId() );
 
 				foreach ($lf_a as $obj) {
@@ -944,11 +951,11 @@ class StationFactory extends Factory {
 			}
 
 			//Insert new mappings.
-			$lf_b = new UserListFactory();
+			$lf_b = TTnew( 'UserListFactory' );
 
 			foreach ($ids as $id) {
 				if ( isset($ids) AND !in_array($id, $tmp_ids) ) {
-					$f = new StationIncludeUserFactory();
+					$f = TTnew( 'StationIncludeUserFactory' );
 					$f->setStation( $this->getId() );
 					$f->setIncludeUser( $id );
 
@@ -969,7 +976,7 @@ class StationFactory extends Factory {
 		return FALSE;
 	}
 	function getExcludeUser() {
-		$lf = new StationExcludeUserListFactory();
+		$lf = TTnew( 'StationExcludeUserListFactory' );
 		$lf->getByStationId( $this->getId() );
 		foreach ($lf as $obj) {
 			$list[] = $obj->getExcludeUser();
@@ -988,7 +995,7 @@ class StationFactory extends Factory {
 
 			if ( !$this->isNew() ) {
 				//If needed, delete mappings first.
-				$lf_a = new StationExcludeUserListFactory();
+				$lf_a = TTnew( 'StationExcludeUserListFactory' );
 				$lf_a->getByStationId( $this->getId() );
 
 				foreach ($lf_a as $obj) {
@@ -1009,11 +1016,11 @@ class StationFactory extends Factory {
 			}
 
 			//Insert new mappings.
-			$lf_b = new UserListFactory();
+			$lf_b = TTnew( 'UserListFactory' );
 
 			foreach ($ids as $id) {
 				if ( isset($ids) AND !in_array($id, $tmp_ids) ) {
-					$f = new StationExcludeUserFactory();
+					$f = TTnew( 'StationExcludeUserFactory' );
 					$f->setStation( $this->getId() );
 					$f->setExcludeUser( $id );
 
@@ -1287,7 +1294,7 @@ class StationFactory extends Factory {
 			return FALSE;
 		}
 
-		$slf = new StationListFactory();
+		$slf = TTnew( 'StationListFactory' );
 		$slf->getById( $id );
 		if ( $slf->getRecordCount() == 1 ) {
 			$ph = array(
@@ -1310,7 +1317,7 @@ class StationFactory extends Factory {
 			return FALSE;
 		}
 
-		$slf = new StationListFactory();
+		$slf = TTnew( 'StationListFactory' );
 		$slf->getById( $id );
 		if ( $slf->getRecordCount() == 1 ) {
 			$ph = array(
@@ -1333,7 +1340,7 @@ class StationFactory extends Factory {
 			return FALSE;
 		}
 
-		$slf = new StationListFactory();
+		$slf = TTnew( 'StationListFactory' );
 		$slf->getById( $id );
 		if ( $slf->getRecordCount() == 1 ) {
 			$ph = array(
@@ -1689,7 +1696,7 @@ class StationFactory extends Factory {
 			return FALSE;
 		}
 
-		$slf = new StationListFactory();
+		$slf = TTnew( 'StationListFactory' );
 		$slf->getById( $id );
 		if ( $slf->getRecordCount() == 1 ) {
 			$ph = array(
@@ -1757,7 +1764,7 @@ class StationFactory extends Factory {
 
 		if ( in_array( $this->getType(), array(10,25) ) AND preg_match('/[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}(\/[0-9]{1,2})*/', $source) ) {
 			Debug::text('Source is an IP address!', __FILE__, __LINE__, __METHOD__, 10);
-		} elseif ( in_array( $this->getType(), array(10,25) ) )  {
+		} elseif ( in_array( $this->getType(), array(10,25) ) AND !in_array( strtolower( $this->getStation() ), $this->getOptions('station_reserved_word') ) )  {
 			Debug::text('Source is NOT an IP address, do hostname lookup: '. $source , __FILE__, __LINE__, __METHOD__, 10);
 
 			$hostname_lookup = $this->getCache( $remote_addr.$source );
@@ -1896,7 +1903,7 @@ class StationFactory extends Factory {
 			}
 		}
 
-		$slf = new StationListFactory();
+		$slf = TTnew( 'StationListFactory' );
 		$slf->getByUserIdAndStatusAndType($user_id, 'ENABLED', $type);
 		Debug::text('Station ID: '. $station_id .' Type: '. $type .' Found Stations: '. $slf->getRecordCount(), __FILE__, __LINE__, __METHOD__, 10);
 		foreach($slf as $station) {
@@ -1911,6 +1918,42 @@ class StationFactory extends Factory {
 		return FALSE;
 	}
 
+	static function getOrCreatePCStation( $station_id, $company_id ) {
+		Debug::text('Checking for Station ID: '. $station_id .' Company ID: '. $company_id, __FILE__, __LINE__, __METHOD__, 10);
+		$slf = new StationListFactory();
+		$slf->getByStationIdandCompanyId( $station_id, $company_id );
+		if ( $slf->getRecordCount() == 1 ) {
+			$retval = $slf->getCurrent()->getStation();
+		} else {
+			Debug::text('Station ID: '. $station_id .' does not exist, creating new station', __FILE__, __LINE__, __METHOD__, 10);
+
+			//Insert new station
+			$sf = TTnew( 'StationFactory' );
+			$sf->setCompany( $company_id );
+			$sf->setStatus( 'ENABLED' );
+			$sf->setType( 'PC' );
+			$sf->setSource( $_SERVER['REMOTE_ADDR'] );
+			$sf->setStation();
+			$sf->setDescription( substr( $_SERVER['HTTP_USER_AGENT'], 0, 250) );
+			if ( $sf->Save(FALSE) ) {
+				$retval = $sf->getStation();
+			}
+		}
+
+		Debug::text('Returning Station ID: '. $station_id, __FILE__, __LINE__, __METHOD__, 10);
+		return $retval;
+	}
+
+	function Validate() {
+		if ( $this->getDescription() == '' ) {
+			$this->Validator->isTrue(		'description',
+											FALSE,
+											TTi18n::gettext('Description must be specified'));
+		}
+
+		return TRUE;
+	}
+
 	function preSave() {
 		//New stations are deny all by default, so if they haven't
 		//set the selection types, default them to only selected, so
@@ -1932,7 +1975,7 @@ class StationFactory extends Factory {
 		$this->removeCache( $this->getStation() );
 /*
 		foreach ($this->getUser() as $user_id ) {
-			$cache_id = 'station::checkAllowed_'.$this->getId().$user_id;
+			$cache_id = 'station_checkAllowed_'.$this->getId().$user_id;
 			$this->removeCache( $cache_id );
 		}
 */
