@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2740 $
- * $Id: StationIncludeUserFactory.class.php 2740 2009-08-19 20:21:50Z ipso $
- * $Date: 2009-08-19 13:21:50 -0700 (Wed, 19 Aug 2009) $
+ * $Revision: 4104 $
+ * $Id: StationIncludeUserFactory.class.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 
 /**
@@ -54,7 +54,7 @@ class StationIncludeUserFactory extends Factory {
 	function setStation($id) {
 		$id = trim($id);
 
-		$slf = new StationListFactory();
+		$slf = TTnew( 'StationListFactory' );
 
 		if (	$id == 0
 				OR
@@ -88,7 +88,7 @@ class StationIncludeUserFactory extends Factory {
 	function setIncludeUser($id) {
 		$id = trim($id);
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 
 		if ( $this->Validator->isResultSetWithRows(	'include_user',
 													$ulf->getByID($id),
