@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: TTDate.class.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4845 $
+ * $Id: TTDate.class.php 4845 2011-06-21 16:23:18Z ipso $
+ * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
  */
 
 /**
@@ -138,13 +138,19 @@ class TTDate {
 		return self::$time_zone;
 	}
 	public static function setTimeZone($time_zone = NULL) {
-		global $config_vars;
+		global $config_vars, $current_user_prefs;
 
 		$time_zone = Misc::trimSortPrefix( trim($time_zone) );
 
 		//Default to system local timezone if no timezone is specified.
 		if ( $time_zone == '' OR strtolower($time_zone) == 'system/localtime' ) { //System/Localtime is an invalid timezone, so default to GMT instead.
-			if ( isset($config_vars['other']['system_timezone']) ) {
+			if ( isset($current_user_prefs) AND is_object($current_user_prefs) ) {
+				//When TTDate is called from the API directly, its not called statically, so
+				//this forces __construct() to call setTimeZone and for the timezone to be set back to the system defined timezone after
+				//$current_user->getUserPreferenceObject()->setDateTimePreferences(); is called.
+				//This checks to see if a user is logged in and uses their own preferences instead.
+				$time_zone = $current_user_prefs->getTimeZone();
+			} elseif ( isset($config_vars['other']['system_timezone']) ) {
 				$time_zone = $config_vars['other']['system_timezone'];
 			} else {
 				//$time_zone = date('e'); //Newer versions of PHP return System/Localtime which is invalid, so force to GMT instead
@@ -167,7 +173,7 @@ class TTDate {
 
 			global $db;
 			if ( isset($db) AND is_object($db) AND strncmp($db->databaseType,'mysql',5) == 0 ) {
-				if ( @$db->Execute('SET SESSION time_zone=\''. $time_zone .'\'') == FALSE ) {
+				if ( @$db->Execute('SET SESSION time_zone='. $db->qstr($time_zone) ) == FALSE ) {
 					return FALSE;
 				}
 			}
@@ -414,6 +420,7 @@ class TTDate {
 	public static function parseDateTime($str) {
 		//List of all formats that require custom parsing.
 		$custom_parse_formats = array(
+									'd-M-y',
 									'd/m/Y',
 									'd/m/y',
 									'd-m-y',
@@ -440,6 +447,14 @@ class TTDate {
 			//Match to: Year, Month, Day
 			$textual_month = FALSE;
 			switch (self::$date_format) {
+				case 'd-M-y':
+					//Two digit year, custom parsing for it to have more control over 1900 or 2000 years.
+					//PHP handles it like this: values between 00-69 are mapped to 2000-2069 and 70-99 to 1970-1999
+					//Debug::text('  Parsing format: M-d-y', __FILE__, __LINE__, __METHOD__, 10);
+					$date_pattern = '/([0-9]{1,2})\-([A-Za-z]{3})\-([0-9]{2,4})/';
+					$match_arr = array( 'year' => 3, 'month' => 2, 'day' => 1 );
+					$textual_month = TRUE;
+					break;
 				case 'M-d-y':
 				case 'M-d-Y':
 					//Debug::text('  Parsing format: M-d-y', __FILE__, __LINE__, __METHOD__, 10);
@@ -479,7 +494,6 @@ class TTDate {
 			if ( isset($date_pattern) ) {
 				//Make regex less strict, and attempt to match time as well.
 				$date_result = preg_match( $date_pattern, $str, $date_matches );
-				//var_dump($date_matches);
 
 				if ( $date_result != 0 ) {
 					//Debug::text('  Custom Date Match Success!', __FILE__, __LINE__, __METHOD__, 10);
@@ -491,19 +505,17 @@ class TTDate {
 									);
 
 					//Handle dates less then 1970
-					//If the two digit year is greater then current year plus 10 we assume its
-					//a 1990 year.
+					//If the two digit year is greater then current year plus 10 we assume its a 1900 year.
 					//Debug::text('Passed Year: '. $date_arr['year'] ." Current Year threshold: ". (date('y')+10), __FILE__, __LINE__, __METHOD__, 10);
 					if ( strlen($date_arr['year']) == 2 AND $date_arr['year'] > (date('y')+10) ) {
 						$date_arr['year'] = (int)'19'.$date_arr['year'];
 					}
-
 					//Debug::Arr($date_arr, 'Date Match Arr!', __FILE__, __LINE__, __METHOD__, 10);
 
 					//; preg_match('/[a-z]/', $date_arr['month']) != 0
 					if ( $textual_month == TRUE) {
 						$numeric_month = self::$month_arr[strtolower($date_arr['month'])];
-						Debug::text('  Numeric Month: '. $numeric_month, __FILE__, __LINE__, __METHOD__, 10);
+						//Debug::text('  Numeric Month: '. $numeric_month, __FILE__, __LINE__, __METHOD__, 10);
 						$date_arr['month'] = $numeric_month;
 						unset($numeric_month);
 					}
@@ -538,7 +550,7 @@ class TTDate {
 				$epoch = FALSE;
 			}
 
-			//Debug::text('  Parsed Date: '. TTDate::getDate('DATE+TIME', $epoch) , __FILE__, __LINE__, __METHOD__, 10);
+			//Debug::text('  Parsed Date: '. TTDate::getDate('DATE+TIME', $epoch) .' ('.$epoch.')', __FILE__, __LINE__, __METHOD__, 10);
 		}
 
 		return $epoch;
@@ -1012,7 +1024,7 @@ class TTDate {
 		}
 
 		$retval=mktime(0,0,0,date('m',$epoch),date('d',$epoch),date('Y',$epoch));
-		//Debug::text('Begin Day Epoch: '. $retval .' - '. TTDate::getDate('DATE+TIME', $retval) .' Epoch: '. $epoch .' - '. TTDate::getDate('DATE+TIME', $epoch)  , __FILE__, __LINE__, __METHOD__, 10);
+		//Debug::text('Begin Day Epoch: '. $retval .' - '. TTDate::getDate('DATE+TIME', $retval) .' Epoch: '. $epoch .' - '. TTDate::getDate('DATE+TIME', $epoch) .' TimeZone: '. self::getTimeZone() , __FILE__, __LINE__, __METHOD__, 10);
 		return $retval;
 	}
 
@@ -1840,7 +1852,7 @@ class TTDate {
 		$retarr = array(
 						'-1000-custom_date' => TTi18n::gettext('Custom Dates'), // Select Start/End dates from calendar.
 						//'-1005-custom_time' => TTi18n::gettext('Custom Date/Time'), // Select Start/End dates & time from calendar.
-						//'-1008-custom_pay_period' => TTi18n::gettext('Custom Pay Periods'), //Select pay periods individually
+						'-1008-custom_pay_period' => TTi18n::gettext('Custom Pay Periods'), //Select pay periods individually
 						'-1010-today' => TTi18n::gettext('Today'),
 						'-1020-yesterday' => TTi18n::gettext('Yesterday'),
 						'-1030-last_24_hours' => TTi18n::gettext('Last 24 Hours'),
@@ -1860,7 +1872,7 @@ class TTDate {
 						'-1310-last_month' => TTi18n::gettext('Last Month'),
 						'-1312-last_2_months' => TTi18n::gettext('Last 2 Months'),
 						'-1320-last_30_days' => TTi18n::gettext('Last 30 Days'),
-						'-1320-last_60_days' => TTi18n::gettext('Last 60 Days'),
+						'-1322-last_60_days' => TTi18n::gettext('Last 60 Days'),
 
 						'-1400-this_quarter' => TTi18n::gettext('This Quarter'),
 						'-1410-last_quarter' => TTi18n::gettext('Last Quarter'),
@@ -1878,9 +1890,14 @@ class TTDate {
 						'-1610-last_6_months' => TTi18n::gettext('Last 6 Months'),
 						'-1620-last_9_months' => TTi18n::gettext('Last 9 Months'),
 						'-1630-last_12_months' => TTi18n::gettext('Last 12 Months'),
+						'-1640-last_18_months' => TTi18n::gettext('Last 18 Months'),
+						'-1650-last_24_months' => TTi18n::gettext('Last 24 Months'),
 
 						'-1700-this_year' => TTi18n::gettext('This Year (Year-To-Date)'),
 						'-1710-last_year' => TTi18n::gettext('Last Year'),
+						'-1720-last_2_years' => TTi18n::gettext('Last Two Years'),
+						'-1730-last_3_years' => TTi18n::gettext('Last Three Years'),
+						'-1740-last_5_years' => TTi18n::gettext('Last Five Years'),
 						'-1990-all_years' => TTi18n::gettext('All Years'),
 					   );
 		return $retarr;
@@ -1919,7 +1936,12 @@ class TTDate {
 					$end_date = $params['end_date'];
 				}
 				break;
-
+			case 'custom_pay_period':
+				//Params must pass pay_period_ids
+				if ( isset($params['pay_period_id']) ) {
+					$pay_period_ids = (array)$params['pay_period_id'];
+				}
+				break;
 			case 'today':
 				$start_date = TTDate::getBeginDayEpoch( $epoch );
 				$end_date = TTDate::getEndDayEpoch( $epoch );
@@ -1980,7 +2002,7 @@ class TTDate {
 				//Since we allow multiple pay_period schedules to be selected, we have to return pay_period_ids, not start/end dates.
 				if ( $time_period == 'this_pay_period' ) {
 					Debug::text('this_pay_period', __FILE__, __LINE__, __METHOD__,10);
-					$pplf = new PayPeriodListFactory();
+					$pplf = TTnew( 'PayPeriodListFactory' );
 					$pplf->getThisPayPeriodByCompanyIdAndPayPeriodScheduleIdAndDate( $user_obj->getCompany(), $params['pay_period_schedule_id'], time() );
 					if ( $pplf->getRecordCount() > 0 ) {
 						foreach( $pplf as $pp_obj ) {
@@ -1989,7 +2011,7 @@ class TTDate {
 					}
 				} elseif ( $time_period == 'last_pay_period' ) {
 					Debug::text('last_pay_period', __FILE__, __LINE__, __METHOD__,10);
-					$pplf = new PayPeriodListFactory();
+					$pplf = TTnew( 'PayPeriodListFactory' );
 					$pplf->getLastPayPeriodByCompanyIdAndPayPeriodScheduleIdAndDate( $user_obj->getCompany(), $params['pay_period_schedule_id'], time() );
 					if ( $pplf->getRecordCount() > 0 ) {
 						foreach( $pplf as $pp_obj ) {
@@ -2114,6 +2136,14 @@ class TTDate {
 				$end_date = TTDate::getEndDayEpoch( (TTDate::getMiddleDayEpoch( $epoch )-86400) );
 				$start_date = mktime(0,0,0, TTDate::getMonth( $end_date), TTDate::getDayOfMonth( $end_date ), (TTDate::getYear( $end_date )-1) );
 				break;
+			case 'last_18_months':
+				$end_date = TTDate::getEndDayEpoch( (TTDate::getMiddleDayEpoch( $epoch )-86400) );
+				$start_date = mktime(0,0,0, TTDate::getMonth( $end_date )-18, TTDate::getDayOfMonth( $end_date ), TTDate::getYear( $end_date ) );
+				break;
+			case 'last_24_months':
+				$end_date = TTDate::getEndDayEpoch( (TTDate::getMiddleDayEpoch( $epoch )-86400) );
+				$start_date = mktime(0,0,0, TTDate::getMonth( $end_date )-24, TTDate::getDayOfMonth( $end_date ), TTDate::getYear( $end_date ) );
+				break;
 			case 'this_year':
 				$start_date = TTDate::getBeginYearEpoch( $epoch );
 				$end_date = TTDate::getEndYearEpoch( $epoch );
@@ -2122,6 +2152,18 @@ class TTDate {
 				$start_date = TTDate::getBeginYearEpoch( (TTDate::getBeginYearEpoch( $epoch )-86400) );
 				$end_date = TTDate::getEndYearEpoch( (TTDate::getBeginYearEpoch( $epoch )-86400) );
 				break;
+			case 'last_2_years':
+				$end_date = TTDate::getEndYearEpoch( (TTDate::getBeginYearEpoch( $epoch )-86400) );
+				$start_date = mktime(0,0,0, TTDate::getMonth( $end_date ), TTDate::getDayOfMonth( $end_date ), TTDate::getYear( $end_date )-2 );
+				break;
+			case 'last_3_years':
+				$end_date = TTDate::getEndYearEpoch( (TTDate::getBeginYearEpoch( $epoch )-86400) );
+				$start_date = mktime(0,0,0, TTDate::getMonth( $end_date ), TTDate::getDayOfMonth( $end_date ), TTDate::getYear( $end_date )-3 );
+				break;
+			case 'last_5_years':
+				$end_date = TTDate::getEndYearEpoch( (TTDate::getBeginYearEpoch( $epoch )-86400) );
+				$start_date = mktime(0,0,0, TTDate::getMonth( $end_date ), TTDate::getDayOfMonth( $end_date ), TTDate::getYear( $end_date )-5 );
+				break;
 			case 'all_years':
 				$start_date = TTDate::getBeginYearEpoch( (TTDate::getBeginYearEpoch( 31564800 )-86400) );
 				$end_date = TTDate::getEndYearEpoch( time()+(86400*(365*2)) );
