@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3928 $
- * $Id: TTi18n.class.php 3928 2010-11-11 20:29:54Z ipso $
- * $Date: 2010-11-11 12:29:54 -0800 (Thu, 11 Nov 2010) $
+ * $Revision: 4676 $
+ * $Id: TTi18n.class.php 4676 2011-05-13 21:31:41Z ipso $
+ * $Date: 2011-05-13 14:31:41 -0700 (Fri, 13 May 2011) $
  */
 
 /*
@@ -445,7 +445,7 @@ class TTi18n {
 			  if ( is_array( $user_locale_pref ) ) {
 				 foreach( $user_locale_pref as $locale ) {
 					  Debug::text('aSetting Locale: ' . $user_locale_pref,  __FILE__, __LINE__, __METHOD__,10);
-					  if ( $success = self::setLocale( $locale, $category ) ) {
+					  if ( $success == self::setLocale( $locale, $category ) ) {
 						 break;
 					  }
 				 }
@@ -471,7 +471,7 @@ class TTi18n {
 				}
 
 				Debug::text('cSetting Locale: ' . $locale,  __FILE__, __LINE__, __METHOD__,10);
-				if ( $success = self::setLocale( $locale, $category ) ) {
+				if ( $success == self::setLocale( $locale, $category ) ) {
 					break;
 				}
 		   }
