@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3321 $
- * $Id: UserDateFactory.class.php 3321 2010-01-28 17:51:23Z ipso $
- * $Date: 2010-01-28 09:51:23 -0800 (Thu, 28 Jan 2010) $
+ * $Revision: 4104 $
+ * $Id: UserDateFactory.class.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 
 /**
@@ -53,7 +53,7 @@ class UserDateFactory extends Factory {
 		if ( is_object($this->user_obj) ) {
 			return $this->user_obj;
 		} else {
-			$ulf = new UserListFactory();
+			$ulf = TTnew( 'UserListFactory' );
 			$this->user_obj = $ulf->getById( $this->getUser() )->getCurrent();
 
 			return $this->user_obj;
@@ -64,7 +64,7 @@ class UserDateFactory extends Factory {
 		if ( is_object($this->pay_period_obj) ) {
 			return $this->pay_period_obj;
 		} else {
-			$pplf = new PayPeriodListFactory();
+			$pplf = TTnew( 'PayPeriodListFactory' );
 			$this->pay_period_obj = $pplf->getById( $this->getPayPeriod() )->getCurrent();
 
 			return $this->pay_period_obj;
@@ -79,7 +79,7 @@ class UserDateFactory extends Factory {
 	function setUser($id) {
 		$id = trim($id);
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 
 		if ( $id == 0
 				OR $this->Validator->isResultSetWithRows(	'user',
@@ -104,7 +104,7 @@ class UserDateFactory extends Factory {
 			//This might happen when the MySQL server is in one timezone (ie: CST) and the pay period
 			//schedule is set to another timezone (ie: PST)
 			//This could severely slow down a lot of operations though, so make this specific to MySQL only.
-			$pplf = new PayPeriodListFactory();
+			$pplf = TTnew( 'PayPeriodListFactory' );
 			$pplf->getByUserIdAndEndDate( $this->getUser(), $this->getDateStamp() );
 			$pay_period = $pplf->getCurrent();
 
@@ -134,7 +134,7 @@ class UserDateFactory extends Factory {
 			$id = $this->findPayPeriod();
 		}
 
-		$pplf = new PayPeriodListFactory();
+		$pplf = TTnew( 'PayPeriodListFactory' );
 
 		//Allow NULL pay period, incase its an absence or something in the future.
 		//Cron will fill in the pay period later.
@@ -198,7 +198,7 @@ class UserDateFactory extends Factory {
 			//Find the employees preferred timezone, base the user date off that instead of the pay period timezone,
 			//as it can be really confusing to the user if they punch in at 10AM on Sept 27th, but it records as Sept 26th because
 			//the PP Schedule timezone is 12hrs different or something.
-			$uplf = new UserPreferenceListFactory();
+			$uplf = TTnew( 'UserPreferenceListFactory' );
 			$uplf->getByUserID( $user_id );
 			if ( $uplf->getRecordCount() > 0 ) {
 				$timezone = $uplf->getCurrent()->getTimeZone();
@@ -208,7 +208,7 @@ class UserDateFactory extends Factory {
 		$date = TTDate::convertTimeZone( $date, $timezone );
 		Debug::text(' Using TimeZone: '. $timezone .' Date: '. TTDate::getDate('DATE+TIME', $date) .'('.$date.')', __FILE__, __LINE__, __METHOD__,10);
 
-		$udlf = new UserDateListFactory();
+		$udlf = TTnew( 'UserDateListFactory' );
 		$udlf->getByUserIdAndDate( $user_id, $date );
 		if ( $udlf->getRecordCount() == 1 ) {
 			$id = $udlf->getCurrent()->getId();
@@ -218,7 +218,7 @@ class UserDateFactory extends Factory {
 			Debug::text(' Inserting new UserDate row.', __FILE__, __LINE__, __METHOD__,10);
 
 			//Insert new row
-			$udf = new UserDateFactory();
+			$udf = TTnew( 'UserDateFactory' );
 			$udf->setUser( $user_id );
 			$udf->setDateStamp( $date );
 			$udf->setPayPeriod();
@@ -305,7 +305,7 @@ class UserDateFactory extends Factory {
 
 
 		//Make sure the date isn't BEFORE the first pay period.
-		$pplf = new PayPeriodListFactory();
+		$pplf = TTnew( 'PayPeriodListFactory' );
 		$pplf->getByUserID( $this->getUser(), NULL, NULL, NULL, array('a.start_date' => 'asc') );
 		if ( $pplf->getRecordCount() > 0 ) {
 			$first_pp_obj = $pplf->getCurrent();
@@ -327,7 +327,7 @@ class UserDateFactory extends Factory {
 		if ( $this->getDeleted() == TRUE ) {
 			//Delete (for real) any already deleted rows in hopes to prevent a
 			//unique index conflict across user_id,date_stamp,deleted
-			$udlf = new UserDateListFactory();
+			$udlf = TTnew( 'UserDateListFactory' );
 			$udlf->deleteByUserIdAndDateAndDeleted( $this->getUser(), $this->getDateStamp(), TRUE );
 		}
 
@@ -344,7 +344,7 @@ class UserDateFactory extends Factory {
 
 			//Delete schedules assigned to this user date.
 			//Turn off any re-calc's
-			$slf = new ScheduleListFactory();
+			$slf = TTnew( 'ScheduleListFactory' );
 			$slf->getByUserDateID( $this->getId() );
 			if ( $slf->getRecordCount() > 0 ) {
 				foreach( $slf as $schedule_obj ) {
@@ -353,7 +353,7 @@ class UserDateFactory extends Factory {
 				}
 			}
 
-			$pclf = new PunchControlListFactory();
+			$pclf = TTnew( 'PunchControlListFactory' );
 			$pclf->getByUserDateID( $this->getId() );
 			if ( $pclf->getRecordCount() > 0 ) {
 				foreach( $pclf as $pc_obj ) {
@@ -363,7 +363,7 @@ class UserDateFactory extends Factory {
 			}
 
 			//Delete exceptions
-			$elf = new ExceptionListFactory();
+			$elf = TTnew( 'ExceptionListFactory' );
 			$elf->getByUserDateID( $this->getId() );
 			if ( $elf->getRecordCount() > 0 ) {
 				foreach( $elf as $e_obj ) {
@@ -373,7 +373,7 @@ class UserDateFactory extends Factory {
 			}
 
 			//Delete user_date_total rows too
-			$udtlf = new UserDateTotalListFactory();
+			$udtlf = TTnew( 'UserDateTotalListFactory' );
 			$udtlf->getByUserDateID( $this->getId() );
 			if ( $udtlf->getRecordCount() > 0 ) {
 				foreach( $udtlf as $udt_obj ) {
