@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2858 $
- * $Id: Wage.class.php 2858 2009-09-29 18:12:05Z ipso $
- * $Date: 2009-09-29 11:12:05 -0700 (Tue, 29 Sep 2009) $
+ * $Revision: 4845 $
+ * $Id: Wage.class.php 4845 2011-06-21 16:23:18Z ipso $
+ * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
  */
 
 /**
@@ -93,7 +93,7 @@ class Wage {
 		if ( is_object($this->user_obj) ) {
 			return $this->user_obj;
 		} else {
-			$ulf = new UserListFactory();
+			$ulf = TTnew( 'UserListFactory' );
 			$this->user_obj = $ulf->getById( $this->getUser() )->getCurrent();
 
 			return $this->user_obj;
@@ -104,7 +104,7 @@ class Wage {
 		if ( is_object($this->pay_stub_entry_account_link_obj) ) {
 			return $this->pay_stub_entry_account_link_obj;
 		} else {
-			$pseallf = new PayStubEntryAccountLinkListFactory();
+			$pseallf = TTnew( 'PayStubEntryAccountLinkListFactory' );
 			$pseallf->getByCompanyId( $this->getUserObject()->getCompany() );
 			if ( $pseallf->getRecordCount() > 0 ) {
 				$this->pay_stub_entry_account_link_obj = $pseallf->getCurrent();
@@ -120,7 +120,7 @@ class Wage {
 			return $this->user_tax_obj;
 		} else {
 
-			$utlf = new UserTaxListFactory();
+			$utlf = TTnew( 'UserTaxListFactory' );
 			$utlf->getByUserId( $this->getUser() );
 			if ( $utlf->getRecordCount() > 0 ) {
 				$this->user_tax_obj = $utlf->getCurrent();
@@ -137,7 +137,7 @@ class Wage {
 			AND is_object($this->user_wage_obj[$user_wage_id]) ) {
 			return $this->user_wage_obj[$user_wage_id];
 		} else {
-			$uwlf = new UserWageListFactory();
+			$uwlf = TTnew( 'UserWageListFactory' );
 
 			$uwlf->getByID( $user_wage_id );
 			if ( $uwlf->getRecordCount() > 0 ) {
@@ -154,7 +154,7 @@ class Wage {
 		if ( is_object($this->pay_period_obj) ) {
 			return $this->pay_period_obj;
 		} else {
-			$pplf = new PayPeriodListFactory();
+			$pplf = TTnew( 'PayPeriodListFactory' );
 
 			$pplf->getById( $this->getPayPeriod() );
 			if ( $pplf->getRecordCount() > 0 ) {
@@ -171,7 +171,7 @@ class Wage {
 		if ( is_object($this->pay_period_schedule_obj) ) {
 			return $this->pay_period_schedule_obj;
 		} else {
-			$ppslf = new PayPeriodScheduleListFactory();
+			$ppslf = TTnew( 'PayPeriodScheduleListFactory' );
 			$this->pay_period_schedule_obj = $ppslf->getById( $this->getPayPeriodObject()->getPayPeriodSchedule() )->getCurrent();
 
 			return $this->pay_period_schedule_obj;
@@ -232,15 +232,7 @@ class Wage {
 
 		return 0;
 	}
-/*
-	function getAnnualHourlyRate( $user_wage_id, $exclude_stats = FALSE, $exclude_vacation = FALSE ) {
-		if ( is_object($this->getUserWageObject( $user_wage_id ) ) ) {
-			return $this->getUserWageObject( $user_wage_id )->getAnnualHourlyRate( $exclude_stats, $exclude_vacation, $this->getPayPeriodObject()->getStartDate() );
-		}
 
-		return 0;
-	}
-*/
 	function getWage($seconds, $rate ) {
 		if ( $seconds == '' OR empty($seconds) ) {
 			return 0;
@@ -263,7 +255,7 @@ class Wage {
 
 	function getPayStubAmendmentEarnings() {
 		//Get pay stub amendments here.
-		$psalf = new PayStubAmendmentListFactory();
+		$psalf = TTnew( 'PayStubAmendmentListFactory' );
 
 		if ( $this->getAdvance() == TRUE ) {
 			//For advances, any PS amendment effective BEFORE the advance end date is considered in full.
@@ -291,7 +283,7 @@ class Wage {
 
 	function getPayStubAmendmentDeductions() {
 		//Get pay stub amendments here.
-		$psalf = new PayStubAmendmentListFactory();
+		$psalf = TTnew( 'PayStubAmendmentListFactory' );
 
 		if ( $this->getAdvance() == TRUE ) {
 			//For advances, any PS amendment effective BEFORE the advance end date is considered in full.
@@ -356,7 +348,7 @@ class Wage {
 	function setUserDateTotalArray() {
 
 		//Loop through unique UserDateTotal rows... Adding entries to pay stubs.
-		$udtlf = new UserDateTotalListFactory();
+		$udtlf = TTnew( 'UserDateTotalListFactory' );
 		$udtlf->getByUserIdAndPayPeriodIdAndEndDate( $this->getUser(), $this->getPayPeriod(), $this->getPayPeriodObject()->getEndDate() );
 
 		$dock_absence_time = 0;
@@ -390,7 +382,7 @@ class Wage {
 						}
 						Debug::text('Wage ID: '. $udt_obj->getColumn('user_wage_id') .' Dock Absence Wage: '. $dock_absence_wage .' Paid Absence Wage: '. $paid_absence_wage, __FILE__, __LINE__, __METHOD__,10);
 
-						$maximum_wage_salary = UserWageFactory::proRateSalary( $this->getMaximumPayPeriodWage( $udt_obj->getColumn('user_wage_id') ) , $this->getUserWageObject( $udt_obj->getColumn('user_wage_id') )->getEffectiveDate(), $prev_wage_effective_date, $this->getPayPeriodObject()->getStartDate(), $this->getPayPeriodObject()->getEndDate() );
+						$maximum_wage_salary = UserWageFactory::proRateSalary( $this->getMaximumPayPeriodWage( $udt_obj->getColumn('user_wage_id') ) , $this->getUserWageObject( $udt_obj->getColumn('user_wage_id') )->getEffectiveDate(), $prev_wage_effective_date, $this->getPayPeriodObject()->getStartDate(), $this->getPayPeriodObject()->getEndDate(), $this->getUserObject()->getTerminationDate() );
 
 						$prev_wage_effective_date = $this->getUserWageObject( $udt_obj->getColumn('user_wage_id') )->getEffectiveDate();
 
