@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3790 $
- * $Id: HierarchyFactory.class.php 3790 2010-08-18 15:32:21Z ipso $
- * $Date: 2010-08-18 08:32:21 -0700 (Wed, 18 Aug 2010) $
+ * $Revision: 4104 $
+ * $Id: HierarchyFactory.class.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 
 /**
@@ -156,12 +156,12 @@ class HierarchyFactory extends Factory {
 		}
 
 		//Make sure both user and parent belong to the same company
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$ulf->getById( $this->getUser() );
 		$user = $ulf->getIterator()->current();
 		unset($ulf);
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$ulf->getById( $this->getParent() );
 		$parent = $ulf->getIterator()->current();
 		unset($ulf);
@@ -207,7 +207,7 @@ class HierarchyFactory extends Factory {
 
 /*
 			//Make sure we're not re-parenting to a child.
-			$uhlf = new UserHierarchyListFactory();
+			$uhlf = TTnew( 'UserHierarchyListFactory' );
 			$hierarchy = $uhlf->getByCompanyIdArray( $parent_company_id );
 
 			Debug::Text(' User ID: '. $this->getUser() .' Parent ID: '. $this->getParent(), __FILE__, __LINE__, __METHOD__,10);
@@ -271,7 +271,7 @@ class HierarchyFactory extends Factory {
 		if ( $retval === TRUE ) {
 			Debug::Text(' Retval true, Setting Shared flag ', __FILE__, __LINE__, __METHOD__,10);
 
-			$hslf = new HierarchyShareListFactory();
+			$hslf = TTnew( 'HierarchyShareListFactory' );
 			$hslf->getByHierarchyControlIdAndUserId( $this->getHierarchyControl(), $this->getUser() );
 			if ( $hslf->getRecordCount() > 0 ) {
 				Debug::Text(' Deleting already set shared flag ', __FILE__, __LINE__, __METHOD__,10);
@@ -283,7 +283,7 @@ class HierarchyFactory extends Factory {
 			if ( $this->getShared() === TRUE ) {
 				Debug::Text(' Setting Shared flag ', __FILE__, __LINE__, __METHOD__,10);
 
-				$hsf = new HierarchyShareFactory();
+				$hsf = TTnew( 'HierarchyShareFactory' );
 				$hsf->setHierarchyControl( $this->getHierarchyControl() );
 				$hsf->setUser( $this->getUser() );
 				$hsf->Save();
@@ -315,7 +315,7 @@ class HierarchyFactory extends Factory {
 			$this->getFastTreeObject()->delete( $this->getUser(), 'RECURSE');
 
 			//FIXME: When deleting recursively, we don't clear out the hierarhcy share table for all the children.
-			$hslf = new HierarchyShareListFactory();
+			$hslf = TTnew( 'HierarchyShareListFactory' );
 			Debug::Text(' Hierarchy Control ID: '. $this->getHierarchyControl() , __FILE__, __LINE__, __METHOD__,10);
 			$hslf->getByHierarchyControlIdAndUserId( $this->getHierarchyControl(), $this->getUser() );
 			if ( $hslf->getRecordCount() > 0 ) {
