@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3508 $
- * $Id: HierarchyListFactory.class.php 3508 2010-04-19 19:46:03Z ipso $
- * $Date: 2010-04-19 12:46:03 -0700 (Mon, 19 Apr 2010) $
+ * $Revision: 4206 $
+ * $Id: HierarchyListFactory.class.php 4206 2011-02-02 00:53:35Z ipso $
+ * $Date: 2011-02-01 16:53:35 -0800 (Tue, 01 Feb 2011) $
  */
 
 /**
@@ -599,8 +599,8 @@ class HierarchyListFactory extends HierarchyFactory implements IteratorAggregate
 
 		$ph = array(
 					'user_id' => $user_id,
-					'object_type_id' => $object_type_id,
 					'company_id' => $company_id,
+					//'object_type_id' => $object_type_id,
 					);
 
 		$query = '
@@ -612,8 +612,8 @@ class HierarchyListFactory extends HierarchyFactory implements IteratorAggregate
 						LEFT JOIN '. $hcf->getTable() .' as e ON w.hierarchy_control_id = e.id
 						WHERE
 							x.user_id = ?
-							AND y.object_type_id = ?
 							AND z.company_id = ?
+							AND y.object_type_id in ('. $this->getListSQL($object_type_id, $ph) .')
 							AND ( w.deleted = 0 AND e.deleted = 0 )
 						ORDER BY w.level DESC
 					';
@@ -680,8 +680,8 @@ class HierarchyListFactory extends HierarchyFactory implements IteratorAggregate
 
 		$ph = array(
 					'user_id' => $user_id,
-					'object_type_id' => $object_type_id,
 					'company_id' => $company_id,
+					//'object_type_id' => $object_type_id,
 					//'user_idb' => $user_id,
 					//'object_type_idb' => $object_type_id,
 					//'company_idb' => $company_id,
@@ -696,39 +696,11 @@ class HierarchyListFactory extends HierarchyFactory implements IteratorAggregate
 						LEFT JOIN '. $hcf->getTable() .' as z2 ON w.hierarchy_control_id = z2.id
 						WHERE
 							x.user_id = ?
-							AND y.object_type_id = ?
 							AND z.company_id = ?
-							AND z2.deleted = 0
+							AND y.object_type_id in ('. $this->getListSQL($object_type_id, $ph) .')
+							AND ( x.deleted = 0 AND z2.deleted = 0 AND z.deleted = 0 )
 					';
 
-/*
-		$query = '
-						select a.user_id as user_id
-						from '. $hlf->getTable() .' as a
-						LEFT JOIN '. $hlf->getTable() .' as b ON a.hierarchy_control_id = b.hierarchy_control_id AND b.user_id = ?
-						LEFT JOIN '. $hotf->getTable() .' as c ON a.hierarchy_control_id = c.hierarchy_control_id AND c.object_type_id = ?
-						LEFT JOIN '. $uf->getTable() .' as d ON a.user_id = d.id AND d.company_id = ?
-						LEFT JOIN '. $hcf->getTable() .' as e ON a.hierarchy_control_id = e.id
-						WHERE a.level > b.level
-							AND a.deleted = 0
-							AND b.deleted = 0
-							AND e.deleted = 0
-
-						UNION ALL
-
-						select w.user_id as user_id
-						from '. $huf->getTable() .' as w
-						LEFT JOIN '. $hlf->getTable() .' as x ON w.hierarchy_control_id = x.hierarchy_control_id
-						LEFT JOIN '. $hotf->getTable() .' as y ON w.hierarchy_control_id = y.hierarchy_control_id
-						LEFT JOIN '. $uf->getTable() .' as z ON x.user_id = z.id
-						LEFT JOIN '. $hcf->getTable() .' as z2 ON w.hierarchy_control_id = z2.id
-						WHERE
-							x.user_id = ?
-							AND y.object_type_id = ?
-							AND z.company_id = ?
-							AND z2.deleted = 0
-					';
-*/
 		//Debug::Text(' Query: '. $query, __FILE__, __LINE__, __METHOD__,10);
 		$rs = $this->db->Execute($query, $ph);
 		//Debug::Text(' Rows: '. $rs->RecordCount(), __FILE__, __LINE__, __METHOD__,10);
