@@ -53,7 +53,7 @@ class HierarchyUserFactory extends Factory {
 		if ( is_object($this->hierarchy_control_obj) ) {
 			return $this->hierarchy_control_obj;
 		} else {
-			$hclf = new HierarchyControlListFactory();
+			$hclf = TTnew( 'HierarchyControlListFactory' );
 			$this->hierarchy_control_obj = $hclf->getById( $this->getHierarchyControl() )->getCurrent();
 
 			return $this->hierarchy_control_obj;
@@ -64,7 +64,7 @@ class HierarchyUserFactory extends Factory {
 		if ( is_object($this->user_obj) ) {
 			return $this->user_obj;
 		} else {
-			$ulf = new UserListFactory();
+			$ulf = TTnew( 'UserListFactory' );
 			$ulf->getById( $this->getUser() );
 			if ( $ulf->getRecordCount() == 1 ) {
 				$this->user_obj = $ulf->getCurrent();
@@ -85,13 +85,15 @@ class HierarchyUserFactory extends Factory {
 	function setHierarchyControl($id) {
 		$id = trim($id);
 
-		$hclf = new HierarchyControlListFactory();
+		$hclf = TTnew( 'HierarchyControlListFactory' );
 
-		if (  $id != 0
+		//This is a sub-class, need to support setting HierachyControlID before its created.
+		if ( $id != 0
 				OR $this->Validator->isResultSetWithRows(	'hierarchy_control_id',
-															$hclf->getByID($id),
-															TTi18n::gettext('Invalid Hierarchy Control')
-															) ) {
+														$hclf->getByID($id),
+														TTi18n::gettext('Invalid Hierarchy Control')
+														)
+			) {
 			$this->data['hierarchy_control_id'] = $id;
 
 			return TRUE;
@@ -100,13 +102,14 @@ class HierarchyUserFactory extends Factory {
 		return FALSE;
 	}
 
-	function isUniqueUser($id) {
-		$hcf = new HierarchyControlFactory();
-		$hotf = new HierarchyObjectTypeFactory();
+	function isUniqueUser($id, $exclude_id = 0 ) {
+		$hcf = TTnew( 'HierarchyControlFactory' );
+		$hotf = TTnew( 'HierarchyObjectTypeFactory' );
 
 		$ph = array(
 					'hierarchy_control_id' => $this->getHierarchyControl(),
 					'id' => $id,
+					'exclude_id' => $exclude_id,
 					);
 
 		//$query = 'select a.id from '. $this->getTable() .' as a, '. $pglf->getTable() .' as b where a.hierarchy_control_id = b.id AND a.user_id = ? AND b.deleted=0';
@@ -120,11 +123,11 @@ class HierarchyUserFactory extends Factory {
 							from hierarchy_object_type
 							where hierarchy_control_id = ? )
 					AND b.user_id = ?
+					AND a.hierarchy_control_id != ?
 					AND c.deleted = 0
 				';
-
+		//Debug::Arr($ph,'Query: '. $query, __FILE__, __LINE__, __METHOD__,10);
 		$user_id = $this->db->GetOne($query, $ph);
-		//Debug::Arr($user_id,'Unique User ID: '. $user_id, __FILE__, __LINE__, __METHOD__,10);
 
 		if ( $user_id === FALSE ) {
 			return TRUE;
@@ -140,8 +143,8 @@ class HierarchyUserFactory extends Factory {
 	function setUser($id) {
 		$id = trim($id);
 
-		$ulf = new UserListFactory();
-		$hllf = new HierarchyLevelListFactory();
+		$ulf = TTnew( 'UserListFactory' );
+		$hllf = TTnew( 'HierarchyLevelListFactory' );
 
 		if ( $id != 0
 				AND $this->Validator->isResultSetWithRows(	'user',
