@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3928 $
- * $Id: HolidayFactory.class.php 3928 2010-11-11 20:29:54Z ipso $
- * $Date: 2010-11-11 12:29:54 -0800 (Thu, 11 Nov 2010) $
+ * $Revision: 4265 $
+ * $Id: HolidayFactory.class.php 4265 2011-02-18 00:49:20Z ipso $
+ * $Date: 2011-02-17 16:49:20 -0800 (Thu, 17 Feb 2011) $
  */
 
 /**
@@ -63,6 +63,9 @@ class HolidayFactory extends Factory {
 										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
 							);
 				break;
+			case 'list_columns':
+				$retval = Misc::arrayIntersectByKey( $this->getOptions('default_display_columns'), Misc::trimSortPrefix( $this->getOptions('columns') ) );
+				break;
 			case 'default_display_columns': //Columns that are displayed by default.
 				$retval = array(
 								'name',
@@ -98,7 +101,7 @@ class HolidayFactory extends Factory {
 			return $this->holiday_policy_obj;
 		} else {
 
-			$hplf = new HolidayPolicyListFactory();
+			$hplf = TTnew( 'HolidayPolicyListFactory' );
 			$hplf->getById( $this->getHolidayPolicyID() );
 
 			if ( $hplf->getRecordCount() == 1 ) {
@@ -121,7 +124,7 @@ class HolidayFactory extends Factory {
 	function setHolidayPolicyID($id) {
 		$id = trim($id);
 
-		$hplf = new HolidayPolicyListFactory();
+		$hplf = TTnew( 'HolidayPolicyListFactory' );
 
 		if (
 				$this->Validator->isResultSetWithRows(	'holiday_policy',
@@ -205,10 +208,16 @@ class HolidayFactory extends Factory {
 			return TRUE;
 		}
 
+		//When a holiday gets moved back/forward due to falling on weekend, it can throw off the check to see if the holiday
+		//appears in the same year. For example new years 01-Jan-2011 gets moved to 31-Dec-2010, its in the same year
+		//as the previous New Years day or 01-Jan-2010, so this check fails.
+		//
+		//I think this can only happen with New Years, or other holidays that fall within two days of the new year.
+		//So exclude the first three days of the year to allow for weekend adjustments.
 		$ph = array(
 					'policy_id' => $this->getHolidayPolicyID(),
 					'name' => $name,
-					'start_date1' => $this->db->BindDate( TTDate::getBeginYearEpoch( $this->getDateStamp() ) ),
+					'start_date1' => $this->db->BindDate( TTDate::getBeginYearEpoch( $this->getDateStamp() )+(86400*3) ),
 					'end_date1' => $this->db->BindDate( TTDate::getEndYearEpoch( $this->getDateStamp() ) ),
 					'start_date2' => $this->db->BindDate( $this->getDateStamp()-(86400*15) ),
 					'end_date2' => $this->db->BindDate( $this->getDateStamp()+(86400*15) ),
@@ -282,7 +291,7 @@ class HolidayFactory extends Factory {
 	}
 
 	function getAverageTime( $user_id ) {
-		$udtlf = new UserDateTotalListFactory();
+		$udtlf = TTnew( 'UserDateTotalListFactory' );
 
 		//Check if Min and Max time is the same, if so we can skip any averaging.
 		if ( $this->getHolidayPolicyObject()->getMinimumTime() > 0
@@ -352,11 +361,11 @@ class HolidayFactory extends Factory {
 
 		//$this->getHolidayPolicyObject();
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$user_obj = $ulf->getById($user_id)->getCurrent();
 
-		$slf = new ScheduleListFactory();
-		$udtlf = new UserDateTotalListFactory();
+		$slf = TTnew( 'ScheduleListFactory' );
+		$udtlf = TTnew( 'UserDateTotalListFactory' );
 
 		//Make sure the employee has been employed long enough according to labor standards
 		//Also make sure that the employee hasn't been terminated on or before the holiday.
