@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: RecurringHolidayFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4401 $
+ * $Id: RecurringHolidayFactory.class.php 4401 2011-03-19 20:29:26Z ipso $
+ * $Date: 2011-03-19 13:29:26 -0700 (Sat, 19 Mar 2011) $
  */
 
 /**
@@ -107,10 +107,15 @@ class RecurringHolidayFactory extends Factory {
 										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
 							);
 				break;
+			case 'list_columns':
+				$retval = Misc::arrayIntersectByKey( $this->getOptions('default_display_columns'), Misc::trimSortPrefix( $this->getOptions('columns') ) );
+				break;
 			case 'default_display_columns': //Columns that are displayed by default.
 				$retval = array(
 								'name',
 								'next_date',
+								'updated_date',
+								'updated_by',
 								);
 				break;
 			case 'unique_columns': //Columns that are unique, and disabled for mass editing.
@@ -150,7 +155,7 @@ class RecurringHolidayFactory extends Factory {
 		if ( is_object($this->company_obj) ) {
 			return $this->company_obj;
 		} else {
-			$clf = new CompanyListFactory();
+			$clf = TTnew( 'CompanyListFactory' );
 			$this->company_obj = $clf->getById( $this->getCompany() )->getCurrent();
 
 			return $this->company_obj;
@@ -168,7 +173,7 @@ class RecurringHolidayFactory extends Factory {
 		$id = trim($id);
 
 		Debug::Text('Company ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
-		$clf = new CompanyListFactory();
+		$clf = TTnew( 'CompanyListFactory' );
 
 		if ( $this->Validator->isResultSetWithRows(	'company',
 													$clf->getByID($id),
@@ -552,7 +557,7 @@ class RecurringHolidayFactory extends Factory {
 		switch (strtolower($country)) {
 			case 'ca':
 				Debug::text('Saving.... New Years', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( 'New Years Day' );
 				$rhf->setType( 10 );
@@ -567,7 +572,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Good Friday/Easter', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( 'Good Friday' );
 				$rhf->setType( 20 );
@@ -578,7 +583,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Canada Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( 'Canada Day' );
 				$rhf->setType( 10 );
@@ -594,7 +599,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Labour Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( 'Labour Day' );
 				$rhf->setType( 20 );
@@ -609,7 +614,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Xmas', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( 'Christmas' );
 				$rhf->setType( 10 );
@@ -626,7 +631,7 @@ class RecurringHolidayFactory extends Factory {
 
 				//BC Holidays
 				Debug::text('Saving.... British Columbia Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( 'BC - British Columbia Day' );
 				$rhf->setType( 20 );
@@ -642,7 +647,7 @@ class RecurringHolidayFactory extends Factory {
 
 				//AB Holidays
 				Debug::text('Saving.... Family Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( 'AB - Family Day' );
 				$rhf->setType( 20 );
@@ -659,7 +664,7 @@ class RecurringHolidayFactory extends Factory {
 
 				//Holidays across different provinces
 				Debug::text('Saving.... Victoria Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( 'Victoria Day' );
 				$rhf->setType( 30 );
@@ -674,7 +679,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Thanksgiving', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( 'Thanksgiving Day' );
 				$rhf->setType( 20 );
@@ -689,7 +694,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Rememberance Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( 'Rememberance Day' );
 				$rhf->setType( 10 );
@@ -707,7 +712,7 @@ class RecurringHolidayFactory extends Factory {
 			case 'us':
 
 				Debug::text('Saving.... New Years', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( 'New Years Day' );
 				$rhf->setType( 10 );
@@ -721,7 +726,7 @@ class RecurringHolidayFactory extends Factory {
 					$rhf->Save();
 				}
 
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( 'Independence Day' );
 				$rhf->setType( 10 );
@@ -736,7 +741,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... New Years', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( 'Veterans Day' );
 				$rhf->setType( 10 );
@@ -750,7 +755,7 @@ class RecurringHolidayFactory extends Factory {
 					$rhf->Save();
 				}
 
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( 'Christmas' );
 				$rhf->setType( 10 );
@@ -764,7 +769,7 @@ class RecurringHolidayFactory extends Factory {
 					$rhf->Save();
 				}
 
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( 'Martin Luther King Day' );
 				$rhf->setType( 20 );
@@ -778,7 +783,7 @@ class RecurringHolidayFactory extends Factory {
 					$rhf->Save();
 				}
 
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( 'Presidents Day' );
 				$rhf->setType( 20 );
@@ -793,7 +798,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				//Pivot Day
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( 'Memorial Day' );
 				$rhf->setType( 30 );
@@ -808,7 +813,7 @@ class RecurringHolidayFactory extends Factory {
 					$rhf->Save();
 				}
 
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( 'Labor Day' );
 				$rhf->setType( 20 );
@@ -821,7 +826,7 @@ class RecurringHolidayFactory extends Factory {
 					$rhf->Save();
 				}
 
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( 'Columbus Day' );
 				$rhf->setType( 20 );
@@ -834,7 +839,7 @@ class RecurringHolidayFactory extends Factory {
 					$rhf->Save();
 				}
 
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( 'Thanksgiving Day' );
 				$rhf->setType( 20 );
@@ -847,7 +852,7 @@ class RecurringHolidayFactory extends Factory {
 					$rhf->Save();
 				}
 
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( 'Day After Thanksgiving Day' );
 				$rhf->setType( 20 );
@@ -861,7 +866,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Good Friday/Easter', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( 'Good Friday' );
 				$rhf->setType( 20 );
@@ -876,7 +881,7 @@ class RecurringHolidayFactory extends Factory {
 			case 'cr':
 
 				Debug::text('Saving.... New Years', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('New Years Day') );
 				$rhf->setType( 10 );
@@ -889,7 +894,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Good Thursday/Easter', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Good Thursday') );
 				$rhf->setType( 20 );
@@ -900,7 +905,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Good Friday/Easter', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Good Friday') );
 				$rhf->setType( 20 );
@@ -911,7 +916,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Juan Santamaria Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Juan Santamaria Day') );
 				$rhf->setType( 10 );
@@ -924,7 +929,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Labour Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Labour Day') );
 				$rhf->setType( 10 );
@@ -937,7 +942,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Anexion de Guanacaste Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Anexion de Guanacaste Day') );
 				$rhf->setType( 10 );
@@ -950,7 +955,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Virgen de los Angeles Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Virgen de los Angeles Day') );
 				$rhf->setType( 10 );
@@ -963,7 +968,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Mothers  Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Mothers Day') );
 				$rhf->setType( 10 );
@@ -976,7 +981,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Independence Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
  				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Independence Day CR') );
 				$rhf->setType( 10 );
@@ -989,7 +994,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Culture Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Culture Day') );
 				$rhf->setType( 10 );
@@ -1002,7 +1007,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Christmas', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Christmas') );
 				$rhf->setType( 10 );
@@ -1018,7 +1023,7 @@ class RecurringHolidayFactory extends Factory {
 			case 'gt':
 
 				Debug::text('Saving.... New Years', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('New Years Day') );
 				$rhf->setType( 10 );
@@ -1031,7 +1036,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Good Wednesday/Easter', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Good Wednesday') );
 				$rhf->setType( 20 );
@@ -1042,7 +1047,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Good Thursday/Easter', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Good Thursday') );
 				$rhf->setType( 20 );
@@ -1053,7 +1058,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Good Friday/Easter', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Good Friday') );
 				$rhf->setType( 20 );
@@ -1064,7 +1069,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Labour Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Labour Day') );
 				$rhf->setType( 10 );
@@ -1077,7 +1082,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Army Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Army Day') );
 				$rhf->setType( 10 );
@@ -1090,7 +1095,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Virgin Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Virgin Day') );
 				$rhf->setType( 10 );
@@ -1103,7 +1108,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Independence Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Independence Day CR') );
 				$rhf->setType( 10 );
@@ -1116,7 +1121,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... 1944 Revolution Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('1944 Revolution Day') );
 				$rhf->setType( 10 );
@@ -1129,7 +1134,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... All Saint Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('All Saint Day') );
 				$rhf->setType( 30 );
@@ -1143,7 +1148,7 @@ class RecurringHolidayFactory extends Factory {
 
 
 				Debug::text('Saving.... Christmas Eve', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Christmas Eve') );
 				$rhf->setType( 10 );
@@ -1156,7 +1161,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Christmas', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Christmas') );
 				$rhf->setType( 10 );
@@ -1173,7 +1178,7 @@ class RecurringHolidayFactory extends Factory {
 			case 'hn':
 
 				Debug::text('Saving.... New Years', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('New Years Day') );
 				$rhf->setType( 10 );
@@ -1186,7 +1191,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Good Thursday/Easter', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Good Thursday') );
 				$rhf->setType( 20 );
@@ -1197,7 +1202,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Good Friday/Easter', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Good Friday') );
 				$rhf->setType( 20 );
@@ -1208,7 +1213,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Good Saturday/Easter', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Good Saturday') );
 				$rhf->setType( 20 );
@@ -1219,7 +1224,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Labour Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Labour Day') );
 				$rhf->setType( 10 );
@@ -1232,7 +1237,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Independence Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Independence Day') );
 				$rhf->setType( 10 );
@@ -1245,7 +1250,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Morazan Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Morazan Day') );
 				$rhf->setType( 10 );
@@ -1258,7 +1263,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Culture Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Culture Day') );
 				$rhf->setType( 30 );
@@ -1272,7 +1277,7 @@ class RecurringHolidayFactory extends Factory {
 
 
 				Debug::text('Saving.... Armed Forces Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Armed Forces Day') );
 				$rhf->setType( 10 );
@@ -1285,7 +1290,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Christmas', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Christmas') );
 				$rhf->setType( 10 );
@@ -1302,7 +1307,7 @@ class RecurringHolidayFactory extends Factory {
 			case 'sv':
 
 				Debug::text('Saving.... New Years', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('New Years Day') );
 				$rhf->setType( 10 );
@@ -1315,7 +1320,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Good Thursday/Easter', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Good Thursday') );
 				$rhf->setType( 20 );
@@ -1326,7 +1331,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Good Friday/Easter', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Good Friday') );
 				$rhf->setType( 20 );
@@ -1337,7 +1342,7 @@ class RecurringHolidayFactory extends Factory {
  				}
 
 				Debug::text('Saving.... Labour Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Labour Day') );
 				$rhf->setType( 10 );
@@ -1350,7 +1355,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
  				Debug::text('Saving.... Bank Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Bank Day') );
 				$rhf->setType( 10 );
@@ -1363,7 +1368,7 @@ class RecurringHolidayFactory extends Factory {
  				}
 
 				Debug::text('Saving.... San Salvador Party', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('San Salvador Party') );
 				$rhf->setType( 10 );
@@ -1376,7 +1381,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Independence Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Independence Day') );
 				$rhf->setType( 10 );
@@ -1389,7 +1394,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Columbus Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Columbus Day') );
 				$rhf->setType( 10 );
@@ -1402,7 +1407,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... All Saints Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('All Saints Day') );
 				$rhf->setType( 10 );
@@ -1415,7 +1420,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... First Cry of Independence', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('First Cry of Independence') );
 				$rhf->setType( 10 );
@@ -1428,7 +1433,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Christmas', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Christmas') );
 				$rhf->setType( 10 );
@@ -1445,7 +1450,7 @@ class RecurringHolidayFactory extends Factory {
 			case 'ni':
 
 				Debug::text('Saving.... New Years', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('New Years Day') );
 				$rhf->setType( 10 );
@@ -1458,7 +1463,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Good Thursday/Easter', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Good Thursday') );
 				$rhf->setType( 20 );
@@ -1469,7 +1474,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Good Friday/Easter', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Good Friday') );
 				$rhf->setType( 20 );
@@ -1480,7 +1485,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Labour Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Labour Day') );
 				$rhf->setType( 10 );
@@ -1493,7 +1498,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Revolution Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Revolution Day') );
 				$rhf->setType( 10 );
@@ -1506,7 +1511,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... San Jacinto Battle', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('San Jacinto Battle') );
 				$rhf->setType( 10 );
@@ -1519,7 +1524,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Independence Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Independence Day') );
 				$rhf->setType( 10 );
@@ -1532,7 +1537,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Christmas', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Christmas') );
 				$rhf->setType( 10 );
@@ -1549,7 +1554,7 @@ class RecurringHolidayFactory extends Factory {
 			case 'pa':
 
 				Debug::text('Saving.... New Years', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('New Years Day') );
 				$rhf->setType( 10 );
@@ -1562,7 +1567,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
   				Debug::text('Saving.... Martyr`s Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
  				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Martyr`s Day') );
 				$rhf->setType( 10 );
@@ -1575,7 +1580,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Good Friday/Easter', __FILE__, __LINE__, __METHOD__, 10);
-	 			$rhf = new RecurringHolidayFactory();
+	 			$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Good Friday') );
 				$rhf->setType( 20 );
@@ -1586,7 +1591,7 @@ class RecurringHolidayFactory extends Factory {
   				}
 
 				Debug::text('Saving.... Labour Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Labour Day') );
  				$rhf->setType( 10 );
@@ -1599,7 +1604,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Separation Day (from Colombia)', __FILE__, __LINE__, __METHOD__, 10);
- 				$rhf = new RecurringHolidayFactory();
+ 				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Separation Day from Colombia') );
 				$rhf->setType( 10 );
@@ -1612,7 +1617,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 	 			Debug::text('Saving.... Flag Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 	 			$rhf->setName( TTi18n::gettext('Flag Day') );
 				$rhf->setType( 10 );
@@ -1625,7 +1630,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Primer Grito de Independencia de la Villa de los Santos', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Primer Grito de Independencia de la Villa de los Santos') );
  				$rhf->setType( 10 );
@@ -1638,7 +1643,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
  				Debug::text('Saving.... Independence Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
  				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Independence Day') );
 				$rhf->setType( 10 );
@@ -1651,7 +1656,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
  				Debug::text('Saving.... Mothers Day', __FILE__, __LINE__, __METHOD__, 10);
-				$rhf = new RecurringHolidayFactory();
+				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Mothers Day') );
  				$rhf->setType( 10 );
@@ -1664,7 +1669,7 @@ class RecurringHolidayFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Christmas', __FILE__, __LINE__, __METHOD__, 10);
- 				$rhf = new RecurringHolidayFactory();
+ 				$rhf = TTnew( 'RecurringHolidayFactory' );
 				$rhf->setCompany( $company_id );
 				$rhf->setName( TTi18n::gettext('Christmas')  );
 				$rhf->setType( 10 );
