@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3513 $
- * $Id: Install.class.php 3513 2010-04-21 18:18:00Z ipso $
- * $Date: 2010-04-21 11:18:00 -0700 (Wed, 21 Apr 2010) $
+ * $Revision: 4849 $
+ * $Id: Install.class.php 4849 2011-06-21 18:28:02Z ipso $
+ * $Date: 2011-06-21 11:28:02 -0700 (Tue, 21 Jun 2011) $
  */
 
 /**
@@ -196,58 +196,104 @@ class Install {
 		return FALSE;
 	}
 
+	function HumanBoolean($bool) {
+		if ( $bool === TRUE OR strtolower(trim($bool)) == 'true' ) {
+			return 'TRUE';
+		} else {
+			return 'FALSE';
+		}
+	}
+
 	function writeConfigFile( $config_vars ) {
 		if ( is_writeable( CONFIG_FILE ) ) {
 			$contents = file_get_contents( CONFIG_FILE );
 
-			//var_dump($contents);
+			//Need to handle INI sections properly.
 
+			//
+			//Database section
+			//
+			preg_match('/^\[[database^\]\r\n]+](?:\r?\n(?:[^[\r\n].*)?)*/mi', $contents, $section );
+			//Debug::Arr( $section, 'Database Section (original): ', __FILE__, __LINE__, __METHOD__,10);
+			$section['database'] = $section[0];
+			if ( isset($config_vars['host']) AND $config_vars['host'] != '' ) {
+				$section['database'] = preg_replace('/^host\s*=.*/im', 'host = '. trim($config_vars['host']), $section['database']);
+			}
 			if ( isset($config_vars['type']) AND $config_vars['type'] != '' ) {
-				$contents = preg_replace('/^type.*=.*/im', 'type = '. trim($config_vars['type']), $contents);
+				$section['database'] = preg_replace('/^type\s*=.*/im', 'type = '. trim($config_vars['type']), $section['database']);
 			}
 			if ( isset($config_vars['host']) AND $config_vars['host'] != '' ) {
-				$contents = preg_replace('/^host.*=.*/im', 'host = '. trim($config_vars['host']), $contents);
+				$section['database'] = preg_replace('/^host\s*=.*/im', 'host = '. trim($config_vars['host']), $section['database']);
 			}
 			if ( isset($config_vars['database_name']) AND $config_vars['database_name'] != '' ) {
-				$contents = preg_replace('/^database_name.*=.*/im', 'database_name = '. trim($config_vars['database_name']), $contents);
+				$section['database'] = preg_replace('/^database_name\s*=.*/im', 'database_name = '. trim($config_vars['database_name']), $section['database']);
 			}
 			if ( isset($config_vars['user']) AND $config_vars['user'] != '') {
-				$contents = preg_replace('/^user.*=.*/im', 'user = '. trim($config_vars['user']), $contents);
+				$section['database'] = preg_replace('/^user\s*=.*/im', 'user = '. trim($config_vars['user']), $section['database']);
 			}
 			if ( isset($config_vars['password']) AND $config_vars['password'] != '' ) {
-				$contents = preg_replace('/^password.*=.*/im', 'password = '. trim($config_vars['password']), $contents);
-			}
-			if ( isset($config_vars['installer_enabled']) AND $config_vars['installer_enabled'] != '' ) {
-				$contents = preg_replace('/^installer_enabled.*=.*/im', 'installer_enabled = '. (bool)$config_vars['installer_enabled'], $contents);
+				$section['database'] = preg_replace('/^password\s*=.*/im', 'password = '. trim($config_vars['password']), $section['database']);
 			}
+			$contents = str_replace( $section[0], $section['database'], $contents );
+			unset($section);
+			//Debug::Arr( $contents, 'Database Contents (new): ', __FILE__, __LINE__, __METHOD__,10);
+
+			//
+			//Path section
+			//
+			preg_match('/^\[[path^\]\r\n]+](?:\r?\n(?:[^[\r\n].*)?)*/mi', $contents, $section );
+			//Debug::Arr( $section, 'Path Section (original): ', __FILE__, __LINE__, __METHOD__,10);
+			$section['path'] = $section[0];
 			if ( isset($config_vars['base_url']) AND $config_vars['base_url'] != '' ) {
-				$contents = preg_replace('/^base_url.*=.*/im', 'base_url = '. preg_replace('@^(?:http://)?([^/]+)@i', '', $config_vars['base_url']), $contents);
+				$section['path'] = preg_replace('/^base_url\s*=.*/im', 'base_url = '. preg_replace('@^(?:http://)?([^/]+)@i', '', $config_vars['base_url']), $section['path']);
 			}
 			if ( isset($config_vars['storage_dir']) AND $config_vars['storage_dir'] != '' ) {
-				$contents = preg_replace('/^storage.*=.*/im', 'storage = '. $config_vars['storage_dir'], $contents);
+				$section['path'] = preg_replace('/^storage\s*=.*/im', 'storage = '. $config_vars['storage_dir'], $section['path']);
 			}
 			if ( isset($config_vars['log_dir']) AND $config_vars['log_dir'] != '' ) {
-				$contents = preg_replace('/^log.*=.*/im', 'log = '. $config_vars['log_dir'], $contents);
+				$section['path'] = preg_replace('/^log\s*=.*/im', 'log = '. $config_vars['log_dir'], $section['path']);
+			}
+			$contents = str_replace( $section[0], $section['path'], $contents );
+			unset($section);
+			//Debug::Arr( $contents, 'Path Contents (new): ', __FILE__, __LINE__, __METHOD__,10);
+
+			//
+			//Cache section
+			//
+			preg_match('/^\[[cache^\]\r\n]+](?:\r?\n(?:[^[\r\n].*)?)*/mi', $contents, $section );
+			//Debug::Arr( $section, 'Cache Section (original): ', __FILE__, __LINE__, __METHOD__,10);
+			$section['cache'] = $section[0];
+			if ( isset($config_vars['cache']['enable']) ) {
+				$section['cache'] = preg_replace('/^enable\s*=.*/im', 'enable = '. $this->HumanBoolean( $config_vars['cache']['enable'] ), $section['cache']);
 			}
 			if ( isset($config_vars['cache_dir']) AND $config_vars['cache_dir'] != '' ) {
-				$contents = preg_replace('/^dir.*=.*/im', 'dir = '. $config_vars['cache_dir'], $contents);
-			}
-
-			//Only change if it isn't already set
-			if ( isset($this->config_vars['other']['salt']) AND ( $this->config_vars['other']['salt'] == '' OR $this->config_vars['other']['salt'] == '0' )
-					AND isset($config_vars['salt']) AND $config_vars['salt'] != '' ) {
-				$contents = preg_replace('/^salt.*=.*/im', 'salt = '. $config_vars['salt'], $contents);
+				$section['cache'] = preg_replace('/^dir\s*=.*/im', 'dir = '. $config_vars['cache_dir'], $section['cache']);
 			}
+			$contents = str_replace( $section[0], $section['cache'], $contents );
+			unset($section);
+			//Debug::Arr( $contents, 'Cache Contents (new): ', __FILE__, __LINE__, __METHOD__,10);
 
+			//
+			//Other section
+			//
+			preg_match('/^\[[other^\]\r\n]+](?:\r?\n(?:[^[\r\n].*)?)*/mi', $contents, $section );
+			//Debug::Arr( $section, 'Other Section (original): ', __FILE__, __LINE__, __METHOD__,10);
+			$section['other'] = $section[0];
 			if ( isset($config_vars['installer_enabled']) AND $config_vars['installer_enabled'] != '' ) {
-				$contents = preg_replace('/^installer_enabled.*=.*/im', 'installer_enabled = '. $config_vars['installer_enabled'], $contents);
+				$section['other'] = preg_replace('/^installer_enabled\s*=.*/im', 'installer_enabled = '. $this->HumanBoolean( $config_vars['installer_enabled'] ), $section['other']);
 			}
-
 			if ( isset($config_vars['primary_company_id']) AND $config_vars['primary_company_id'] != '' ) {
-				$contents = preg_replace('/^primary_company_id.*=.*/im', 'primary_company_id = '. $config_vars['primary_company_id'], $contents);
+				$section['other'] = preg_replace('/^primary_company_id\s*=.*/im', 'primary_company_id = '. $config_vars['primary_company_id'], $section['other']);
 			}
 
-			//var_dump($contents);
+			if ( isset($this->config_vars['other']['salt']) AND ( $this->config_vars['other']['salt'] == '' OR $this->config_vars['other']['salt'] == '0' )
+			        AND isset($config_vars['salt']) AND $config_vars['salt'] != '' ) {
+				$section['other'] = preg_replace('/^salt\s*=.*/im', 'salt = '. $config_vars['salt'], $section['other']);
+			}
+			$contents = str_replace( $section[0], $section['other'], $contents );
+			unset($section);
+			//Debug::Arr( $contents, 'Other Contents (new): ', __FILE__, __LINE__, __METHOD__,10);
+
 			Debug::text('Modified Config File!', __FILE__, __LINE__, __METHOD__,9);
 
 			return file_put_contents( CONFIG_FILE, $contents);
@@ -258,16 +304,15 @@ class Install {
 		return FALSE;
 	}
 
-
 	function setVersions() {
 		if ( is_array($this->versions) ) {
 			foreach( $this->versions as $name => $value ) {
-				$sslf = new SystemSettingListFactory();
+				$sslf = TTnew( 'SystemSettingListFactory' );
 				$sslf->getByName( $name );
 				if ( $sslf->getRecordCount() == 1 ) {
 					$obj = $sslf->getCurrent();
 				} else {
-					$obj = new SystemSettingListFactory();
+					$obj = TTnew( 'SystemSettingListFactory' );
 				}
 
 				$obj->setName( $name );
@@ -361,8 +406,8 @@ class Install {
 		$schema_files = array();
 
 		$dir = $is_obj->getSQLFileDirectory();
-		if ($handle = opendir($dir)) {
-			while (false !== ($file = readdir($handle))) {
+		if ( $handle = opendir($dir) ) {
+			while ( FALSE !== ($file = readdir($handle))) {
 				list($schema_base_name,$extension) = explode('.', $file);
 				$schema_group = substr($schema_base_name, -1,1 );
 				Debug::text('Schema: '. $file .' Group: '. $schema_group, __FILE__, __LINE__, __METHOD__,9);
@@ -386,7 +431,11 @@ class Install {
 	//Creates DB schema starting at and including start_version, and ending at, including end version.
 	//Starting at NULL is first version, ending at NULL is last version.
 	function createSchemaRange( $start_version = NULL, $end_version = NULL, $group = array('A','B','T') ) {
-		global $cache, $progress_bar;
+		global $cache, $progress_bar, $config_vars;
+
+		//Disable detailed audit logging during schema upgrades, as it breaks upgrading from pre-audit log versions to post-audit log versions.
+		//ie: v2.2.22 to v3.3.2.
+		$config_vars['other']['disable_audit_log_detail'] = TRUE;
 
 		$schema_versions = $this->getAllSchemaVersions( $group );
 
@@ -441,7 +490,7 @@ class Install {
 		if ( $this->checkTableExists( 'system_setting') == TRUE ) {
 			Debug::text('System Setting Table DOES exist...', __FILE__, __LINE__, __METHOD__,9);
 
-			$sslf = new SystemSettingListFactory();
+			$sslf = TTnew( 'SystemSettingListFactory' );
 			$sslf->getByName( 'schema_version_group_'. substr( $version,-1,1) );
 			if ( $sslf->getRecordCount() > 0 ) {
 				$ss_obj = $sslf->getCurrent();
@@ -622,6 +671,77 @@ class Install {
 		return $retval;
 	}
 
+	function checkFileChecksums() {
+		// Return
+		//
+		// 0 = OK
+		// 1 = Invalid
+		// 2 = Unsupported
+
+		if ( PRODUCTION == FALSE OR DEPLOYMENT_ON_DEMAND == TRUE ) {
+			return 0; //Skip checksums.
+		}
+
+		//Load checksum file.
+		$checksum_file = dirname( __FILE__) . DIRECTORY_SEPARATOR .'..'. DIRECTORY_SEPARATOR .'..'. DIRECTORY_SEPARATOR .'..'. DIRECTORY_SEPARATOR . 'files.sha1';
+
+		if ( file_exists( $checksum_file ) ) {
+			$checksum_data = file_get_contents( $checksum_file );
+			$checksums = explode("\n", $checksum_data );
+			unset($checksum_data);
+			if ( is_array($checksums) ) {
+				$i=0;
+				foreach($checksums as $checksum_line ) {
+
+					//1st line contains the TT version for the checksums, make sure it matches current version.
+					if ( $i == 0 ) {
+						if ( preg_match( '/\d\.\d\.\d/', $checksum_line, $checksum_version ) ) {
+							Debug::Text('Checksum version: '. $checksum_version[0], __FILE__, __LINE__, __METHOD__,10);
+							if ( version_compare( APPLICATION_VERSION, $checksum_version[0], '=') ) {
+								Debug::Text('Checksum version matches!', __FILE__, __LINE__, __METHOD__,10);
+							} else {
+								Debug::Text('Checksum version DOES NOT match! Version: '. APPLICATION_VERSION .' Checksum Version: '. $checksum_version[0], __FILE__, __LINE__, __METHOD__,10);
+								return 1;
+							}
+						} else {
+							Debug::Text('Checksum version not found in file: '. $checksum_line, __FILE__, __LINE__, __METHOD__,10);
+						}
+					} elseif ( strlen( $checksum_line ) > 1 ) {
+						$split_line = explode(' ', $checksum_line );
+						if ( is_array($split_line) ) {
+							$file_name = Environment::getBasePath() . str_replace( '/', DIRECTORY_SEPARATOR, str_replace('./', '', trim($split_line[2]) ) );
+							$checksum = trim($split_line[0]);
+
+							if ( file_exists( $file_name ) ) {
+								$my_checksum = sha1_file( $file_name );
+								if ( $my_checksum == $checksum ) {
+									Debug::Text('File: '. $file_name .' Checksum: '. $checksum .' MATCHES', __FILE__, __LINE__, __METHOD__,10);
+								} else {
+									Debug::Text('File: '. $file_name .' Checksum: '. $my_checksum .' DOES NOT match provided checksum of: '. $checksum, __FILE__, __LINE__, __METHOD__,10);
+									return 1; //Invalid
+								}
+								unset($my_checksum);
+							} else {
+								Debug::Text('File does not exist: '. $file_name, __FILE__, __LINE__, __METHOD__,10);
+								return 1; //Invalid
+							}
+
+						}
+						unset($split_line, $file_name, $checksum);
+					}
+
+					$i++;
+				}
+
+				return 0; //OK
+			}
+		} else {
+			Debug::Text('Checksum file does not exist: '. $checksum_file, __FILE__, __LINE__, __METHOD__,10);
+		}
+
+		return 1; //Invalid
+	}
+
 	function checkDatabaseType() {
 		// Return
 		//
@@ -881,6 +1001,20 @@ class Install {
 		return 1;
 	}
 
+	function cleanCacheDirectory() {
+		global $smarty;
+
+		if ( isset($smarty) ) {
+			$smarty->clear_all_cache();
+		}
+
+		if ( DEPLOYMENT_ON_DEMAND == FALSE ) {
+			return Misc::cleanDir( $this->config_vars['cache']['dir'], TRUE, TRUE );
+		}
+
+		return FALSE;
+	}
+
 	function checkCleanCacheDirectory() {
 		if ( DEPLOYMENT_ON_DEMAND == FALSE ) {
 			$raw_cache_files = scandir( $this->config_vars['cache']['dir'] );
@@ -997,6 +1131,7 @@ class Install {
 			$retarr[$this->checkCleanCacheDirectory()]++;
 			$retarr[$this->checkWritableStorageDirectory()]++;
 			$retarr[$this->checkWritableLogDirectory()]++;
+			$retarr[$this->checkFileChecksums()]++;
 		}
 
 		$retarr[$this->checkPHPSafeMode()]++;
