@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2095 $
- * $Id: InstallSchema_1000A.class.php 2095 2008-09-01 07:04:25Z ipso $
- * $Date: 2008-09-01 00:04:25 -0700 (Mon, 01 Sep 2008) $
+ * $Revision: 4104 $
+ * $Id: InstallSchema_1000A.class.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 
 /**
@@ -65,7 +65,7 @@ class InstallSchema_1000A extends InstallSchema_Base {
 		Debug::text('Cron Job Base Command: '. $cron_job_base_command, __FILE__, __LINE__, __METHOD__,9);
 
 		// >> /dev/null 2>&1
-		$cjf = new CronJobFactory();
+		$cjf = TTnew( 'CronJobFactory' );
 		$cjf->setName('AddPayPeriod');
 		$cjf->setMinute(0);
 		$cjf->setHour(0);
@@ -75,7 +75,7 @@ class InstallSchema_1000A extends InstallSchema_Base {
 		$cjf->setCommand($cron_job_base_command.'AddPayPeriod.php');
 		$cjf->Save();
 
-		$cjf = new CronJobFactory();
+		$cjf = TTnew( 'CronJobFactory' );
 		$cjf->setName('AddUserDate');
 		$cjf->setMinute(15);
 		$cjf->setHour(0);
@@ -85,7 +85,7 @@ class InstallSchema_1000A extends InstallSchema_Base {
 		$cjf->setCommand($cron_job_base_command.'AddUserDate.php');
 		$cjf->Save();
 
-		$cjf = new CronJobFactory();
+		$cjf = TTnew( 'CronJobFactory' );
 		$cjf->setName('calcExceptions');
 		$cjf->setMinute(30);
 		$cjf->setHour(0);
@@ -95,7 +95,7 @@ class InstallSchema_1000A extends InstallSchema_Base {
 		$cjf->setCommand($cron_job_base_command.'calcExceptions.php');
 		$cjf->Save();
 
-		$cjf = new CronJobFactory();
+		$cjf = TTnew( 'CronJobFactory' );
 		$cjf->setName('AddRecurringPayStubAmendment');
 		$cjf->setMinute(45);
 		$cjf->setHour(0);
@@ -105,7 +105,7 @@ class InstallSchema_1000A extends InstallSchema_Base {
 		$cjf->setCommand($cron_job_base_command.'AddRecurringPayStubAmendment.php');
 		$cjf->Save();
 
-		$cjf = new CronJobFactory();
+		$cjf = TTnew( 'CronJobFactory' );
 		$cjf->setName('AddRecurringHoliday');
 		$cjf->setMinute(55);
 		$cjf->setHour(0);
@@ -115,7 +115,7 @@ class InstallSchema_1000A extends InstallSchema_Base {
 		$cjf->setCommand($cron_job_base_command.'AddRecurringHoliday.php');
 		$cjf->Save();
 
-		$cjf = new CronJobFactory();
+		$cjf = TTnew( 'CronJobFactory' );
 		$cjf->setName('UserCount');
 		$cjf->setMinute(15);
 		$cjf->setHour(1);
@@ -125,7 +125,7 @@ class InstallSchema_1000A extends InstallSchema_Base {
 		$cjf->setCommand($cron_job_base_command.'UserCount.php');
 		$cjf->Save();
 
-		$cjf = new CronJobFactory();
+		$cjf = TTnew( 'CronJobFactory' );
 		$cjf->setName('AddRecurringScheduleShift');
 		$cjf->setMinute('20,50');
 		$cjf->setHour('*');
@@ -135,7 +135,7 @@ class InstallSchema_1000A extends InstallSchema_Base {
 		$cjf->setCommand($cron_job_base_command.'AddRecurringScheduleShift.php');
 		$cjf->Save();
 
-		$cjf = new CronJobFactory();
+		$cjf = TTnew( 'CronJobFactory' );
 		$cjf->setName('CheckForUpdate');
 		$cjf->setMinute( rand(0,59) ); //Random time once a day for load balancing
 		$cjf->setHour( rand(0,23) ); //Random time once a day for load balancing
