@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2095 $
- * $Id: InstallSchema_1002T.class.php 2095 2008-09-01 07:04:25Z ipso $
- * $Date: 2008-09-01 00:04:25 -0700 (Mon, 01 Sep 2008) $
+ * $Revision: 4104 $
+ * $Id: InstallSchema_1002T.class.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 
 /**
@@ -56,7 +56,7 @@ class InstallSchema_1002T extends InstallSchema_Base {
 
 		Debug::text('postInstall: '. $this->getVersion(), __FILE__, __LINE__, __METHOD__,9);
 
-		$sslf = new SystemSettingListFactory();
+		$sslf = TTnew( 'SystemSettingListFactory' );
 
 		//
 		// Tax Data Version
@@ -65,7 +65,7 @@ class InstallSchema_1002T extends InstallSchema_Base {
 		if ( $sslf->getRecordCount() == 1 ) {
 			$obj = $sslf->getCurrent();
 		} else {
-			$obj = new SystemSettingListFactory();
+			$obj = TTnew( 'SystemSettingListFactory' );
 		}
 
 		$tax_data_version = '20070101.0';
@@ -83,7 +83,7 @@ class InstallSchema_1002T extends InstallSchema_Base {
 		if ( $sslf->getRecordCount() == 1 ) {
 			$obj = $sslf->getCurrent();
 		} else {
-			$obj = new SystemSettingListFactory();
+			$obj = TTnew( 'SystemSettingListFactory' );
 		}
 
 		$tax_engine_version = '1.0.3';
