@@ -56,7 +56,7 @@ class InstallSchema_1008T extends InstallSchema_Base {
 
 		Debug::text('postInstall: '. $this->getVersion(), __FILE__, __LINE__, __METHOD__,9);
 
-		$sslf = new SystemSettingListFactory();
+		$sslf = TTnew( 'SystemSettingListFactory' );
 
 		//
 		// Tax Data Version
@@ -65,7 +65,7 @@ class InstallSchema_1008T extends InstallSchema_Base {
 		if ( $sslf->getRecordCount() == 1 ) {
 			$obj = $sslf->getCurrent();
 		} else {
-			$obj = new SystemSettingListFactory();
+			$obj = TTnew( 'SystemSettingListFactory' );
 		}
 
 		$tax_data_version = '20090101';
@@ -83,7 +83,7 @@ class InstallSchema_1008T extends InstallSchema_Base {
 		if ( $sslf->getRecordCount() == 1 ) {
 			$obj = $sslf->getCurrent();
 		} else {
-			$obj = new SystemSettingListFactory();
+			$obj = TTnew( 'SystemSettingListFactory' );
 		}
 
 		$tax_engine_version = '1.0.9';
