@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2095 $
- * $Id: InstallSchema_1012A.class.php 2095 2008-09-01 07:04:25Z ipso $
- * $Date: 2008-09-01 00:04:25 -0700 (Mon, 01 Sep 2008) $
+ * $Revision: 4104 $
+ * $Id: InstallSchema_1012A.class.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 
 /**
@@ -56,7 +56,7 @@ class InstallSchema_1012A extends InstallSchema_Base {
 		Debug::text('postInstall: '. $this->getVersion(), __FILE__, __LINE__, __METHOD__,9);
 		
 		//Get all pay period schedules.
-		$ppslf = new PayPeriodScheduleListFactory();
+		$ppslf = TTnew( 'PayPeriodScheduleListFactory' );
 		$ppslf->getAll();
 		if ( $ppslf->getRecordCount() > 0 ) {
 			foreach( $ppslf as $pps_obj ) {
@@ -64,7 +64,7 @@ class InstallSchema_1012A extends InstallSchema_Base {
 				if ( is_array($user_ids) ) {
 					$time_zone_arr = array();
 					foreach( $user_ids as $user_id ) {
-						$uplf = new UserPreferenceListFactory();
+						$uplf = TTnew( 'UserPreferenceListFactory' );
 						$uplf->getByUserId( $user_id );
 						if ( $uplf->getRecordCount() > 0 ) {
 							if ( isset($time_zone_arr[$uplf->getCurrent()->getTimeZone()]) ) {
