@@ -58,7 +58,7 @@ class InstallSchema_1026A extends InstallSchema_Base {
 
 		//Find out if they have both TimeClocks and FingerPrint stations. If they do
 		//we need to copy the fingerprint data to both types of UserIdentification rows.
-		$clf = new CompanyListFactory();
+		$clf = TTnew( 'CompanyListFactory' );
 		$clf->getAll();
 
 		$clf->StartTransaction();
@@ -67,7 +67,7 @@ class InstallSchema_1026A extends InstallSchema_Base {
 
 			$max_templates = 4;
 
-			$slf = new StationListFactory();
+			$slf = TTnew( 'StationListFactory' );
 			$slf->getByCompanyIdAndTypeId( $c_obj->getId(), array(30,40,50,100,110) );
 			if ( $slf->getRecordCount() > 0 ) {
 				$slf_tmp1 = $slf->getByCompanyIdAndTypeId( $c_obj->getId(), array(50) );
@@ -86,14 +86,14 @@ class InstallSchema_1026A extends InstallSchema_Base {
 				unset($slf_tmp3);
 
 				//Loop through each user copying their data to the UserIdenfification Table.
-				$ulf = new UserListFactory();
+				$ulf = TTnew( 'UserListFactory' );
 				$ulf->getByCompanyID( $c_obj->getId() );
 				if ( $ulf->getRecordCount() > 0 ) {
 					foreach( $ulf as $u_obj ) {
 						Debug::text('  User: '. $u_obj->getUserName(), __FILE__, __LINE__, __METHOD__,9);
 						if ( $u_obj->getIButtonID() != '' ) {
 							Debug::text('    Converting iButton...', __FILE__, __LINE__, __METHOD__,9);
-							$uif = new UserIdentificationFactory();
+							$uif = TTnew( 'UserIdentificationFactory' );
 							$uif->setUser( $u_obj->getId() );
 							$uif->setType( 10 ); //10=iButton
 							$uif->setNumber( 0 );
@@ -106,7 +106,7 @@ class InstallSchema_1026A extends InstallSchema_Base {
 
 						if ( $u_obj->getRFID() != '' ) {
 							Debug::text('    Converting RFID...', __FILE__, __LINE__, __METHOD__,9);
-							$uif = new UserIdentificationFactory();
+							$uif = TTnew( 'UserIdentificationFactory' );
 							$uif->setUser( $u_obj->getId() );
 							$uif->setType( 40 ); //40=Proximity
 							$uif->setNumber( 0 );
@@ -119,7 +119,7 @@ class InstallSchema_1026A extends InstallSchema_Base {
 
 						if ( $barcode_stations > 0 AND $u_obj->getEmployeeNumber() != '' ) {
 							Debug::text('    Converting EmployeeNumber...', __FILE__, __LINE__, __METHOD__,9);
-							$uif = new UserIdentificationFactory();
+							$uif = TTnew( 'UserIdentificationFactory' );
 							$uif->setUser( $u_obj->getId() );
 							$uif->setType( 30 ); //30=Barcode
 							$uif->setNumber( 0 );
@@ -139,7 +139,7 @@ class InstallSchema_1026A extends InstallSchema_Base {
 										AND substr($u_obj->$get_fingerprint_function(), 0, 4) == 'p/8B' ) {
 									Debug::text('    Converting Griaule FingerPrint: '. $t, __FILE__, __LINE__, __METHOD__,9);
 
-									$uif = new UserIdentificationFactory();
+									$uif = TTnew( 'UserIdentificationFactory' );
 									$uif->setUser( $u_obj->getId() );
 									$uif->setType( 20 ); //20=Griaule, 100=ZK
 									$uif->setNumber( ($t*10) );
@@ -161,7 +161,7 @@ class InstallSchema_1026A extends InstallSchema_Base {
 								if ( $u_obj->$get_fingerprint_function() != ''
 										AND substr($u_obj->$get_fingerprint_function(), 0, 3) == 'oco' ) {
 									Debug::text('    Converting ZK FingerPrint: '. $t, __FILE__, __LINE__, __METHOD__,9);
-									$uif = new UserIdentificationFactory();
+									$uif = TTnew( 'UserIdentificationFactory' );
 									$uif->setUser( $u_obj->getId() );
 									$uif->setType( 100 ); //20=Griaule, 100=ZK
 									$uif->setNumber( $t );
