@@ -55,7 +55,7 @@ class InstallSchema_1031A extends InstallSchema_Base {
 		Debug::text('postInstall: '. $this->getVersion(), __FILE__, __LINE__, __METHOD__,9);
 
 		//Go through all pay period schedules and update the annual pay period column
-		$ppslf = new PayPeriodScheduleListFactory();
+		$ppslf = TTnew( 'PayPeriodScheduleListFactory' );
 		$ppslf->getAll();
 		if ( $ppslf->getRecordCount() > 0 ) {
 			foreach( $ppslf as $pps_obj ) {
@@ -69,7 +69,7 @@ class InstallSchema_1031A extends InstallSchema_Base {
 		//Go through all employee wages and update HourlyRate to the accurate annual hourly rate.
 		//**Handle this in 1034A postInstall() instead, as it needs to handle incorrect effective_dates properly.
 		/*
-		$uwlf = new UserWageListFactory();
+		$uwlf = TTnew( 'UserWageListFactory' );
 		$uwlf->getAll();
 		if ( $uwlf->getRecordCount() > 0 ) {
 			foreach( $uwlf as $uw_obj ) {
@@ -82,20 +82,15 @@ class InstallSchema_1031A extends InstallSchema_Base {
 		*/
 
 		//Upgrade to new hierarchy format.
-		$clf = new CompanyListFactory();
+		$clf = TTnew( 'CompanyListFactory' );
 		$clf->getAll();
 		if ( $clf->getRecordCount() > 0 ) {
 			foreach ( $clf as $c_obj ) {
 				if ( $c_obj->getStatus() != 30 ) {
-/*
-					if ( !($c_obj->getId() == 1052) ) { //$c_obj->getId() == 1009 OR $c_obj->getId() == 1087 OR
-						continue;
-					}
-*/
 					$company_id = $c_obj->getId();
 					Debug::Text(' Company ID: '. $company_id, __FILE__, __LINE__, __METHOD__,10);
 
-					$hclf = new HierarchyControlListFactory();
+					$hclf = TTnew( 'HierarchyControlListFactory' );
 					$hclf->StartTransaction();
 					$hclf->getByCompanyId( $company_id );
 					if ( $hclf->getRecordCount() > 0 ) {
@@ -103,10 +98,10 @@ class InstallSchema_1031A extends InstallSchema_Base {
 							$paths_to_root = array();
 							$hierarchy_id = $hc_obj->getId();
 
-							$hlf = new HierarchyListFactory();
+							$hlf = TTnew( 'HierarchyListFactory' );
 							$hierarchy_users = $hlf->getByCompanyIdAndHierarchyControlId( $company_id, $hierarchy_id );
 							if ( is_array($hierarchy_users) AND count($hierarchy_users) > 0 ) {
-								$hotlf = new HierarchyObjectTypeListFactory();
+								$hotlf = TTnew( 'HierarchyObjectTypeListFactory' );
 								$hotlf->getByHierarchyControlId( $hierarchy_id );
 								if ( $hotlf->getRecordCount() > 0 ) {
 									foreach( $hotlf as $hot_obj ) {
@@ -122,7 +117,7 @@ class InstallSchema_1031A extends InstallSchema_Base {
 									$i = 0;
 									do {
 										Debug::Text(' Iteration...', __FILE__, __LINE__, __METHOD__,10);
-										$hlf_b = new HierarchyListFactory();
+										$hlf_b = TTnew( 'HierarchyListFactory' );
 										$parents = $hlf_b->getParentLevelIdArrayByHierarchyControlIdAndUserId( $hierarchy_id, $tmp_id);
 										sort($parents);
 
@@ -171,7 +166,7 @@ class InstallSchema_1031A extends InstallSchema_Base {
 										Debug::Text(' Company ID: '. $company_id, __FILE__, __LINE__, __METHOD__,10);
 
 										//Create new hierarchy_control
-										$hcf = new HierarchyControlFactory();
+										$hcf = TTnew( 'HierarchyControlFactory' );
 										$hcf->setCompany( $company_id );
 										$hcf->setObjectType(  $object_types[$decoded_path['hierarchy_control_id']] );
 
@@ -182,7 +177,7 @@ class InstallSchema_1031A extends InstallSchema_Base {
 
 											foreach( $decoded_path['path'] as $level => $superior_ids ) {
 												foreach( $superior_ids as $superior_id) {
-													$ulf = new UserListFactory();
+													$ulf = TTnew( 'UserListFactory' );
 													$ulf->getById( $superior_id );
 
 													if ( $ulf->getRecordCount() > 0 ) {
@@ -211,7 +206,7 @@ class InstallSchema_1031A extends InstallSchema_Base {
 											if ( isset($decoded_path['path']) AND is_array($decoded_path['path']) ) {
 												foreach( $decoded_path['path'] as $level => $superior_ids ) {
 													foreach( $superior_ids as $superior_id ) {
-														$hlf = new HierarchyLevelFactory();
+														$hlf = TTnew( 'HierarchyLevelFactory' );
 														$hlf->setHierarchyControl( $hc_id );
 														$hlf->setLevel( $level );
 														$hlf->setUser( $superior_id );
@@ -245,18 +240,18 @@ class InstallSchema_1031A extends InstallSchema_Base {
 		}
 
 		//Go through each permission group, and enable break policies for anyone who can see meal policies
-		$clf = new CompanyListFactory();
+		$clf = TTnew( 'CompanyListFactory' );
 		$clf->getAll();
 		if ( $clf->getRecordCount() > 0 ) {
 			foreach( $clf as $c_obj ) {
 				Debug::text('Company: '. $c_obj->getName(), __FILE__, __LINE__, __METHOD__,9);
 				if ( $c_obj->getStatus() != 30 ) {
-					$pclf = new PermissionControlListFactory();
-					$pclf->getByCompanyId( $c_obj->getId() );
+					$pclf = TTnew( 'PermissionControlListFactory' );
+					$pclf->getByCompanyId( $c_obj->getId(), NULL, NULL, NULL, array( 'name' => 'asc' ) ); //Force order to prevent references to columns that haven't been created yet.
 					if ( $pclf->getRecordCount() > 0 ) {
 						foreach( $pclf as $pc_obj ) {
 							Debug::text('Permission Group: '. $pc_obj->getName(), __FILE__, __LINE__, __METHOD__,9);
-							$plf = new PermissionListFactory();
+							$plf = TTnew( 'PermissionListFactory' );
 							$plf->getByCompanyIdAndPermissionControlIdAndSectionAndName( $c_obj->getId(), $pc_obj->getId(), 'meal_policy', 'enabled');
 							if ( $plf->getRecordCount() > 0 ) {
 								Debug::text('Found permission group with meal policy enabled: '. $plf->getCurrent()->getValue(), __FILE__, __LINE__, __METHOD__,9);
@@ -280,8 +275,81 @@ class InstallSchema_1031A extends InstallSchema_Base {
 			}
 		}
 
+		//This used to be handled in 1016T postInstall function, but when upgrading really old versions (ie: 2.2.22) of TimeTrex to newer
+		//ones (ie: 3.3.2) it would fail because new columns have been added to the company_deduction table in schema 1031A.
+		//Migrate to completely separate Tax / Deductions for social security, as the employee and employer rates are different now.
+		$clf = TTnew( 'CompanyListFactory' );
+		$clf->getAll();
+		if ( $clf->getRecordCount() > 0 ) {
+			foreach( $clf as $c_obj ) {
+				Debug::text('Company: '. $c_obj->getName(), __FILE__, __LINE__, __METHOD__,9);
+				if ( $c_obj->getStatus() != 30 AND $c_obj->getCountry() == 'US' ) {
+					//Get PayStub Link accounts
+					$pseallf = TTnew( 'PayStubEntryAccountLinkListFactory' );
+					$pseallf->getByCompanyId( $c_obj->getID() );
+					if  ( $pseallf->getRecordCount() > 0 ) {
+						$psea_obj = $pseallf->getCurrent();
+					} else {
+						Debug::text('Failed getting PayStubEntryLink for Company ID: '. $company_id , __FILE__, __LINE__, __METHOD__, 10);
+						continue;
+					}
+
+					$include_pay_stub_accounts = FALSE;
+					$exclude_pay_stub_accounts = FALSE;
+
+					$cdlf = TTnew( 'CompanyDeductionListFactory' );
+					$cdlf->getByCompanyIdAndName($c_obj->getID(), 'Social Security - Employee' );
+					if ( $cdlf->getRecordCount() == 1 ) {
+						$cd_obj = $cdlf->getCurrent();
+						Debug::text('Found SS Employee Tax / Deduction, ID: '. $c_obj->getID() .' Percent: '. $cd_obj->getUserValue1() .' Wage Base: '. $cd_obj->getUserValue2(), __FILE__, __LINE__, __METHOD__,9);
+						if ( $cd_obj->getCalculation() == 15 AND $cd_obj->getUserValue1() == 6.2 AND $cd_obj->getUserValue2() <= 106800 ) {
+							Debug::text('SS Employee Tax / Deduction Matches... Adjusting for 2011...', __FILE__, __LINE__, __METHOD__,9);
+							$cd_obj->setUserValue1(4.2);
+							$cd_obj->setUserValue2(106800);
+							$include_pay_stub_accounts = $cd_obj->getIncludePayStubEntryAccount();
+							$exclude_pay_stub_accounts = $cd_obj->getExcludePayStubEntryAccount();
+							if ( $cd_obj->isValid() ) {
+								$cd_obj->Save();
+							}
+						}
+					} else {
+						Debug::text('Failed to find SS Employee Tax / Deduction for Company: '. $c_obj->getName(), __FILE__, __LINE__, __METHOD__,9);
+					}
+					unset($cdlf, $cd_obj);
+
+					$cdlf = TTnew( 'CompanyDeductionListFactory' );
+					$cdlf->getByCompanyIdAndName($c_obj->getID(), 'Social Security - Employer' );
+					if ( $cdlf->getRecordCount() == 1 ) {
+						$cd_obj = $cdlf->getCurrent();
+						Debug::text('Found SS Employer Tax / Deduction, ID: '. $c_obj->getID() .' Percent: '. $cd_obj->getUserValue1(), __FILE__, __LINE__, __METHOD__,9);
+						if ( $cd_obj->getCalculation() == 10 AND $cd_obj->getUserValue1() == 100 ) {
+							Debug::text('SS Employer Tax / Deduction Matches... Adjusting for 2011...', __FILE__, __LINE__, __METHOD__,9);
+							$cd_obj->setCalculation(15);
+							$cd_obj->setUserValue1(6.2);
+							$cd_obj->setUserValue2(106800);
+							if ( $include_pay_stub_accounts !== FALSE ) {
+								Debug::text('Matching Include/Exclude accounts with SS Employee Entry...', __FILE__, __LINE__, __METHOD__,9);
+								//Match include accounts with SS employee entry.
+								$cd_obj->setIncludePayStubEntryAccount( $include_pay_stub_accounts );
+								$cd_obj->setExcludePayStubEntryAccount( $exclude_pay_stub_accounts );
+							} else {
+								Debug::text('NOT Matching Include/Exclude accounts with SS Employee Entry...', __FILE__, __LINE__, __METHOD__,9);
+								$cd_obj->setIncludePayStubEntryAccount( array( $psea_obj->getTotalGross() ));
+							}
+
+							if ( $cd_obj->isValid() ) {
+								$cd_obj->Save();
+							}
+						}
+					} else {
+						Debug::text('Failed to find SS Employer Tax / Deduction for Company: '. $c_obj->getName(), __FILE__, __LINE__, __METHOD__,9);
+					}
+				}
+			}
+		}
+
 		//Add MiscDaily cronjob to database.
-		$cjf = new CronJobFactory();
+		$cjf = TTnew( 'CronJobFactory' );
 		$cjf->setName('MiscDaily');
 		$cjf->setMinute(55);
 		$cjf->setHour(1);
@@ -292,7 +360,7 @@ class InstallSchema_1031A extends InstallSchema_Base {
 		$cjf->Save();
 
 		//Add MiscWeekly cronjob to database.
-		$cjf = new CronJobFactory();
+		$cjf = TTnew( 'CronJobFactory' );
 		$cjf->setName('MiscWeekly');
 		$cjf->setMinute(55);
 		$cjf->setHour(1);
