@@ -123,6 +123,9 @@ class MessageControlFactory extends Factory {
 										//'-2030-updated_date' => TTi18n::gettext('Updated Date'),
 							);
 				break;
+			case 'list_columns':
+				$retval = Misc::arrayIntersectByKey( $this->getOptions('default_display_columns'), Misc::trimSortPrefix( $this->getOptions('columns') ) );
+				break;
 			case 'default_display_columns': //Columns that are displayed by default.
 				$retval = array(
 								'from_first_name',
@@ -283,16 +286,16 @@ class MessageControlFactory extends Factory {
 			switch ( $this->getObjectType() ) {
 				case 5:
 				case 100:
-					$this->obj_handler = new UserListFactory();
+					$this->obj_handler = TTnew( 'UserListFactory' );
 					break;
 				case 40:
-					$this->obj_handler = new AuthorizationListFactory();
+					$this->obj_handler = TTnew( 'AuthorizationListFactory' );
 					break;
 				case 50:
-					$this->obj_handler = new RequestListFactory();
+					$this->obj_handler = TTnew( 'RequestListFactory' );
 					break;
 				case 90:
-					$this->obj_handler = new PayPeriodTimeSheetVerifyListFactory();
+					$this->obj_handler = TTnew( 'PayPeriodTimeSheetVerifyListFactory' );
 					break;
 			}
 
@@ -491,7 +494,7 @@ class MessageControlFactory extends Factory {
 
 		Debug::Arr($ids, 'Message Recipeint Ids: ', __FILE__, __LINE__, __METHOD__,10);
 
-		$mrlf = new MessageRecipientListFactory();
+		$mrlf = TTnew( 'MessageRecipientListFactory' );
 		$mrlf->getByCompanyIdAndUserIdAndMessageSenderIdAndStatus( $company_id, $user_id, $ids, 10 );
 		if ( $mrlf->getRecordCount() > 0 ) {
 			foreach( $mrlf as $mr_obj ) {
@@ -509,7 +512,7 @@ class MessageControlFactory extends Factory {
 			//Get user preferences and determine if they accept email notifications.
 			Debug::Arr($user_ids, 'Recipient User Ids: ', __FILE__, __LINE__, __METHOD__,10);
 
-			$uplf = new UserPreferenceListFactory();
+			$uplf = TTnew( 'UserPreferenceListFactory' );
 			$uplf->getByUserId( $user_ids );
 			if ( $uplf->getRecordCount() > 0 ) {
 				foreach( $uplf as $up_obj ) {
@@ -647,7 +650,7 @@ class MessageControlFactory extends Factory {
 					//On the other hand, having multiple sender records, one for each recipient makes it hard to show
 					//just the necessary messages on the embedded message list, as it wants to show duplicates messages for
 					//each recipient.
-					$msf = new MessageSenderFactory();
+					$msf = TTnew( 'MessageSenderFactory' );
 					$msf->setUser( $this->getFromUserId() );
 					Debug::Text('Parent ID: '. $this->getParent(), __FILE__, __LINE__, __METHOD__,10);
 
@@ -663,7 +666,7 @@ class MessageControlFactory extends Factory {
 						Debug::Text('Message Sender ID: '. $message_sender_id, __FILE__, __LINE__, __METHOD__,10);
 
 						if ( $message_sender_id != FALSE ) {
-							$mrf = new MessageRecipientFactory();
+							$mrf = TTnew( 'MessageRecipientFactory' );
 							$mrf->setUser( $to_user_id );
 							$mrf->setMessageSender( $message_sender_id );
 							if ( isset($this->migration_status) ) {
