@@ -227,8 +227,6 @@ class MessageControlListFactory extends MessageControlFactory implements Iterato
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
 
-		//Debug::text('Query: '. $query , __FILE__, __LINE__, __METHOD__,9);
-
 		if ($limit == NULL) {
 			//Run query without limit
 			$this->rs = $this->db->Execute($query, $ph);
@@ -315,8 +313,6 @@ class MessageControlListFactory extends MessageControlFactory implements Iterato
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order, $strict, array('from_last_name', 'to_last_name') );
 
-		//Debug::text('Query: '. $query , __FILE__, __LINE__, __METHOD__,9);
-
 		if ($limit == NULL) {
 			//Run query without limit
 			$this->rs = $this->db->Execute($query, $ph);
@@ -417,8 +413,6 @@ class MessageControlListFactory extends MessageControlFactory implements Iterato
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
 
-		//Debug::text('Query: '. $query , __FILE__, __LINE__, __METHOD__,9);
-
 		if ($limit == NULL) {
 			//Run query without limit
 			$this->rs = $this->db->Execute($query, $ph);
@@ -485,8 +479,6 @@ class MessageControlListFactory extends MessageControlFactory implements Iterato
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
 
-		//Debug::text('Query: '. $query , __FILE__, __LINE__, __METHOD__,9);
-
 		if ($limit == NULL) {
 			//Run query without limit
 			$this->rs = $this->db->Execute($query, $ph);
@@ -719,8 +711,6 @@ class MessageControlListFactory extends MessageControlFactory implements Iterato
 						';
 		}
 
-		Debug::Text('Query: '. $query, __FILE__, __LINE__, __METHOD__,10);
-
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
 
@@ -808,8 +798,6 @@ class MessageControlListFactory extends MessageControlFactory implements Iterato
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order, $strict, array('from_last_name', 'to_last_name') );
 
-		//Debug::text('Query: '. $query , __FILE__, __LINE__, __METHOD__,9);
-
 		if ($limit == NULL) {
 			//Run query without limit
 			$this->rs = $this->db->Execute($query, $ph);
