@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3351 $
- * $Id: MessageFactory.class.php 3351 2010-02-18 17:22:09Z ipso $
- * $Date: 2010-02-18 09:22:09 -0800 (Thu, 18 Feb 2010) $
+ * $Revision: 4104 $
+ * $Id: MessageFactory.class.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 
 /**
@@ -123,7 +123,7 @@ class MessageFactory extends Factory {
 			$id = 0;
 		}
 
-		$mlf = new MessageListFactory();
+		$mlf = TTnew( 'MessageListFactory' );
 
 		if ( $id == 0
 				OR $this->Validator->isResultSetWithRows(	'parent',
@@ -145,16 +145,16 @@ class MessageFactory extends Factory {
 			switch ( $this->getObjectType() ) {
 				case 5:
 				case 100:
-					$this->obj_handler = new UserListFactory();
+					$this->obj_handler = TTnew( 'UserListFactory' );
 					break;
 				case 40:
-					$this->obj_handler = new AuthorizationListFactory();
+					$this->obj_handler = TTnew( 'AuthorizationListFactory' );
 					break;
 				case 50:
-					$this->obj_handler = new RequestListFactory();
+					$this->obj_handler = TTnew( 'RequestListFactory' );
 					break;
 				case 90:
-					$this->obj_handler = new PayPeriodTimeSheetVerifyListFactory();
+					$this->obj_handler = TTnew( 'PayPeriodTimeSheetVerifyListFactory' );
 					break;
 			}
 
@@ -430,7 +430,7 @@ class MessageFactory extends Factory {
 			}
 		}
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 
 		if ( $this->Validator->isResultSetWithRows(	'ack_by',
 													$ulf->getByID($id),
@@ -460,7 +460,7 @@ class MessageFactory extends Factory {
 						if ( $this->getParent() == 0 ) {
 							$user_ids[] = $obj->getId();
 						} else {
-							$mlf = new MessageListFactory();
+							$mlf = TTnew( 'MessageListFactory' );
 							$mlf->getById( $this->getParent() );
 							if ( $mlf->getRecordCount() > 0 ) {
 								$m_obj = $mlf->getCurrent();
@@ -475,7 +475,7 @@ class MessageFactory extends Factory {
 						break;
 					case 50: //Request
 						//Get all users who have contributed to the thread.
-						$mlf = new MessageListFactory();
+						$mlf = TTnew( 'MessageListFactory' );
 						$mlf->getMessagesInThreadById( $this->getId() );
 						Debug::Text(' Messages In Thread: '. $mlf->getRecordCount() , __FILE__, __LINE__, __METHOD__,10);
 						if ( $mlf->getRecordCount() > 0 ) {
@@ -492,7 +492,7 @@ class MessageFactory extends Factory {
 							//Get direct parent in hierarchy.
 							$u_obj = $obj->getUserObject();
 
-							$hlf = new HierarchyListFactory();
+							$hlf = TTnew( 'HierarchyListFactory' );
 							$user_ids[] = $hlf->getHierarchyParentByCompanyIdAndUserIdAndObjectTypeID( $u_obj->getCompany(), $u_obj->getId(), $this->getObjectType(), TRUE, FALSE );
 							unset($hlf);
 						}
@@ -522,7 +522,7 @@ class MessageFactory extends Factory {
 				//Get user preferences and determine if they accept email notifications.
 				Debug::Arr($user_ids, 'Recipient User Ids: ', __FILE__, __LINE__, __METHOD__,10);
 
-				$uplf = new UserPreferenceListFactory();
+				$uplf = TTnew( 'UserPreferenceListFactory' );
 				$uplf->getByUserId( $user_ids );
 				if ( $uplf->getRecordCount() > 0 ) {
 					foreach( $uplf as $up_obj ) {
