@@ -68,7 +68,7 @@ class MessageRecipientFactory extends Factory {
 	function setUser($id) {
 		$id = trim($id);
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 
 		if ( $id == 0
 				OR $this->Validator->isResultSetWithRows(	'user',
@@ -93,7 +93,7 @@ class MessageRecipientFactory extends Factory {
 	function setMessageSender($id) {
 		$id = trim($id);
 
-		$mslf = new MessageSenderListFactory();
+		$mslf = TTnew( 'MessageSenderListFactory' );
 
 		if ( $this->Validator->isResultSetWithRows(	'message_sender_id',
 													$mslf->getByID($id),
@@ -117,7 +117,7 @@ class MessageRecipientFactory extends Factory {
 	function setMessageControl($id) {
 		$id = trim($id);
 
-		$mclf = new MessageControlListFactory();
+		$mclf = TTnew( 'MessageControlListFactory' );
 
 		if ( $this->Validator->isResultSetWithRows(	'message_control_id',
 													$mclf->getByID($id),
