@@ -53,7 +53,7 @@ class MessageSenderFactory extends Factory {
 	function setUser($id) {
 		$id = trim($id);
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 
 		if ( $id == 0
 				OR $this->Validator->isResultSetWithRows(	'user',
@@ -82,7 +82,7 @@ class MessageSenderFactory extends Factory {
 			$id = 0;
 		}
 
-		$mslf = new MessageSenderListFactory();
+		$mslf = TTnew( 'MessageSenderListFactory' );
 
 		if ( $id == 0
 				OR $this->Validator->isResultSetWithRows(	'parent',
@@ -107,7 +107,7 @@ class MessageSenderFactory extends Factory {
 	function setMessageControl($id) {
 		$id = trim($id);
 
-		$mclf = new MessageControlListFactory();
+		$mclf = TTnew( 'MessageControlListFactory' );
 
 		if ( $this->Validator->isResultSetWithRows(	'message_control_id',
 													$mclf->getByID($id),
