@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3628 $
- * $Id: EFT.class.php 3628 2010-05-28 00:36:37Z ipso $
- * $Date: 2010-05-27 17:36:37 -0700 (Thu, 27 May 2010) $
+ * $Revision: 3934 $
+ * $Id: EFT.class.php 3934 2010-11-17 23:29:44Z ipso $
+ * $Date: 2010-11-17 15:29:44 -0800 (Wed, 17 Nov 2010) $
  */
 
 /*
@@ -653,6 +653,7 @@ class EFT_record extends EFT {
 
 /**
  * @package Module_Other
+ * CPA005 Specification: http://www.google.ca/url?sa=t&source=web&cd=2&ved=0CBkQFjAB&url=https%3A%2F%2Fwww.rbcroyalbank.com%2Fach%2Ffile-451771.pdf&rct=j&q=CPA%20005%20file%20format&ei=KMK8TNqaE46osQORn-ScDw&usg=AFQjCNECApa4o_mADTwtF4WIrBDf6cZq9w
  */
 class EFT_File_Format_1464 Extends EFT {
 	var $header_data = NULL;
@@ -738,7 +739,21 @@ class EFT_File_Format_1464 Extends EFT {
 			}
 			unset($sanity_check_2);
 
+			$line[] = $this->padRecord( NULL, 15, 'AN'); //Originators Sundry Info. -- Blank
+			$line[] = $this->padRecord( NULL, 22, 'AN'); //Stored Trace Number -- Blank
+			$line[] = $this->padRecord( NULL, 2, 'AN'); //Settlement Code -- Blank
+			$line[] = $this->padRecord( NULL, 11, 'N'); //Invalid Data Element, must be 0's for HSBC to accept it -- Blank
+
+			$sanity_check_3 = strlen( implode('', $line) );
+			Debug::Text('Digits to END of invalid data element: '. $sanity_check_3 .' - Should be: 264', __FILE__, __LINE__, __METHOD__, 10);
+			if ( $sanity_check_3 !== 264 ) {
+				Debug::Text('Failed Sanity Check 3', __FILE__, __LINE__, __METHOD__, 10);
+				return FALSE;
+			}
+			unset($sanity_check_3);
+
 			$d_record = $this->padLine( implode('', $line), 1464 );
+			//strlen($d_record) might show 1466 (2digits more), due to "/n" being at the end.
 			Debug::Text('D Record:'. $d_record .' - Length: '. strlen($d_record), __FILE__, __LINE__, __METHOD__, 10);
 
 			$retval[] = $d_record;
@@ -764,7 +779,7 @@ class EFT_File_Format_1464 Extends EFT {
 		$line[] = 'Z'; //Z Record
 
 		//$line[] = '000000001'; //Z Record number
-		$line[] = $this->padRecord( count($this->compiled_data)+2, 9, 'N'); //add 2, 1 for the A record, and 1 for the Z record.
+		$line[] = $this->padRecord( count($this->data)+2, 9, 'N'); //add 2, 1 for the A record, and 1 for the Z record.
 
 		$line[] = $this->padRecord( $this->getOriginatorID(), 10, 'AN');
 		$line[] = $this->padRecord( $this->getFileCreationNumber(), 4, 'N');
@@ -790,6 +805,11 @@ class EFT_File_Format_1464 Extends EFT {
 		$line[] = $this->padRecord( $this->removeDecimal( $c_record_total ), 14, 'N');
 		$line[] = $this->padRecord( $c_record_count, 8, 'N');
 
+		$line[] = $this->padRecord( NULL, 14, 'N'); //Invalid Data Element, must be 0's for HSBC to accept it -- Blank
+		$line[] = $this->padRecord( NULL, 8, 'N'); //Invalid Data Element, must be 0's for HSBC to accept it -- Blank
+		$line[] = $this->padRecord( NULL, 14, 'N'); //Invalid Data Element, must be 0's for HSBC to accept it -- Blank
+		$line[] = $this->padRecord( NULL, 8, 'N'); //Invalid Data Element, must be 0's for HSBC to accept it -- Blank
+
 		$retval = $this->padLine( implode('', $line), 1464 );
 
 		Debug::Text('Z Record:'. $retval, __FILE__, __LINE__, __METHOD__, 10);
