@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3392 $
- * $Id: ROEFactory.class.php 3392 2010-03-05 19:31:18Z ipso $
- * $Date: 2010-03-05 11:31:18 -0800 (Fri, 05 Mar 2010) $
+ * $Revision: 4126 $
+ * $Id: ROEFactory.class.php 4126 2011-01-13 05:52:21Z ipso $
+ * $Date: 2011-01-12 21:52:21 -0800 (Wed, 12 Jan 2011) $
  */
 
 /**
@@ -81,7 +81,7 @@ class ROEFactory extends Factory {
 		if ( is_object($this->user_obj) ) {
 			return $this->user_obj;
 		} else {
-			$ulf = new UserListFactory();
+			$ulf = TTnew( 'UserListFactory' );
 			$this->user_obj = $ulf->getById( $this->getUser() )->getCurrent();
 
 			return $this->user_obj;
@@ -92,7 +92,7 @@ class ROEFactory extends Factory {
 		if ( is_object($this->pay_stub_entry_account_link_obj) ) {
 			return $this->pay_stub_entry_account_link_obj;
 		} else {
-			$pseallf = new PayStubEntryAccountLinkListFactory();
+			$pseallf = TTnew( 'PayStubEntryAccountLinkListFactory' );
 			$pseallf->getByCompanyID( $this->getUserObject()->getCompany() );
 			if ( $pseallf->getRecordCount() > 0 ) {
 				$this->pay_stub_entry_account_link_obj = $pseallf->getCurrent();
@@ -113,7 +113,7 @@ class ROEFactory extends Factory {
 	function setUser($id) {
 		$id = trim($id);
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 
 		if ( $this->Validator->isResultSetWithRows(	'user',
 															$ulf->getByID($id),
@@ -139,7 +139,7 @@ class ROEFactory extends Factory {
 
 		Debug::Text('Type ID: '. $value, __FILE__, __LINE__, __METHOD__,10);
 
-		$ppsf = new PayPeriodScheduleFactory();
+		$ppsf = TTnew( 'PayPeriodScheduleFactory' );
 
 		$key = Option::getByValue($value, $ppsf->getOptions('type') );
 		if ($key !== FALSE) {
@@ -429,7 +429,7 @@ class ROEFactory extends Factory {
 
 		$start_date = FALSE;
 
-		$pplf = new PayPeriodListFactory();
+		$pplf = TTnew( 'PayPeriodListFactory' );
 		$pay_period_obj = $pplf->getByUserIdAndEndDate( $this->getUser(), $this->getLastDate() )->getCurrent();
 		Debug::Text('Pay Period ID: '. $pay_period_obj->getId(), __FILE__, __LINE__, __METHOD__,10);
 
@@ -500,7 +500,7 @@ class ROEFactory extends Factory {
 	function getSetupData() {
 		//FIXME: Alert the user if they don't have enough information in TimeTrex to get accurate values.
 		//Get insurable hours, earnings, and vacation pay now that the final pay stub is generated
-		$ugdlf = new UserGenericDataListFactory();
+		$ugdlf = TTnew( 'UserGenericDataListFactory' );
 		$ugdlf->getByCompanyIdAndScriptAndDefault( $this->getUserObject()->getCompany(), $this->getTable() );
 		if ( $ugdlf->getRecordCount() > 0 ) {
 			Debug::Text('Found Company Form Setup!', __FILE__, __LINE__, __METHOD__,10);
@@ -528,7 +528,7 @@ class ROEFactory extends Factory {
 
 		$insurable_earnings_start_date = $this->getInsurablePayPeriodStartDate( $this->getInsurableEarningsReportPayPeriods() );
 
-		$pself = new PayStubEntryListFactory();
+		$pself = TTnew( 'PayStubEntryListFactory' );
 		$pself->getPayPeriodReportByUserIdAndEntryNameIdAndStartDateAndEndDate( $this->getUser(), $setup_data['insurable_earnings_psea_ids'], $insurable_earnings_start_date, $this->getLastDate(), 0, NULL, array('x.start_date' => 'desc') );
 		if ( $pself->getRecordCount() > 0 ) {
 			foreach( $pself as $pse_obj ) {
@@ -589,7 +589,7 @@ class ROEFactory extends Factory {
 		if ( is_array( $pay_period_earnings ) ) {
 			$last_pay_period_id = array_shift( array_keys( $pay_period_earnings ) );
 
-			$pself = new PayStubEntryListFactory();
+			$pself = TTnew( 'PayStubEntryListFactory' );
 			$retval = $pself->getAmountSumByUserIdAndEntryNameIdAndPayPeriodId( $this->getUser(), $setup_data['vacation_psea_ids'], (int)$last_pay_period_id);
 
 			Debug::Text('Last Pay Period Vacation Pay: '. $retval['amount'] .' Last Pay Period ID: '. $last_pay_period_id, __FILE__, __LINE__, __METHOD__,10);
@@ -602,7 +602,7 @@ class ROEFactory extends Factory {
 	function reCalculate() {
 		//Re-generate final pay stub
 		//get current pay period based off their last day of work
-		$pplf = new PayPeriodListFactory();
+		$pplf = TTnew( 'PayPeriodListFactory' );
 		$pay_period_id = $pplf->getByUserIdAndEndDate( $this->getUser(), $this->getLastDate() )->getCurrent()->getId();
 		Debug::Text('Pay Period ID: '. $pay_period_id, __FILE__, __LINE__, __METHOD__,10);
 
@@ -615,7 +615,7 @@ class ROEFactory extends Factory {
 		if ( $this->getEnableGeneratePayStub() == TRUE ) {
 			//Find out if a pay stub is already generated for the pay period we are currently in.
 			//If it is, delete it so we can start from fresh
-			$pslf = new PayStubListFactory();
+			$pslf = TTnew( 'PayStubListFactory' );
 			$pslf->getByUserIdAndPayPeriodId( $this->getUser(), $pay_period_id );
 
 			foreach ($pslf as $pay_stub) {
@@ -643,7 +643,7 @@ class ROEFactory extends Factory {
 
 		//FIXME: Alert the user if they don't have enough information in TimeTrex to get accurate values.
 		//Get insurable hours, earnings, and vacation pay now that the final pay stub is generated
-		$ugdlf = new UserGenericDataListFactory();
+		$ugdlf = TTnew( 'UserGenericDataListFactory' );
 		$ugdlf->getByCompanyIdAndScriptAndDefault( $this->getUserObject()->getCompany(), $this->getTable() );
 		if ( $ugdlf->getRecordCount() > 0 ) {
 			Debug::Text('Found Company Form Setup!', __FILE__, __LINE__, __METHOD__,10);
@@ -668,7 +668,7 @@ class ROEFactory extends Factory {
 
 		//Insurable hours dont include stats!Just get total signed in hours.
 		//If someone has just a negative bank time balance, those are NOT insurable.
-		$udtlf = new UserDateTotalListFactory();
+		$udtlf = TTnew( 'UserDateTotalListFactory' );
 		$worked_total_time = $udtlf->getWorkedTimeSumByUserIDAndStartDateAndEndDate( $this->getUser(), $insurable_hours_start_date, $this->getLastDate() );
 		Debug::text('Worked Total Time: '. $worked_total_time, __FILE__, __LINE__, __METHOD__,10);
 
@@ -677,7 +677,7 @@ class ROEFactory extends Factory {
 
 		$insurable_earnings_start_date = $this->getInsurablePayPeriodStartDate( $this->getInsurableEarningsReportPayPeriods() );
 
-		$pself = new PayStubEntryListFactory();
+		$pself = TTnew( 'PayStubEntryListFactory' );
 		$total_earnings = $this->getTotalInsurableEarnings();
 		//$total_earnings = $pself->getAmountSumByUserIdAndEntryNameIdAndStartDateAndEndDate( $this->getUser(), $insurable_earnings_psea_ids, $insurable_earnings_start_date, $this->getLastDate(), 0 );
 		//$total_earnings = $total_earnings['amount'];
@@ -688,7 +688,7 @@ class ROEFactory extends Factory {
 
 		//ReSave these
 		if ( $this->getId() != '' ) {
-			$rlf = new ROEListFactory();
+			$rlf = TTnew( 'ROEListFactory' );
 			$rlf->getById( $this->getId() );
 			if ( $rlf->getRecordCount() > 0 ) {
 				$roe_obj = $rlf->getCurrent();
@@ -706,7 +706,7 @@ class ROEFactory extends Factory {
 
 	function exportROE( $rlf ) {
 		if ( !is_object($rlf) AND $this->getId() != '' ) {
-			$rlf = new ROEListFactory();
+			$rlf = TTnew( 'ROEListFactory' );
 			$rlf->getById( $this->getId() );
 		}
 
@@ -717,7 +717,7 @@ class ROEFactory extends Factory {
 		$border = 0;
 
 		if ( $rlf->getRecordCount() > 0 ) {
-			$ppsf = new PayPeriodScheduleListFactory();
+			$ppsf = TTnew( 'PayPeriodScheduleListFactory' );
 			$pay_period_type_options = array(
 											//5 => TTi18n::gettext('Manual'),
 											10  => 'W',
@@ -729,19 +729,19 @@ class ROEFactory extends Factory {
 			$xml = new SimpleXMLElement('<ROEHEADER Application="RoeWeb" FileVersion="1.00"></ROEHEADER>');
 
 			$r=0;
-			foreach ($rlf  as $r_obj) {
+			foreach ($rlf as $r_obj) {
 
 				//$r_obj->getTotalInsurableEarnings();
 
 				//Get User information
-				$ulf = new UserListFactory();
+				$ulf = TTnew( 'UserListFactory' );
 				$user_obj = $ulf->getById( $r_obj->getUser() )->getCurrent();
 
-				$ulf = new UserListFactory();
+				$ulf = TTnew( 'UserListFactory' );
 				$created_user_obj = $ulf->getById( $r_obj->getCreatedBy() )->getCurrent();
 
 				//Get company information
-				$clf = new CompanyListFactory();
+				$clf = TTnew( 'CompanyListFactory' );
 				$company_obj = $clf->getById( $user_obj->getCompany() )->getCurrent();
 
 				$xml->addChild('ROE');
@@ -846,7 +846,7 @@ class ROEFactory extends Factory {
 
 	function getROE( $rlf = NULL, $show_background = TRUE ) {
 		if ( !is_object($rlf) AND $this->getId() != '' ) {
-			$rlf = new ROEListFactory();
+			$rlf = TTnew( 'ROEListFactory' );
 			$rlf->getById( $this->getId() );
 		}
 
@@ -857,7 +857,7 @@ class ROEFactory extends Factory {
 		$border = 0;
 
 		if ( $rlf->getRecordCount() > 0 ) {
-			$ppsf = new PayPeriodScheduleListFactory();
+			$ppsf = TTnew( 'PayPeriodScheduleListFactory' );
 			$pay_period_type_options = $ppsf->getOptions('type');
 
 			$pdf = new TTPDF();
@@ -868,19 +868,20 @@ class ROEFactory extends Factory {
 				$pdf->SetFont('freesans','',12);
 
 				//Get User information
-				$ulf = new UserListFactory();
+				$ulf = TTnew( 'UserListFactory' );
 				$user_obj = $ulf->getById( $r_obj->getUser() )->getCurrent();
 
-				$ulf = new UserListFactory();
+				$ulf = TTnew( 'UserListFactory' );
 				$created_user_obj = $ulf->getById( $r_obj->getCreatedBy() )->getCurrent();
 
 				//Get company information
-				$clf = new CompanyListFactory();
+				$clf = TTnew( 'CompanyListFactory' );
 				$company_obj = $clf->getById( $user_obj->getCompany() )->getCurrent();
 
 				$pdf->AddPage();
 
 				if ( $show_background == TRUE ) {
+					//Use this command to convert PDF to images: convert -density 600x600 -quality 00 $file
 					$pdf->Image(Environment::getImagesPath() .'roe-template.jpg',0,0,210,300);
 				}
 
@@ -1102,7 +1103,7 @@ class ROEFactory extends Factory {
 
 		if ( $this->getEnableReCalculate() == TRUE ) {
 			//Set User Termination date to Last Day.
-			$ulf = new UserListFactory();
+			$ulf = TTnew( 'UserListFactory' );
 			$ulf->getById( $this->getUser() );
 			if ( $ulf->getRecordCount() > 0 ) {
 				Debug::Text('Setting User Termination Date', __FILE__, __LINE__, __METHOD__,10);
