@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: PayStubEntryAccountFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4265 $
+ * $Id: PayStubEntryAccountFactory.class.php 4265 2011-02-18 00:49:20Z ipso $
+ * $Date: 2011-02-17 16:49:20 -0800 (Thu, 17 Feb 2011) $
  */
 
 /**
@@ -95,6 +95,9 @@ class PayStubEntryAccountFactory extends Factory {
 										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
 							);
 				break;
+			case 'list_columns':
+				$retval = Misc::arrayIntersectByKey( $this->getOptions('default_display_columns'), Misc::trimSortPrefix( $this->getOptions('columns') ) );
+				break;
 			case 'default_display_columns': //Columns that are displayed by default.
 				$retval = array(
 								'status',
@@ -149,7 +152,7 @@ class PayStubEntryAccountFactory extends Factory {
 		$id = trim($id);
 
 		Debug::Text('Company ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
-		$clf = new CompanyListFactory();
+		$clf = TTnew( 'CompanyListFactory' );
 
 		if ( $this->Validator->isResultSetWithRows(	'company',
 													$clf->getByID($id),
@@ -364,7 +367,7 @@ class PayStubEntryAccountFactory extends Factory {
 		//Usually accounts like Vacation Accrual Release etc...
 		if ( $this->
 
-		$psealf = new PayStubEntryAccountListFactory();
+		$psealf = TTnew( 'PayStubEntryAccountListFactory' );
 		$psealf->getByCompanyIdAndStatusIdAndTypeId( $user_obj->getCompany(), 10, 50);
 
 	}
@@ -381,12 +384,12 @@ class PayStubEntryAccountFactory extends Factory {
 		$id = trim($id);
 
 		Debug::Text('ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
-		$psealf = new PayStubEntryAccountListFactory();
+		$psealf = TTnew( 'PayStubEntryAccountListFactory' );
 		$psealf->getByID($id);
 		if ( $psealf->getRecordCount() > 0 ) {
 			if ( $psealf->getCurrent()->getType() != 50 ) {
 				//Reset Result set so an error occurs.
-				$psealf = new PayStubEntryAccountListFactory();
+				$psealf = TTnew( 'PayStubEntryAccountListFactory' );
 			}
 		}
 
@@ -411,7 +414,7 @@ class PayStubEntryAccountFactory extends Factory {
 			return FALSE;
 		}
 
-		$clf = new CompanyListFactory();
+		$clf = TTnew( 'CompanyListFactory' );
 		$clf->getById( $company_id );
 		if ( $clf->getRecordCount() > 0 ) {
 			$company_obj = $clf->getCurrent();
@@ -421,7 +424,7 @@ class PayStubEntryAccountFactory extends Factory {
 			return FALSE;
 		}
 
-		$pseaf = new PayStubEntryAccountFactory();
+		$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 		$pseaf->StartTransaction();
 
 		/*
@@ -435,12 +438,12 @@ class PayStubEntryAccountFactory extends Factory {
 		*/
 
 		//See if accounts are already linked
-		$pseallf = new PayStubEntryAccountLinkListFactory();
+		$pseallf = TTnew( 'PayStubEntryAccountLinkListFactory' );
 		$pseallf->getByCompanyId( $company_id );
 		if ( $pseallf->getRecordCount() > 0 ) {
 			$psealf = $pseallf->getCurrent();
 		} else {
-			$psealf = new PayStubEntryAccountLinkFactory();
+			$psealf = TTnew( 'PayStubEntryAccountLinkFactory' );
 			$psealf->setCompany( $company_id );
 		}
 
@@ -448,7 +451,7 @@ class PayStubEntryAccountFactory extends Factory {
 		switch (strtolower($country)) {
 			case 'ca':
 				Debug::text('Saving.... Federal Taxes', __FILE__, __LINE__, __METHOD__, 10);
-				$pseaf = new PayStubEntryAccountFactory();
+				$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 				$pseaf->setCompany( $company_id );
 				$pseaf->setStatus(10);
 				$pseaf->setType(20);
@@ -459,7 +462,7 @@ class PayStubEntryAccountFactory extends Factory {
 					$pseaf->Save();
 				}
 
-				$pseaf = new PayStubEntryAccountFactory();
+				$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 				$pseaf->setCompany( $company_id );
 				$pseaf->setStatus(10);
 				$pseaf->setType(20);
@@ -470,7 +473,7 @@ class PayStubEntryAccountFactory extends Factory {
 					$pseaf->Save();
 				}
 
-				$pseaf = new PayStubEntryAccountFactory();
+				$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 				$pseaf->setCompany( $company_id );
 				$pseaf->setStatus(10);
 				$pseaf->setType(20);
@@ -481,7 +484,7 @@ class PayStubEntryAccountFactory extends Factory {
 					$pseaf->Save();
 				}
 
-				$pseaf = new PayStubEntryAccountFactory();
+				$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 				$pseaf->setCompany( $company_id );
 				$pseaf->setStatus(10);
 				$pseaf->setType(20);
@@ -494,7 +497,7 @@ class PayStubEntryAccountFactory extends Factory {
 					unset($psea_id);
 				}
 
-				$pseaf = new PayStubEntryAccountFactory();
+				$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 				$pseaf->setCompany( $company_id );
 				$pseaf->setStatus(10);
 				$pseaf->setType(20);
@@ -508,7 +511,7 @@ class PayStubEntryAccountFactory extends Factory {
 				}
 
 				//Employer Contributions
-				$pseaf = new PayStubEntryAccountFactory();
+				$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 				$pseaf->setCompany( $company_id );
 				$pseaf->setStatus(10);
 				$pseaf->setType(30);
@@ -519,7 +522,7 @@ class PayStubEntryAccountFactory extends Factory {
 					$pseaf->Save();
 				}
 
-				$pseaf = new PayStubEntryAccountFactory();
+				$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 				$pseaf->setCompany( $company_id );
 				$pseaf->setStatus(10);
 				$pseaf->setType(30);
@@ -530,7 +533,7 @@ class PayStubEntryAccountFactory extends Factory {
 					$pseaf->Save();
 				}
 
-				$pseaf = new PayStubEntryAccountFactory();
+				$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 				$pseaf->setCompany( $company_id );
 				$pseaf->setStatus(10);
 				$pseaf->setType(30);
@@ -542,7 +545,7 @@ class PayStubEntryAccountFactory extends Factory {
 				}
 
 				Debug::text('Saving.... Vacation Accrual', __FILE__, __LINE__, __METHOD__, 10);
-				$pseaf = new PayStubEntryAccountFactory();
+				$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 				$pseaf->setCompany( $company_id );
 				$pseaf->setStatus(10);
 				$pseaf->setType(50);
@@ -553,7 +556,7 @@ class PayStubEntryAccountFactory extends Factory {
 					$vacation_accrual_id = $pseaf->Save();
 
 					Debug::text('Saving.... Earnings - Vacation Accrual Release', __FILE__, __LINE__, __METHOD__, 10);
-					$pseaf = new PayStubEntryAccountFactory();
+					$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 					$pseaf->setCompany( $company_id );
 					$pseaf->setStatus(10);
 					$pseaf->setType(10);
@@ -570,7 +573,7 @@ class PayStubEntryAccountFactory extends Factory {
 
 				break;
 			case 'us':
-				$pseaf = new PayStubEntryAccountFactory();
+				$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 				$pseaf->setCompany( $company_id );
 				$pseaf->setStatus(10);
 				$pseaf->setType(20);
@@ -581,7 +584,7 @@ class PayStubEntryAccountFactory extends Factory {
 					$pseaf->Save();
 				}
 
-				$pseaf = new PayStubEntryAccountFactory();
+				$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 				$pseaf->setCompany( $company_id );
 				$pseaf->setStatus(10);
 				$pseaf->setType(20);
@@ -592,7 +595,7 @@ class PayStubEntryAccountFactory extends Factory {
 					$pseaf->Save();
 				}
 
-				$pseaf = new PayStubEntryAccountFactory();
+				$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 				$pseaf->setCompany( $company_id );
 				$pseaf->setStatus(10);
 				$pseaf->setType(20);
@@ -603,7 +606,7 @@ class PayStubEntryAccountFactory extends Factory {
 					$pseaf->Save();
 				}
 
-				$pseaf = new PayStubEntryAccountFactory();
+				$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 				$pseaf->setCompany( $company_id );
 				$pseaf->setStatus(10);
 				$pseaf->setType(20);
@@ -614,7 +617,7 @@ class PayStubEntryAccountFactory extends Factory {
 					$pseaf->Save();
 				}
 
-				$pseaf = new PayStubEntryAccountFactory();
+				$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 				$pseaf->setCompany( $company_id );
 				$pseaf->setStatus(10);
 				$pseaf->setType(20);
@@ -625,7 +628,7 @@ class PayStubEntryAccountFactory extends Factory {
 					$pseaf->Save();
 				}
 
-				$pseaf = new PayStubEntryAccountFactory();
+				$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 				$pseaf->setCompany( $company_id );
 				$pseaf->setStatus(10);
 				$pseaf->setType(20);
@@ -636,7 +639,7 @@ class PayStubEntryAccountFactory extends Factory {
 					$pseaf->Save();
 				}
 
-				$pseaf = new PayStubEntryAccountFactory();
+				$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 				$pseaf->setCompany( $company_id );
 				$pseaf->setStatus(10);
 				$pseaf->setType(20);
@@ -647,7 +650,7 @@ class PayStubEntryAccountFactory extends Factory {
 					$pseaf->Save();
 				}
 
-				$pseaf = new PayStubEntryAccountFactory();
+				$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 				$pseaf->setCompany( $company_id );
 				$pseaf->setStatus(10);
 				$pseaf->setType(30);
@@ -658,7 +661,7 @@ class PayStubEntryAccountFactory extends Factory {
 					$pseaf->Save();
 				}
 
-				$pseaf = new PayStubEntryAccountFactory();
+				$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 				$pseaf->setCompany( $company_id );
 				$pseaf->setStatus(10);
 				$pseaf->setType(30);
@@ -669,7 +672,7 @@ class PayStubEntryAccountFactory extends Factory {
 					$pseaf->Save();
 				}
 
-				$pseaf = new PayStubEntryAccountFactory();
+				$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 				$pseaf->setCompany( $company_id );
 				$pseaf->setStatus(10);
 				$pseaf->setType(20);
@@ -680,7 +683,7 @@ class PayStubEntryAccountFactory extends Factory {
 					$pseaf->Save();
 				}
 
-				$pseaf = new PayStubEntryAccountFactory();
+				$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 				$pseaf->setCompany( $company_id );
 				$pseaf->setStatus(10);
 				$pseaf->setType(20);
@@ -691,7 +694,7 @@ class PayStubEntryAccountFactory extends Factory {
 					$pseaf->Save();
 				}
 
-				$pseaf = new PayStubEntryAccountFactory();
+				$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 				$pseaf->setCompany( $company_id );
 				$pseaf->setStatus(10);
 				$pseaf->setType(30);
@@ -702,7 +705,7 @@ class PayStubEntryAccountFactory extends Factory {
 					$pseaf->Save();
 				}
 
-				$pseaf = new PayStubEntryAccountFactory();
+				$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 				$pseaf->setCompany( $company_id );
 				$pseaf->setStatus(10);
 				$pseaf->setType(20);
@@ -713,7 +716,7 @@ class PayStubEntryAccountFactory extends Factory {
 					$pseaf->Save();
 				}
 
-				$pseaf = new PayStubEntryAccountFactory();
+				$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 				$pseaf->setCompany( $company_id );
 				$pseaf->setStatus(10);
 				$pseaf->setType(30);
@@ -724,7 +727,7 @@ class PayStubEntryAccountFactory extends Factory {
 					$pseaf->Save();
 				}
 
-				$pseaf = new PayStubEntryAccountFactory();
+				$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 				$pseaf->setCompany( $company_id );
 				$pseaf->setStatus(10);
 				$pseaf->setType(30);
@@ -741,7 +744,7 @@ class PayStubEntryAccountFactory extends Factory {
 		Debug::text('Province: '. $province , __FILE__, __LINE__, __METHOD__, 10);
 		switch (strtolower($province)) {
 			case 'ny':
-				$pseaf = new PayStubEntryAccountFactory();
+				$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 				$pseaf->setCompany( $company_id );
 				$pseaf->setStatus(10);
 				$pseaf->setType(30);
@@ -756,7 +759,7 @@ class PayStubEntryAccountFactory extends Factory {
 		}
 
 		Debug::text('Saving.... Earnings - Regular Time', __FILE__, __LINE__, __METHOD__, 10);
-		$pseaf = new PayStubEntryAccountFactory();
+		$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 		$pseaf->setCompany( $company_id );
 		$pseaf->setStatus(10);
 		$pseaf->setType(10);
@@ -770,7 +773,7 @@ class PayStubEntryAccountFactory extends Factory {
 		}
 
 		Debug::text('Saving.... Earnings - Over Time 1', __FILE__, __LINE__, __METHOD__, 10);
-		$pseaf = new PayStubEntryAccountFactory();
+		$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 		$pseaf->setCompany( $company_id );
 		$pseaf->setStatus(10);
 		$pseaf->setType(10);
@@ -782,7 +785,7 @@ class PayStubEntryAccountFactory extends Factory {
 		}
 
 		Debug::text('Saving.... Earnings - Over Time 2', __FILE__, __LINE__, __METHOD__, 10);
-		$pseaf = new PayStubEntryAccountFactory();
+		$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 		$pseaf->setCompany( $company_id );
 		$pseaf->setStatus(10);
 		$pseaf->setType(10);
@@ -794,7 +797,7 @@ class PayStubEntryAccountFactory extends Factory {
 		}
 
 		Debug::text('Saving.... Earnings - Premium Time 1', __FILE__, __LINE__, __METHOD__, 10);
-		$pseaf = new PayStubEntryAccountFactory();
+		$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 		$pseaf->setCompany( $company_id );
 		$pseaf->setStatus(10);
 		$pseaf->setType(10);
@@ -806,7 +809,7 @@ class PayStubEntryAccountFactory extends Factory {
 		}
 
 		Debug::text('Saving.... Earnings - Premium Time 2', __FILE__, __LINE__, __METHOD__, 10);
-		$pseaf = new PayStubEntryAccountFactory();
+		$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 		$pseaf->setCompany( $company_id );
 		$pseaf->setStatus(10);
 		$pseaf->setType(10);
@@ -818,7 +821,7 @@ class PayStubEntryAccountFactory extends Factory {
 		}
 
 		Debug::text('Saving.... Earnings - Bonus', __FILE__, __LINE__, __METHOD__, 10);
-		$pseaf = new PayStubEntryAccountFactory();
+		$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 		$pseaf->setCompany( $company_id );
 		$pseaf->setStatus(10);
 		$pseaf->setType(10);
@@ -830,7 +833,7 @@ class PayStubEntryAccountFactory extends Factory {
 		}
 
 		Debug::text('Saving.... Earnings - Other', __FILE__, __LINE__, __METHOD__, 10);
-		$pseaf = new PayStubEntryAccountFactory();
+		$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 		$pseaf->setCompany( $company_id );
 		$pseaf->setStatus(10);
 		$pseaf->setType(10);
@@ -842,7 +845,7 @@ class PayStubEntryAccountFactory extends Factory {
 		}
 
 		Debug::text('Saving.... Union Dues', __FILE__, __LINE__, __METHOD__, 10);
-		$pseaf = new PayStubEntryAccountFactory();
+		$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 		$pseaf->setCompany( $company_id );
 		$pseaf->setStatus(10);
 		$pseaf->setType(20);
@@ -854,7 +857,7 @@ class PayStubEntryAccountFactory extends Factory {
 		}
 
 		Debug::text('Saving.... Employee Benefits Plan', __FILE__, __LINE__, __METHOD__, 10);
-		$pseaf = new PayStubEntryAccountFactory();
+		$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 		$pseaf->setCompany( $company_id );
 		$pseaf->setStatus(10);
 		$pseaf->setType(20);
@@ -866,7 +869,7 @@ class PayStubEntryAccountFactory extends Factory {
 		}
 
 		Debug::text('Saving.... Employer Benefits Plan', __FILE__, __LINE__, __METHOD__, 10);
-		$pseaf = new PayStubEntryAccountFactory();
+		$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 		$pseaf->setCompany( $company_id );
 		$pseaf->setStatus(10);
 		$pseaf->setType(30);
@@ -878,7 +881,7 @@ class PayStubEntryAccountFactory extends Factory {
 		}
 
 		Debug::text('Saving.... Total Earnings', __FILE__, __LINE__, __METHOD__, 10);
-		$pseaf = new PayStubEntryAccountFactory();
+		$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 		$pseaf->setCompany( $company_id );
 		$pseaf->setStatus(10);
 		$pseaf->setType(40);
@@ -892,7 +895,7 @@ class PayStubEntryAccountFactory extends Factory {
 		}
 
 		Debug::text('Saving.... Total Deductions', __FILE__, __LINE__, __METHOD__, 10);
-		$pseaf = new PayStubEntryAccountFactory();
+		$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 		$pseaf->setCompany( $company_id );
 		$pseaf->setStatus(10);
 		$pseaf->setType(40);
@@ -906,7 +909,7 @@ class PayStubEntryAccountFactory extends Factory {
 		}
 
 		Debug::text('Saving.... Net Pay', __FILE__, __LINE__, __METHOD__, 10);
-		$pseaf = new PayStubEntryAccountFactory();
+		$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 		$pseaf->setCompany( $company_id );
 		$pseaf->setStatus(10);
 		$pseaf->setType(40);
@@ -920,7 +923,7 @@ class PayStubEntryAccountFactory extends Factory {
 		}
 
 		Debug::text('Saving.... Employer Total Cont', __FILE__, __LINE__, __METHOD__, 10);
-		$pseaf = new PayStubEntryAccountFactory();
+		$pseaf = TTnew( 'PayStubEntryAccountFactory' );
 		$pseaf->setCompany( $company_id );
 		$pseaf->setStatus(10);
 		$pseaf->setType(40);
@@ -961,12 +964,12 @@ class PayStubEntryAccountFactory extends Factory {
 		}
 
 		//Make sure PS order is correct, in that types can't be separated by total or accrual accounts.
-		$pseallf = new PayStubEntryAccountLinkListFactory();
+		$pseallf = TTnew( 'PayStubEntryAccountLinkListFactory' );
 		$pseallf->getByCompanyId( $this->getCompany() );
 		if ( $pseallf->getRecordCount() > 0 ) {
 			$pseal_obj = $pseallf->getCurrent();
 
-			$psealf = new PayStubEntryAccountListFactory();
+			$psealf = TTnew( 'PayStubEntryAccountListFactory' );
 			$psealf->getByCompanyIdAndTypeId( $this->getCompany(), 40 );
 			if ( $psealf->getRecordCount() > 0 ) {
 				foreach( $psealf as $psea_obj ) {
@@ -1023,7 +1026,7 @@ class PayStubEntryAccountFactory extends Factory {
 			Debug::text('Attempting to delete PSE Account', __FILE__, __LINE__, __METHOD__, 10);
 
 			//Check to see if account is in use.
-			$pself = new PayStubEntryListFactory();
+			$pself = TTnew( 'PayStubEntryListFactory' );
 			$pself->getByEntryNameId( $this->getId() );
 			if ( $pself->getRecordCount() > 0 ) {
 				Debug::text('PSE Account is in use... Disabling instead.', __FILE__, __LINE__, __METHOD__, 10);
