@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2838 $
- * $Id: PayStubEntryAccountListFactory.class.php 2838 2009-09-18 20:57:41Z ipso $
- * $Date: 2009-09-18 13:57:41 -0700 (Fri, 18 Sep 2009) $
+ * $Revision: 4265 $
+ * $Id: PayStubEntryAccountListFactory.class.php 4265 2011-02-18 00:49:20Z ipso $
+ * $Date: 2011-02-17 16:49:20 -0800 (Thu, 17 Feb 2011) $
  */
 
 /**
@@ -423,6 +423,9 @@ class PayStubEntryAccountListFactory extends PayStubEntryAccountFactory implemen
 					where	a.company_id = ?
 					';
 
+		if ( isset($filter_data['permission_children_ids']) AND isset($filter_data['permission_children_ids'][0]) AND !in_array(-1, (array)$filter_data['permission_children_ids']) ) {
+			$query  .=	' AND a.created_by in ('. $this->getListSQL($filter_data['permission_children_ids'], $ph) .') ';
+		}
 		if ( isset($filter_data['id']) AND isset($filter_data['id'][0]) AND !in_array(-1, (array)$filter_data['id']) ) {
 			$query  .=	' AND a.id in ('. $this->getListSQL($filter_data['id'], $ph) .') ';
 		}
