@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3928 $
- * $Id: PayStubEntryListFactory.class.php 3928 2010-11-11 20:29:54Z ipso $
- * $Date: 2010-11-11 12:29:54 -0800 (Thu, 11 Nov 2010) $
+ * $Revision: 4582 $
+ * $Id: PayStubEntryListFactory.class.php 4582 2011-04-26 15:47:38Z ipso $
+ * $Date: 2011-04-26 08:47:38 -0700 (Tue, 26 Apr 2011) $
  */
 
 /**
@@ -235,8 +235,6 @@ class PayStubEntryListFactory extends PayStubEntryFactory implements IteratorAgg
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order );
 
-		Debug::Text('Query: '. $query , __FILE__, __LINE__, __METHOD__,10);
-
 		$this->rs = $this->db->Execute($query, $ph);
 
 		return $this;
@@ -406,7 +404,7 @@ class PayStubEntryListFactory extends PayStubEntryFactory implements IteratorAgg
 		if ( $row['units'] === NULL ) {
 			$row['units'] = 0;
 		}
-		Debug::text('YTD Sum Query: '. $query, __FILE__, __LINE__, __METHOD__, 10);
+		//Debug::text('YTD Sum Query: '. $query, __FILE__, __LINE__, __METHOD__, 10);
 		Debug::text('YTD Sum for User ID: '. $id .' Entry Name ID: '. $type_id .': Amount '. $row['amount'] .' Units: '. $row['units'], __FILE__, __LINE__, __METHOD__, 10);
 
 		return $row;
@@ -489,7 +487,7 @@ class PayStubEntryListFactory extends PayStubEntryFactory implements IteratorAgg
 		if ( $row['units'] === NULL ) {
 			$row['units'] = 0;
 		}
-		Debug::text('YTD Sum Query: '. $query, __FILE__, __LINE__, __METHOD__, 10);
+		//Debug::text('YTD Sum Query: '. $query, __FILE__, __LINE__, __METHOD__, 10);
 		Debug::text('YTD Sum for User ID: '. $id .' Entry Name ID: '. $entry_name_id .': Amount '. $row['amount'] .' Units: '. $row['units'], __FILE__, __LINE__, __METHOD__, 10);
 
 		return $row;
@@ -670,8 +668,6 @@ class PayStubEntryListFactory extends PayStubEntryFactory implements IteratorAgg
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order );
 
-		Debug::Text('Query: '. $query , __FILE__, __LINE__, __METHOD__,10);
-
 		$row = $this->db->GetRow($query, $ph);
 
 		if ( $row['amount'] === NULL ) {
@@ -730,8 +726,6 @@ class PayStubEntryListFactory extends PayStubEntryFactory implements IteratorAgg
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order );
 
-		Debug::Text('Query: '. $query , __FILE__, __LINE__, __METHOD__,10);
-
 		$row = $this->db->GetRow($query, $ph);
 
 		if ( $row['amount'] === NULL ) {
@@ -831,7 +825,7 @@ class PayStubEntryListFactory extends PayStubEntryFactory implements IteratorAgg
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order );
 
-		Debug::text('YTD Sum by Entry Name Query: '. $query, __FILE__, __LINE__, __METHOD__, 10);
+		//Debug::text('YTD Sum by Entry Name Query: '. $query, __FILE__, __LINE__, __METHOD__, 10);
 		$row = $this->db->GetRow($query, $ph);
 		//var_dump($row);
 
@@ -906,7 +900,7 @@ class PayStubEntryListFactory extends PayStubEntryFactory implements IteratorAgg
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order );
 
-		Debug::text('YTD Sum by Entry Name Query: '. $query, __FILE__, __LINE__, __METHOD__, 10);
+		//Debug::text('YTD Sum by Entry Name Query: '. $query, __FILE__, __LINE__, __METHOD__, 10);
 		$row = $this->db->GetRow($query, $ph);
 		//var_dump($row);
 
@@ -983,7 +977,7 @@ class PayStubEntryListFactory extends PayStubEntryFactory implements IteratorAgg
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order );
 
-		Debug::text('Pay Stub Sum by type Query: '. $query, __FILE__, __LINE__, __METHOD__, 10);
+		//Debug::text('Pay Stub Sum by type Query: '. $query, __FILE__, __LINE__, __METHOD__, 10);
 		$row = $this->db->GetRow($query, $ph);
 
 		if ( $row['amount'] === NULL ) {
@@ -1320,11 +1314,6 @@ class PayStubEntryListFactory extends PayStubEntryFactory implements IteratorAgg
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order, FALSE );
 
-		Debug::Text('Query: '. $query , __FILE__, __LINE__, __METHOD__,10);
-
-		$query .= $this->getWhereSQL( $where );
-		$query .= $this->getSortSQL( $order );
-
 		$this->rs = $this->db->Execute($query, $ph);
 
 		return $this;
@@ -1591,6 +1580,7 @@ class PayStubEntryListFactory extends PayStubEntryFactory implements IteratorAgg
 		//Debug::Arr($order,'Order Data:', __FILE__, __LINE__, __METHOD__,10);
 		//Debug::Arr($filter_data,'Filter Data:', __FILE__, __LINE__, __METHOD__,10);
 
+		$ppf = new PayPeriodFactory();
 		$bf = new BranchFactory();
 		$df = new DepartmentFactory();
 		$ugf = new UserGroupFactory();
@@ -1606,6 +1596,10 @@ class PayStubEntryListFactory extends PayStubEntryFactory implements IteratorAgg
 					select 	a.*,
 							b.user_id as user_id,
 							b.pay_period_id as pay_period_id,
+							ppf.start_date as pay_period_start_date,
+							ppf.end_date as pay_period_end_date,
+							ppf.transaction_date as pay_period_transaction_date,
+
 							b.start_date as pay_stub_start_date,
 							b.end_date as pay_stub_end_date,
 							b.transaction_date as pay_stub_transaction_date,
@@ -1690,6 +1684,7 @@ class PayStubEntryListFactory extends PayStubEntryFactory implements IteratorAgg
 							) a
 						LEFT JOIN '. $psf->getTable() .' as b ON a.pay_stub_id = b.id
 						LEFT JOIN '. $uf->getTable() .' as c ON b.user_id = c.id
+						LEFT JOIN '. $ppf->getTable() .' as ppf ON b.pay_period_id = ppf.id
 					where	1=1
 					';
 
@@ -1699,8 +1694,6 @@ class PayStubEntryListFactory extends PayStubEntryFactory implements IteratorAgg
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
 
-		Debug::Text('Query: '. $query , __FILE__, __LINE__, __METHOD__,10);
-
 		if ($limit == NULL) {
 			$this->rs = $this->db->Execute($query, $ph);
 		} else {
