@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3928 $
- * $Id: PayStubListFactory.class.php 3928 2010-11-11 20:29:54Z ipso $
- * $Date: 2010-11-11 12:29:54 -0800 (Thu, 11 Nov 2010) $
+ * $Revision: 4600 $
+ * $Id: PayStubListFactory.class.php 4600 2011-04-28 21:35:12Z ipso $
+ * $Date: 2011-04-28 14:35:12 -0700 (Thu, 28 Apr 2011) $
  */
 
 /**
@@ -178,8 +178,8 @@ class PayStubListFactory extends PayStubFactory implements IteratorAggregate {
 		}
 
 		$ph = array(
-					'id' => $id,
-					'user_id' => $user_id,
+					'id' => (int)$id,
+					'user_id' => (int)$user_id,
 					);
 
 		$query = '
@@ -865,8 +865,6 @@ class PayStubListFactory extends PayStubFactory implements IteratorAggregate {
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
 
-		Debug::Text('Query: '. $query, __FILE__, __LINE__, __METHOD__,10);
-
 		if ($limit == NULL) {
 			$this->rs = $this->db->Execute($query, $ph);
 		} else {
@@ -888,25 +886,16 @@ class PayStubListFactory extends PayStubFactory implements IteratorAggregate {
 			}
 		}
 
-		$additional_order_fields = array('b.last_name', 'b.first_name');
+		$additional_order_fields = array('user_status_id','last_name', 'first_name', 'default_branch', 'default_department', 'user_group', 'title', 'country', 'province', 'currency');
+
+		$sort_column_aliases = array(
+									'user_status' => 'user_status_id',
+									);
+		$order = $this->getColumnsFromAliases( $order, $sort_column_aliases );
 		if ( $order == NULL ) {
 			$order = array( 'a.transaction_date' => 'desc', 'b.last_name' => 'asc' );
 			$strict = FALSE;
 		} else {
-			//Always try to order by status first so UNPAID employees go to the bottom.
-			if ( isset($order['last_name']) ) {
-				$order['b.last_name'] = $order['last_name'];
-				unset($order['last_name']);
-			}
-			if ( isset($order['first_name']) ) {
-				$order['b.first_name'] = $order['first_name'];
-				unset($order['first_name']);
-			}
-			if ( isset($order['status']) ) {
-				$order['status_id'] = $order['status'];
-				unset($order['status']);
-			}
-
 			if ( isset($order['transaction_date']) ) {
 				$order['last_name'] = 'asc';
 			} else {
@@ -1006,15 +995,15 @@ class PayStubListFactory extends PayStubFactory implements IteratorAggregate {
 			$query  .=	' AND b.title_id in ('. $this->getListSQL($filter_data['title_id'], $ph) .') ';
 		}
 
-		/*
 		if ( isset($filter_data['start_date']) AND trim($filter_data['start_date']) != '' ) {
-			$ph[] = strtolower(trim($filter_data['start_date']));
-			$query  .=	' AND a.start_date >= ?';
+			$ph[] = $this->db->BindTimeStamp($filter_data['start_date']);
+			$query  .=	' AND a.transaction_date >= ?';
 		}
 		if ( isset($filter_data['end_date']) AND trim($filter_data['end_date']) != '' ) {
-			$ph[] = strtolower(trim($filter_data['end_date']));
-			$query  .=	' AND a.end_date <= ?';
+			$ph[] = $this->db->BindTimeStamp( $filter_data['end_date'] );
+			$query  .=	' AND a.transaction_date <= ?';
 		}
+		/*
 		if ( isset($filter_data['transaction_date']) AND trim($filter_data['transaction_date']) != '' ) {
 			$ph[] = strtolower(trim($filter_data['transaction_date']));
 			$query  .=	' AND a.end_date <= ?';
@@ -1034,6 +1023,8 @@ class PayStubListFactory extends PayStubFactory implements IteratorAggregate {
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
 
+		Debug::Arr($ph, 'Query: '. $query, __FILE__, __LINE__, __METHOD__,10);
+
 		if ($limit == NULL) {
 			$this->rs = $this->db->Execute($query, $ph);
 		} else {
