@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2095 $
- * $Id: PayStubPDF.class.php 2095 2008-09-01 07:04:25Z ipso $
- * $Date: 2008-09-01 00:04:25 -0700 (Mon, 01 Sep 2008) $
+ * $Revision: 4104 $
+ * $Id: PayStubPDF.class.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 
 /**
@@ -81,9 +81,9 @@ class PayStubPDF {
 	}
 
 	function getData() {
-		$psenlf = new PayStubEntryNameListFactory();
+		$psenlf = TTnew( 'PayStubEntryNameListFactory' );
 
-		$pslf = new PayStubListFactory();
+		$pslf = TTnew( 'PayStubListFactory' );
 
 		//$pslf->getByIdAndUserId($id, $current_user->getId(), $current_user_prefs->getItemsPerPage(), $page, NULL, array($sort_column => $sort_order) );
 		$pslf->getById( $this->pay_stub_id );
@@ -93,7 +93,7 @@ class PayStubPDF {
 		foreach ($pslf as $pay_stub_obj) {
 
 			//Get pay stub entries.
-			$pself = new PayStubEntryListFactory();
+			$pself = TTnew( 'PayStubEntryListFactory' );
 			$pself->getByPayStubId( $pay_stub_obj->getId() );
 
 			$prev_type = NULL;
@@ -160,7 +160,7 @@ class PayStubPDF {
 							);
 
 			//Get Pay Period information
-			$pplf = new PayPeriodListFactory();
+			$pplf = TTnew( 'PayPeriodListFactory' );
 			$pay_period_obj = $pplf->getById( $pay_stub_obj->getPayPeriod() )->getCurrent();
 
 			if ( $pay_stub_obj->getAdvance() == TRUE ) {
@@ -180,11 +180,11 @@ class PayStubPDF {
 									);
 
 			//Get User information
-			$ulf = new UserListFactory();
+			$ulf = TTnew( 'UserListFactory' );
 			$this->user_obj = $ulf->getById( $pay_stub_obj->getUser() )->getCurrent();
 
 			//Get company information
-			$clf = new CompanyListFactory();
+			$clf = TTnew( 'CompanyListFactory' );
 			$this->company_obj = $clf->getById( $this->user_obj->getCompany() )->getCurrent();
 
 		}
