@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: PayStubAmendmentFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4287 $
+ * $Id: PayStubAmendmentFactory.class.php 4287 2011-02-24 00:17:02Z ipso $
+ * $Date: 2011-02-23 16:17:02 -0800 (Wed, 23 Feb 2011) $
  */
 
 /**
@@ -97,7 +97,7 @@ class PayStubAmendmentFactory extends Factory {
 										'-1002-last_name' => TTi18n::gettext('Last Name'),
 										'-1005-user_status' => TTi18n::gettext('Employee Status'),
 										'-1010-title' => TTi18n::gettext('Title'),
-										'-1020-group' => TTi18n::gettext('Group'),
+										'-1020-user_group' => TTi18n::gettext('Group'),
 										'-1030-default_branch' => TTi18n::gettext('Default Branch'),
 										'-1040-default_department' => TTi18n::gettext('Default Department'),
 
@@ -117,6 +117,9 @@ class PayStubAmendmentFactory extends Factory {
 										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
 							);
 				break;
+			case 'list_columns':
+				$retval = Misc::arrayIntersectByKey( $this->getOptions('default_display_columns'), Misc::trimSortPrefix( $this->getOptions('columns') ) );
+				break;
 			case 'default_display_columns': //Columns that are displayed by default.
 				$retval = array(
 								'first_name',
@@ -151,7 +154,7 @@ class PayStubAmendmentFactory extends Factory {
 										'user_status_id' => FALSE,
 										'user_status' => FALSE,
 										'group_id' => FALSE,
-										'group' => FALSE,
+										'user_group' => FALSE,
 										'title_id' => FALSE,
 										'title' => FALSE,
 										'default_branch_id' => FALSE,
@@ -184,7 +187,7 @@ class PayStubAmendmentFactory extends Factory {
 		if ( is_object($this->user_obj) ) {
 			return $this->user_obj;
 		} else {
-			$ulf = new UserListFactory();
+			$ulf = TTnew( 'UserListFactory' );
 			$this->user_obj = $ulf->getById( $this->getUser() )->getCurrent();
 
 			return $this->user_obj;
@@ -195,7 +198,7 @@ class PayStubAmendmentFactory extends Factory {
 		if ( is_object($this->pay_stub_entry_account_link_obj) ) {
 			return $this->pay_stub_entry_account_link_obj;
 		} else {
-			$pseallf = new PayStubEntryAccountLinkListFactory();
+			$pseallf = TTnew( 'PayStubEntryAccountLinkListFactory' );
 			$pseallf->getByCompanyID( $this->getUserObject()->getCompany() );
 			if ( $pseallf->getRecordCount() > 0 ) {
 				$this->pay_stub_entry_account_link_obj = $pseallf->getCurrent();
@@ -210,7 +213,7 @@ class PayStubAmendmentFactory extends Factory {
 		if ( is_object($this->pay_stub_entry_name_obj) ) {
 			return $this->pay_stub_entry_name_obj;
 		} else {
-			$psealf = new PayStubEntryAccountListFactory();
+			$psealf = TTnew( 'PayStubEntryAccountListFactory' );
 			$psealf->getByID( $this->getPayStubEntryNameId() );
 			if ( $psealf->getRecordCount() > 0 ) {
 				$this->pay_stub_entry_name_obj = $psealf->getCurrent();
@@ -225,7 +228,7 @@ class PayStubAmendmentFactory extends Factory {
 		if ( is_object($this->percent_amount_entry_name_obj) ) {
 			return $this->percent_amount_entry_name_obj;
 		} else {
-			$psealf = new PayStubEntryAccountListFactory();
+			$psealf = TTnew( 'PayStubEntryAccountListFactory' );
 			$psealf->getByID( $this->getPercentAmountEntryNameId() );
 			if ( $psealf->getRecordCount() > 0 ) {
 				$this->percent_amount_entry_name_obj = $psealf->getCurrent();
@@ -242,7 +245,7 @@ class PayStubAmendmentFactory extends Factory {
 	function setUser($id) {
 		$id = trim($id);
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 
 		if ( $this->Validator->isResultSetWithRows(	'user_id',
 															$ulf->getByID($id),
@@ -266,8 +269,8 @@ class PayStubAmendmentFactory extends Factory {
 	function setPayStubEntryNameId($id) {
 		$id = trim($id);
 
-		//$psenlf = new PayStubEntryNameListFactory();
-		$psealf = new PayStubEntryAccountListFactory();
+		//$psenlf = TTnew( 'PayStubEntryNameListFactory' );
+		$psealf = TTnew( 'PayStubEntryAccountListFactory' );
 		$result = $psealf->getById( $id );
 		//Debug::Arr($result, 'Result: ID: '. $id .' Rows: '. $result->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
 
@@ -287,7 +290,7 @@ class PayStubAmendmentFactory extends Factory {
 	function setName($name) {
 		$name = trim($name);
 
-		$psenlf = new PayStubEntryNameListFactory();
+		$psenlf = TTnew( 'PayStubEntryNameListFactory' );
 		$result = $psenlf->getByName($name);
 
 		if (  $this->Validator->isResultSetWithRows(	'name',
@@ -313,7 +316,7 @@ class PayStubAmendmentFactory extends Factory {
 	function setRecurringPayStubAmendmentId($id) {
 		$id = trim($id);
 
-		$rpsalf = new RecurringPayStubAmendmentListFactory();
+		$rpsalf = TTnew( 'RecurringPayStubAmendmentListFactory' );
 		$rpsalf->getById( $id );
 		//Not sure why we tried to use $result here, as if the ID passed is NULL, it causes a fatal error.
 		//$result = $rpsalf->getById( $id )->getCurrent();
@@ -473,14 +476,14 @@ class PayStubAmendmentFactory extends Factory {
 
 	function getPayStubId() {
 		//Find which pay period this effective date belongs too
-		$pplf = new PayPeriodListFactory();
+		$pplf = TTnew( 'PayPeriodListFactory' );
 		$pplf->getByUserIdAndEndDate( $this->getUser(), $this->getEffectiveDate() );
 		if ( $pplf->getRecordCount() > 0 ) {
 			$pp_obj = $pplf->getCurrent();
 			Debug::text('Found Pay Period ID: '. $pp_obj->getId(), __FILE__, __LINE__, __METHOD__,10);
 
 			//Percent PS amendments can't work on advances.
-			$pslf = new PayStubListFactory();
+			$pslf = TTnew( 'PayStubListFactory' );
 			$pslf->getByUserIdAndPayPeriodIdAndAdvance( $this->getUser(), $pp_obj->getId(), FALSE );
 			if ( $pslf->getRecordCount() > 0 ) {
 				$ps_obj = $pslf->getCurrent();
@@ -502,7 +505,7 @@ class PayStubAmendmentFactory extends Factory {
 			return FALSE;
 		}
 
-		$pself = new PayStubEntryListFactory();
+		$pself = TTnew( 'PayStubEntryListFactory' );
 
 		//Get Linked accounts so we know which IDs are totals.
 		$total_gross_key = array_search( $this->getPayStubEntryAccountLinkObject()->getTotalGross(), $ids);
@@ -647,7 +650,7 @@ class PayStubAmendmentFactory extends Factory {
 	function setPercentAmountEntryNameId($id) {
 		$id = trim($id);
 
-		$psealf = new PayStubEntryAccountListFactory();
+		$psealf = TTnew( 'PayStubEntryAccountListFactory' );
 		$psealf->getById( $id );
 		//Not sure why we tried to use $result here, as if the ID passed is NULL, it causes a fatal error.
 		//$result = $psealf->getById( $id )->getCurrent();
@@ -731,7 +734,7 @@ class PayStubAmendmentFactory extends Factory {
 		}
 		Debug::Text('Effective Date: '. TTDate::getDate('DATE+TIME', $effective_date), __FILE__, __LINE__, __METHOD__,10);
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$ulf->getById( $user_id );
 		if ( $ulf->getRecordCount() > 0 ) {
 			$user_obj = $ulf->getCurrent();
@@ -740,18 +743,19 @@ class PayStubAmendmentFactory extends Factory {
 		}
 
 		//Get all PSE acccount accruals
-		$psealf = new PayStubEntryAccountListFactory();
+		$psealf = TTnew( 'PayStubEntryAccountListFactory' );
 		$psealf->getByCompanyIdAndStatusIdAndTypeId( $user_obj->getCompany(), 10, 50);
 		if ( $psealf->getRecordCount() > 0 ) {
 			$ulf->StartTransaction();
 			foreach( $psealf as $psea_obj ) {
 				//Get PSE account that affects this accrual.
-				$psealf_tmp = new PayStubEntryAccountListFactory();
+				//What if there are two accounts? It takes the first one in the list.
+				$psealf_tmp = TTnew( 'PayStubEntryAccountListFactory' );
 				$psealf_tmp->getByCompanyIdAndAccrualId( $user_obj->getCompany(), $psea_obj->getId() );
 				if ( $psealf_tmp->getRecordCount() > 0 ) {
 					$release_account_id = $psealf_tmp->getCurrent()->getId();
 
-					$psaf = new PayStubAmendmentFactory();
+					$psaf = TTnew( 'PayStubAmendmentFactory' );
 					$psaf->setStatus( 50 ); //Active
 					$psaf->setType( 20 ) ; //Percent
 					$psaf->setUser( $user_obj->getId() );
@@ -871,8 +875,8 @@ class PayStubAmendmentFactory extends Factory {
 		return FALSE;
 	}
 
-	function getObjectAsArray( $include_columns = NULL ) {
-		$uf = new UserFactory();
+	function getObjectAsArray( $include_columns = NULL, $permission_children_ids = FALSE ) {
+		$uf = TTnew( 'UserFactory' );
 
 		$variable_function_map = $this->getVariableToFunctionMap();
 		if ( is_array( $variable_function_map ) ) {
@@ -885,7 +889,7 @@ class PayStubAmendmentFactory extends Factory {
 						case 'last_name':
 						case 'user_status_id':
 						case 'group_id':
-						case 'group':
+						case 'user_group':
 						case 'title_id':
 						case 'title':
 						case 'default_branch_id':
@@ -919,6 +923,7 @@ class PayStubAmendmentFactory extends Factory {
 
 				}
 			}
+			$this->getPermissionColumns( &$data, $this->getID(), $this->getCreatedBy(), $permission_children_ids, $include_columns );
 			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
 		}
 
