@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3928 $
- * $Id: PayStubAmendmentListFactory.class.php 3928 2010-11-11 20:29:54Z ipso $
- * $Date: 2010-11-11 12:29:54 -0800 (Thu, 11 Nov 2010) $
+ * $Revision: 4401 $
+ * $Id: PayStubAmendmentListFactory.class.php 4401 2011-03-19 20:29:26Z ipso $
+ * $Date: 2011-03-19 13:29:26 -0700 (Sat, 19 Mar 2011) $
  */
 
 /**
@@ -429,7 +429,6 @@ class PayStubAmendmentListFactory extends PayStubAmendmentFactory implements Ite
 
 		$this->rs = $this->db->Execute($query, $ph);
 		if ( $this->getRecordCount() > 0 ) {
-			Debug::text('isModified Query: '. $query, __FILE__, __LINE__, __METHOD__,10);
 			Debug::text('PS Amendment rows have been modified: '. $this->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
 
 			return TRUE;
@@ -489,8 +488,6 @@ class PayStubAmendmentListFactory extends PayStubAmendmentFactory implements Ite
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order );
 
-		//Debug::text(' Query: '. $query, __FILE__, __LINE__, __METHOD__, 10);
-
 		$this->rs = $this->db->Execute($query, $ph);
 
 		return $this;
@@ -542,8 +539,6 @@ class PayStubAmendmentListFactory extends PayStubAmendmentFactory implements Ite
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order );
 
-		//Debug::text(' Query: '. $query, __FILE__, __LINE__, __METHOD__, 10);
-
 		$this->rs = $this->db->Execute($query, $ph);
 
 		return $this;
@@ -590,8 +585,6 @@ class PayStubAmendmentListFactory extends PayStubAmendmentFactory implements Ite
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order );
 
-		Debug::text(' Query: '. $query, __FILE__, __LINE__, __METHOD__, 10);
-
 		$this->rs = $this->db->Execute($query, $ph);
 
 		return $this;
@@ -664,7 +657,6 @@ class PayStubAmendmentListFactory extends PayStubAmendmentFactory implements Ite
 		$query .= $this->getSortSQL( $order );
 
 		$this->rs = $this->db->Execute($query, $ph);
-		Debug::text(' Query: '. $query, __FILE__, __LINE__, __METHOD__, 10);
 
 		return $this;
 	}
@@ -711,9 +703,6 @@ class PayStubAmendmentListFactory extends PayStubAmendmentFactory implements Ite
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order );
 
-		//$this->rs = $this->db->Execute($query);
-		Debug::text(' Query: '. $query, __FILE__, __LINE__, __METHOD__, 10);
-
 		$sum = $this->db->GetOne($query, $ph);
 
 		if ( $sum !== FALSE OR $sum !== NULL) {
@@ -856,18 +845,29 @@ class PayStubAmendmentListFactory extends PayStubAmendmentFactory implements Ite
 			}
 		}
 
-		$additional_order_fields = array();
+		$additional_order_fields = array('pay_stub_entry_name', 'user_status_id','last_name', 'first_name', 'default_branch', 'default_department', 'user_group', 'title');
+
+		$sort_column_aliases = array(
+									'user_status' => 'user_status_id',
+									'status' => 'status_id',
+									'type' => 'type_id',
+									);
+		$order = $this->getColumnsFromAliases( $order, $sort_column_aliases );
 		if ( $order == NULL ) {
-			$order = array( 'last_name' => 'asc' );
+			$order = array( 'effective_date' => 'desc', 'last_name' => 'asc' );
 			$strict = FALSE;
 		} else {
-			//Always sort by last name,first name after other columns
+			//Always sort by effective_date,last name after other columns
+			if ( !isset($order['effective_date']) ) {
+				$order['effective_date'] = 'desc';
+			}
+
 			if ( !isset($order['last_name']) ) {
 				$order['last_name'] = 'asc';
 			}
 			$strict = TRUE;
 		}
-		//Debug::Arr($order,'Order Data:', __FILE__, __LINE__, __METHOD__,10);
+		Debug::Arr($order,'Order Data:', __FILE__, __LINE__, __METHOD__,10);
 		//Debug::Arr($filter_data,'Filter Data:', __FILE__, __LINE__, __METHOD__,10);
 
 		if ( strncmp($this->db->databaseType,'mysql',5) == 0 ) {
@@ -883,6 +883,7 @@ class PayStubAmendmentListFactory extends PayStubAmendmentFactory implements Ite
 		$utf = new UserTitleFactory();
 		$pseaf = new PayStubEntryAccountFactory();
 		$ppf = new PayPeriodFactory();
+		$ppsuf = new PayPeriodScheduleUserFactory();
 
 		$ph = array(
 					'company_id' => $company_id,
@@ -899,7 +900,7 @@ class PayStubAmendmentListFactory extends PayStubAmendmentFactory implements Ite
 							b.default_department_id as default_department_id,
 							df.name as default_department,
 							b.group_id as group_id,
-							ugf.name as group,
+							ugf.name as user_group,
 							b.title_id as title_id,
 							utf.name as title,
 
@@ -919,7 +920,8 @@ class PayStubAmendmentListFactory extends PayStubAmendmentFactory implements Ite
 						LEFT JOIN '. $utf->getTable() .' as utf ON ( b.title_id = utf.id AND utf.deleted = 0 )
 
 						LEFT JOIN '. $pseaf->getTable() .' as pseaf ON ( a.pay_stub_entry_name_id = pseaf.id AND pseaf.deleted = 0 )
-						LEFT JOIN '. $ppf->getTable() .' as ppf ON ( '. $to_timestamp_sql .' >= ppf.start_date AND '. $to_timestamp_sql .' <= ppf.end_date AND ppf.deleted = 0 )
+						LEFT JOIN '. $ppsuf->getTable() .' as ppsuf ON ( a.user_id = ppsuf.user_id )
+						LEFT JOIN '. $ppf->getTable() .' as ppf ON ( ppsuf.pay_period_schedule_id = ppf.pay_period_schedule_id AND '. $to_timestamp_sql .' >= ppf.start_date AND '. $to_timestamp_sql .' <= ppf.end_date AND ppf.deleted = 0 )
 
 						LEFT JOIN '. $uf->getTable() .' as y ON ( a.created_by = y.id AND y.deleted = 0 )
 						LEFT JOIN '. $uf->getTable() .' as z ON ( a.updated_by = z.id AND z.deleted = 0 )
