@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: RecurringPayStubAmendmentFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4265 $
+ * $Id: RecurringPayStubAmendmentFactory.class.php 4265 2011-02-18 00:49:20Z ipso $
+ * $Date: 2011-02-17 16:49:20 -0800 (Thu, 17 Feb 2011) $
  */
 
 /**
@@ -127,6 +127,9 @@ class RecurringPayStubAmendmentFactory extends Factory {
 										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
 							);
 				break;
+			case 'list_columns':
+				$retval = Misc::arrayIntersectByKey( $this->getOptions('default_display_columns'), Misc::trimSortPrefix( $this->getOptions('columns') ) );
+				break;
 			case 'default_display_columns': //Columns that are displayed by default.
 				$retval = array(
 								'status',
@@ -189,7 +192,7 @@ class RecurringPayStubAmendmentFactory extends Factory {
 		$id = trim($id);
 
 		Debug::Text('Company ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
-		$clf = new CompanyListFactory();
+		$clf = TTnew( 'CompanyListFactory' );
 
 		if ( $this->Validator->isResultSetWithRows(	'company',
 													$clf->getByID($id),
@@ -337,7 +340,7 @@ class RecurringPayStubAmendmentFactory extends Factory {
 	}
 
 	function getUser() {
-		$rpsaulf = new RecurringPayStubAmendmentUserListFactory();
+		$rpsaulf = TTnew( 'RecurringPayStubAmendmentUserListFactory' );
 		$rpsaulf->getByRecurringPayStubAmendment( $this->getId() );
 		foreach ($rpsaulf as $ps_amendment_user) {
 			$user_list[] = $ps_amendment_user->getUser();
@@ -363,7 +366,7 @@ class RecurringPayStubAmendmentFactory extends Factory {
 
 			if ( !$this->isNew() ) {
 				//If needed, delete mappings first.
-				$rpsaulf = new RecurringPayStubAmendmentUserListFactory();
+				$rpsaulf = TTnew( 'RecurringPayStubAmendmentUserListFactory' );
 				$rpsaulf->getByRecurringPayStubAmendment( $this->getId() );
 
 				$tmp_ids = array();
@@ -385,12 +388,12 @@ class RecurringPayStubAmendmentFactory extends Factory {
 			}
 
 			//Insert new mappings.
-			$ulf = new UserListFactory();
+			$ulf = TTnew( 'UserListFactory' );
 			foreach ($ids as $id) {
 				if ( isset($ids) AND !in_array($id, $tmp_ids) ) {
 					if ( $id == -1 ) {
 						Debug::text('--ALL-- Employees selected...', __FILE__, __LINE__, __METHOD__, 10);
-						$rpsauf = new RecurringPayStubAmendmentUserFactory();
+						$rpsauf = TTnew( 'RecurringPayStubAmendmentUserFactory' );
 						$rpsauf->setRecurringPayStubAmendment( $this->getId() );
 						$rpsauf->setUser( $id );
 
@@ -401,7 +404,7 @@ class RecurringPayStubAmendmentFactory extends Factory {
 						}
 
 					} else {
-						$rpsauf = new RecurringPayStubAmendmentUserFactory();
+						$rpsauf = TTnew( 'RecurringPayStubAmendmentUserFactory' );
 						$rpsauf->setRecurringPayStubAmendment( $this->getId() );
 						$rpsauf->setUser( $id );
 
@@ -436,7 +439,7 @@ class RecurringPayStubAmendmentFactory extends Factory {
 	function setPayStubEntryNameId($id) {
 		$id = trim($id);
 
-		$psealf = new PayStubEntryAccountListFactory();
+		$psealf = TTnew( 'PayStubEntryAccountListFactory' );
 		$psealf->getById( $id );
 
 		if (  $this->Validator->isResultSetWithRows(	'pay_stub_entry_name_id',
@@ -455,7 +458,7 @@ class RecurringPayStubAmendmentFactory extends Factory {
 	function setPayStubEntryName($name) {
 		$name = trim($name);
 
-		$psenlf = new PayStubEntryNameListFactory();
+		$psenlf = TTnew( 'PayStubEntryNameListFactory' );
 		$result = $psenlf->getByName($name);
 
 		if (  $this->Validator->isResultSetWithRows(	'ps_entry_name',
@@ -652,7 +655,7 @@ class RecurringPayStubAmendmentFactory extends Factory {
 	function setPercentAmountEntryNameId($id) {
 		$id = trim($id);
 
-		$psealf = new PayStubEntryAccountListFactory();
+		$psealf = TTnew( 'PayStubEntryAccountListFactory' );
 		$psealf->getById( $id );
 		//Not sure why we tried to use $result here, as if the ID passed is NULL, it causes a fatal error.
 		//$result = $psealf->getById( $id )->getCurrent();
@@ -719,7 +722,7 @@ class RecurringPayStubAmendmentFactory extends Factory {
 			$epoch = TTDate::getTime();
 		}
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 
 		Debug::text('Recurring PS Amendment ID: '. $this->getId() .' Frequency: '. $this->getFrequency(), __FILE__, __LINE__, __METHOD__,10);
 
@@ -745,7 +748,7 @@ class RecurringPayStubAmendmentFactory extends Factory {
 			switch( $this->getFrequency() ) {
 				case 10:
 					//Get all open pay periods
-					$pplf = new PayPeriodListFactory();
+					$pplf = TTnew( 'PayPeriodListFactory' );
 					//FIXME: Get all non-closed pay periods AFTER the start date.
 					$pplf->getByUserIdListAndNotStatusAndStartDateAndEndDate($user_ids, 20, $this->getStartDate(), $this->getEndDate() ); //All non-closed pay periods
 					Debug::text('Found Open Pay Periods: '. $pplf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
@@ -758,7 +761,7 @@ class RecurringPayStubAmendmentFactory extends Factory {
 								AND $this->checkTimeFrame($epoch) ) {
 							Debug::text('After end of pay period. Start Date: '. TTDate::getDate('DATE+TIME', $pay_period_obj->getStartDate() ) .' End Date: '. TTDate::getDate('DATE+TIME', $pay_period_obj->getEndDate() ) , __FILE__, __LINE__, __METHOD__,10);
 
-							$psalf = new PayStubAmendmentListFactory();
+							$psalf = TTnew( 'PayStubAmendmentListFactory' );
 
 							//Loop through each user of this Pay Period Schedule adding PS amendments if they don't already exist.
 							$pay_period_schedule_users = $pay_period_obj->getPayPeriodScheduleObject()->getUser();
@@ -777,7 +780,7 @@ class RecurringPayStubAmendmentFactory extends Factory {
 										//No amendment, good to insert one
 										Debug::text('Inserting Recurring PS Amendment for User: '. $user_id, __FILE__, __LINE__, __METHOD__,10);
 
-										$psaf = new PayStubAmendmentFactory();
+										$psaf = TTnew( 'PayStubAmendmentFactory' );
 										$psaf->setUser( $user_id );
 										$psaf->setStatus( 50 );
 
@@ -859,12 +862,12 @@ class RecurringPayStubAmendmentFactory extends Factory {
 								continue;
 							}
 
-							$psalf = new PayStubAmendmentListFactory();
+							$psalf = TTnew( 'PayStubAmendmentListFactory' );
 							if ( $psalf->getByUserIdAndRecurringPayStubAmendmentIdAndStartDateAndEndDate( $user_id, $this->getId(), $start_date, $end_date )->getRecordCount() == 0 ) {
 								//No amendment, good to insert one
 								Debug::text('Inserting Recurring PS Amendment for User: '. $user_id, __FILE__, __LINE__, __METHOD__,10);
 
-								$psaf = new PayStubAmendmentFactory();
+								$psaf = TTnew( 'PayStubAmendmentFactory' );
 								$psaf->setUser( $user_id );
 								$psaf->setStatus( 50 );
 
@@ -1021,7 +1024,7 @@ class RecurringPayStubAmendmentFactory extends Factory {
 	}
 
 	function getObjectAsArray( $include_columns = NULL ) {
-		$uf = new UserFactory();
+		$uf = TTnew( 'UserFactory' );
 
 		$variable_function_map = $this->getVariableToFunctionMap();
 		if ( is_array( $variable_function_map ) ) {
