@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3928 $
- * $Id: PayPeriodFactory.class.php 3928 2010-11-11 20:29:54Z ipso $
- * $Date: 2010-11-11 12:29:54 -0800 (Thu, 11 Nov 2010) $
+ * $Revision: 4845 $
+ * $Id: PayPeriodFactory.class.php 4845 2011-06-21 16:23:18Z ipso $
+ * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
  */
 
 /**
@@ -71,7 +71,8 @@ class PayPeriodFactory extends Factory {
 										'-1050-end_date' => TTi18n::gettext('End Date'),
 										'-1060-transaction_date' => TTi18n::gettext('Transaction Date'),
 
-										'-1500-pending_requests' => TTi18n::gettext('Pending Requests'),
+										'-1500-total_punches' => TTi18n::gettext('Punches'),
+										'-1505-pending_requests' => TTi18n::gettext('Pending Requests'),
 										'-1510-exceptions_high' => TTi18n::gettext('High'),
 										'-1512-exceptions_medium' => TTi18n::gettext('Medium'),
 										'-1514-exceptions_low' => TTi18n::gettext('Low'),
@@ -87,6 +88,9 @@ class PayPeriodFactory extends Factory {
 										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
 							);
 				break;
+			case 'list_columns':
+				$retval = Misc::arrayIntersectByKey( $this->getOptions('default_display_columns'), Misc::trimSortPrefix( $this->getOptions('columns') ) );
+				break;
 			case 'default_display_columns': //Columns that are displayed by default.
 				$retval = array(
 								'pay_period_schedule',
@@ -99,6 +103,9 @@ class PayPeriodFactory extends Factory {
 				break;
 			case 'unique_columns': //Columns that are unique, and disabled for mass editing.
 				$retval = array(
+								'start_date',
+								'end_date',
+								'transaction_date',
 								);
 				break;
 			case 'linked_columns': //Columns that are linked together, mainly for Mass Edit, if one changes, they all must.
@@ -131,6 +138,7 @@ class PayPeriodFactory extends Factory {
 											//'tainted_date' => 'TaintedDate',
 											//'tainted_by' => 'TaintedBy',
 
+											'total_punches' => 'TotalPunches',
 											'pending_requests' => 'PendingRequests',
 											'exceptions_high' => 'Exceptions',
 											'exceptions_medium' => 'Exceptions',
@@ -150,7 +158,7 @@ class PayPeriodFactory extends Factory {
 		if ( is_object($this->pay_period_schedule_obj) ) {
 			return $this->pay_period_schedule_obj;
 		} else {
-			$ppslf = new PayPeriodScheduleListFactory();
+			$ppslf = TTnew( 'PayPeriodScheduleListFactory' );
 			//$this->pay_period_schedule_obj = $ppslf->getById( $this->getPayPeriodSchedule() )->getCurrent();
 			$ppslf->getById( $this->getPayPeriodSchedule() );
 			if ( $ppslf->getRecordCount() > 0 ) {
@@ -159,7 +167,6 @@ class PayPeriodFactory extends Factory {
 			}
 
 			return FALSE;
-
 		}
 	}
 
@@ -169,7 +176,7 @@ class PayPeriodFactory extends Factory {
 	function setCompany($id) {
 		$id = trim($id);
 
-		$clf = new CompanyListFactory();
+		$clf = TTnew( 'CompanyListFactory' );
 
 		if ( $this->Validator->isResultSetWithRows(	'company',
 													$clf->getByID($id),
@@ -192,21 +199,35 @@ class PayPeriodFactory extends Factory {
 		return FALSE;
 	}
 	function setStatus($status) {
-		$status = trim($status);
+		$status = (int)trim($status);
 
-		$key = Option::getByValue($status, $this->getOptions('status') );
-		if ($key !== FALSE) {
-			$status = $key;
+		$status_options = $this->getOptions('status');
+		$validate_msg = TTi18n::gettext('Invalid Status');
+
+		Debug::Text('Current Status: '. $this->getStatus() .' New Status: '. $status, __FILE__, __LINE__, __METHOD__,10);
+		switch ( $this->getStatus() ) {
+			case 20: //Closed
+				$valid_statuses = array( 20, 30 );
+				$status_options = Misc::arrayIntersectByKey( $valid_statuses, $status_options );
+				$validate_msg = TTi18n::gettext('Status can only be changed from Closed to Post Adjustment');
+				break;
+			case 30: //Post Adjustment
+				$valid_statuses = array( 20, 30 );
+				$status_options = Misc::arrayIntersectByKey( $valid_statuses, $status_options );
+				$validate_msg = TTi18n::gettext('Status can only be changed from Post Adjustment to Closed');
+				break;
+			default:
+				break;
 		}
 
-		if ( $this->Validator->inArrayKey(	'status',
+		if ( $this->Validator->inArrayKey(	'status_id',
 											$status,
-											TTi18n::gettext('Incorrect Status'),
-											$this->getOptions('status')) ) {
+											$validate_msg,
+											$status_options ) ) {
 
 			$this->data['status_id'] = $status;
 
-			return FALSE;
+			return TRUE;
 		}
 
 		return FALSE;
@@ -222,7 +243,7 @@ class PayPeriodFactory extends Factory {
 	function setPayPeriodSchedule($id) {
 		$id = trim($id);
 
-		$ppslf = new PayPeriodScheduleListFactory();
+		$ppslf = TTnew( 'PayPeriodScheduleListFactory' );
 
 		if ( $id == 0
 				OR $this->Validator->isResultSetWithRows(	'pay_period_schedule',
@@ -245,10 +266,10 @@ class PayPeriodFactory extends Factory {
 		}
 
 		$ph = array(
-					'pay_period_schedule_id' => $this->getPayPeriodSchedule(),
+					'pay_period_schedule_id' => (int)$this->getPayPeriodSchedule(),
 					'start_date' => $this->db->BindTimeStamp($epoch),
 					'end_date' => $this->db->BindTimeStamp($epoch),
-					'id' => $id,
+					'id' => (int)$id,
 					);
 
 		//Used to have LIMIT 1 at the end, but GetOne() should do that for us.
@@ -434,7 +455,7 @@ class PayPeriodFactory extends Factory {
 
 		$this->StartTransaction();
 
-		$pslf = new PayStubListFactory();
+		$pslf = TTnew( 'PayStubListFactory' );
 		$pslf->getByPayPeriodId( $this->getId() );
 		foreach($pslf as $pay_stub) {
 			//Only change status of advance pay stubs if we're in the advance part of the pay period.
@@ -519,7 +540,7 @@ class PayPeriodFactory extends Factory {
 			}
 		}
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 
 		if ( $this->Validator->isResultSetWithRows(	'tainted_by',
 													$ulf->getByID($id),
@@ -550,6 +571,7 @@ class PayPeriodFactory extends Factory {
 	}
 	function getTimeSheetVerifyWindowEndDate() {
 		if ( is_object( $this->getPayPeriodScheduleObject() ) ) {
+			//FIXME: Make this end at midnight, otherwise it defaults to noon. Allow float values for this perhaps, like 2.5days?
 			return (int)$this->getTransactionDate()-( (int)$this->getPayPeriodScheduleObject()->getTimeSheetVerifyBeforeTransactionDate()*86400);
 		}
 
@@ -594,7 +616,7 @@ class PayPeriodFactory extends Factory {
 
 		if ( is_object( $pps_obj ) ) {
 			//Get all users assigned to this pp schedule
-			$udlf = new UserDateListFactory();
+			$udlf = TTnew( 'UserDateListFactory' );
 			$udlf->getByUserIdAndStartDateAndEndDateAndEmptyPayPeriod( $pps_obj->getUser(), $this->getStartDate(), $this->getEndDate() );
 			Debug::text(' Pay Period ID: '. $this->getId() .' Pay Period orphaned User Date Rows: '. $udlf->getRecordCount() .' Start Date: '. TTDate::getDate('DATE+TIME', $this->getStartDate() ) .' End Date: '. TTDate::getDate('DATE+TIME', $this->getEndDate() ), __FILE__, __LINE__, __METHOD__,10);
 			if ( $udlf->getRecordCount() > 0 ) {
@@ -618,7 +640,7 @@ class PayPeriodFactory extends Factory {
 	function importData() {
 		$pps_obj = $this->getPayPeriodScheduleObject();
 
-		$udlf = new UserDateListFactory();
+		$udlf = TTnew( 'UserDateListFactory' );
 
 		$udlf->StartTransaction();
 		$udlf->getByUserIdAndStartDateAndEndDate($pps_obj->getUser(), $this->getStartDate(), $this->getEndDate() );
@@ -650,7 +672,7 @@ class PayPeriodFactory extends Factory {
 	function deleteData() {
 		Debug::text('Deleting all data from pay period: '. $this->getID(), __FILE__, __LINE__, __METHOD__, 10);
 		//Remove all user_date rows, punch control, punches, and schedules
-		$udlf = new UserDateListFactory();
+		$udlf = TTnew( 'UserDateListFactory' );
 		$udlf->getByPayPeriodID( $this->getId() );
 		Debug::text(' Pay Period ID: '. $this->getId() .' Pay Period User Date Rows: '. $udlf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
 		if ( $udlf->getRecordCount() > 0 ) {
@@ -671,7 +693,7 @@ class PayPeriodFactory extends Factory {
 	function getPendingRequests() {
 		if ( $this->getCompany() != '' AND $this->isNew() == FALSE ) {
 			//Get all pending requests
-			$rlf = new RequestListFactory();
+			$rlf = TTnew( 'RequestListFactory' );
 			$rlf->getSumByCompanyIDAndPayPeriodIdAndStatus( $this->getCompany(), $this->getID(), 30 );
 			if ( $rlf->getRecordCount() == 1 ) {
 				return $rlf->getCurrent()->getColumn('total');
@@ -690,10 +712,10 @@ class PayPeriodFactory extends Factory {
 						'exceptions_high' => 0,
 						);
 
-		$elf = new ExceptionListFactory();
+		$elf = TTnew( 'ExceptionListFactory' );
 		$elf->getSumExceptionsByPayPeriodIdAndBeforeDate( $this->getID(), $this->getEndDate() );
 		if ( $elf->getRecordCount() > 0 ) {
-			Debug::Text(' Found Exceptions: '. $elf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
+			//Debug::Text(' Found Exceptions: '. $elf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
 			foreach($elf as $e_obj ) {
 				if ( $e_obj->getColumn('severity_id') == 10 ) {
 					$retarr['exceptions_low'] = $e_obj->getColumn('count');
@@ -707,12 +729,20 @@ class PayPeriodFactory extends Factory {
 
 			}
 		} else {
-			Debug::Text(' No Exceptions!', __FILE__, __LINE__, __METHOD__,10);
+			//Debug::Text(' No Exceptions!', __FILE__, __LINE__, __METHOD__,10);
 		}
 
 		return $retarr;
 	}
 
+	function getTotalPunches() {
+		//Count how many punches are in this pay period.
+		$plf = TTnew( 'PunchListFactory' );
+		$retval = $plf->getByPayPeriodId( $this->getID() )->getRecordCount();
+		Debug::Text(' Total Punches: '. $retval, __FILE__, __LINE__, __METHOD__,10);
+		return $retval;
+	}
+
 	function getTimeSheets() {
 		$retarr = array(
 						'verified_timesheets' => 0,
@@ -721,7 +751,7 @@ class PayPeriodFactory extends Factory {
 						);
 
 		//Get verified timesheets
-		$pptsvlf = new PayPeriodTimeSheetVerifyListFactory();
+		$pptsvlf = TTnew( 'PayPeriodTimeSheetVerifyListFactory' );
 		$pptsvlf->getByPayPeriodIdAndCompanyId( $this->getID(), $this->getCompany() );
 		if ( $pptsvlf->getRecordCount() > 0 ) {
 			foreach( $pptsvlf as $pptsv_obj ) {
@@ -734,7 +764,7 @@ class PayPeriodFactory extends Factory {
 		}
 
 		//Get total employees with time for this pay period.
-		$udtlf = new UserDateTotalListFactory();
+		$udtlf = TTnew( 'UserDateTotalListFactory' );
 		$retarr['total_timesheets'] = $udtlf->getWorkedUsersByPayPeriodId( $this->getID() );
 
 		return $retarr;
@@ -742,7 +772,7 @@ class PayPeriodFactory extends Factory {
 
 	function getPayStubAmendments() {
 		//Get PS Amendments.
-		$psalf = new PayStubAmendmentListFactory();
+		$psalf = TTnew( 'PayStubAmendmentListFactory' );
 		$psalf->getByCompanyIdAndAuthorizedAndStartDateAndEndDate( $this->getCompany(), TRUE, $this->getStartDate(), $this->getEndDate() );
 		$total_ps_amendments = 0;
 		if ( is_object($psalf) ) {
@@ -755,9 +785,9 @@ class PayPeriodFactory extends Factory {
 
 	function getPayStubs() {
 		//Count how many pay stubs for each pay period.
-		$pslf = new PayStubListFactory();
+		$pslf = TTnew( 'PayStubListFactory' );
 		$total_pay_stubs = $pslf->getByPayPeriodId( $this->getId() )->getRecordCount();
-		Debug::Text(' Total Pay Stubs: '. $total_pay_stubs, __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Text(' Total Pay Stubs: '. $total_pay_stubs, __FILE__, __LINE__, __METHOD__,10);
 		return $total_pay_stubs;
 	}
 
@@ -767,51 +797,29 @@ class PayPeriodFactory extends Factory {
 
 		//Make sure End Date is after Start Date, and transaction date is the same or after End Date.
 		Debug::text('Start Date: '. $this->getStartDate() .' End Date: '. $this->getEndDate(), __FILE__, __LINE__, __METHOD__, 10);
-		if ( $this->getEndDate() <= $this->getStartDate() ) {
+		if ( $this->getStartDate() != '' AND $this->getEndDate() != '' AND $this->getEndDate() <= $this->getStartDate() ) {
 			$this->Validator->isTrue(		'end_date',
 											FALSE,
 											TTi18n::gettext('Conflicting end date'));
 		}
 
-		if ( $this->getTransactionDate() < $this->getEndDate() ) {
+		if ( $this->getEndDate() != '' AND $this->getTransactionDate() != '' AND $this->getTransactionDate() < $this->getEndDate() ) {
 			$this->Validator->isTrue(		'transaction_date',
 											FALSE,
 											TTi18n::gettext('Conflicting transaction date'));
 		}
 
+		if ( ( $this->getStatus() == 20 OR $this->getStatus() == 30 ) AND $this->getEndDate() > 0 AND TTDate::getBeginDayEpoch( time() ) <= $this->getEndDate() ) {
+			$this->Validator->isTrue(		'status_id',
+											FALSE,
+											TTi18n::gettext('Invalid status, unable to lock or close pay periods before their end date.'));
+
+		}
+
 		//Make sure if this a monthly+advanc pay period, advance dates are set.
-        $ppslf = new PayPeriodScheduleListFactory();
+        $ppslf = TTnew( 'PayPeriodScheduleListFactory' );
 		$ppslf->getById( $this->getPayPeriodSchedule() );
-		if ( $ppslf->getRecordCount() == 1 AND is_object($ppslf) AND $ppslf->getCurrent()->getType() == 40 ) {
-			Debug::text('Pay Period Type IS Monthly + Advance: ', __FILE__, __LINE__, __METHOD__, 10);
-			if ( $this->getAdvanceEndDate() === FALSE ) {
-				$this->Validator->isTrue(		'advance_end_date',
-												FALSE,
-												TTi18n::gettext('Advance end date is not set') );
-			}
-
-			if ( $this->getAdvanceTransactionDate() === FALSE ) {
-				$this->Validator->isTrue(		'advance_transaction_date',
-												FALSE,
-												TTi18n::gettext('Advance transaction date is not set') );
-			}
-
-			//Make sure advance dates are in the proper range.
-			if ( $this->getAdvanceEndDate() > $this->getEndDate()
-					OR  $this->getAdvanceEndDate() < $this->getStartDate() ) {
-						$this->Validator->isDate(		'advance_end_date',
-														FALSE,
-														TTi18n::gettext('Incorrect advance end date'));
-			}
-
-			if ( $this->getAdvanceTransactionDate() > $this->getEndDate()
-					OR  $this->getAdvanceTransactionDate() < $this->getAdvanceEndDate() ) {
-						$this->Validator->isDate(		'advance_transaction_date',
-														FALSE,
-														TTi18n::gettext('Incorrect advance transaction date'));
-			}
-
-		} elseif ( $ppslf->getRecordCount() == 1 AND is_object($ppslf) ) {
+		if ( $ppslf->getRecordCount() == 1 AND is_object($ppslf) ) {
 			Debug::text('Pay Period Type is NOT Monthly + Advance... Advance End Date: '. $this->getAdvanceEndDate(), __FILE__, __LINE__, __METHOD__, 10);
 			if ( $this->getAdvanceEndDate() != '' ) {
 				$this->Validator->isTrue(		'advance_end_date',
@@ -824,9 +832,9 @@ class PayPeriodFactory extends Factory {
 												FALSE,
 												TTi18n::gettext('Advance transaction date is set') );
 			}
-		} else {
+		} elseif ( $this->getPayPeriodSchedule() == '' ) { // Used to be != for some reason?
 			Debug::text('Pay Period Schedule not found: '. $this->getPayPeriodSchedule(), __FILE__, __LINE__, __METHOD__, 10);
-			$this->Validator->isTrue(		'pay_period_schedule',
+			$this->Validator->isTrue(		'pay_period_schedule_id',
 											FALSE,
 											TTi18n::gettext('Incorrect Pay Period Schedule') );
 		}
@@ -857,9 +865,9 @@ class PayPeriodFactory extends Factory {
 			Debug::text('Delete TRUE: ', __FILE__, __LINE__, __METHOD__, 10);
 			//Unassign user_date rows from this pay period, no need to delete this data anymore as it can be easily done otherways and users don't realize
 			//how much data will actually be deleted.
-			$udf = new UserDateFactory();
+			$udf = TTnew( 'UserDateFactory' );
 
-			$query = 'update '. $udf->getTable() .' set pay_period_id = 0 where pay_period_id = '. $this->getId();
+			$query = 'update '. $udf->getTable() .' set pay_period_id = 0 where pay_period_id = '. (int)$this->getId();
 			$this->db->Execute($query);
 		} else {
 			if ( $this->getStatus() == 20 ) { //Closed
@@ -915,7 +923,7 @@ class PayPeriodFactory extends Factory {
 	function getObjectAsArray( $include_columns = NULL ) {
 		$variable_function_map = $this->getVariableToFunctionMap();
 		if ( is_array( $variable_function_map ) ) {
-	        $ppsf = new PayPeriodScheduleFactory();
+	        $ppsf = TTnew( 'PayPeriodScheduleFactory' );
 
 			foreach( $variable_function_map as $variable => $function_stub ) {
 				if ( $include_columns == NULL OR ( isset($include_columns[$variable]) AND $include_columns[$variable] == TRUE ) ) {
@@ -930,11 +938,7 @@ class PayPeriodFactory extends Factory {
 							break;
 						case 'type':
 							//Make sure type_id is set first.
-							if ( isset($data['type_id']) ) {
-								$data[$variable] = Option::getByKey( $data['type_id'], $ppsf->getOptions( $variable ) );
-							} else {
-								$data[$variable] = NULL;
-							}
+							$data[$variable] = Option::getByKey( $this->getColumn('type_id'), $ppsf->getOptions( $variable ) );
 							break;
 						case 'type_id':
 						case 'pay_period_schedule':
@@ -947,6 +951,7 @@ class PayPeriodFactory extends Factory {
 								$data[$variable] = TTDate::getAPIDate( 'DATE+TIME', $this->$function() );
 							}
 							break;
+						case 'total_punches':
 						case 'pending_requests':
 						case 'ps_amendments':
 						case 'pay_stubs':
