@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3939 $
- * $Id: PayPeriodListFactory.class.php 3939 2010-11-19 22:41:24Z ipso $
- * $Date: 2010-11-19 14:41:24 -0800 (Fri, 19 Nov 2010) $
+ * $Revision: 4669 $
+ * $Id: PayPeriodListFactory.class.php 4669 2011-05-13 19:30:08Z ipso $
+ * $Date: 2011-05-13 12:30:08 -0700 (Fri, 13 May 2011) $
  */
 
 /**
@@ -1135,12 +1135,21 @@ class PayPeriodListFactory extends PayPeriodFactory implements IteratorAggregate
 		$psf = new PayStubFactory();
 
 		//Make sure just one row per pay period is returned.
+
+/*
+		//This is way too slow on older versions of PGSQL.
 		$query = '
 					select 	a.*
 					from	'. $this->getTable() .' as a
 					where	a.company_id = ?
 						AND ( a.deleted = 0 )
 						AND EXISTS ( select id from '. $psf->getTable() .' as b WHERE a.id = b.pay_period_id AND b.deleted = 0)';
+*/
+		$query = '	select 	distinct a.*
+					from	'. $this->getTable() .' as a
+						LEFT JOIN '.  $psf->getTable() .' as b on ( a.id = b.pay_period_id )
+					where	a.company_id = ?
+						AND ( a.deleted = 0 AND b.deleted = 0 )';
 
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order );
@@ -1162,12 +1171,6 @@ class PayPeriodListFactory extends PayPeriodFactory implements IteratorAggregate
 			return FALSE;
 		}
 
-		if ( $include_all_pay_period_schedules == TRUE ) {
-			$cache_id = 'JSCalendarPayPeriodArray_'.$current_company->getId().'_0';
-		} else {
-			$cache_id = 'JSCalendarPayPeriodArray_'.$current_company->getId().'_'.$current_user->getId();
-		}
-
 		if ( !is_object($current_company) ) {
 			return FALSE;
 		}
@@ -1176,15 +1179,19 @@ class PayPeriodListFactory extends PayPeriodFactory implements IteratorAggregate
 			return FALSE;
 		}
 
+		if ( $include_all_pay_period_schedules == TRUE ) {
+			$cache_id = 'JSCalendarPayPeriodArray_'.$current_company->getId().'_0';
+		} else {
+			$cache_id = 'JSCalendarPayPeriodArray_'.$current_company->getId().'_'.$current_user->getId();
+		}
+
 		$retarr = $this->getCache($cache_id);
 		if ( $retarr === FALSE ) {
 			$pplf = new PayPeriodListFactory();
 			if ( $include_all_pay_period_schedules == TRUE ) {
 				$pplf->getByCompanyId( $current_company->getId(), 13);
-				$cache_id = 'JSCalendarPayPeriodArray_'.$current_company->getId().'_0';
 			} else {
 				$pplf->getByUserId( $current_user->getId(), 13);
-				$cache_id = 'JSCalendarPayPeriodArray_'.$current_company->getId().'_'.$current_user->getId();
 			}
 
 			$retarr = FALSE;
@@ -1261,6 +1268,9 @@ class PayPeriodListFactory extends PayPeriodFactory implements IteratorAggregate
 					where	a.company_id = ?
 					';
 
+		if ( isset($filter_data['permission_children_ids']) AND isset($filter_data['permission_children_ids'][0]) AND !in_array(-1, (array)$filter_data['permission_children_ids']) ) {
+			$query  .=	' AND a.created_by in ('. $this->getListSQL($filter_data['permission_children_ids'], $ph) .') ';
+		}
 		if ( isset($filter_data['id']) AND isset($filter_data['id'][0]) AND !in_array(-1, (array)$filter_data['id']) ) {
 			$query  .=	' AND a.id in ('. $this->getListSQL($filter_data['id'], $ph) .') ';
 		}
