@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3883 $
- * $Id: PayPeriodScheduleFactory.class.php 3883 2010-10-01 21:10:50Z ipso $
- * $Date: 2010-10-01 14:10:50 -0700 (Fri, 01 Oct 2010) $
+ * $Revision: 4556 $
+ * $Id: PayPeriodScheduleFactory.class.php 4556 2011-04-20 23:27:04Z ipso $
+ * $Date: 2011-04-20 16:27:04 -0700 (Wed, 20 Apr 2011) $
  */
 
 /**
@@ -125,6 +125,9 @@ class PayPeriodScheduleFactory extends Factory {
 										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
 							);
 				break;
+			case 'list_columns':
+				$retval = Misc::arrayIntersectByKey( $this->getOptions('default_display_columns'), Misc::trimSortPrefix( $this->getOptions('columns') ) );
+				break;
 			case 'default_display_columns': //Columns that are displayed by default.
 				$retval = array(
 								'type',
@@ -183,7 +186,7 @@ class PayPeriodScheduleFactory extends Factory {
 	function setCompany($id) {
 		$id = trim($id);
 
-		$clf = new CompanyListFactory();
+		$clf = TTnew( 'CompanyListFactory' );
 
 		if ( $this->Validator->isResultSetWithRows(	'company',
 													$clf->getByID($id),
@@ -603,7 +606,7 @@ class PayPeriodScheduleFactory extends Factory {
 	}
 
 	function getTimeZoneOptions() {
-		$upf = new UserPreferenceFactory();
+		$upf = TTnew( 'UserPreferenceFactory' );
 
 		return $upf->getOptions('time_zone');
 	}
@@ -826,7 +829,7 @@ class PayPeriodScheduleFactory extends Factory {
 	}
 
 	function getUser() {
-		$ppsulf = new PayPeriodScheduleUserListFactory();
+		$ppsulf = TTnew( 'PayPeriodScheduleUserListFactory' );
 		$ppsulf->getByPayPeriodScheduleId( $this->getId() );
 		foreach ($ppsulf as $pay_period_schedule) {
 			$user_list[] = $pay_period_schedule->getUser();
@@ -846,7 +849,7 @@ class PayPeriodScheduleFactory extends Factory {
 		if ( is_array($ids) ) {
 			if ( !$this->isNew() ) {
 				//If needed, delete mappings first.
-				$ppsulf = new PayPeriodScheduleUserListFactory();
+				$ppsulf = TTnew( 'PayPeriodScheduleUserListFactory' );
 				$ppsulf->getByPayPeriodScheduleId( $this->getId() );
 
 				$user_ids = array();
@@ -867,11 +870,11 @@ class PayPeriodScheduleFactory extends Factory {
 			}
 
 			//Insert new mappings.
-			$ulf = new UserListFactory();
+			$ulf = TTnew( 'UserListFactory' );
 
 			foreach ($ids as $id) {
 				if ( $id != '' AND isset($user_ids) AND !in_array($id, $user_ids) ) {
-					$ppsuf = new PayPeriodScheduleUserFactory();
+					$ppsuf = TTnew( 'PayPeriodScheduleUserFactory' );
 					$ppsuf->setPayPeriodSchedule( $this->getId() );
 					$ppsuf->setUser( $id );
 
@@ -899,7 +902,7 @@ class PayPeriodScheduleFactory extends Factory {
 		$user_ids = $this->getUser();
 
 		if ( count($user_ids) > 0 ) {
-			$hlf = new HolidayListFactory();
+			$hlf = TTnew( 'HolidayListFactory' );
 			$hlf->getByPolicyGroupUserIdAndStartDateAndEndDate( $user_ids, $epoch-(86400*14), $epoch+(86400*2) );
 			if ( $hlf->getRecordCount() > 0 ) {
 				foreach( $hlf as $h_obj ) {
@@ -926,7 +929,7 @@ class PayPeriodScheduleFactory extends Factory {
 			return FALSE;
 		}
 
-		$pplf = new PayPeriodListFactory();
+		$pplf = TTnew( 'PayPeriodListFactory' );
 
 		//Debug::text('PP Schedule ID: '. $this->getId(), __FILE__, __LINE__, __METHOD__, 10);
 		//Debug::text('PP Schedule Name: '. $this->getName(), __FILE__, __LINE__, __METHOD__, 10);
@@ -1179,7 +1182,7 @@ class PayPeriodScheduleFactory extends Factory {
 		if ( $this->getNextStartDate() <= ( TTDate::getTime() + $offset ) ) {
 			Debug::text('Insert new pay period. Start Date: '. $this->getNextStartDate() .' End Date: '. $this->getNextEndDate() , __FILE__, __LINE__, __METHOD__,10);
 
-			$ppf = new PayPeriodFactory();
+			$ppf = TTnew( 'PayPeriodFactory' );
 			$ppf->setCompany( $this->getCompany() );
 			$ppf->setPayPeriodSchedule( $this->getId() );
 			$ppf->setStatus(10);
@@ -1283,7 +1286,7 @@ class PayPeriodScheduleFactory extends Factory {
 /*
 		//FIXME: If a company starts with TimeTrex half way through the year, this will be incorrect.
 		//Because it only counts pay periods that exist, not pay periods that WOULD have existed.
-		$pplf = new PayPeriodListFactory();
+		$pplf = TTnew( 'PayPeriodListFactory' );
 		$pplf->getByPayPeriodScheduleIdAndStartTransactionDateAndEndTransactionDate( $this->getId(), TTDate::getBeginYearEpoch( $epoch ), $epoch );
 		$retval = $pplf->getRecordCount();
 
@@ -1340,7 +1343,7 @@ class PayPeriodScheduleFactory extends Factory {
 				$retval = FALSE;
 
 				if ( $this->getId() > 0 ) {
-					$pplf = new PayPeriodListFactory();
+					$pplf = TTnew( 'PayPeriodListFactory' );
 					$retarr = $pplf->getFirstStartDateAndLastEndDateByPayPeriodScheduleId( $this->getId() );
 					if ( is_array($retarr) AND isset($retarr['first_start_date']) AND isset($retarr['last_end_date']) ) {
 						$retarr['first_start_date'] = TTDate::strtotime( $retarr['first_start_date'] );
@@ -1355,6 +1358,9 @@ class PayPeriodScheduleFactory extends Factory {
 
 				break;
 			case 10:
+				//Needs to take into account years, where 53 weeks may occur.
+				//Will need to get the day weeks start on and the year for this to calculate properly.
+				//I believe 2015 is the next time this will occur.
 				$retval = 52;
 				break;
 			case 20:
@@ -1379,7 +1385,7 @@ class PayPeriodScheduleFactory extends Factory {
 
 	//Returns shift data according to the pay period schedule criteria for use
 	//in determining which day punches belong to.
-	function getShiftData( $user_date_id = NULL, $user_id = NULL, $epoch = NULL, $filter = NULL, $tmp_punch_control_obj = NULL ) {
+	function getShiftData( $user_date_id = NULL, $user_id = NULL, $epoch = NULL, $filter = NULL, $tmp_punch_control_obj = NULL, $maximum_shift_time = NULL ) {
 		global $profiler;
 		$profiler->startTimer( 'PayPeriodScheduleFactory::getShiftData()' );
 
@@ -1391,10 +1397,14 @@ class PayPeriodScheduleFactory extends Factory {
 			return FALSE;
 		}
 
+		if ( $maximum_shift_time === NULL ) {
+			$maximum_shift_time = $this->getMaximumShiftTime();
+		}
+
 		//Debug::text('User Date ID: '. $user_date_id .' User ID: '. $user_id .' TimeStamp: '. TTDate::getDate('DATE+TIME', $epoch), __FILE__, __LINE__, __METHOD__, 10);
 		$new_shift_trigger_time = $this->getNewDayTriggerTime();
 
-		$plf = new PunchListFactory();
+		$plf = TTnew( 'PunchListFactory' );
 		if ( $user_date_id != '' ) {
 			$plf->getByUserDateId( $user_date_id );
 		} else {
@@ -1403,11 +1413,11 @@ class PayPeriodScheduleFactory extends Factory {
 			if ( is_object( $tmp_punch_control_obj ) ) {
 				$punch_control_id = $tmp_punch_control_obj->getId();
 			}
-			$plf->getShiftPunchesByUserIDAndEpoch( $user_id, $epoch, $punch_control_id, $this->getMaximumShiftTime() );
+			$plf->getShiftPunchesByUserIDAndEpoch( $user_id, $epoch, $punch_control_id, $maximum_shift_time );
 			unset($punch_control_id);
 		}
 
-		Debug::text('Punch Rows: '. $plf->getRecordCount() .' UserID: '. $user_id .' Date: '. TTDate::getDate('DATE+TIME', $epoch) .'('.$epoch.') MaximumShiftTime: '. $this->getMaximumShiftTime(), __FILE__, __LINE__, __METHOD__, 10);
+		Debug::text('Punch Rows: '. $plf->getRecordCount() .' UserID: '. $user_id .' Date: '. TTDate::getDate('DATE+TIME', $epoch) .'('.$epoch.') MaximumShiftTime: '. $maximum_shift_time .' Filter: '. $filter, __FILE__, __LINE__, __METHOD__, 10);
 
 		if ( $plf->getRecordCount() > 0 ) {
 			$shift = 0;
@@ -1450,14 +1460,15 @@ class PayPeriodScheduleFactory extends Factory {
 				//punches in a pair, the remaining punch is ignored and causing punches to jump around between days in some cases.
 				if ( $i > 0 AND isset($shift_data[$shift]['last_out'])
 						AND ( $p_obj->getStatus() == 10 OR $p_obj->getStatus() == $prev_punch_arr['status_id'] )) {
-					//Debug::text('Checking for new shift...', __FILE__, __LINE__, __METHOD__, 10);
+					//Debug::text('Checking for new shift... This Control ID: '.$p_obj->getPunchControlID() .' Last Out Control ID: '. $shift_data[$shift]['last_out']['punch_control_id'] , __FILE__, __LINE__, __METHOD__, 10);
 					//Assume that if two punches are assigned to the same punch_control_id are the same shift, even if the time between
 					//them exceeds the new_shift_trigger_time. This helps fix the bug where you could add a In punch then add a Out
 					//punch BEFORE the In punch as long as it was more than the Maximum Shift Time before the In Punch.
 					//ie: Add: In Punch 10-Dec-09 @ 8:00AM, Add: Out Punch 09-Dec-09 @ 5:00PM.
 					//Basically it just helps the validation checks to determine the error.
+					//If shifts are split at midnight, new_shift_trigger_time must be 0, so the "split" punch can occur at midnight.
 					if ( $p_obj->getPunchControlID() != $shift_data[$shift]['last_out']['punch_control_id']
-							AND ($p_obj->getTimeStamp() - $shift_data[$shift]['last_out']['time_stamp']) > $new_shift_trigger_time ) {
+							AND ( $p_obj->getTimeStamp() - $shift_data[$shift]['last_out']['time_stamp']) >= $new_shift_trigger_time ) {
 						$shift++;
 					}
 				}
@@ -1473,10 +1484,17 @@ class PayPeriodScheduleFactory extends Factory {
 
 				//Determine which shift is closest to the given epoch.
 				$punch_difference_from_epoch = abs($epoch-$p_obj->getTimeStamp());
-				if ( $nearest_punch_difference === FALSE OR $punch_difference_from_epoch < $nearest_punch_difference ) {
+				if ( $nearest_punch_difference === FALSE OR $punch_difference_from_epoch <= $nearest_punch_difference ) {
 					Debug::text('Nearest Shift Determined to be: '. $shift .' Nearest Punch Diff: '. (int)$nearest_punch_difference .' Punch Diff: '. $punch_difference_from_epoch, __FILE__, __LINE__, __METHOD__, 10);
-					$nearest_shift_id = $shift;
-					$nearest_punch_difference = $punch_difference_from_epoch;
+
+					//If two punches have the same timestamp, use the shift that matches the passed punch control object, which is usually the one we are currently editing...
+					//This is for splitting shifts at exactly midnight.
+					if ( $punch_difference_from_epoch != $nearest_punch_difference
+							OR ( $punch_difference_from_epoch == $nearest_punch_difference AND ( is_object( $tmp_punch_control_obj ) AND $tmp_punch_control_obj->getId() == $p_obj->getPunchControlID() ) ) ) {
+						//Debug::text('Found two punches with the same timestamp... Tmp Punch Control: '.$tmp_punch_control_obj->getId() .' Punch Control: '. $p_obj->getPunchControlID() , __FILE__, __LINE__, __METHOD__, 10);
+						$nearest_shift_id = $shift;
+						$nearest_punch_difference = $punch_difference_from_epoch;
+					}
 				}
 
 				$punch_arr = array(
@@ -1493,7 +1511,10 @@ class PayPeriodScheduleFactory extends Factory {
 				if ( $punch_control_obj->getUserDateID() != FALSE ) {
 					$shift_data[$shift]['user_date_ids'][] = $punch_control_obj->getUserDateID();
 				}
-				$shift_data[$shift]['span_midnight'] = FALSE;
+
+				if ( !isset($shift_data[$shift]['span_midnight']) ) {
+					$shift_data[$shift]['span_midnight'] = FALSE;
+				}
 				if ( !isset($shift_data[$shift]['first_in']) AND $p_obj->getStatus() == 10 ) {
 					//Debug::text('First In -- Punch ID: '. $p_obj->getID() .' Punch Control ID: '. $p_obj->getPunchControlID() .' TimeStamp: '. TTDate::getDate('DATE+TIME', $p_obj->getTimeStamp() ), __FILE__, __LINE__, __METHOD__, 10);
 
@@ -1644,7 +1665,7 @@ class PayPeriodScheduleFactory extends Factory {
 
 		if ( $this->getDeleted() == TRUE ) {
 			//Delete pay periods assigned to this schedule.
-			$pplf = new PayPeriodListFactory();
+			$pplf = TTnew( 'PayPeriodListFactory' );
 			$pplf->getByPayPeriodScheduleId( $this->getId() );
 			if ( $pplf->getRecordCount() > 0 ) {
 				Debug::text('Delete Pay Periods: '. $pplf->getRecordCount(), __FILE__, __LINE__, __METHOD__, 10);
@@ -1671,14 +1692,14 @@ class PayPeriodScheduleFactory extends Factory {
 		$this->removeCache( $this->getId() );
 
 		if ( $this->getEnableInitialPayPeriods() == TRUE AND $this->getCreateInitialPayPeriods() == TRUE ) {
-			$ppslf = new PayPeriodScheduleListFactory();
+			$ppslf = TTnew( 'PayPeriodScheduleListFactory' );
 			$pay_period_schedule_obj = $ppslf->getById( $this->getId() )->getCurrent();
 
 			$pay_period_schedule_obj->createNextPayPeriod( $pay_period_schedule_obj->getAnchorDate() );
 			Debug::text('New Pay Period Schdule, creating pay periods start from ('.$pay_period_schedule_obj->getAnchorDate().'): '. TTDate::getDate('DATE+TIME', $pay_period_schedule_obj->getAnchorDate() ), __FILE__, __LINE__, __METHOD__, 10);
 
-			//Create pay periods up until now, at most 104.
-			for($i=0; $i <= 104; $i++ ) {
+			//Create pay periods up until now, at most 260. (5yrs of weekly ones)
+			for($i=0; $i <= 260; $i++ ) {
 				if ( $pay_period_schedule_obj->createNextPayPeriod() == FALSE ) {
 					Debug::text('createNextPayPeriod returned false, stopping loop.', __FILE__, __LINE__, __METHOD__, 10);
 					break;
