@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3790 $
- * $Id: PayPeriodScheduleUserFactory.class.php 3790 2010-08-18 15:32:21Z ipso $
- * $Date: 2010-08-18 08:32:21 -0700 (Wed, 18 Aug 2010) $
+ * $Revision: 4104 $
+ * $Id: PayPeriodScheduleUserFactory.class.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 
 /**
@@ -54,7 +54,7 @@ class PayPeriodScheduleUserFactory extends Factory {
 	function setPayPeriodSchedule($id) {
 		$id = trim($id);
 
-		$ppslf = new PayPeriodScheduleListFactory();
+		$ppslf = TTnew( 'PayPeriodScheduleListFactory' );
 
 		if ( $id != 0
 				OR $this->Validator->isResultSetWithRows(	'pay_period_schedule',
@@ -73,7 +73,7 @@ class PayPeriodScheduleUserFactory extends Factory {
 		if ( is_object($this->user_obj) ) {
 			return $this->user_obj;
 		} else {
-			$ulf = new UserListFactory();
+			$ulf = TTnew( 'UserListFactory' );
 			$ulf->getById( $this->getUser() );
 			if ( $ulf->getRecordCount() == 1 ) {
 				$this->user_obj = $ulf->getCurrent();
@@ -84,7 +84,7 @@ class PayPeriodScheduleUserFactory extends Factory {
 		}
 	}
 	function isUniqueUser($id) {
-		$ppslf = new PayPeriodScheduleListFactory();
+		$ppslf = TTnew( 'PayPeriodScheduleListFactory' );
 
 		$ph = array(
 					'id' => $id,
@@ -110,7 +110,7 @@ class PayPeriodScheduleUserFactory extends Factory {
 	function setUser($id) {
 		$id = trim($id);
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 
 		if ( $id != 0
 				AND $this->Validator->isResultSetWithRows(	'user',
