@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3928 $
- * $Id: PayPeriodTimeSheetVerifyFactory.class.php 3928 2010-11-11 20:29:54Z ipso $
- * $Date: 2010-11-11 12:29:54 -0800 (Thu, 11 Nov 2010) $
+ * $Revision: 4531 $
+ * $Id: PayPeriodTimeSheetVerifyFactory.class.php 4531 2011-04-15 01:35:07Z ipso $
+ * $Date: 2011-04-14 18:35:07 -0700 (Thu, 14 Apr 2011) $
  */
 
 /**
@@ -65,16 +65,82 @@ class PayPeriodTimeSheetVerifyFactory extends Factory {
 										60 => TTi18n::gettext('DISABLED')
 									);
 				break;
+			case 'columns':
+				$retval = array(
+										'-1010-first_name' => TTi18n::gettext('First Name'),
+										'-1020-last_name' => TTi18n::gettext('Last Name'),
+										'-1060-title' => TTi18n::gettext('Title'),
+										'-1070-user_group' => TTi18n::gettext('Group'),
+										'-1080-default_branch' => TTi18n::gettext('Branch'),
+										'-1090-default_department' => TTi18n::gettext('Department'),
+
+										'-1110-start_date' => TTi18n::gettext('Start Date'),
+										'-1112-end_date' => TTi18n::gettext('End Date'),
+										'-1115-transaction_date' => TTi18n::gettext('Transaction Date'),
+										'-1120-status' => TTi18n::gettext('Status'),
+
+										'-2000-created_by' => TTi18n::gettext('Created By'),
+										'-2010-created_date' => TTi18n::gettext('Created Date'),
+										'-2020-updated_by' => TTi18n::gettext('Updated By'),
+										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
+							);
+				break;
+			case 'list_columns':
+				$retval = Misc::arrayIntersectByKey( $this->getOptions('default_display_columns'), Misc::trimSortPrefix( $this->getOptions('columns') ) );
+				break;
+			case 'default_display_columns': //Columns that are displayed by default.
+				$retval = array(
+								'first_name',
+								'last_name',
+								'start_date',
+								'end_date',
+								'status'
+								);
+				break;
+			case 'unique_columns': //Columns that are unique, and disabled for mass editing.
+				$retval = array(
+								);
+				break;
+			case 'linked_columns': //Columns that are linked together, mainly for Mass Edit, if one changes, they all must.
+				$retval = array(
+								);
+				break;
+
 		}
 
 		return $retval;
 	}
 
+	function _getVariableToFunctionMap() {
+		$variable_function_map = array(
+										'id' => 'ID',
+										'pay_period_id' => 'PayPeriod',
+										'start_date' => FALSE, //PayPeriod
+										'end_date' => FALSE, //PayPeriod
+										'transaction_date' => FALSE, //PayPeriod
+										'user_id' => 'User',
+										'first_name' => FALSE,
+										'last_name' => FALSE,
+										'default_branch' => FALSE,
+										'default_department' => FALSE,
+										'user_group' => FALSE,
+										'title' => FALSE,
+										'status_id' => 'Status',
+										'status' => FALSE,
+										'user_verified' => 'UserVerified',
+										'user_verified_date' => 'UserVerifiedDate',
+										'authorized' => 'Authorized',
+										'authorization_level' => 'AuthorizationLevel',
+										'deleted' => 'Deleted',
+										);
+		return $variable_function_map;
+	 }
+
 	function getUserObject() {
 		if ( is_object($this->user_obj) ) {
 			return $this->user_obj;
 		} else {
-			$ulf = new UserListFactory();
+			$ulf = TTnew( 'UserListFactory' );
 			$this->user_obj = $ulf->getById( $this->getUser() )->getCurrent();
 
 			return $this->user_obj;
@@ -85,7 +151,7 @@ class PayPeriodTimeSheetVerifyFactory extends Factory {
 		if ( is_object($this->pay_period_obj) ) {
 			return $this->pay_period_obj;
 		} else {
-			$pplf = new PayPeriodListFactory();
+			$pplf = TTnew( 'PayPeriodListFactory' );
 			$pplf->getById( $this->getPayPeriod() );
 			if ( $pplf->getRecordCount() > 0 ) {
 				$this->pay_period_obj = $pplf->getCurrent();
@@ -111,7 +177,7 @@ class PayPeriodTimeSheetVerifyFactory extends Factory {
 			$id = $this->findPayPeriod();
 		}
 
-		$pplf = new PayPeriodListFactory();
+		$pplf = TTnew( 'PayPeriodListFactory' );
 
 		if (
 				$this->Validator->isResultSetWithRows(	'pay_period',
@@ -148,7 +214,7 @@ class PayPeriodTimeSheetVerifyFactory extends Factory {
 	function setUser($id) {
 		$id = trim($id);
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 
 		if ( $id == 0
 				OR $this->Validator->isResultSetWithRows(	'user',
@@ -345,8 +411,19 @@ class PayPeriodTimeSheetVerifyFactory extends Factory {
 		return $retval;
 	}
 
+	function getVerificationConfirmationMessage() {
+		$pp_obj = $this->getPayPeriodObject();
+		if ( is_object( $pp_obj ) ) {
+			$retval = TTi18n::getText('I hereby certify that this timesheet for the pay period of').' '. TTDate::getDate('DATE', $pp_obj->getStartDate() ) .' '. TTi18n::getText('to') .' '. TTDate::getDate('DATE', $pp_obj->getEndDate() ) .' '. TTi18n::getText('is accurate and correct.');
+
+			return $retval;
+		}
+
+		return FALSE;
+	}
+
 	function getPreviousPayPeriodObject() {
-		$pplf = new PayPeriodListFactory();
+		$pplf = TTnew( 'PayPeriodListFactory' );
 		$pplf->getPreviousPayPeriodById( $this->getPayPeriod() );
 		if ( $pplf->getRecordCount() > 0 ) {
 			return $pplf->getCurrent();
@@ -368,7 +445,7 @@ class PayPeriodTimeSheetVerifyFactory extends Factory {
 			if ( $previous_pay_period_obj->getStatus() == 20 ) {
 				$is_previous_time_sheet_verified = TRUE;
 			} else {
-				$pptsvlf = new PayPeriodTimeSheetVerifyListFactory();
+				$pptsvlf = TTnew( 'PayPeriodTimeSheetVerifyListFactory' );
 				$pptsvlf->getByPayPeriodIdAndUserId( $previous_pay_period_obj->getId(), $user_id );
 				if ( $pptsvlf->getRecordCount() > 0 ) {
 					$pptsv_obj = $pptsvlf->getCurrent();
@@ -401,7 +478,6 @@ class PayPeriodTimeSheetVerifyFactory extends Factory {
 		$is_previous_time_sheet_verified = $this->isPreviousPayPeriodVerified( $user_id );
 		Debug::text('Previous Pay Period Verified: '. (int)$is_previous_time_sheet_verified, __FILE__, __LINE__, __METHOD__,10);
 
-
 		$pay_period_verify_type_id = $this->getVerificationType();
 		$is_timesheet_superior = $this->isHierarchySuperior( $current_user_id, $user_id );
 		if (
@@ -468,13 +544,13 @@ class PayPeriodTimeSheetVerifyFactory extends Factory {
 			$user_id = $this->getUser();
 		}
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$ulf->getById( $user_id );
 		if ( $ulf->getRecordCount() == 1 ) {
 			$user_obj = $ulf->getCurrent();
 
 			//Get timesheet verification hierarchy, so we know who the superiors are.
-			$hlf = new HierarchyListFactory();
+			$hlf = TTnew( 'HierarchyListFactory' );
 			$timesheet_parent_level_user_ids = $hlf->getHierarchyParentByCompanyIdAndUserIdAndObjectTypeID( $user_obj->getCompany(), $user_obj->getId(), 90, TRUE, FALSE ); //Immediate superiors only can verify timesheets directly.
 			Debug::Arr( $timesheet_parent_level_user_ids, 'TimeSheet Parent Level Ids', __FILE__, __LINE__, __METHOD__,10);
 			if ( in_array( $current_user_id, (array)$timesheet_parent_level_user_ids ) ) {
@@ -492,7 +568,7 @@ class PayPeriodTimeSheetVerifyFactory extends Factory {
 
 	//Returns all superiors that have authorized this timesheet so far.
 	function getAuthorizedUsers() {
-		$alf = new AuthorizationListFactory();
+		$alf = TTnew( 'AuthorizationListFactory' );
 		$alf->getByObjectTypeAndObjectId(90, $this->getId() );
 		if ($alf->getRecordCount() > 0 ) {
 			foreach( $alf as $a_obj ) {
@@ -543,7 +619,7 @@ class PayPeriodTimeSheetVerifyFactory extends Factory {
 					$this->setUserVerified( TRUE );
 
 					if (  $this->getAuthorized() == TRUE ) { //If this has already been verified by superiors, and the employee is the last step, make sure mark this as verified.
-						$this->setStatus(50); //Verified
+						$this->setStatus( 50 ); //Verified
 					} else {
 						$this->setStatus( 30 ); //Pending Authorization.
 					}
@@ -558,7 +634,7 @@ class PayPeriodTimeSheetVerifyFactory extends Factory {
 
 			//If this is a new verification, find the current authorization level to assign to it.
 			if ( ( $this->isNew() == TRUE  OR $this->getStatus() == 55 ) AND ( $time_sheet_verification_type_id == 30 OR $time_sheet_verification_type_id == 40 )  ) {
-				$hlf = new HierarchyListFactory();
+				$hlf = TTnew( 'HierarchyListFactory' );
 				$hierarchy_arr = $hlf->getHierarchyParentByCompanyIdAndUserIdAndObjectTypeID( $this->getUserObject()->getCompany(), $this->getUserObject()->getID(), 90, FALSE);
 
 				$hierarchy_highest_level = 99;
@@ -581,7 +657,7 @@ class PayPeriodTimeSheetVerifyFactory extends Factory {
 	function postSave() {
 		//If status is pending auth (55=declined) delete all authorization history, because they could be re-verifying.
 		if ( $this->getCurrentUser() != FALSE AND $this->getStatus() == 55 ) {
-			$alf = new AuthorizationListFactory();
+			$alf = TTnew( 'AuthorizationListFactory' );
 			$alf->getByObjectTypeAndObjectId( 90, $this->getId() );
 			if ( $alf->getRecordCount() > 0 ) {
 				foreach( $alf as $a_obj ) {
@@ -609,7 +685,7 @@ class PayPeriodTimeSheetVerifyFactory extends Factory {
 			}
 
 			if ( $authorize_timesheet == TRUE ) {
-				$af = new AuthorizationFactory();
+				$af = TTnew( 'AuthorizationFactory' );
 				$af->setObjectType('timesheet');
 				$af->setObject( $this->getId() );
 				$af->setAuthorized(TRUE);
@@ -622,6 +698,75 @@ class PayPeriodTimeSheetVerifyFactory extends Factory {
 		return TRUE;
 	}
 
+	function setObjectFromArray( $data ) {
+		if ( is_array( $data ) ) {
+			$variable_function_map = $this->getVariableToFunctionMap();
+			foreach( $variable_function_map as $key => $function ) {
+				if ( isset($data[$key]) ) {
+
+					$function = 'set'.$function;
+					switch( $key ) {
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$this->$function( $data[$key] );
+							}
+							break;
+					}
+				}
+			}
+
+			$this->setCreatedAndUpdatedColumns( $data );
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getObjectAsArray( $include_columns = NULL, $permission_children_ids = NULL ) {
+		$variable_function_map = $this->getVariableToFunctionMap();
+		if ( is_array( $variable_function_map ) ) {
+			foreach( $variable_function_map as $variable => $function_stub ) {
+				if ( $include_columns == NULL OR ( isset($include_columns[$variable]) AND $include_columns[$variable] == TRUE ) ) {
+
+					$function = 'get'.$function_stub;
+					switch( $variable ) {
+						case 'first_name':
+						case 'last_name':
+						case 'title':
+						case 'user_group':
+						case 'default_branch':
+						case 'default_department':
+						case 'user_id':
+							$data[$variable] = $this->getColumn( $variable );
+							break;
+						case 'start_date':
+						case 'end_date':
+						case 'transaction_date':
+							$data[$variable] = TTDate::getAPIDate( 'DATE+TIME', TTDate::strtotime( $this->getColumn( $variable ) ) );
+							break;
+						case 'status':
+							$function = 'get'.$variable;
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = Option::getByKey( $this->$function(), $this->getOptions( $variable ) );
+							}
+							break;
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = $this->$function();
+							}
+							break;
+					}
+
+				}
+			}
+			$this->getPermissionColumns( &$data, $this->getColumn( 'user_id' ), $this->getCreatedBy(), $permission_children_ids, $include_columns );
+			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
+		}
+
+		return $data;
+	}
+
 	function addLog( $log_action ) {
 		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('TimeSheet Verify'), NULL, $this->getTable() );
 	}
