@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: AbsencePolicyFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4845 $
+ * $Id: AbsencePolicyFactory.class.php 4845 2011-06-21 16:23:18Z ipso $
+ * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
  */
 
 /**
@@ -70,6 +70,8 @@ class AbsencePolicyFactory extends Factory {
 										'-1020-name' => TTi18n::gettext('Name'),
 
 										'-1030-rate' => TTi18n::gettext('Rate'),
+
+										'-1080-accrual_policy' => TTi18n::gettext('Accrual Policy'),
 										'-1090-accrual_rate' => TTi18n::gettext('Accrual Rate'),
 
 										'-2000-created_by' => TTi18n::gettext('Created By'),
@@ -78,10 +80,15 @@ class AbsencePolicyFactory extends Factory {
 										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
 							);
 				break;
+			case 'list_columns':
+				$retval = Misc::arrayIntersectByKey( $this->getOptions('default_display_columns'), Misc::trimSortPrefix( $this->getOptions('columns') ) );
+				break;
 			case 'default_display_columns': //Columns that are displayed by default.
 				$retval = array(
 								'type',
 								'name',
+								'updated_date',
+								'updated_by',
 								);
 				break;
 			case 'unique_columns': //Columns that are unique, and disabled for mass editing.
@@ -109,6 +116,7 @@ class AbsencePolicyFactory extends Factory {
 											'wage_group_id' => 'WageGroup',
 											'accrual_rate' => 'AccrualRate',
 											'accrual_policy_id' => 'AccrualPolicyID',
+											'accrual_policy' => FALSE,
 											'pay_stub_entry_account_id' => 'PayStubEntryAccountId',
 											'deleted' => 'Deleted',
 											);
@@ -119,7 +127,7 @@ class AbsencePolicyFactory extends Factory {
 		if ( is_object($this->company_obj) ) {
 			return $this->company_obj;
 		} else {
-			$clf = new CompanyListFactory();
+			$clf = TTnew( 'CompanyListFactory' );
 			$this->company_obj = $clf->getById( $this->getCompany() )->getCurrent();
 
 			return $this->company_obj;
@@ -137,7 +145,7 @@ class AbsencePolicyFactory extends Factory {
 		$id = trim($id);
 
 		Debug::Text('Company ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
-		$clf = new CompanyListFactory();
+		$clf = TTnew( 'CompanyListFactory' );
 
 		if ( $this->Validator->isResultSetWithRows(	'company',
 													$clf->getByID($id),
@@ -248,7 +256,7 @@ class AbsencePolicyFactory extends Factory {
 	function setWageGroup($id) {
 		$id = trim($id);
 
-		$wglf = new WageGroupListFactory();
+		$wglf = TTnew( 'WageGroupListFactory' );
 
 		if ( $id == 0
 				OR
@@ -304,7 +312,7 @@ class AbsencePolicyFactory extends Factory {
 			$id = NULL;
 		}
 
-		$aplf = new AccrualPolicyListFactory();
+		$aplf = TTnew( 'AccrualPolicyListFactory' );
 
 		if ( $id == NULL
 				OR
@@ -337,7 +345,7 @@ class AbsencePolicyFactory extends Factory {
 			$id = NULL;
 		}
 
-		$psealf = new PayStubEntryAccountListFactory();
+		$psealf = TTnew( 'PayStubEntryAccountListFactory' );
 
 		if (	$id == NULL
 				OR
@@ -356,7 +364,7 @@ class AbsencePolicyFactory extends Factory {
 	function Validate() {
 		if ( $this->getDeleted() == TRUE ) {
 			//Check to make sure there are no hours using this OT policy.
-			$udtlf = new UserDateTotalListFactory();
+			$udtlf = TTnew( 'UserDateTotalListFactory' );
 			$udtlf->getByAbsencePolicyId( $this->getId() );
 			if ( $udtlf->getRecordCount() > 0 ) {
 				$this->Validator->isTRUE(	'in_use',
@@ -416,6 +424,9 @@ class AbsencePolicyFactory extends Factory {
 
 					$function = 'get'.$function_stub;
 					switch( $variable ) {
+						case 'accrual_policy':
+							$data[$variable] = $this->getColumn( $variable );
+							break;
 						case 'type':
 							$function = 'get'.$variable;
 							if ( method_exists( $this, $function ) ) {
