@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: AccrualPolicyFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4845 $
+ * $Id: AccrualPolicyFactory.class.php 4845 2011-06-21 16:23:18Z ipso $
+ * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
  */
 
 /**
@@ -79,10 +79,15 @@ class AccrualPolicyFactory extends Factory {
 										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
 							);
 				break;
+			case 'list_columns':
+				$retval = Misc::arrayIntersectByKey( $this->getOptions('default_display_columns'), Misc::trimSortPrefix( $this->getOptions('columns') ) );
+				break;
 			case 'default_display_columns': //Columns that are displayed by default.
 				$retval = array(
 								'type',
 								'name',
+								'updated_date',
+								'updated_by',
 								);
 				break;
 			case 'unique_columns': //Columns that are unique, and disabled for mass editing.
@@ -128,7 +133,7 @@ class AccrualPolicyFactory extends Factory {
 		if ( is_object($this->company_obj) ) {
 			return $this->company_obj;
 		} else {
-			$clf = new CompanyListFactory();
+			$clf = TTnew( 'CompanyListFactory' );
 			$this->company_obj = $clf->getById( $this->getCompany() )->getCurrent();
 
 			return $this->company_obj;
@@ -146,7 +151,7 @@ class AccrualPolicyFactory extends Factory {
 		$id = trim($id);
 
 		Debug::Text('Company ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
-		$clf = new CompanyListFactory();
+		$clf = TTnew( 'CompanyListFactory' );
 
 		if ( $this->Validator->isResultSetWithRows(	'company',
 													$clf->getByID($id),
@@ -480,7 +485,7 @@ class AccrualPolicyFactory extends Factory {
 		}
 
 		Debug::Text('Milestone Rollover Date: '. TTDate::getDate('DATE+TIME', $retval) .' Hire Date: '. TTDate::getDate('DATE+TIME', $user_hire_date), __FILE__, __LINE__, __METHOD__,10);
-		return $retval;
+		return TTDate::getBeginDayEpoch( $retval ); //Some hire dates might be at noon, so make sure they are all at midnight.
 	}
 
 	function getCurrentMilestoneRolloverDate( $epoch, $user_hire_date = NULL ) {
@@ -516,7 +521,10 @@ class AccrualPolicyFactory extends Factory {
 		}
 
 		//Round to nearest minute, or 15mins?
-		$retval = TTDate::roundTime( $retval, 60, 20 );
+		//Well, if they accrue 99hrs/year on a weekly basis, rounding to the nearest minute means 98.8hrs/year...
+		//Should round to the nearest second instead then.
+		//$retval = TTDate::roundTime( $retval, 60, 20 );
+		$retval = round($retval, 0);
 
 		Debug::Text('Accrual Rate Per Frequency: '. $retval .' Accrual Rate: '. $accrual_rate .' Pay Periods: '. $annual_pay_periods , __FILE__, __LINE__, __METHOD__,10);
 
@@ -603,7 +611,7 @@ class AccrualPolicyFactory extends Factory {
 			return FALSE;
 		}
 
-		$udtlf = new UserDateTotalListFactory();
+		$udtlf = TTnew( 'UserDateTotalListFactory' );
 		$retval = $udtlf->getWorkedTimeSumByUserIDAndStartDateAndEndDate( $user_id, 1, $end_date );
 
 		Debug::Text('Worked Seconds: '. (int)$retval .' Before: '. TTDate::getDate('DATE+TIME', $end_date), __FILE__, __LINE__, __METHOD__,10);
@@ -622,7 +630,7 @@ class AccrualPolicyFactory extends Factory {
 
 		$milestone_obj = FALSE;
 
-		$apmlf = new AccrualPolicyMilestoneListFactory();
+		$apmlf = TTnew( 'AccrualPolicyMilestoneListFactory' );
 		$apmlf->getByAccrualPolicyId($this->getId(), NULL, array('length_of_service_days' => 'desc' ) );
 		Debug::Text('&nbsp;&nbsp;Total Accrual Policy MileStones: '. (int)$apmlf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
 		if ( $apmlf->getRecordCount() > 0 ) {
@@ -681,7 +689,7 @@ class AccrualPolicyFactory extends Factory {
 		}
 
 		//Check min/max times of accrual policy.
-		$ablf = new AccrualBalanceListFactory();
+		$ablf = TTnew( 'AccrualBalanceListFactory' );
 		$ablf->getByUserIdAndAccrualPolicyId( $user_id, $accrual_policy_id );
 		if ( $ablf->getRecordCount() > 0 ) {
 			$accrual_balance = $ablf->getCurrent()->getBalance();
@@ -718,7 +726,7 @@ class AccrualPolicyFactory extends Factory {
 
 		Debug::Text('Accrual Policy ID: '. $this->getId() .' Current EPOCH: '. TTDate::getDate('DATE+TIME', $epoch), __FILE__, __LINE__, __METHOD__,10);
 
-		$pglf = new PolicyGroupListFactory();
+		$pglf = TTnew( 'PolicyGroupListFactory' );
 
 		$pglf->StartTransaction();
 
@@ -734,7 +742,7 @@ class AccrualPolicyFactory extends Factory {
 						Debug::Text('Policy Group User ID: '. $user_id, __FILE__, __LINE__, __METHOD__,10);
 
 						//Get User Object
-						$ulf = new UserListFactory();
+						$ulf = TTnew( 'UserListFactory' );
 						$ulf->getByIDAndCompanyID( $user_id, $this->getCompany() );
 						if ( $ulf->getRecordCount() == 1 ) {
 							$u_obj = $ulf->getCurrent();
@@ -763,7 +771,7 @@ class AccrualPolicyFactory extends Factory {
 										//Because of pay period frequencies, and users being assigned to different
 										//pay period schedules we need to get the last pay period of each user individually.
 										//This will return the pay period that just ended in the offset time.
-										$pplf = new PayPeriodListFactory();
+										$pplf = TTnew( 'PayPeriodListFactory' );
 										$pplf->getByUserIdAndEndDate( $user_id, ($epoch-$offset) );
 										if ( $pplf->getRecordCount() > 0 ) {
 											foreach( $pplf as $pp_obj ) {
@@ -809,7 +817,7 @@ class AccrualPolicyFactory extends Factory {
 
 										//Check to make sure there isn't an identical entry already made.
 										//Ignore rollover adjustment is another adjustment of any amount has been made on the same day.
-										$alf = new AccrualListFactory();
+										$alf = TTnew( 'AccrualListFactory' );
 										$alf->getByCompanyIdAndUserIdAndAccrualPolicyIDAndTypeIDAndTimeStamp( $u_obj->getCompany(), $user_id, $this->getId(), 60, TTDate::getMiddleDayEpoch( $epoch ) );
 										if ( $alf->getRecordCount() == 0 ) {
 
@@ -821,7 +829,7 @@ class AccrualPolicyFactory extends Factory {
 											}
 
 											//Round to nearest 1min
-											$af = new AccrualFactory();
+											$af = TTnew( 'AccrualFactory' );
 											$af->setUser( $user_id );
 											$af->setType( 60 ); //Rollover Adjustment
 											$af->setAccrualPolicyID( $this->getId() );
@@ -861,12 +869,12 @@ class AccrualPolicyFactory extends Factory {
 												Debug::Text('&nbsp;&nbsp; Min/Max Adjusted Accrual Amount: '. $accrual_amount .' Limits: Min: '. $milestone_obj->getMinimumTime() .' Max: '. $milestone_obj->getMaximumTime(), __FILE__, __LINE__, __METHOD__,10);
 
 												//Check to make sure there isn't an identical entry already made.
-												$alf = new AccrualListFactory();
+												$alf = TTnew( 'AccrualListFactory' );
 												$alf->getByCompanyIdAndUserIdAndAccrualPolicyIDAndTimeStampAndAmount( $u_obj->getCompany(), $user_id, $this->getId(), TTDate::getMiddleDayEpoch( $epoch ),  $accrual_amount );
 												if ( $alf->getRecordCount() == 0 ) {
 
 													//Round to nearest 1min
-													$af = new AccrualFactory();
+													$af = TTnew( 'AccrualFactory' );
 													$af->setUser( $user_id );
 													$af->setType( 75 ); //Accrual Policy
 													$af->setAccrualPolicyID( $this->getId() );
@@ -911,7 +919,7 @@ class AccrualPolicyFactory extends Factory {
 	function Validate() {
 		if ( $this->getDeleted() == TRUE ){
 			//Check to make sure there are no hours using this OT policy.
-			$alf = new AccrualListFactory();
+			$alf = TTnew( 'AccrualListFactory' );
 			$alf->getByAccrualPolicyId( $this->getId() );
 			if ( $alf->getRecordCount() > 0 ) {
 				$this->Validator->isTRUE(	'in_use',
