@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2682 $
- * $Id: AccrualPolicyMilestoneListFactory.class.php 2682 2009-07-23 22:31:20Z ipso $
- * $Date: 2009-07-23 15:31:20 -0700 (Thu, 23 Jul 2009) $
+ * $Revision: 4265 $
+ * $Id: AccrualPolicyMilestoneListFactory.class.php 4265 2011-02-18 00:49:20Z ipso $
+ * $Date: 2011-02-17 16:49:20 -0800 (Thu, 17 Feb 2011) $
  */
 
 /**
@@ -221,6 +221,9 @@ class AccrualPolicyMilestoneListFactory extends AccrualPolicyMilestoneFactory im
 					where	b.company_id = ?
 					';
 
+		if ( isset($filter_data['permission_children_ids']) AND isset($filter_data['permission_children_ids'][0]) AND !in_array(-1, (array)$filter_data['permission_children_ids']) ) {
+			$query  .=	' AND a.created_by in ('. $this->getListSQL($filter_data['permission_children_ids'], $ph) .') ';
+		}
 		if ( isset($filter_data['id']) AND isset($filter_data['id'][0]) AND !in_array(-1, (array)$filter_data['id']) ) {
 			$query  .=	' AND a.id in ('. $this->getListSQL($filter_data['id'], $ph) .') ';
 		}
