@@ -80,6 +80,7 @@ class BreakPolicyFactory extends Factory {
 										//'-1090-maximum_punch_time' => TTi18n::gettext('Maximum Punch Time'),
 
 										'-1100-include_break_punch_time' => TTi18n::gettext('Include Break Punch'),
+										'-1110-include_multiple_breaks' => TTi18n::gettext('Include Multiple Breaks'),
 
 										'-2000-created_by' => TTi18n::gettext('Created By'),
 										'-2010-created_date' => TTi18n::gettext('Created Date'),
@@ -87,11 +88,16 @@ class BreakPolicyFactory extends Factory {
 										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
 							);
 				break;
+			case 'list_columns':
+				$retval = Misc::arrayIntersectByKey( $this->getOptions('default_display_columns'), Misc::trimSortPrefix( $this->getOptions('columns') ) );
+				break;
 			case 'default_display_columns': //Columns that are displayed by default.
 				$retval = array(
 								'name',
 								'type',
-								'amount'
+								'amount',
+								'updated_date',
+								'updated_by',
 								);
 				break;
 			case 'unique_columns': //Columns that are unique, and disabled for mass editing.
@@ -125,6 +131,7 @@ class BreakPolicyFactory extends Factory {
 										'minimum_punch_time' => 'MinimumPunchTime',
 										'maximum_punch_time' => 'MaximumPunchTime',
 										'include_break_punch_time' => 'IncludeBreakPunchTime',
+										'include_multiple_breaks' => 'IncludeMultipleBreaks',
 										'deleted' => 'Deleted',
 										);
 		return $variable_function_map;
@@ -134,7 +141,7 @@ class BreakPolicyFactory extends Factory {
 		if ( is_object($this->company_obj) ) {
 			return $this->company_obj;
 		} else {
-			$clf = new CompanyListFactory();
+			$clf = TTnew( 'CompanyListFactory' );
 			$this->company_obj = $clf->getById( $this->getCompany() )->getCurrent();
 
 			return $this->company_obj;
@@ -152,7 +159,7 @@ class BreakPolicyFactory extends Factory {
 		$id = trim($id);
 
 		Debug::Text('Company ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
-		$clf = new CompanyListFactory();
+		$clf = TTnew( 'CompanyListFactory' );
 
 		if ( $this->Validator->isResultSetWithRows(	'company',
 													$clf->getByID($id),
@@ -419,10 +426,23 @@ class BreakPolicyFactory extends Factory {
 		return TRUE;
 	}
 
+	function getIncludeMultipleBreaks() {
+		if ( isset($this->data['include_multiple_breaks']) ) {
+			return $this->fromBool( $this->data['include_multiple_breaks'] );
+		}
+
+		return FALSE;
+	}
+	function setIncludeMultipleBreaks($bool) {
+		$this->data['include_multiple_breaks'] = $this->toBool($bool);
+
+		return TRUE;
+	}
+
 	function Validate() {
 		if ( $this->getDeleted() == TRUE ){
 			//Check to make sure there are no hours using this break policy.
-			$udtlf = new UserDateTotalListFactory();
+			$udtlf = TTnew( 'UserDateTotalListFactory' );
 			$udtlf->getByBreakPolicyId( $this->getId() );
 			if ( $udtlf->getRecordCount() > 0 ) {
 				$this->Validator->isTRUE(	'in_use',
