@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: ExceptionPolicyFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4845 $
+ * $Id: ExceptionPolicyFactory.class.php 4845 2011-06-21 16:23:18Z ipso $
+ * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
  */
 
 /**
@@ -48,9 +48,8 @@ class ExceptionPolicyFactory extends Factory {
 
 	protected $enable_grace = array('S3', 'S4', 'S5', 'S6', 'L1', 'L2', 'B1','B2', 'S7', 'S8', 'S9');
 	protected $enable_watch_window = array('S3', 'S4', 'S5', 'S6', 'O1','O2');
-	protected static $premature_exceptions = array('M1', 'M2', 'M3', 'M4', 'L3', 'B4', 'S8');
-	//16hrs... If punches are older then this time, its no longer premature.
-	//This should actually be the PayPeriod Schedule maximum shift time.
+	protected static $premature_exceptions = array('M1', 'M2', 'M3', 'M4', 'L3', 'B4', 'B5', 'S8');
+
 	protected static $premature_delay = 57600;
 
 	function _getFactoryOptions( $name ) {
@@ -70,6 +69,7 @@ class ExceptionPolicyFactory extends Factory {
 										'S7' /* G */ => TTi18n::gettext('Over Daily Scheduled Time'),
 										'S8' /* H */ => TTi18n::gettext('Under Daily Scheduled Time'),
 										'S9' => TTi18n::gettext('Over Weekly Scheduled Time'),
+										//'S10' => TTi18n::gettext('Under Weekly Scheduled Time'), //Is this needed?
 
 //Add setting to set some sort of "Grace" period, or early warning system? Approaching overtime?
 //Have exception where they can set the cutoff in hours, and it triggers once the employee has exceeded the weekly hours.
@@ -91,9 +91,10 @@ class ExceptionPolicyFactory extends Factory {
 										'B2' => TTi18n::gettext('Short Break'),
 										'B3' => TTi18n::gettext('Too Many Breaks'),
 										'B4' => TTi18n::gettext('Too Few Breaks'),
+										'B5' => TTi18n::gettext('No Break'),
 //Worked too long without break/lunch, allow to set the time frame.
 //Make grace period the amount of time a break has to exceed, and watch window the longest they can work without a break?
-//										'B5' => TTi18n::gettext('Worked Too Long without Break')
+//										'B6' => TTi18n::gettext('Worked Too Long without Break')
 
 										//Job Exceptions
 										'J1' /* T J1 */  => TTi18n::gettext('Not Allowed On Job'),
@@ -170,7 +171,7 @@ class ExceptionPolicyFactory extends Factory {
 	function setExceptionPolicyControl($id) {
 		$id = trim($id);
 
-		$epclf = new ExceptionPolicyControlListFactory();
+		$epclf = TTnew( 'ExceptionPolicyControlListFactory' );
 
 		if ( $this->Validator->isResultSetWithRows(	'exception_policy_control',
 													$epclf->getByID($id),
@@ -515,6 +516,21 @@ class ExceptionPolicyFactory extends Factory {
 												'is_enabled_watch_window' => $this->isEnabledWatchWindow( $type_id )
 												);
 					break;
+				case 'B5': //No Break
+					$retarr[$type_id] = array(
+												'id' => -1,
+												'type_id' => $type_id,
+												'name' => $type_options[$type_id],
+												'active' => FALSE,
+												'severity_id' => 20,
+												'email_notification_id' => 100,
+												'demerit' => 0,
+												'grace' => 0,
+												'is_enabled_grace' => $this->isEnabledGrace( $type_id ),
+												'watch_window' => 0,
+												'is_enabled_watch_window' => $this->isEnabledWatchWindow( $type_id )
+												);
+					break;
 				case 'J1': //Not allowed on job
 					$retarr[$type_id] = array(
 												'id' => -1,
@@ -808,7 +824,7 @@ class ExceptionPolicyFactory extends Factory {
 		Debug::text(' User Date ID: '. $user_date_id .' PreMature: '. (int)$enable_premature_exceptions , __FILE__, __LINE__, __METHOD__,10);
 
 		//Get user date info
-		$udlf = new UserDateListFactory();
+		$udlf = TTnew( 'UserDateListFactory' );
 		$udlf->getById( $user_date_id );
 		if ( $udlf->getRecordCount() > 0 ) {
 			$user_date_obj = $udlf->getCurrent();
@@ -821,10 +837,20 @@ class ExceptionPolicyFactory extends Factory {
 			return FALSE;
 		}
 
+		//16hrs... If punches are older then this time, its no longer premature.
+		//This should actually be the PayPeriod Schedule maximum shift time.
+		if ( is_object($user_date_obj->getPayPeriodObject())
+				AND is_object($user_date_obj->getPayPeriodObject()->getPayPeriodScheduleObject()) ) {
+			self::$premature_delay = $user_date_obj->getPayPeriodObject()->getPayPeriodScheduleObject()->getMaximumShiftTime();
+			Debug::text(' Setting preMature Exception delay to maximum shift time: '. self::$premature_delay , __FILE__, __LINE__, __METHOD__,10);
+		} else {
+			self::$premature_delay = 57600;
+		}
+
 		//Get list of existing exceptions, so we can determine if we need to delete any. We can't delete them all blindly and re-create them
 		//as this will send duplicate email notifications for every single punch.
 		$existing_exceptions = array();
-		$elf = new ExceptionListFactory();
+		$elf = TTnew( 'ExceptionListFactory' );
 		$elf->getByUserDateID( $user_date_id );
 		if ( $elf->getRecordCount() > 0 ) {
 			foreach( $elf as $e_obj ) {
@@ -841,13 +867,13 @@ class ExceptionPolicyFactory extends Factory {
 		unset($elf, $e_obj);
 
 		//Get all Punches on this date for this user.
-		$plf = new PunchListFactory();
+		$plf = TTnew( 'PunchListFactory' );
 		$plf->getByUserDateId( $user_date_id );
 		if ( $plf->getRecordCount() > 0 ) {
 			Debug::text(' Found Punches: '.  $plf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
 		}
 
-		$slf = new ScheduleListFactory();
+		$slf = TTnew( 'ScheduleListFactory' );
 		$slf->getByUserDateIdAndStatusId( $user_date_id, 10 );
 		if ( $slf->getRecordCount() > 0 ) {
 			Debug::text(' Found Schedule: '.  $slf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
@@ -858,7 +884,7 @@ class ExceptionPolicyFactory extends Factory {
 		$current_exceptions = array(); //Array holding current exception data.
 
 		//Get all active exceptions.
-		$eplf = new ExceptionPolicyListFactory();
+		$eplf = TTnew( 'ExceptionPolicyListFactory' );
 		$eplf->getByPolicyGroupUserIdAndActive( $user_date_obj->getUser(), TRUE );
 		if ( $eplf->getRecordCount() > 0 ) {
 			Debug::text(' Found Active Exceptions: '.  $eplf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
@@ -879,10 +905,15 @@ class ExceptionPolicyFactory extends Factory {
 								//Ignore these exceptions if the schedule is after today (not including today),
 								//so if a supervisors schedules an employee two days in advance they don't get a unscheduled
 								//absence appearing right away.
+								//Since we now trigger In Late/Out Late exceptions immediately after schedule time, only trigger this exception after
+								//the schedule end time has passed.
 						if ( $plf->getRecordCount() == 0 ) {
 							if ( $slf->getRecordCount() > 0 ) {
 								foreach( $slf as $s_obj ) {
-									if ( $s_obj->getStatus() == 10 AND ( TTDate::getBeginDayEpoch( $s_obj->getStartTime() ) - TTDate::getBeginDayEpoch( TTDate::getTime() ) ) <= 0 ) {
+									if ( $s_obj->getStatus() == 10
+											//AND ( TTDate::getBeginDayEpoch( $s_obj->getStartTime() ) - TTDate::getBeginDayEpoch( TTDate::getTime() ) ) <= 0
+											AND ( TTDate::getTime() >= $s_obj->getEndTime() )
+											) {
 										$current_exceptions[] = array(
 																		'user_date_id' => $user_date_id,
 																		'exception_policy_id' => $ep_obj->getId(),
@@ -918,8 +949,10 @@ class ExceptionPolicyFactory extends Factory {
 					case 's3': //In Early
 						if ( $plf->getRecordCount() > 0 ) {
 							//Loop through each punch, find out if they are scheduled, and if they are in early
+							$prev_punch_time_stamp = FALSE;
 							foreach ( $plf as $p_obj ) {
-								if ( $p_obj->getType() == 10 AND $p_obj->getStatus() == 10 ) { //Normal In
+								//Ignore punches that have the exact same timestamp, as they are likely transfer punches.
+								if ( $prev_punch_time_stamp != $p_obj->getTimeStamp() AND $p_obj->getType() == 10 AND $p_obj->getStatus() == 10 ) { //Normal In
 									if ( !isset($scheduled_id_cache[$p_obj->getID()]) ) {
 										$scheduled_id_cache[$p_obj->getID()] = $p_obj->findScheduleID( NULL, $user_date_obj->getUser() );
 									}
@@ -942,13 +975,16 @@ class ExceptionPolicyFactory extends Factory {
 										Debug::text('&nbsp;&nbsp;&nbsp;&nbsp;NO Schedule Found', __FILE__, __LINE__, __METHOD__,10);
 									}
 								}
+								$prev_punch_time_stamp = $p_obj->getTimeStamp();
 							}
 						}
 						break;
 					case 's4': //In Late
 						if ( $plf->getRecordCount() > 0 ) {
+							$prev_punch_time_stamp = FALSE;
 							foreach ( $plf as $p_obj ) {
-								if ( $p_obj->getType() == 10 AND $p_obj->getStatus() == 10 ) { //Normal In
+								//Ignore punches that have the exact same timestamp, as they are likely transfer punches.
+								if ( $prev_punch_time_stamp != $p_obj->getTimeStamp() AND $p_obj->getType() == 10 AND $p_obj->getStatus() == 10 ) { //Normal In
 									if ( !isset($scheduled_id_cache[$p_obj->getID()]) ) {
 										$scheduled_id_cache[$p_obj->getID()] = $p_obj->findScheduleID( NULL, $user_date_obj->getUser() );
 									}
@@ -971,14 +1007,43 @@ class ExceptionPolicyFactory extends Factory {
 										Debug::text('&nbsp;&nbsp;&nbsp;&nbsp;NO Schedule Found', __FILE__, __LINE__, __METHOD__,10);
 									}
 								}
+								$prev_punch_time_stamp = $p_obj->getTimeStamp();
+							}
+						} else {
+							//Late Starting their shift, with no punch yet, trigger exception if:
+							//  - Schedule is found
+							//	- Current time is after schedule start time and before schedule end time.
+							// 	- Current time is after exception grace time
+							Debug::text('&nbsp;&nbsp;&nbsp;&nbsp;No punch yet, checking Late Starting Shift exception... Current time: '. TTDate::getDate('DATE+TIME', TTDate::getTime() ), __FILE__, __LINE__, __METHOD__,10);
+							if ( $slf->getRecordCount() > 0 ) {
+								foreach ( $slf as $s_obj ) {
+									Debug::text(' Schedule Start Time: '. TTDate::getDate('DATE+TIME', $s_obj->getStartTime() ) .' End Time: '. TTDate::getDate('DATE+TIME', $s_obj->getEndTime() ), __FILE__, __LINE__, __METHOD__,10);
+									if ( TTDate::getTime() >= $s_obj->getStartTime() AND TTDate::getTime() <= $s_obj->getEndTime() ) {
+										if ( TTDate::inWindow( TTDate::getTime(), $s_obj->getStartTime(), $ep_obj->getGrace() ) == TRUE ) {
+											Debug::text('&nbsp;&nbsp;&nbsp;&nbsp;Within Grace time, IGNORE EXCEPTION: ', __FILE__, __LINE__, __METHOD__,10);
+										} else {
+											Debug::text('&nbsp;&nbsp;&nbsp;&nbsp;NOT Within Grace time, SET EXCEPTION: ', __FILE__, __LINE__, __METHOD__,10);
+											$current_exceptions[] = array(
+																			'user_date_id' => $user_date_id,
+																			'exception_policy_id' => $ep_obj->getId(),
+																			'type_id' => $type_id,
+																			'punch_id' => FALSE,
+																			'punch_control_id' => FALSE,
+																		);
+										}
+									}
+								}
+							} else {
+								Debug::text('&nbsp;&nbsp;&nbsp;&nbsp;NO Schedule Found', __FILE__, __LINE__, __METHOD__,10);
 							}
 						}
 						break;
 					case 's5': //Out Early
 						if ( $plf->getRecordCount() > 0 ) {
 							//Loop through each punch, find out if they are scheduled, and if they are in early
+							$prev_punch_time_stamp = FALSE;
 							foreach ( $plf as $p_obj ) {
-								if ( $p_obj->getType() == 10 AND $p_obj->getStatus() == 20 ) { //Normal Out
+								if ( $prev_punch_time_stamp != $p_obj->getTimeStamp() AND $p_obj->getType() == 10 AND $p_obj->getStatus() == 20 ) { //Normal Out
 									if ( !isset($scheduled_id_cache[$p_obj->getID()]) ) {
 										$scheduled_id_cache[$p_obj->getID()] = $p_obj->findScheduleID( NULL, $user_date_obj->getUser() );
 									}
@@ -1001,13 +1066,17 @@ class ExceptionPolicyFactory extends Factory {
 										Debug::text('&nbsp;&nbsp;&nbsp;&nbsp;NO Schedule Found', __FILE__, __LINE__, __METHOD__,10);
 									}
 								}
+								$prev_punch_time_stamp = $p_obj->getTimeStamp();
 							}
 						}
 						break;
 					case 's6': //Out Late
-						if ( $plf->getRecordCount() > 0 ) {
+						if ( $plf->getRecordCount() > 0  ) {
+							$prev_punch_time_stamp = FALSE;
 							foreach ( $plf as $p_obj ) {
-								if ( $p_obj->getType() == 10 AND $p_obj->getStatus() == 20 ) { //Normal Out
+								$punch_pairs[$p_obj->getPunchControlID()][] = array( 'status_id' => $p_obj->getStatus(), 'punch_control_id' => $p_obj->getPunchControlID() );
+
+								if ( $prev_punch_time_stamp != $p_obj->getTimeStamp() AND $p_obj->getType() == 10 AND $p_obj->getStatus() == 20 ) { //Normal Out
 									if ( !isset($scheduled_id_cache[$p_obj->getID()]) ) {
 										$scheduled_id_cache[$p_obj->getID()] = $p_obj->findScheduleID( NULL, $user_date_obj->getUser() );
 									}
@@ -1030,7 +1099,47 @@ class ExceptionPolicyFactory extends Factory {
 										Debug::text('&nbsp;&nbsp;&nbsp;&nbsp;NO Schedule Found', __FILE__, __LINE__, __METHOD__,10);
 									}
 								}
+								$prev_punch_time_stamp = $p_obj->getTimeStamp();
 							}
+
+							//Trigger exception if no out punch and we have passed schedule out time.
+							//  - Schedule is found
+							//	- Make sure the user is missing an OUT punch.
+							//	- Current time is after schedule end time
+							// 	- Current time is after exception grace time
+							//  - Current time is before schedule end time + maximum shift time.
+							if ( isset($punch_pairs) AND $slf->getRecordCount() > 0 ) {
+								foreach($punch_pairs as $punch_control_id => $punch_pair) {
+									if ( count($punch_pair) != 2 ) {
+										Debug::text('aFound Missing Punch: ', __FILE__, __LINE__, __METHOD__,10);
+
+										if ( $punch_pair[0]['status_id'] == 10 ) { //Missing Out Punch
+											Debug::text('bFound Missing Out Punch: ', __FILE__, __LINE__, __METHOD__,10);
+
+											foreach ( $slf as $s_obj ) {
+												Debug::text(' Schedule Start Time: '. TTDate::getDate('DATE+TIME', $s_obj->getStartTime() ) .' End Time: '. TTDate::getDate('DATE+TIME', $s_obj->getEndTime() ), __FILE__, __LINE__, __METHOD__,10);
+												if ( TTDate::getTime() >= $s_obj->getEndTime() AND TTDate::getTime() <= ($s_obj->getEndTime()+self::$premature_delay) ) {
+													if ( TTDate::inWindow( TTDate::getTime(), $s_obj->getEndTime(), $ep_obj->getGrace() ) == TRUE ) {
+														Debug::text('&nbsp;&nbsp;&nbsp;&nbsp;Within Grace time, IGNORE EXCEPTION: ', __FILE__, __LINE__, __METHOD__,10);
+													} else {
+														Debug::text('&nbsp;&nbsp;&nbsp;&nbsp;NOT Within Grace time, SET EXCEPTION: ', __FILE__, __LINE__, __METHOD__,10);
+														$current_exceptions[] = array(
+																						'user_date_id' => $user_date_id,
+																						'exception_policy_id' => $ep_obj->getId(),
+																						'type_id' => $type_id,
+																						'punch_id' => FALSE,
+																						'punch_control_id' => $punch_pair[0]['punch_control_id'],
+																					);
+													}
+												}
+											}
+										}
+									} else {
+										Debug::text('No Missing Punches...', __FILE__, __LINE__, __METHOD__,10);
+									}
+								}
+							}
+							unset($punch_pairs, $punch_pair);
 						}
 						break;
 					case 'm1': //Missing In Punch
@@ -1233,7 +1342,7 @@ class ExceptionPolicyFactory extends Factory {
 								$daily_total_time = 0;
 								if ( $schedule_total_time > 0 ) {
 									//Get daily total time.
-									$udtlf = new UserDateTotalListFactory();
+									$udtlf = TTnew( 'UserDateTotalListFactory' );
 
 									//Take into account auto-deduct/add meal policies
 									//$udtlf->getByUserDateIdAndStatus( $user_date_id, 20 );
@@ -1281,7 +1390,7 @@ class ExceptionPolicyFactory extends Factory {
 								$daily_total_time = 0;
 								if ( $schedule_total_time > 0 ) {
 									//Get daily total time.
-									$udtlf = new UserDateTotalListFactory();
+									$udtlf = TTnew( 'UserDateTotalListFactory' );
 
 									//Take into account auto-deduct/add meal policies
 									//$udtlf->getByUserDateIdAndStatus( $user_date_id, 20 );
@@ -1323,7 +1432,7 @@ class ExceptionPolicyFactory extends Factory {
 							$daily_total_time = 0;
 
 							//Get daily total time.
-							$udtlf = new UserDateTotalListFactory();
+							$udtlf = TTnew( 'UserDateTotalListFactory' );
 
 							//Take into account auto-deduct/add meal policies
 							$udtlf->getByUserDateIdAndStatusAndType( $user_date_id, 10, 10 );
@@ -1369,7 +1478,7 @@ class ExceptionPolicyFactory extends Factory {
 							//In either case though we should take into account the entires week worth of scheduled time even if we are only partially through
 							//the week, that way we won't be triggering s9 exceptions on a Wed and a Fri or something, it will only occur on the last days of the week.
 							if ( strtolower( $ep_obj->getType() ) == 's9' ) {
-								$tmp_slf = new ScheduleListFactory();
+								$tmp_slf = TTnew( 'ScheduleListFactory' );
 								$tmp_slf->getByUserIdAndStartDateAndEndDate( $user_date_obj->getUser(), TTDate::getBeginWeekEpoch($user_date_obj->getDateStamp(), $start_week_day_id), TTDate::getEndWeekEpoch($user_date_obj->getDateStamp(), $start_week_day_id) );
 								if ( $tmp_slf->getRecordCount() > 0 ) {
 									foreach( $tmp_slf as $s_obj ) {
@@ -1383,7 +1492,7 @@ class ExceptionPolicyFactory extends Factory {
 							$weekly_total_time = 0;
 
 							//Get daily total time.
-							$udtlf = new UserDateTotalListFactory();
+							$udtlf = TTnew( 'UserDateTotalListFactory' );
 							$weekly_total_time = $udtlf->getWorkedTimeSumByUserIDAndStartDateAndEndDate( $user_date_obj->getUser(), TTDate::getBeginWeekEpoch($user_date_obj->getDateStamp(), $start_week_day_id), $user_date_obj->getDateStamp() );
 
 							Debug::text(' Weekly Total Time: '. $weekly_total_time .' Weekly Scheduled Total Time: '. $weekly_scheduled_total_time .' Watch Window: '. $ep_obj->getWatchWindow() .' Grace: '. $ep_obj->getGrace() .' User Date ID: '. $user_date_id, __FILE__, __LINE__, __METHOD__,10);
@@ -1446,7 +1555,7 @@ class ExceptionPolicyFactory extends Factory {
 												AND is_object( $p_obj->getScheduleObject()->getSchedulePolicyObject() ) == TRUE ) {
 											$mp_obj = $p_obj->getScheduleObject()->getSchedulePolicyObject()->getMealPolicyObject();
 										} else {
-											$mplf = new MealPolicyListFactory();
+											$mplf = TTnew( 'MealPolicyListFactory' );
 											$mplf->getByPolicyGroupUserId( $user_date_obj->getUserObject()->getId() );
 											if ( $mplf->getRecordCount() > 0 ) {
 												Debug::text('Found Meal Policy to apply.', __FILE__, __LINE__, __METHOD__, 10);
@@ -1509,7 +1618,7 @@ class ExceptionPolicyFactory extends Factory {
 							//Also ignore this exception if the lunch is auto-deduct.
 							$daily_total_time = 0;
 
-							$udtlf = new UserDateTotalListFactory();
+							$udtlf = TTnew( 'UserDateTotalListFactory' );
 							$udtlf->getByUserDateIdAndStatus( $user_date_id, 20 );
 							if ( $udtlf->getRecordCount() > 0 ) {
 								foreach( $udtlf as $udt_obj ) {
@@ -1558,7 +1667,7 @@ class ExceptionPolicyFactory extends Factory {
 										Debug::text('No Schedule Found...', __FILE__, __LINE__, __METHOD__,10);
 
 										//Check if they have a meal policy, with no schedule.
-										$mplf = new MealPolicyListFactory();
+										$mplf = TTnew( 'MealPolicyListFactory' );
 										$mplf->getByPolicyGroupUserId( $user_date_obj->getUser() );
 										if ( $mplf->getRecordCount() > 0 ) {
 											Debug::text('Found UnScheduled Meal Policy...', __FILE__, __LINE__, __METHOD__,10);
@@ -1635,7 +1744,7 @@ class ExceptionPolicyFactory extends Factory {
 										}
 
 										//Check to see if they have a schedule policy
-										$bplf = new BreakPolicyListFactory();
+										$bplf = TTnew( 'BreakPolicyListFactory' );
 										if ( $p_obj->setScheduleID( $scheduled_id_cache[$p_obj->getID()] ) == TRUE
 												AND is_object( $p_obj->getScheduleObject() ) == TRUE
 												AND is_object( $p_obj->getScheduleObject()->getSchedulePolicyObject() ) == TRUE ) {
@@ -1731,7 +1840,21 @@ class ExceptionPolicyFactory extends Factory {
 							}
 							unset($pair);
 
+							//Get daily total time.
+							$daily_total_time = 0;
+							$udtlf = TTnew( 'UserDateTotalListFactory' );
+							$udtlf->getByUserDateIdAndStatusAndType( $user_date_id, 10, 10 );
+							if ( $udtlf->getRecordCount() > 0 ) {
+								foreach( $udtlf as $udt_obj ) {
+									$daily_total_time += $udt_obj->getTotalTime();
+								}
+							}
 
+							Debug::text(' Daily Total Time: '. $daily_total_time .' User Date ID: '. $user_date_id, __FILE__, __LINE__, __METHOD__,10);
+
+							//Make sure we take into account how long they have currently worked, so we don't
+							//say too few breaks for 3hr shift that they employee took one break on.
+							//Trigger this exception if the employee doesn't take a break at all?
 							if ( isset($break_punch_arr) ) {
 								$total_breaks = count($break_punch_arr);
 
@@ -1747,14 +1870,15 @@ class ExceptionPolicyFactory extends Factory {
 										}
 
 										//Check to see if they have a schedule policy
-										$bplf = new BreakPolicyListFactory();
+										$bplf = TTnew( 'BreakPolicyListFactory' );
 										if ( $p_obj->setScheduleID( $scheduled_id_cache[$p_obj->getID()] ) == TRUE
 												AND is_object( $p_obj->getScheduleObject() ) == TRUE
 												AND is_object( $p_obj->getScheduleObject()->getSchedulePolicyObject() ) == TRUE ) {
 											$break_policy_ids = $p_obj->getScheduleObject()->getSchedulePolicyObject()->getBreakPolicy();
 											$bplf->getByIdAndCompanyId( $break_policy_ids, $user_date_obj->getUserObject()->getCompany() );
 										} else {
-											$bplf->getByPolicyGroupUserId( $user_date_obj->getUser() );
+											//$bplf->getByPolicyGroupUserId( $user_date_obj->getUser() );
+											$bplf->getByPolicyGroupUserIdAndDayTotalTime( $user_date_obj->getUser(), $daily_total_time );
 										}
 										unset($break_policy_ids);
 
@@ -1799,13 +1923,109 @@ class ExceptionPolicyFactory extends Factory {
 							}
 						}
 						break;
+					case 'b5': //No Break
+						if ( $plf->getRecordCount() > 0 ) {
+							//If they are scheduled or not, we can check for a meal policy and base our
+							//decision off that. We don't want a No Lunch exception on a 3hr shift though.
+							//Also ignore this exception if the lunch is auto-deduct.
+							$daily_total_time = 0;
+
+							$udtlf = TTnew( 'UserDateTotalListFactory' );
+							$udtlf->getByUserDateIdAndStatus( $user_date_id, 20 );
+							if ( $udtlf->getRecordCount() > 0 ) {
+								foreach( $udtlf as $udt_obj ) {
+									$daily_total_time += $udt_obj->getTotalTime();
+								}
+							}
+							Debug::text('Day Total Time: '. $daily_total_time, __FILE__, __LINE__, __METHOD__,10);
+
+							if ( $daily_total_time > 0 ) {
+								//Check for break punch.
+								$break_punch = FALSE;
+								foreach ( $plf as $p_obj ) {
+									if ( $p_obj->getType() == 20 ) {
+										Debug::text('Found break Punch: '. $p_obj->getTimeStamp(), __FILE__, __LINE__, __METHOD__,10);
+										$break_punch = TRUE;
+										break;
+									}
+								}
+
+								if ( $break_punch == FALSE ) {
+									Debug::text('DID NOT Find break Punch... Checking break policies. ', __FILE__, __LINE__, __METHOD__,10);
+
+									//Use scheduled break policy first.
+									if ( $slf->getRecordCount() > 0 ) {
+										Debug::text('Schedule Found...', __FILE__, __LINE__, __METHOD__,10);
+										foreach ( $slf as $s_obj ) {
+											if ( $s_obj->getSchedulePolicyObject() !== FALSE
+													AND $s_obj->getSchedulePolicyObject()->getBreakPolicyObject() !== FALSE
+													AND $s_obj->getSchedulePolicyObject()->getBreakPolicyObject()->getType() != 10 ) {
+												Debug::text('Found Schedule Break Policy... Trigger Time: '. $s_obj->getSchedulePolicyObject()->getBreakPolicyObject()->getTriggerTime(), __FILE__, __LINE__, __METHOD__,10);
+												if ( $daily_total_time > $s_obj->getSchedulePolicyObject()->getBreakPolicyObject()->getTriggerTime() ) {
+													Debug::text('Daily Total Time is After Schedule Break Policy Trigger Time: ', __FILE__, __LINE__, __METHOD__,10);
+													$current_exceptions[] = array(
+																					'user_date_id' => $user_date_id,
+																					'exception_policy_id' => $ep_obj->getId(),
+																					'type_id' => $type_id,
+																					'punch_id' => FALSE,
+																					'punch_control_id' => FALSE,
+																				);
+												}
+											} else {
+												Debug::text('Schedule Break Policy does not exist, or is auto-deduct?', __FILE__, __LINE__, __METHOD__,10);
+											}
+										}
+									} else {
+										Debug::text('No Schedule Found...', __FILE__, __LINE__, __METHOD__,10);
+
+										//Check if they have a break policy, with no schedule.
+										$bplf = TTnew( 'BreakPolicyListFactory' );
+										$bplf->getByPolicyGroupUserId( $user_date_obj->getUser() );
+										if ( $bplf->getRecordCount() > 0 ) {
+											Debug::text('Found UnScheduled Break Policy...', __FILE__, __LINE__, __METHOD__,10);
+
+											$b_obj = $bplf->getCurrent();
+											if ( $daily_total_time > $b_obj->getTriggerTime()
+													AND $b_obj->getType() == 20 ) {
+												Debug::text('Daily Total Time is After Schedule Break Policy Trigger Time: '. $b_obj->getTriggerTime(), __FILE__, __LINE__, __METHOD__,10);
+												$current_exceptions[] = array(
+																				'user_date_id' => $user_date_id,
+																				'exception_policy_id' => $ep_obj->getId(),
+																				'type_id' => $type_id,
+																				'punch_id' => FALSE,
+																				'punch_control_id' => FALSE,
+																			);
+											} else {
+												Debug::text('Auto-deduct break policy, ignorning this exception.', __FILE__, __LINE__, __METHOD__,10);
+											}
+										} else {
+											//There is no  break policy or schedule policy with a break policy assigned to it
+											//With out this we could still apply No Break exceptions, but they will happen even on
+											//a 2minute shift.
+											Debug::text('No meal policy, applying No break exception.', __FILE__, __LINE__, __METHOD__,10);
+											$current_exceptions[] = array(
+																			'user_date_id' => $user_date_id,
+																			'exception_policy_id' => $ep_obj->getId(),
+																			'type_id' => $type_id,
+																			'punch_id' => FALSE,
+																			'punch_control_id' => FALSE,
+																		);
+										}
+									}
+
+								} else {
+									Debug::text('Found break Punch... Ignoring this exception. ', __FILE__, __LINE__, __METHOD__,10);
+								}
+							}
+						}
+						break;
 					case 'j1': //Not Allowed on Job
 						if ( $plf->getRecordCount() > 0 ) {
 							foreach ( $plf as $p_obj ) {
 								if ( $p_obj->getStatus() == 10 ) { //In punches
 									if ( is_object( $p_obj->getPunchControlObject() ) AND $p_obj->getPunchControlObject()->getJob() > 0 ) {
 										//Found job punch, check job settings.
-										$jlf = new JobListFactory();
+										$jlf = TTnew( 'JobListFactory' );
 										$jlf->getById( $p_obj->getPunchControlObject()->getJob() );
 										if ( $jlf->getRecordCount() > 0 ) {
 											$j_obj = $jlf->getCurrent();
@@ -1838,7 +2058,7 @@ class ExceptionPolicyFactory extends Factory {
 								if ( $p_obj->getStatus() == 10 ) { //In punches
 									if ( is_object( $p_obj->getPunchControlObject() ) AND $p_obj->getPunchControlObject()->getJob() > 0 AND $p_obj->getPunchControlObject()->getJobItem() > 0 ) {
 										//Found job punch, check job settings.
-										$jlf = new JobListFactory();
+										$jlf = TTnew( 'JobListFactory' );
 										$jlf->getById( $p_obj->getPunchControlObject()->getJob() );
 										if ( $jlf->getRecordCount() > 0 ) {
 											$j_obj = $jlf->getCurrent();
@@ -1872,7 +2092,7 @@ class ExceptionPolicyFactory extends Factory {
 								if ( $p_obj->getStatus() == 10 ) { //In punches
 									if ( is_object( $p_obj->getPunchControlObject() ) AND $p_obj->getPunchControlObject()->getJob() > 0 ) {
 										//Found job punch, check job settings.
-										$jlf = new JobListFactory();
+										$jlf = TTnew( 'JobListFactory' );
 										$jlf->getById( $p_obj->getPunchControlObject()->getJob() );
 										if ( $jlf->getRecordCount() > 0 ) {
 											$j_obj = $jlf->getCurrent();
@@ -1939,7 +2159,7 @@ class ExceptionPolicyFactory extends Factory {
 			if ( isset($exceptions['create_exceptions']) AND is_array($exceptions['create_exceptions']) ) {
 				Debug::text('Creating new exceptions...', __FILE__, __LINE__, __METHOD__,10);
 				foreach( $exceptions['create_exceptions'] as $tmp_exception ) {
-					$ef = new ExceptionFactory();
+					$ef = TTnew( 'ExceptionFactory' );
 					$ef->setUserDateID( $tmp_exception['user_date_id'] );
 					$ef->setExceptionPolicyID( $tmp_exception['exception_policy_id'] );
 					$ef->setType( $tmp_exception['type_id'] );
@@ -1952,7 +2172,7 @@ class ExceptionPolicyFactory extends Factory {
 					$ef->setEnableDemerits( TRUE );
 					if ( $ef->isValid() ) {
 						if ( $enable_premature_exceptions == TRUE ) {
-							$eplf = new ExceptionPolicyListFactory();
+							$eplf = TTnew( 'ExceptionPolicyListFactory' );
 							$eplf->getById( $tmp_exception['exception_policy_id'] );
 							if ( $eplf->getRecordCount() == 1 ) {
 								$ep_obj = $eplf->getCurrent();
@@ -1966,7 +2186,7 @@ class ExceptionPolicyFactory extends Factory {
 
 			if ( isset($exceptions['delete_exceptions']) AND is_array($exceptions['delete_exceptions']) ) {
 				Debug::Text('Deleting no longer valid exceptions...', __FILE__, __LINE__, __METHOD__,10);
-				$ef = new ExceptionFactory();
+				$ef = TTnew( 'ExceptionFactory' );
 				$ef->bulkDelete( $exceptions['delete_exceptions'] );
 			}
 		}
@@ -2009,10 +2229,10 @@ class ExceptionPolicyFactory extends Factory {
 						AND
 						$current_exception['punch_id'] == $existing_exception['punch_id']
 					) {
-					Debug::text('Removing current exception that matches existing exception: '. $current_key, __FILE__, __LINE__, __METHOD__,10);
+					//Debug::text('Removing current exception that matches existing exception: '. $current_key, __FILE__, __LINE__, __METHOD__,10);
 					unset($new_exceptions[$current_key]);
 				} else {
-					Debug::text('NOT Removing current exception that matches existing exception: Current: '. $current_key .' Existing: '. $existing_key, __FILE__, __LINE__, __METHOD__,10);
+					//Debug::text('NOT Removing current exception that matches existing exception: Current: '. $current_key .' Existing: '. $existing_key, __FILE__, __LINE__, __METHOD__,10);
 				}
 			}
 		}
@@ -2029,11 +2249,11 @@ class ExceptionPolicyFactory extends Factory {
 				if ( !( $current_exception['exception_policy_id'] == $existing_exception['exception_policy_id'] AND $current_exception['type_id'] == $existing_exception['type_id'] AND $current_exception['user_date_id'] == $existing_exception['user_date_id'] AND $current_exception['punch_control_id'] == $existing_exception['punch_control_id'] AND $current_exception['punch_id'] == $existing_exception['punch_id'] ) ) {
 					$match_count--;
 				}
-				Debug::text('aDetermining if we should delete this exception... Match Count: '. $match_count .' Total: '. $total_current_exceptions .' Existing Key: '. $existing_key, __FILE__, __LINE__, __METHOD__,10);
+				//Debug::text('aDetermining if we should delete this exception... Match Count: '. $match_count .' Total: '. $total_current_exceptions .' Existing Key: '. $existing_key, __FILE__, __LINE__, __METHOD__,10);
 			}
 
 			if ( $match_count == 0 ) {
-				Debug::text('bDetermining if we should delete this exception... Match Count: '. $match_count .' Total: '. $total_current_exceptions .' Existing Key: '. $existing_key, __FILE__, __LINE__, __METHOD__,10);
+				//Debug::text('bDetermining if we should delete this exception... Match Count: '. $match_count .' Total: '. $total_current_exceptions .' Existing Key: '. $existing_key, __FILE__, __LINE__, __METHOD__,10);
 				$delete_exceptions[] = $existing_exception['id'];
 			}
 		}
