@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: HolidayPolicyFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4401 $
+ * $Id: HolidayPolicyFactory.class.php 4401 2011-03-19 20:29:26Z ipso $
+ * $Date: 2011-03-19 13:29:26 -0700 (Sat, 19 Mar 2011) $
  */
 
 /**
@@ -55,7 +55,7 @@ class HolidayPolicyFactory extends Factory {
 		$retval = NULL;
 		switch( $name ) {
 			case 'default_schedule_status':
-				$sf = new ScheduleFactory();
+				$sf = TTnew( 'ScheduleFactory' );
 				$retval = $sf->getOptions('status');
 				break;
 			case 'type':
@@ -86,10 +86,15 @@ class HolidayPolicyFactory extends Factory {
 										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
 							);
 				break;
+			case 'list_columns':
+				$retval = Misc::arrayIntersectByKey( $this->getOptions('default_display_columns'), Misc::trimSortPrefix( $this->getOptions('columns') ) );
+				break;
 			case 'default_display_columns': //Columns that are displayed by default.
 				$retval = array(
 								'name',
 								'type',
+								'updated_date',
+								'updated_by',
 								);
 				break;
 			case 'unique_columns': //Columns that are unique, and disabled for mass editing.
@@ -144,7 +149,7 @@ class HolidayPolicyFactory extends Factory {
 		if ( is_object($this->round_interval_policy_obj) ) {
 			return $this->round_interval_policy_obj;
 		} else {
-			$riplf = new RoundIntervalPolicyListFactory();
+			$riplf = TTnew( 'RoundIntervalPolicyListFactory' );
 			$riplf->getById( $this->getRoundIntervalPolicyID() );
 			if ( $riplf->getRecordCount() > 0 ) {
 				$this->round_interval_policy_obj = $riplf->getCurrent();
@@ -158,7 +163,7 @@ class HolidayPolicyFactory extends Factory {
 		if ( is_object($this->absence_policy_obj) ) {
 			return $this->absence_policy_obj;
 		} else {
-			$aplf = new AbsencePolicyListFactory();
+			$aplf = TTnew( 'AbsencePolicyListFactory' );
 			$aplf->getById( $this->getAbsencePolicyID() );
 			if ( $aplf->getRecordCount() > 0 ) {
 				$this->absence_policy_obj = $aplf->getCurrent();
@@ -172,7 +177,7 @@ class HolidayPolicyFactory extends Factory {
 		if ( is_object($this->company_obj) ) {
 			return $this->company_obj;
 		} else {
-			$clf = new CompanyListFactory();
+			$clf = TTnew( 'CompanyListFactory' );
 			$this->company_obj = $clf->getById( $this->getCompany() )->getCurrent();
 
 			return $this->company_obj;
@@ -190,7 +195,7 @@ class HolidayPolicyFactory extends Factory {
 		$id = trim($id);
 
 		Debug::Text('Company ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
-		$clf = new CompanyListFactory();
+		$clf = TTnew( 'CompanyListFactory' );
 
 		if ( $this->Validator->isResultSetWithRows(	'company',
 													$clf->getByID($id),
@@ -266,7 +271,7 @@ class HolidayPolicyFactory extends Factory {
 	function setDefaultScheduleStatus($value) {
 		$value = trim($value);
 
-		$sf = new ScheduleFactory();
+		$sf = TTnew( 'ScheduleFactory' );
 
 		$key = Option::getByValue($value, $sf->getOptions('status') );
 		if ($key !== FALSE) {
@@ -561,7 +566,7 @@ class HolidayPolicyFactory extends Factory {
 			$id = NULL;
 		}
 
-		$riplf = new RoundIntervalPolicyListFactory();
+		$riplf = TTnew( 'RoundIntervalPolicyListFactory' );
 
 		if ( $id == NULL
 				OR
@@ -655,7 +660,7 @@ class HolidayPolicyFactory extends Factory {
 			$id = 0;
 		}
 
-		$aplf = new AbsencePolicyListFactory();
+		$aplf = TTnew( 'AbsencePolicyListFactory' );
 
 		if ( $id == 0
 				OR
@@ -673,7 +678,7 @@ class HolidayPolicyFactory extends Factory {
 	}
 
 	function getRecurringHoliday() {
-		$hprhlf = new HolidayPolicyRecurringHolidayListFactory();
+		$hprhlf = TTnew( 'HolidayPolicyRecurringHolidayListFactory' );
 		$hprhlf->getByHolidayPolicyId( $this->getId() );
 		Debug::text('Found Recurring Holidays Attached to this Policy: '. $hprhlf->getRecordCount(), __FILE__, __LINE__, __METHOD__, 10);
 		foreach ($hprhlf as $obj) {
@@ -692,7 +697,7 @@ class HolidayPolicyFactory extends Factory {
 			$tmp_ids = array();
 			if ( !$this->isNew() ) {
 				//If needed, delete mappings first.
-				$hprhlf = new HolidayPolicyRecurringHolidayListFactory();
+				$hprhlf = TTnew( 'HolidayPolicyRecurringHolidayListFactory' );
 				$hprhlf->getByHolidayPolicyId( $this->getId() );
 
 				foreach ($hprhlf as $obj) {
@@ -713,11 +718,11 @@ class HolidayPolicyFactory extends Factory {
 			}
 
 			//Insert new mappings.
-			$rhlf = new RecurringHolidayListFactory();
+			$rhlf = TTnew( 'RecurringHolidayListFactory' );
 
 			foreach ($ids as $id) {
 				if ( isset($ids) AND !in_array($id, $tmp_ids) AND $id > 0 ) {
-					$hprhf = new HolidayPolicyRecurringHolidayFactory();
+					$hprhf = TTnew( 'HolidayPolicyRecurringHolidayFactory' );
 					$hprhf->setHolidayPolicy( $this->getId() );
 					$hprhf->setRecurringHoliday( $id );
 
