@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: HolidayPolicyRecurringHolidayFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4104 $
+ * $Id: HolidayPolicyRecurringHolidayFactory.class.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 
 /**
@@ -52,7 +52,7 @@ class HolidayPolicyRecurringHolidayFactory extends Factory {
 		if ( is_object($this->recurring_holiday_obj) ) {
 			return $this->recurring_holiday_obj;
 		} else {
-			$lf = new RecurringHolidayListFactory();
+			$lf = TTnew( 'RecurringHolidayListFactory' );
 			$lf->getById( $this->getRecurringHoliday() );
 			if ( $lf->getRecordCount() == 1 ) {
 				$this->recurring_holiday_obj = $lf->getCurrent();
@@ -73,7 +73,7 @@ class HolidayPolicyRecurringHolidayFactory extends Factory {
 	function setHolidayPolicy($id) {
 		$id = trim($id);
 
-		$hplf = new HolidayPolicyListFactory();
+		$hplf = TTnew( 'HolidayPolicyListFactory' );
 
 		if (
 			  $this->Validator->isNumeric(	'holiday_policy',
@@ -102,7 +102,7 @@ class HolidayPolicyRecurringHolidayFactory extends Factory {
 	function setRecurringHoliday($id) {
 		$id = trim($id);
 
-		$rhlf = new RecurringHolidayListFactory();
+		$rhlf = TTnew( 'RecurringHolidayListFactory' );
 
 		if ( $id != 0
 				AND $this->Validator->isResultSetWithRows(	'recurring_holiday',
