@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2095 $
- * $Id: PolicyGroupRoundIntervalPolicyFactory.class.php 2095 2008-09-01 07:04:25Z ipso $
- * $Date: 2008-09-01 00:04:25 -0700 (Mon, 01 Sep 2008) $
+ * $Revision: 4104 $
+ * $Id: PolicyGroupRoundIntervalPolicyFactory.class.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 
 /**
@@ -55,7 +55,7 @@ class PolicyGroupRoundIntervalPolicyFactory extends Factory {
 	function setPolicyGroup($id) {
 		$id = trim($id);
 
-		$pglf = new PolicyGroupListFactory();
+		$pglf = TTnew( 'PolicyGroupListFactory' );
 
 		if ( $this->Validator->isResultSetWithRows(	'policy_group',
 															$pglf->getByID($id),
@@ -77,7 +77,7 @@ class PolicyGroupRoundIntervalPolicyFactory extends Factory {
 	function setRoundInterValPolicy($id) {
 		$id = trim($id);
 
-		$riplf = new RoundIntervalPolicyListFactory();
+		$riplf = TTnew( 'RoundIntervalPolicyListFactory' );
 
 		if ( $id == 0
 				OR
