@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: PremiumPolicyBranchFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4104 $
+ * $Id: PremiumPolicyBranchFactory.class.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 
 /**
@@ -52,7 +52,7 @@ class PremiumPolicyBranchFactory extends Factory {
 		if ( is_object($this->branch_obj) ) {
 			return $this->branch_obj;
 		} else {
-			$lf = new BranchListFactory();
+			$lf = TTnew( 'BranchListFactory' );
 			$lf->getById( $this->getBranch() );
 			if ( $lf->getRecordCount() == 1 ) {
 				$this->branch_obj = $lf->getCurrent();
@@ -71,7 +71,7 @@ class PremiumPolicyBranchFactory extends Factory {
 	function setPremiumPolicy($id) {
 		$id = trim($id);
 
-		$pplf = new PremiumPolicyListFactory();
+		$pplf = TTnew( 'PremiumPolicyListFactory' );
 
 		if (	$id == 0
 				OR
@@ -104,7 +104,7 @@ class PremiumPolicyBranchFactory extends Factory {
 	function setBranch($id) {
 		$id = trim($id);
 
-		$blf = new BranchListFactory();
+		$blf = TTnew( 'BranchListFactory' );
 
 		if ( $this->Validator->isResultSetWithRows(	'branch',
 													$blf->getByID($id),
