@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: PremiumPolicyFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4562 $
+ * $Id: PremiumPolicyFactory.class.php 4562 2011-04-22 16:47:34Z ipso $
+ * $Date: 2011-04-22 09:47:34 -0700 (Fri, 22 Apr 2011) $
  */
 
 /**
@@ -57,6 +57,8 @@ class PremiumPolicyFactory extends Factory {
 										10 => TTi18n::gettext('Date/Time'),
 										20 => TTi18n::gettext('Shift Differential'),
 										30 => TTi18n::gettext('Meal/Break'),
+										40 => TTi18n::gettext('Callback'),
+										50 => TTi18n::gettext('Minimum Shift Time'),
 										100 => TTi18n::gettext('Advanced'),
 									);
 				break;
@@ -127,10 +129,15 @@ class PremiumPolicyFactory extends Factory {
 										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
 							);
 				break;
+			case 'list_columns':
+				$retval = Misc::arrayIntersectByKey( $this->getOptions('default_display_columns'), Misc::trimSortPrefix( $this->getOptions('columns') ) );
+				break;
 			case 'default_display_columns': //Columns that are displayed by default.
 				$retval = array(
 								'name',
 								'type',
+								'updated_date',
+								'updated_by',
 								);
 				break;
 			case 'unique_columns': //Columns that are unique, and disabled for mass editing.
@@ -174,6 +181,9 @@ class PremiumPolicyFactory extends Factory {
 										'include_partial_punch' => 'IncludePartialPunch',
 										'maximum_no_break_time' => 'MaximumNoBreakTime',
 										'minimum_break_time' => 'MinimumBreakTime',
+										'minimum_time_between_shift' => 'MinimumTimeBetweenShift',
+										'minimum_first_shift_time' => 'MinimumFirstShiftTime',
+										'minimum_shift_time' => 'MinimumShiftTime',
 										'minimum_time' => 'MinimumTime',
 										'maximum_time' => 'MaximumTime',
 										'include_meal_policy' => 'IncludeMealPolicy',
@@ -213,7 +223,7 @@ class PremiumPolicyFactory extends Factory {
 		if ( is_object($this->company_obj) ) {
 			return $this->company_obj;
 		} else {
-			$clf = new CompanyListFactory();
+			$clf = TTnew( 'CompanyListFactory' );
 			$this->company_obj = $clf->getById( $this->getCompany() )->getCurrent();
 
 			return $this->company_obj;
@@ -231,7 +241,7 @@ class PremiumPolicyFactory extends Factory {
 		$id = trim($id);
 
 		Debug::Text('Company ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
-		$clf = new CompanyListFactory();
+		$clf = TTnew( 'CompanyListFactory' );
 
 		if ( $this->Validator->isResultSetWithRows(	'company',
 													$clf->getByID($id),
@@ -652,6 +662,84 @@ class PremiumPolicyFactory extends Factory {
 		return FALSE;
 	}
 
+	function getMinimumTimeBetweenShift() {
+		if ( isset($this->data['minimum_time_between_shift']) ) {
+			return (int)$this->data['minimum_time_between_shift'];
+		}
+
+		return FALSE;
+	}
+	function setMinimumTimeBetweenShift($int) {
+		$int = trim($int);
+
+		if  ( empty($int) ){
+			$int = 0;
+		}
+
+		if 	( $int == 0
+				OR $this->Validator->isNumeric(		'minimum_time_between_shift',
+													$int,
+													TTi18n::gettext('Incorrect Minimum Time Between Shifts')) ) {
+			$this->data['minimum_time_between_shift'] = $int;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getMinimumFirstShiftTime() {
+		if ( isset($this->data['minimum_first_shift_time']) ) {
+			return (int)$this->data['minimum_first_shift_time'];
+		}
+
+		return FALSE;
+	}
+	function setMinimumFirstShiftTime($int) {
+		$int = trim($int);
+
+		if  ( empty($int) ){
+			$int = 0;
+		}
+
+		if 	(	$int == 0
+				OR $this->Validator->isNumeric(		'minimum_first_shift_time',
+													$int,
+													TTi18n::gettext('Incorrect Minimum First Shift Time')) ) {
+			$this->data['minimum_first_shift_time'] = $int;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getMinimumShiftTime() {
+		if ( isset($this->data['minimum_shift_time']) ) {
+			return (int)$this->data['minimum_shift_time'];
+		}
+
+		return FALSE;
+	}
+	function setMinimumShiftTime($int) {
+		$int = trim($int);
+
+		if  ( empty($int) ){
+			$int = 0;
+		}
+
+		if 	(	$int == 0
+				OR $this->Validator->isNumeric(		'minimum_shift_time',
+													$int,
+													TTi18n::gettext('Incorrect Minimum Shift Time')) ) {
+			$this->data['minimum_shift_time'] = $int;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
 
 	function getMinimumTime() {
 		if ( isset($this->data['minimum_time']) ) {
@@ -739,7 +827,7 @@ class PremiumPolicyFactory extends Factory {
 	function setWageGroup($id) {
 		$id = trim($id);
 
-		$wglf = new WageGroupListFactory();
+		$wglf = TTnew( 'WageGroupListFactory' );
 
 		if ( $id == 0
 				OR
@@ -820,7 +908,7 @@ class PremiumPolicyFactory extends Factory {
 			$id = NULL;
 		}
 
-		$aplf = new AccrualPolicyListFactory();
+		$aplf = TTnew( 'AccrualPolicyListFactory' );
 
 		if ( $id == NULL
 				OR
@@ -853,7 +941,7 @@ class PremiumPolicyFactory extends Factory {
 			$id = NULL;
 		}
 
-		$psealf = new PayStubEntryAccountListFactory();
+		$psealf = TTnew( 'PayStubEntryAccountListFactory' );
 
 		if (
 				$this->Validator->isResultSetWithRows(	'pay_stub_entry_account_id',
@@ -931,7 +1019,7 @@ class PremiumPolicyFactory extends Factory {
 	}
 
 	function getBranch() {
-		$lf = new PremiumPolicyBranchListFactory();
+		$lf = TTnew( 'PremiumPolicyBranchListFactory' );
 		$lf->getByPremiumPolicyId( $this->getId() );
 		foreach ($lf as $obj) {
 			$list[] = $obj->getBranch();
@@ -951,7 +1039,7 @@ class PremiumPolicyFactory extends Factory {
 
 			if ( !$this->isNew() ) {
 				//If needed, delete mappings first.
-				$lf_a = new PremiumPolicyBranchListFactory();
+				$lf_a = TTnew( 'PremiumPolicyBranchListFactory' );
 				$lf_a->getByPremiumPolicyId( $this->getId() );
 
 				foreach ($lf_a as $obj) {
@@ -972,11 +1060,11 @@ class PremiumPolicyFactory extends Factory {
 			}
 
 			//Insert new mappings.
-			$lf_b = new BranchListFactory();
+			$lf_b = TTnew( 'BranchListFactory' );
 
 			foreach ($ids as $id) {
 				if ( isset($ids) AND $id > 0 AND !in_array($id, $tmp_ids) ) {
-					$f = new PremiumPolicyBranchFactory();
+					$f = TTnew( 'PremiumPolicyBranchFactory' );
 					$f->setPremiumPolicy( $this->getId() );
 					$f->setBranch( $id );
 
@@ -1035,7 +1123,7 @@ class PremiumPolicyFactory extends Factory {
 	}
 
 	function getDepartment() {
-		$lf = new PremiumPolicyDepartmentListFactory();
+		$lf = TTnew( 'PremiumPolicyDepartmentListFactory' );
 		$lf->getByPremiumPolicyId( $this->getId() );
 		foreach ($lf as $obj) {
 			$list[] = $obj->getDepartment();
@@ -1054,7 +1142,7 @@ class PremiumPolicyFactory extends Factory {
 
 			if ( !$this->isNew() ) {
 				//If needed, delete mappings first.
-				$lf_a = new PremiumPolicyDepartmentListFactory();
+				$lf_a = TTnew( 'PremiumPolicyDepartmentListFactory' );
 				$lf_a->getByPremiumPolicyId( $this->getId() );
 
 				foreach ($lf_a as $obj) {
@@ -1075,11 +1163,11 @@ class PremiumPolicyFactory extends Factory {
 			}
 
 			//Insert new mappings.
-			$lf_b = new DepartmentListFactory();
+			$lf_b = TTnew( 'DepartmentListFactory' );
 
 			foreach ($ids as $id) {
 				if ( isset($ids) AND $id > 0 AND !in_array($id, $tmp_ids) ) {
-					$f = new PremiumPolicyDepartmentFactory();
+					$f = TTnew( 'PremiumPolicyDepartmentFactory' );
 					$f->setPremiumPolicy( $this->getId() );
 					$f->setDepartment( $id );
 
@@ -1132,7 +1220,7 @@ class PremiumPolicyFactory extends Factory {
 			return FALSE;
 		}
 
-		$lf = new PremiumPolicyJobGroupListFactory();
+		$lf = TTnew( 'PremiumPolicyJobGroupListFactory' );
 		$lf->getByPremiumPolicyId( $this->getId() );
 		foreach ($lf as $obj) {
 			$list[] = $obj->getJobGroup();
@@ -1155,7 +1243,7 @@ class PremiumPolicyFactory extends Factory {
 
 			if ( !$this->isNew() ) {
 				//If needed, delete mappings first.
-				$lf_a = new PremiumPolicyJobGroupListFactory();
+				$lf_a = TTnew( 'PremiumPolicyJobGroupListFactory' );
 				$lf_a->getByPremiumPolicyId( $this->getId() );
 
 				foreach ($lf_a as $obj) {
@@ -1176,11 +1264,11 @@ class PremiumPolicyFactory extends Factory {
 			}
 
 			//Insert new mappings.
-			$lf_b = new JobGroupListFactory();
+			$lf_b = TTnew( 'JobGroupListFactory' );
 
 			foreach ($ids as $id) {
 				if ( isset($ids) AND $id > 0 AND !in_array($id, $tmp_ids) ) {
-					$f = new PremiumPolicyJobGroupFactory();
+					$f = TTnew( 'PremiumPolicyJobGroupFactory' );
 					$f->setPremiumPolicy( $this->getId() );
 					$f->setJobGroup( $id );
 
@@ -1230,7 +1318,7 @@ class PremiumPolicyFactory extends Factory {
 			return FALSE;
 		}
 
-		$lf = new PremiumPolicyJobListFactory();
+		$lf = TTnew( 'PremiumPolicyJobListFactory' );
 		$lf->getByPremiumPolicyId( $this->getId() );
 		foreach ($lf as $obj) {
 			$list[] = $obj->getjob();
@@ -1253,7 +1341,7 @@ class PremiumPolicyFactory extends Factory {
 
 			if ( !$this->isNew() ) {
 				//If needed, delete mappings first.
-				$lf_a = new PremiumPolicyJobListFactory();
+				$lf_a = TTnew( 'PremiumPolicyJobListFactory' );
 				$lf_a->getByPremiumPolicyId( $this->getId() );
 
 				foreach ($lf_a as $obj) {
@@ -1274,11 +1362,11 @@ class PremiumPolicyFactory extends Factory {
 			}
 
 			//Insert new mappings.
-			$lf_b = new JobListFactory();
+			$lf_b = TTnew( 'JobListFactory' );
 
 			foreach ($ids as $id) {
 				if ( isset($ids) AND $id > 0 AND !in_array($id, $tmp_ids) ) {
-					$f = new PremiumPolicyJobFactory();
+					$f = TTnew( 'PremiumPolicyJobFactory' );
 					$f->setPremiumPolicy( $this->getId() );
 					$f->setJob( $id );
 
@@ -1328,7 +1416,7 @@ class PremiumPolicyFactory extends Factory {
 			return FALSE;
 		}
 
-		$lf = new PremiumPolicyJobItemGroupListFactory();
+		$lf = TTnew( 'PremiumPolicyJobItemGroupListFactory' );
 		$lf->getByPremiumPolicyId( $this->getId() );
 		foreach ($lf as $obj) {
 			$list[] = $obj->getJobItemGroup();
@@ -1351,7 +1439,7 @@ class PremiumPolicyFactory extends Factory {
 
 			if ( !$this->isNew() ) {
 				//If needed, delete mappings first.
-				$lf_a = new PremiumPolicyJobItemGroupListFactory();
+				$lf_a = TTnew( 'PremiumPolicyJobItemGroupListFactory' );
 				$lf_a->getByPremiumPolicyId( $this->getId() );
 
 				foreach ($lf_a as $obj) {
@@ -1372,11 +1460,11 @@ class PremiumPolicyFactory extends Factory {
 			}
 
 			//Insert new mappings.
-			$lf_b = new JobItemGroupListFactory();
+			$lf_b = TTnew( 'JobItemGroupListFactory' );
 
 			foreach ($ids as $id) {
 				if ( isset($ids) AND $id > 0 AND !in_array($id, $tmp_ids) ) {
-					$f = new PremiumPolicyJobItemGroupFactory();
+					$f = TTnew( 'PremiumPolicyJobItemGroupFactory' );
 					$f->setPremiumPolicy( $this->getId() );
 					$f->setJobItemGroup( $id );
 
@@ -1426,7 +1514,7 @@ class PremiumPolicyFactory extends Factory {
 			return FALSE;
 		}
 
-		$lf = new PremiumPolicyJobItemListFactory();
+		$lf = TTnew( 'PremiumPolicyJobItemListFactory' );
 		$lf->getByPremiumPolicyId( $this->getId() );
 		foreach ($lf as $obj) {
 			$list[] = $obj->getJobItem();
@@ -1449,7 +1537,7 @@ class PremiumPolicyFactory extends Factory {
 
 			if ( !$this->isNew() ) {
 				//If needed, delete mappings first.
-				$lf_a = new PremiumPolicyJobItemListFactory();
+				$lf_a = TTnew( 'PremiumPolicyJobItemListFactory' );
 				$lf_a->getByPremiumPolicyId( $this->getId() );
 
 				foreach ($lf_a as $obj) {
@@ -1470,11 +1558,11 @@ class PremiumPolicyFactory extends Factory {
 			}
 
 			//Insert new mappings.
-			$lf_b = new JobItemListFactory();
+			$lf_b = TTnew( 'JobItemListFactory' );
 
 			foreach ($ids as $id) {
 				if ( isset($ids) AND $id > 0 AND !in_array($id, $tmp_ids) ) {
-					$f = new PremiumPolicyJobItemFactory();
+					$f = TTnew( 'PremiumPolicyJobItemFactory' );
 					$f->setPremiumPolicy( $this->getId() );
 					$f->setJobItem( $id );
 
@@ -1688,7 +1776,7 @@ class PremiumPolicyFactory extends Factory {
 	function Validate() {
 		if ( $this->getDeleted() == TRUE ) {
 			//Check to make sure there are no hours using this premium policy.
-			$udtlf = new UserDateTotalListFactory();
+			$udtlf = TTnew( 'UserDateTotalListFactory' );
 			$udtlf->getByPremiumTimePolicyId( $this->getId() );
 			if ( $udtlf->getRecordCount() > 0 ) {
 				$this->Validator->isTRUE(	'in_use',
