@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3764 $
- * $Id: RoundIntervalPolicyFactory.class.php 3764 2010-08-13 18:07:55Z ipso $
- * $Date: 2010-08-13 11:07:55 -0700 (Fri, 13 Aug 2010) $
+ * $Revision: 4401 $
+ * $Id: RoundIntervalPolicyFactory.class.php 4401 2011-03-19 20:29:26Z ipso $
+ * $Date: 2011-03-19 13:29:26 -0700 (Sat, 19 Mar 2011) $
  */
 
 /**
@@ -102,11 +102,16 @@ class RoundIntervalPolicyFactory extends Factory {
 										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
 							);
 				break;
+			case 'list_columns':
+				$retval = Misc::arrayIntersectByKey( $this->getOptions('default_display_columns'), Misc::trimSortPrefix( $this->getOptions('columns') ) );
+				break;
 			case 'default_display_columns': //Columns that are displayed by default.
 				$retval = array(
 								'punch_type',
 								'round_type',
 								'name',
+								'updated_date',
+								'updated_by',
 								);
 				break;
 			case 'unique_columns': //Columns that are unique, and disabled for mass editing.
@@ -145,7 +150,7 @@ class RoundIntervalPolicyFactory extends Factory {
 		if ( is_object($this->company_obj) ) {
 			return $this->company_obj;
 		} else {
-			$clf = new CompanyListFactory();
+			$clf = TTnew( 'CompanyListFactory' );
 			$this->company_obj = $clf->getById( $this->getCompany() )->getCurrent();
 
 			return $this->company_obj;
@@ -163,7 +168,7 @@ class RoundIntervalPolicyFactory extends Factory {
 		$id = trim($id);
 
 		Debug::Text('Company ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
-		$clf = new CompanyListFactory();
+		$clf = TTnew( 'CompanyListFactory' );
 
 		if ( $this->Validator->isResultSetWithRows(	'company',
 													$clf->getByID($id),
