@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3884 $
- * $Id: PunchControlFactory.class.php 3884 2010-10-05 14:40:19Z ipso $
- * $Date: 2010-10-05 07:40:19 -0700 (Tue, 05 Oct 2010) $
+ * $Revision: 4845 $
+ * $Id: PunchControlFactory.class.php 4845 2011-06-21 16:23:18Z ipso $
+ * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
  */
 
 /**
@@ -92,7 +92,7 @@ class PunchControlFactory extends Factory {
 				$id = $this->getUserDateID();
 			}
 
-			$udlf = new UserDateListFactory();
+			$udlf = TTnew( 'UserDateListFactory' );
 			$udlf->getById( $id );
 			if ( $udlf->getRecordCount() > 0 ) {
 				$this->user_date_obj = $udlf->getCurrent();
@@ -105,7 +105,7 @@ class PunchControlFactory extends Factory {
 
 	function getPLFByPunchControlID() {
 		if ( $this->plf == NULL AND $this->getID() != FALSE ) {
-			$this->plf = new PunchListFactory();
+			$this->plf = TTnew( 'PunchListFactory' );
 			$this->plf->getByPunchControlID( $this->getID() );
 		}
 
@@ -117,7 +117,7 @@ class PunchControlFactory extends Factory {
 			return $this->pay_period_schedule_obj;
 		} else {
 			if ( $this->getUser() > 0 ) {
-				$ppslf = new PayPeriodScheduleListFactory();
+				$ppslf = TTnew( 'PayPeriodScheduleListFactory' );
 				$ppslf->getByUserId( $this->getUser() );
 				if ( $ppslf->getRecordCount() == 1 ) {
 					$this->pay_period_schedule_obj = $ppslf->getCurrent();
@@ -145,7 +145,7 @@ class PunchControlFactory extends Factory {
 		if ( is_object($this->job_obj) ) {
 			return $this->job_obj;
 		} else {
-			$jlf = new JobListFactory();
+			$jlf = TTnew( 'JobListFactory' );
 			$jlf->getById( $this->getJob() );
 			if ( $jlf->getRecordCount() > 0 ) {
 				$this->job_obj = $jlf->getCurrent();
@@ -160,7 +160,7 @@ class PunchControlFactory extends Factory {
 		if ( is_object($this->job_item_obj) ) {
 			return $this->job_item_obj;
 		} else {
-			$jilf = new JobItemListFactory();
+			$jilf = TTnew( 'JobItemListFactory' );
 			$jilf->getById( $this->getJobItem() );
 			if ( $jilf->getRecordCount() > 0 ) {
 				$this->job_item_obj = $jilf->getCurrent();
@@ -333,7 +333,7 @@ class PunchControlFactory extends Factory {
 	function setUserDateID( $id ) {
 		$id = trim($id);
 
-		$udlf = new UserDateListFactory();
+		$udlf = TTnew( 'UserDateListFactory' );
 		if (  $this->Validator->isResultSetWithRows(	'user_date',
 														$udlf->getByID($id),
 														TTi18n::gettext('Invalid User Date ID')
@@ -366,7 +366,7 @@ class PunchControlFactory extends Factory {
 			$id = 0;
 		}
 
-		$blf = new BranchListFactory();
+		$blf = TTnew( 'BranchListFactory' );
 
 		if (  $id == 0
 				OR
@@ -396,7 +396,7 @@ class PunchControlFactory extends Factory {
 			$id = 0;
 		}
 
-		$dlf = new DepartmentListFactory();
+		$dlf = TTnew( 'DepartmentListFactory' );
 
 		if (  $id == 0
 				OR
@@ -427,7 +427,7 @@ class PunchControlFactory extends Factory {
 		}
 
 		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
-			$jlf = new JobListFactory();
+			$jlf = TTnew( 'JobListFactory' );
 		}
 
 		if (  $id == 0
@@ -459,7 +459,7 @@ class PunchControlFactory extends Factory {
 		}
 
 		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
-			$jilf = new JobItemListFactory();
+			$jilf = TTnew( 'JobItemListFactory' );
 		}
 
 		if (  $id == 0
@@ -588,7 +588,7 @@ class PunchControlFactory extends Factory {
 			$id = NULL;
 		}
 
-		$mplf = new MealPolicyListFactory();
+		$mplf = TTnew( 'MealPolicyListFactory' );
 
 		if ( $id == NULL
 				OR
@@ -758,7 +758,7 @@ class PunchControlFactory extends Factory {
 		if ( $force == TRUE OR $this->is_total_time_calculated == FALSE ) {
 			$this->is_total_time_calculated == TRUE;
 
-			$plf = new PunchListFactory();
+			$plf = TTnew( 'PunchListFactory' );
 			$plf->getByPunchControlId( $this->getId() );
 			//Make sure punches are in In/Out pairs before we bother calculating.
 			if ( $plf->getRecordCount() > 0 AND ( $plf->getRecordCount() % 2 ) == 0 ) {
@@ -829,7 +829,7 @@ class PunchControlFactory extends Factory {
 					if ( $this->getPunchObject()->inMealPolicyWindow( $this->getPunchObject()->getTimeStamp(), $previous_punch_arr['time_stamp'] ) == TRUE ) {
 						Debug::text(' Previous Punch needs to change to Lunch...', __FILE__, __LINE__, __METHOD__,10);
 
-						$plf = new PunchListFactory();
+						$plf = TTnew( 'PunchListFactory' );
 						$plf->getById( $previous_punch_arr['id'] );
 						if ( $plf->getRecordCount() == 1 ) {
 							Debug::text(' Modifying previous punch...', __FILE__, __LINE__, __METHOD__,10);
@@ -864,7 +864,7 @@ class PunchControlFactory extends Factory {
 					if ( $this->getPunchObject()->inBreakPolicyWindow( $this->getPunchObject()->getTimeStamp(), $previous_punch_arr['time_stamp'] ) == TRUE ) {
 						Debug::text(' Previous Punch needs to change to Break...', __FILE__, __LINE__, __METHOD__,10);
 
-						$plf = new PunchListFactory();
+						$plf = TTnew( 'PunchListFactory' );
 						$plf->getById( $previous_punch_arr['id'] );
 						if ( $plf->getRecordCount() == 1 ) {
 							Debug::text(' Modifying previous punch...', __FILE__, __LINE__, __METHOD__,10);
@@ -1075,7 +1075,7 @@ class PunchControlFactory extends Factory {
 				unset($punch_data);
 
 				if ( isset($punches[$this->getID()]) ) {
-					Debug::text('Current Punch ID Id: '. $this->getPunchObject()->getId() .' Punch Control ID: '. $this->getID() .' Status: '. $this->getPunchObject()->getStatus(), __FILE__, __LINE__, __METHOD__,10);
+					Debug::text('Current Punch ID: '. $this->getPunchObject()->getId() .' Punch Control ID: '. $this->getID() .' Status: '. $this->getPunchObject()->getStatus(), __FILE__, __LINE__, __METHOD__,10);
 					//Debug::Arr($punches, 'Punches Arr: ', __FILE__, __LINE__, __METHOD__,10);
 
 					if ( $this->getPunchObject()->getStatus() == 10 AND isset($punches[$this->getID()][20]) AND $this->getPunchObject()->getTimeStamp() > $punches[$this->getID()][20]['time_stamp'] ) {
@@ -1128,7 +1128,7 @@ class PunchControlFactory extends Factory {
 
 		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL AND $this->getEnableStrictJobValidation() == TRUE ) {
 			if ( $this->getJob() > 0 ) {
-				$jlf = new JobListFactory();
+				$jlf = TTnew( 'JobListFactory' );
 				$jlf->getById( $this->getJob() );
 				if ( $jlf->getRecordCount() > 0 ) {
 					$j_obj = $jlf->getCurrent();
@@ -1218,7 +1218,7 @@ class PunchControlFactory extends Factory {
 					$this->old_user_date_ids[] = $this->getOldUserDateID();
 
 					foreach( $shift_data['punch_control_ids'] as $punch_control_id ) {
-						$pclf = new PunchControlListFactory();
+						$pclf = TTnew( 'PunchControlListFactory' );
 						$pclf->getById( $punch_control_id );
 						if ( $pclf->getRecordCount() == 1 ) {
 							$pc_obj = $pclf->getCurrent();
@@ -1250,7 +1250,7 @@ class PunchControlFactory extends Factory {
 
 			//Add a row to the user date total table, as "worked" hours.
 			//Edit if it already exists and is not set as override.
-			$udtlf = new UserDateTotalListFactory();
+			$udtlf = TTnew( 'UserDateTotalListFactory' );
 			$udtlf->getByUserDateIdAndPunchControlId( $this->getUserDateID(), $this->getId() );
 			Debug::text(' Checking for Conflicting User Date Total Records, count: '. $udtlf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
 			if ( $udtlf->getRecordCount() > 0 ) {
@@ -1266,7 +1266,7 @@ class PunchControlFactory extends Factory {
 			Debug::text(' cFound Conflicting User Date Total Records, removing them before re-calc: PreMature: '. (int)$this->getEnablePreMatureException(), __FILE__, __LINE__, __METHOD__,10);
 			if ( $this->getDeleted() == FALSE ) {
 				Debug::text(' Calculating Total Time for day. Punch Control ID: '. $this->getId(), __FILE__, __LINE__, __METHOD__,10);
-				$udtf = new UserDateTotalFactory();
+				$udtf = TTnew( 'UserDateTotalFactory' );
 				$udtf->setUserDateID( $this->getUserDateID() );
 				$udtf->setPunchControlID( $this->getId() );
 				$udtf->setStatus( 20 ); //Worked
@@ -1296,11 +1296,14 @@ class PunchControlFactory extends Factory {
 	//This function handles when th UI wants to drag and drop punches around the time sheet.
 	//$action = 0 (Copy), 1 (Move)
 	//$position = -1 (Before), 0 (Overwrite), 1 (After)
-	static function dragNdropPunch( $company_id, $src_punch_id, $dst_punch_id, $position, $action = 0, $dst_date = NULL ) {
+	//$dst_status_id = 10 (In), 20 (Out), this is the status of the row the punch is being dragged too, or the resulting status_id in *most* (not all) cases.
+	//					It is really only needed when using the overwrite position setting, and dragging a punch to a blank cell. Other than that it can be left NULL.
+	static function dragNdropPunch( $company_id, $src_punch_id, $dst_punch_id, $dst_status_id = NULL, $position = 0, $action = 0, $dst_date = NULL ) {
 		/*
 			Operations to handle:
 				- Moving punch from Out to In, or In to Out in same punch pair, this is ALWAYS a move, and not a copy.
 				- Move punch from one pair to another in the same day, this can be a copy or move.
+					- Check moving AND copying Out punch from one punch pair to In in another on the same day. ie: In 8:00AM, Out 1:00PM, Out 5:00PM. Move the 1PM punch to pair with 5PM.
 				- Move punch from one day to another, inserting inbetween other punches if necessary.
 				- Move punch from one day to another without any other punches.
 
@@ -1313,12 +1316,12 @@ class PunchControlFactory extends Factory {
 				- If no dst_punch_id is specified, assume copying to a blank cell, just copy the punch to that date along with the punch_control?
 		*/
 		$dst_date = TTDate::getMiddleDayEpoch( $dst_date );
-		Debug::text('Src Punch ID: '. $src_punch_id .' Dst Punch ID: '. $dst_punch_id .' Position: '. $position .' Action: '. $action .' Dst Date: '. $dst_date, __FILE__, __LINE__, __METHOD__,10);
+		Debug::text('Src Punch ID: '. $src_punch_id .' Dst Punch ID: '. $dst_punch_id .' Dst Status ID: '. $dst_status_id .' Position: '. $position .' Action: '. $action .' Dst Date: '. $dst_date, __FILE__, __LINE__, __METHOD__,10);
 
 		$retval = FALSE;
 
 		//Get source and destination punch objects.
-		$plf = new PunchListFactory();
+		$plf = TTnew( 'PunchListFactory' );
 		$plf->StartTransaction();
 
 		$plf->getByCompanyIDAndId( $company_id, $src_punch_id );
@@ -1331,8 +1334,13 @@ class PunchControlFactory extends Factory {
 			//Especially if we are just moving a punch to fill a gap in the same day.
 			//If the punch being moved is in the same day, or within the same punch pair, we don't want to delete the source punch, instead we just modify
 			//the necessary bits later on. So we need to short circuit the move functionality when copying/moving punches within the same day.
-			if ( ( $action == 1 AND $src_punch_id != $dst_punch_id AND $src_punch_date != $dst_date )
-					OR ( $action == 0 AND $src_punch_id != $dst_punch_id AND $src_punch_date == $dst_date ) ) { //Move
+			if (
+					( $action == 1 AND $src_punch_id != $dst_punch_id AND $src_punch_date != $dst_date )
+					OR
+					( $action == 1 AND $src_punch_id != $dst_punch_id AND $src_punch_date == $dst_date )
+					//OR
+					//( $action == 0 AND $src_punch_id != $dst_punch_id AND $src_punch_date == $dst_date ) //Since we have dst_status_id, we don't need to force-move punches even though the user selected copy.
+				) { //Move
 				Debug::text('Deleting original punch...: '. $src_punch_id, __FILE__, __LINE__, __METHOD__,10);
 				$src_punch_obj->setUser( $src_punch_obj->getPunchControlObject()->getUserDateObject()->getUser() );
 				$src_punch_obj->setDeleted(TRUE);
@@ -1350,7 +1358,8 @@ class PunchControlFactory extends Factory {
 
 			if ( $src_punch_id == $dst_punch_id OR $dst_punch_id == '' ) {
 				//Assume we are just moving a punch within the same punch pair, unless a new date is specfied.
-				if ( $src_punch_date != $dst_date ) {
+				//However if we're simply splitting an existing punch pair, like dragging the Out punch from an In/Out pair into its own separate pair.
+				if ( $src_punch_date != $dst_date OR $src_punch_date == $dst_date AND $dst_punch_id == '' ) {
 					Debug::text('aCopying punch to new day...', __FILE__, __LINE__, __METHOD__,10);
 					//Moving punch to a new date.
 					//Copy source punch to proper location by destination punch.
@@ -1366,10 +1375,14 @@ class PunchControlFactory extends Factory {
 					$src_punch_obj->setTimeStamp( $new_time_stamp, FALSE );
 					$src_punch_obj->setActualTimeStamp( $new_time_stamp );
 					$src_punch_obj->setOriginalTimeStamp( $new_time_stamp );
+					if ( $dst_status_id != '' ) {
+						$src_punch_obj->setStatus( $dst_status_id ); //Change the status to fit in the proper place.
+					}
 					if ( $src_punch_obj->isValid() == TRUE ) {
-						$src_punch_obj->Save( FALSE );
+						$insert_id = $src_punch_obj->Save( FALSE );
 
 						$src_punch_control_obj->shift_data = NULL; //Need to clear the shift data so its obtained from the DB again, otherwise shifts will appear on strange days.
+						$src_punch_control_obj->user_date_obj = NULL; //Need to clear user_date_obj from cache so a new one is obtained.
 						$src_punch_control_obj->setId( $src_punch_obj->getPunchControlID() );
 						$src_punch_control_obj->setPunchObject( $src_punch_obj );
 
@@ -1386,8 +1399,10 @@ class PunchControlFactory extends Factory {
 							$src_punch_control_obj->setEnableCalcUserDateTotal( TRUE );
 							$src_punch_control_obj->setEnableCalcException( TRUE );
 							if ( $src_punch_control_obj->isValid() == TRUE ) {
-								if ( $src_punch_control_obj->Save( TRUE, TRUE ) == TRUE ) { //Force isNew() lookup.
-									$retval = TRUE;
+								if ( $src_punch_control_obj->Save( TRUE, TRUE ) == TRUE ) {
+									//Return newly inserted punch_id, so Flex can base other actions on it.
+									//$retval = TRUE;
+									$retval = $insert_id;
 								}
 							}
 						}
@@ -1398,8 +1413,9 @@ class PunchControlFactory extends Factory {
 					$src_punch_obj->setStatus( $src_punch_obj->getNextStatus() ); //Change just the punch status.
 					//$src_punch_obj->setDeleted(FALSE); //Just in case it was marked deleted by the MOVE action.
 					if ( $src_punch_obj->isValid() == TRUE ) {
-						$src_punch_obj->Save( FALSE );
-						$retval = TRUE;
+						//Return punch_id, so Flex can base other actions on it.
+						$retval = $src_punch_obj->Save( FALSE );
+						//$retval = TRUE;
 					}
 				}
 			} else {
@@ -1410,6 +1426,7 @@ class PunchControlFactory extends Factory {
 					$dst_punch_obj = $plf->getCurrent();
 					$dst_punch_control_obj = $dst_punch_obj->getPunchControlObject();
 
+					$is_punch_control_split = FALSE;
 					if ( $position == 0 ) { //Overwrite
 						//All we need to do is update the time of the destination punch.
 						$punch_obj = $dst_punch_obj;
@@ -1418,7 +1435,7 @@ class PunchControlFactory extends Factory {
 						if ( ( $position == -1 AND $dst_punch_obj->getStatus() == 20 )
 								OR ( $position == 1 AND $dst_punch_obj->getStatus() == 10 ) ) { //Before on Out punch, After on In Punch,
 							Debug::text('Need to split destination punch out to its own Punch Control row...', __FILE__, __LINE__, __METHOD__,10);
-							PunchControlFactory::splitPunchControl( $dst_punch_obj->getPunchControlID() );
+							$is_punch_control_split = PunchControlFactory::splitPunchControl( $dst_punch_obj->getPunchControlID() );
 
 							//Once a split occurs, we need to re-get the destination punch as the punch_control_id may have changed.
 							//We could probably optimize this to only occur when the destination punch is an In punch, as the
@@ -1434,6 +1451,7 @@ class PunchControlFactory extends Factory {
 							$punch_control_id = $dst_punch_obj->getPunchControlID();
 						} else {
 							Debug::text('No Need to split destination punch, simply add a new punch/punch_control all on its own.', __FILE__, __LINE__, __METHOD__,10);
+							//Check to see if the src and dst punches are the same status though.
 							$punch_control_id = (int)$dst_punch_control_obj->getNextInsertId();
 						}
 
@@ -1452,8 +1470,17 @@ class PunchControlFactory extends Factory {
 					$punch_obj->setTimeStamp( $new_time_stamp, FALSE );
 					$punch_obj->setActualTimeStamp( $new_time_stamp );
 					$punch_obj->setOriginalTimeStamp( $new_time_stamp );
+
+					//Need to take into account copying a Out punch and inserting it BEFORE another Out punch in a punch pair.
+					//In this case a split needs to occur, and the status needs to stay the same.
+					//Status also needs to stay the same when overwriting an existing punch.
+					Debug::text('Punch Status: '. $punch_obj->getStatus()  .' DST Punch Status: '. $dst_punch_obj->getStatus() .' Split Punch Control: '. (int)$is_punch_control_split , __FILE__, __LINE__, __METHOD__,10);
+					if ( ( $position != 0 AND $is_punch_control_split == FALSE AND $punch_obj->getStatus() == $dst_punch_obj->getStatus() AND $punch_obj->getPunchControlID() == $dst_punch_obj->getPunchControlID() ) ) {
+						Debug::text('Changing punch status to opposite: '. $dst_punch_obj->getNextStatus(), __FILE__, __LINE__, __METHOD__,10);
+						$punch_obj->setStatus( $dst_punch_obj->getNextStatus() ); //Change the status to fit in the proper place.
+					}
 					if ( $punch_obj->isValid() == TRUE ) {
-						$punch_obj->Save( FALSE );
+						$insert_id = $punch_obj->Save( FALSE );
 
 						$dst_punch_control_obj->shift_data = NULL; //Need to clear the shift data so its obtained from the DB again, otherwise shifts will appear on strange days, or cause strange conflicts.
 						$dst_punch_control_obj->setID( $punch_obj->getPunchControlID() );
@@ -1473,7 +1500,9 @@ class PunchControlFactory extends Factory {
 							$dst_punch_control_obj->setEnableCalcException( TRUE );
 							if ( $dst_punch_control_obj->isValid() == TRUE ) {
 								if ( $dst_punch_control_obj->Save( TRUE, TRUE ) == TRUE ) { //Force isNew() lookup.
-									$retval = TRUE;
+									//Return newly inserted punch_id, so Flex can base other actions on it.
+									$retval = $insert_id;
+									//$retval = TRUE;
 								}
 							}
 						}
@@ -1494,12 +1523,13 @@ class PunchControlFactory extends Factory {
 
 	//When passed a punch_control_id, if it has two punches assigned to it, a new punch_control_id row is created and the punches are split between the two.
 	static function splitPunchControl( $punch_control_id ) {
+		$retval = FALSE;
 		if ( $punch_control_id != '' ) {
-			$plf = new PunchListFactory();
+			$plf = TTnew( 'PunchListFactory' );
 			$plf->StartTransaction();
 			$plf->getByPunchControlID( $punch_control_id, NULL, array( 'time_stamp' => 'desc' ) ); //Move out punch to new punch_control_id.
 			if ( $plf->getRecordCount() == 2 ) {
-				$pclf = new PunchControlListFactory();
+				$pclf = TTnew( 'PunchControlListFactory' );
 				$new_punch_control_id = (int)$pclf->getNextInsertId();
 				Debug::text(' Punch Control ID: '. $punch_control_id .' only has two punches assigned, splitting... New Punch Control ID: '. $new_punch_control_id, __FILE__, __LINE__, __METHOD__,10);
 				$i = 0;
@@ -1528,7 +1558,7 @@ class PunchControlFactory extends Factory {
 								$pc_obj->setEnableCalcWeeklySystemTotalTime( FALSE ); //Do this for In punch only.
 								$pc_obj->setEnableCalcUserDateTotal( TRUE );
 								$pc_obj->setEnableCalcException( TRUE );
-								$pc_obj->Save( TRUE, TRUE ); //Force isNew() lookup.
+								$retval = $pc_obj->Save( TRUE, TRUE ); //Force isNew() lookup.
 							}
 						}
 					} else {
@@ -1543,7 +1573,7 @@ class PunchControlFactory extends Factory {
 						$pc_obj->setEnableCalcWeeklySystemTotalTime( TRUE );
 						$pc_obj->setEnableCalcUserDateTotal( TRUE );
 						$pc_obj->setEnableCalcException( TRUE );
-						$pc_obj->Save();
+						$retval = $pc_obj->Save();
 					}
 
 					$i++;
@@ -1556,7 +1586,7 @@ class PunchControlFactory extends Factory {
 			$plf->CommitTransaction();
 		}
 
-		return FALSE;
+		return $retval;
 	}
 
 	function postSave() {
@@ -1604,7 +1634,7 @@ class PunchControlFactory extends Factory {
 		return FALSE;
 	}
 
-	function getObjectAsArray( $include_columns = NULL ) {
+	function getObjectAsArray( $include_columns = NULL, $permission_children_ids = FALSE  ) {
 		$variable_function_map = $this->getVariableToFunctionMap();
 		if ( is_array( $variable_function_map ) ) {
 			foreach( $variable_function_map as $variable => $function_stub ) {
@@ -1623,6 +1653,7 @@ class PunchControlFactory extends Factory {
 
 				}
 			}
+			$this->getPermissionColumns( &$data, $this->getColumn( 'user_id' ), $this->getCreatedBy(), $permission_children_ids, $include_columns );
 			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
 		}
 
