@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: PunchFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4845 $
+ * $Id: PunchFactory.class.php 4845 2011-06-21 16:23:18Z ipso $
+ * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
  */
 
 /**
@@ -99,6 +99,9 @@ class PunchFactory extends Factory {
 										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
 							);
 				break;
+			case 'list_columns':
+				$retval = Misc::arrayIntersectByKey( $this->getOptions('default_display_columns'), Misc::trimSortPrefix( $this->getOptions('columns') ) );
+				break;
 			case 'default_display_columns': //Columns that are displayed by default.
 				$retval = array(
 								'first_name',
@@ -139,7 +142,14 @@ class PunchFactory extends Factory {
 											'actual_time_stamp' => 'ActualTimeStamp',
 											'original_time_stamp' => 'OriginalTimeStamp',
 											'schedule_id' => 'ScheduleID',
+
 											'station_id' => 'Station',
+											'station_station_id' => FALSE,
+											'station_type_id' => FALSE,
+											'station_type' => FALSE,
+											'station_source' => FALSE,
+											'station_description' => FALSE,
+
 											'longitude' => 'Longitude',
 											'latitude' => 'Latitude',
 
@@ -183,7 +193,7 @@ class PunchFactory extends Factory {
 			return $this->punch_control_obj;
 		} else {
 			if ( $this->getPunchControlID() !== FALSE ) {
-				$pclf = new PunchControlListFactory();
+				$pclf = TTnew( 'PunchControlListFactory' );
 				$this->punch_control_obj = $pclf->getById( $this->getPunchControlID() )->getCurrent();
 
 				return $this->punch_control_obj;
@@ -197,7 +207,7 @@ class PunchFactory extends Factory {
 		if ( is_object($this->schedule_policy_obj) ) {
 			return $this->schedule_policy_obj;
 		} else {
-			$splf = new SchedulePolicyListFactory();
+			$splf = TTnew( 'SchedulePolicyListFactory' );
 			$splf->getById( $this->getScheduleObject()->getSchedulePolicyID() );
 			if ( $splf->getRecordCount() > 0 ) {
 				$this->schedule_policy_obj = $splf->getCurrent();
@@ -213,7 +223,7 @@ class PunchFactory extends Factory {
 			return $this->schedule_obj;
 		} else {
 			if ( $this->getScheduleID() !== FALSE ) {
-				$slf = new ScheduleListFactory();
+				$slf = TTnew( 'ScheduleListFactory' );
 				$slf->getById( $this->getScheduleID() );
 				if ( $slf->getRecordCount() > 0 ) {
 					$this->schedule_obj = $slf->getCurrent();
@@ -253,7 +263,7 @@ class PunchFactory extends Factory {
 		if ( $this->getPunchControlID() != FALSE ) {
 			$retval = $this->getPunchControlID();
 		} else {
-			$pclf = new PunchControlListFactory();
+			$pclf = TTnew( 'PunchControlListFactory' );
 			Debug::Text('Checking for incomplete punch control... User: '. $this->getUser() .' TimeStamp: '. $this->getTimeStamp() .' Status: '. $this->getStatus(), __FILE__, __LINE__, __METHOD__,10);
 
 			//Need to make sure the punch is rounded before we can get the proper punch_control_id. However
@@ -278,7 +288,7 @@ class PunchFactory extends Factory {
 	function setPunchControlID($id) {
 		$id = trim($id);
 
-		$pclf = new PunchControlListFactory();
+		$pclf = TTnew( 'PunchControlListFactory' );
 
 		//Can't check to make sure the PunchControl row exists, as it may be inserted later. So just
 		//make sure its an non-zero INT.
@@ -412,7 +422,7 @@ class PunchFactory extends Factory {
 	function setStation($id) {
 		$id = trim($id);
 
-		$slf = new StationListFactory();
+		$slf = TTnew( 'StationListFactory' );
 /*
 		if (	$id == 0
 				OR
@@ -433,10 +443,10 @@ class PunchFactory extends Factory {
 		$original_epoch = $epoch;
 
 		Debug::text(' Rounding Timestamp: '. TTDate::getDate('DATE+TIME', $epoch ) .' Status ID: '. $this->getStatus() .' Type ID: '. $this->getType() , __FILE__, __LINE__, __METHOD__,10);
-		
+
 		//Punch control is no longer used for rounding.
 		//Check for rounding policies.
-		$riplf = new RoundIntervalPolicyListFactory();
+		$riplf = TTnew( 'RoundIntervalPolicyListFactory' );
 		$type_id = $riplf->getPunchTypeFromPunchStatusAndType( $this->getStatus(), $this->getType() );
 
 		Debug::text(' Round Interval Punch Type: '. $type_id .' User: '. $this->getUser(), __FILE__, __LINE__, __METHOD__,10);
@@ -456,7 +466,7 @@ class PunchFactory extends Factory {
 					//If strict is set, round to scheduled lunch time?
 					//Find Lunch Punch In.
 
-					$plf = new PunchListFactory();
+					$plf = TTnew( 'PunchListFactory' );
 					//$plf->getPreviousPunchByUserDateIdAndStatusAndTypeAndEpoch( $this->getPunchControlObject()->getUserDateID(), 20, 20, $epoch );
 					$plf->getPreviousPunchByUserIdAndStatusAndTypeAndEpoch( $this->getUser(), 20, 20, $epoch );
 					if ( $plf->getRecordCount() == 1 ) {
@@ -516,7 +526,7 @@ class PunchFactory extends Factory {
 					//If strict is set, round to scheduled break time?
 					//Find break Punch In.
 
-					$plf = new PunchListFactory();
+					$plf = TTnew( 'PunchListFactory' );
 					//$plf->getPreviousPunchByUserDateIdAndStatusAndTypeAndEpoch( $this->getPunchControlObject()->getUserDateID(), 20, 30, $epoch );
 					$plf->getPreviousPunchByUserIdAndStatusAndTypeAndEpoch( $this->getUser(), 20, 30, $epoch );
 					if ( $plf->getRecordCount() == 1 ) {
@@ -575,13 +585,13 @@ class PunchFactory extends Factory {
 
 					//If strict is set, round to scheduled time?
 
-					$plf = new PunchListFactory();
+					$plf = TTnew( 'PunchListFactory' );
 					$plf->getPreviousPunchByUserIdAndEpochAndNotPunchIDAndMaximumShiftTime( $this->getUser(), $epoch, $this->getId() );
 					if ( $plf->getRecordCount() == 1 ) {
 						Debug::text('Found Previous Punch In: '. TTDate::getDate('DATE+TIME', $plf->getCurrent()->getTimeStamp() ), __FILE__, __LINE__, __METHOD__,10);
 
 						//Get day total time prior to this punch control.
-						$pclf = new PunchControlListFactory();
+						$pclf = TTnew( 'PunchControlListFactory' );
 						$pclf->getByUserDateId( $plf->getCurrent()->getPunchControlObject()->getUserDateID() );
 						if ( $pclf->getRecordCount() > 0 ) {
 							$day_total_time = $epoch - $plf->getCurrent()->getTimeStamp();
@@ -894,7 +904,7 @@ class PunchFactory extends Factory {
 		//We need to make sure we get schedules within about a 24hr
 		//window of this punch, because if punch is at 11:55AM and the schedule starts at 12:30AM it won't
 		//be found by a user_date_id.
-		$slf = new ScheduleListFactory();
+		$slf = TTnew( 'ScheduleListFactory' );
 		$slf->getByUserIdAndStartDateAndEndDate( $user_id, ($epoch-43200), ($epoch+43200) );
 		if ( $slf->getRecordCount() > 0 ) {
 			//Check for schedule policy
@@ -1106,7 +1116,7 @@ class PunchFactory extends Factory {
 		} else {
 			//Make sure prev punch is a Lunch Out Punch
 			//Check NON-scheduled meal policies
-			$mplf = new MealPolicyListFactory();
+			$mplf = TTnew( 'MealPolicyListFactory' );
 			$mplf->getByPolicyGroupUserId( $this->getUser() );
 			if ( $mplf->getRecordCount() > 0 ) {
 				$mp_obj = $mplf->getCurrent();
@@ -1185,7 +1195,7 @@ class PunchFactory extends Factory {
 		} else {
 			//Make sure prev punch is a Break Out Punch
 			//Check NON-scheduled break policies
-			$bplf = new BreakPolicyListFactory();
+			$bplf = TTnew( 'BreakPolicyListFactory' );
 			$bplf->getByPolicyGroupUserId( $this->getUser() );
 			if ( $bplf->getRecordCount() > 0 ) {
 				$bp_objs[] = $bplf->getCurrent();
@@ -1259,7 +1269,7 @@ class PunchFactory extends Factory {
 				Debug::text(' Transfer is Enabled, automatic punch out of last punch pair: ', __FILE__, __LINE__, __METHOD__,10);
 
 				//Check to make sure there is an open punch pair.
-				$plf = new PunchListFactory();
+				$plf = TTnew( 'PunchListFactory' );
 				$plf->getPreviousPunchByUserIdAndEpoch( $this->getUser(), $this->getTimeStamp() );
 				if ( $plf->getRecordCount() > 0 ) {
 					$p_obj = $plf->getCurrent();
@@ -1271,7 +1281,7 @@ class PunchFactory extends Factory {
 						$this->setStatus(10); //In
 						$this->setType(10); //Normal (can't transfer in/out of lunches?)
 
-						$pf = new PunchFactory();
+						$pf = TTnew( 'PunchFactory' );
 						$pf->setUser( $this->getUser() );
 						$pf->setEnableAutoTransfer( FALSE );
 						$pf->setPunchControlID( $p_obj->getPunchControlID() );
@@ -1320,7 +1330,7 @@ class PunchFactory extends Factory {
 							AND is_object( $this->getPunchControlObject()->getPayPeriodScheduleObject() )
 							AND $this->getPunchControlObject()->getPayPeriodScheduleObject()->getShiftAssignedDay() == 40 ) ) {
 
-				$plf = new PunchListFactory();
+				$plf = TTnew( 'PunchListFactory' );
 				$plf->getPreviousPunchByUserIdAndEpoch( $this->getUser(), $this->getTimeStamp() );
 				if ( $plf->getRecordCount() > 0 ) {
 					$p_obj = $plf->getCurrent();
@@ -1349,7 +1359,7 @@ class PunchFactory extends Factory {
 						//The issue with this is that if rounding is enabled this will ignore it, and the shift for this day may total: 3.98hrs.
 						//when they want it to total 4.00hrs. Why don't we split shifts at exactly midnight with no gap at all?
 						//Split shifts right at midnight causes additional issues when editing those punches, TimeTrex will want to combine them on the same day again.
-						$pf = new PunchFactory();
+						$pf = TTnew( 'PunchFactory' );
 						$pf->setUser( $this->getUser() );
 						$pf->setEnableSplitAtMidnight( FALSE );
 						$pf->setTransfer( FALSE );
@@ -1358,7 +1368,8 @@ class PunchFactory extends Factory {
 						$pf->setType( 10 ); //Normal
 						$pf->setStatus( 20 ); //Out
 
-						$before_midnight_timestamp = (TTDate::getBeginDayEpoch( $this->getTimeStamp() )-60);
+						//We used to have to make this punch 60seconds before midnight, but getShiftData() was modified to support punch at exactly midnight.
+						$before_midnight_timestamp = (TTDate::getBeginDayEpoch( $this->getTimeStamp() ) );
 						$pf->setTimeStamp( $before_midnight_timestamp, FALSE ); //Disable rounding.
 
 						$pf->setActualTimeStamp( $before_midnight_timestamp );
@@ -1384,7 +1395,7 @@ class PunchFactory extends Factory {
 						//
 						//Punch in again right at midnight.
 						//
-						$pf = new PunchFactory();
+						$pf = TTnew( 'PunchFactory' );
 						$pf->setUser( $this->getUser() );
 						$pf->setEnableSplitAtMidnight( FALSE );
 						$pf->setTransfer( FALSE );
@@ -1402,7 +1413,7 @@ class PunchFactory extends Factory {
 						$pf->setPunchControlID( $new_punch_control_id );
 						if ( $pf->isValid() ) {
 							if ( $pf->Save( FALSE ) == TRUE ) {
-								$pcf = new PunchControlFactory();
+								$pcf = TTnew( 'PunchControlFactory' );
 								$pcf->setId( $pf->getPunchControlID() );
 								$pcf->setPunchObject( $pf );
 
@@ -1444,7 +1455,7 @@ class PunchFactory extends Factory {
 	function postSave() {
 
 		if ( $this->getDeleted() == TRUE ) {
-			$plf = new PunchListFactory();
+			$plf = TTnew( 'PunchListFactory' );
 			$plf->getByPunchControlId( $this->getPunchControlID() );
 			if ( $plf->getRecordCount() == 0 ) {
 				//Check to see if any other punches are assigned to this punch_control_id
@@ -1623,8 +1634,9 @@ class PunchFactory extends Factory {
 		return FALSE;
 	}
 
-	function getObjectAsArray( $include_columns = NULL ) {
-		$uf = new UserFactory();
+	function getObjectAsArray( $include_columns = NULL, $permission_children_ids = FALSE ) {
+		$uf = TTnew( 'UserFactory' );
+		$sf = TTnew('StationFactory');
 
 		$variable_function_map = $this->getVariableToFunctionMap();
 		if ( is_array( $variable_function_map ) ) {
@@ -1659,6 +1671,10 @@ class PunchFactory extends Factory {
 						case 'user_date_id':
 						case 'meal_policy_id':
 						case 'note':
+						case 'station_type_id':
+						case 'station_station_id':
+						case 'station_source':
+						case 'station_description':
 							$data[$variable] = $this->getColumn( $variable );
 							break;
 						case 'status':
@@ -1687,15 +1703,18 @@ class PunchFactory extends Factory {
 						case 'actual_time_stamp':
 							$data[$variable] = TTDate::getAPIDate( 'DATE+TIME', TTDate::strtotime( $this->getColumn( 'actual_time_stamp' ) ) );
 							break;
+						case 'station_type':
+							$data[$variable] = Option::getByKey( $this->getColumn( 'station_type_id' ), $sf->getOptions( 'type' ) );
+							break;
 						default:
 							if ( method_exists( $this, $function ) ) {
 								$data[$variable] = $this->$function();
 							}
 							break;
 					}
-
 				}
 			}
+			$this->getPermissionColumns( &$data, $this->getColumn( 'user_id' ), $this->getCreatedBy(), $permission_children_ids, $include_columns );
 			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
 		}
 
