@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: PunchListFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4845 $
+ * $Id: PunchListFactory.class.php 4845 2011-06-21 16:23:18Z ipso $
+ * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
  */
 
 /**
@@ -1473,6 +1473,7 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
 			$query .= ',
 						x.name as job_name,
+						x.description as job_description,
 						x.status_id as job_status_id,
 						x.manual_id as job_manual_id,
 						x.branch_id as job_branch_id,
@@ -1592,6 +1593,510 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 		return $this;
 	}
 
+	function getPunchSummaryReportByCompanyIdAndArrayCriteria( $company_id, $filter_data, $limit = NULL, $page = NULL, $where = NULL, $order = NULL) {
+
+		//$order = array( 'b.pay_period_id' => 'asc', 'b.user_id' => 'asc' );
+		//$order = array( 'b.pay_period_id' => 'asc','uf.last_name' => 'asc', 'b.date_stamp' => 'asc' );
+		/*
+		if ( $order == NULL ) {
+			$order = array( 'b.pay_period_id' => 'asc', 'b.user_id' => 'asc' );
+			$strict = FALSE;
+		} else {
+			$strict = TRUE;
+		}
+		*/
+
+		if ( isset($filter_data['punch_branch_ids']) ) {
+			$filter_data['punch_branch_id'] = $filter_data['punch_branch_ids'];
+		}
+		if ( isset($filter_data['punch_department_ids']) ) {
+			$filter_data['punch_department_id'] = $filter_data['punch_department_ids'];
+		}
+
+		if ( isset($filter_data['branch_ids']) ) {
+			$filter_data['branch_id'] = $filter_data['branch_ids'];
+		}
+		if ( isset($filter_data['department_ids']) ) {
+			$filter_data['department_id'] = $filter_data['department_ids'];
+		}
+
+		$uf = new UserFactory();
+		$udf = new UserDateFactory();
+		$bf = new BranchFactory();
+		$df = new DepartmentFactory();
+		$ppf_b = new PayPeriodFactory();
+		$uwf = new UserWageFactory();
+		$pcf = new PunchControlFactory();
+		$pf = new PunchFactory();
+		$sf = new StationFactory();
+
+		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
+			$jf = new JobFactory();
+			$jif = new JobItemFactory();
+		}
+
+		$ph = array( 'company_id' => $company_id );
+
+		//Make it so employees with 0 hours still show up!! Very important!
+		//Order dock hours first, so it can be deducted from regular time.
+		$query = '
+					select
+							a.id as punch_id,
+							a.punch_control_id as punch_control_id,
+							a.type_id as type_id,
+							a.status_id as status_id,
+							a.time_stamp as punch_time_stamp,
+							a.actual_time_stamp as punch_actual_time_stamp,
+
+							pcf.user_date_id as user_date_id,
+							pcf.branch_id as branch_id,
+							pcf.department_id as department_id,
+							pcf.job_id as job_id,
+							pcf.job_item_id as job_item_id,
+							pcf.quantity as quantity_id,
+							pcf.bad_quantity as bad_quantity_id,
+							pcf.total_time as total_time,
+							pcf.actual_total_time as actual_total_time,
+							pcf.meal_policy_id as meal_policy_id,
+							pcf.other_id1 as other_id1,
+							pcf.other_id2 as other_id2,
+							pcf.other_id3 as other_id3,
+							pcf.other_id4 as other_id4,
+							pcf.other_id5 as other_id5,
+							pcf.note as note,
+
+							b.user_id as user_id,
+							b.date_stamp as date_stamp,
+							b.pay_period_id as pay_period_id,
+							ppf.id as pay_period_id,
+							ppf.start_date as pay_period_start_date,
+							ppf.end_date as pay_period_end_date,
+							ppf.transaction_date as pay_period_transaction_date,
+
+							bf.name as branch,
+							df.name as department,
+							a.status_id as status_id,
+							a.type_id as type_id,
+
+							z.id as user_wage_id,
+							z.effective_date as user_wage_effective_date,
+							z.hourly_rate as hourly_rate,
+
+							sf.type_id as station_type_id,
+							sf.station_id as station_station_id,
+							sf.source as station_source,
+							sf.description as station_description
+
+					from	'. $this->getTable() .' as a
+					LEFT JOIN '. $pcf->getTable() .' as pcf ON a.punch_control_id = pcf.id
+					LEFT JOIN '. $udf->getTable() .' as b ON pcf.user_date_id = b.id
+					LEFT JOIN '. $ppf_b->getTable() .' as ppf ON b.pay_period_id = ppf.id
+					LEFT JOIN '. $uf->getTable() .' as uf ON b.user_id = uf.id
+
+					LEFT JOIN '. $bf->getTable() .' as bf ON pcf.branch_id = bf.id
+					LEFT JOIN '. $df->getTable() .' as df ON pcf.department_id = df.id
+
+					LEFT JOIN '. $sf->getTable() .' as sf ON a.station_id = sf.id
+
+					LEFT JOIN '. $uwf->getTable() .' as z ON z.id = (select z.id
+																		from '. $uwf->getTable() .' as z
+																		where z.user_id = b.user_id
+																			and z.effective_date <= b.date_stamp
+																			and z.wage_group_id = 0
+																			and z.deleted = 0
+																			order by z.effective_date desc limit 1)
+					where 	uf.company_id = ? ';
+
+		if ( isset($filter_data['permission_children_ids']) AND isset($filter_data['permission_children_ids'][0]) AND !in_array(-1, (array)$filter_data['permission_children_ids']) ) {
+			$query  .=	' AND uf.id in ('. $this->getListSQL($filter_data['permission_children_ids'], $ph) .') ';
+		}
+		if ( isset($filter_data['include_user_id']) AND isset($filter_data['include_user_id'][0]) AND !in_array(-1, (array)$filter_data['include_user_id']) ) {
+			$query  .=	' AND uf.id in ('. $this->getListSQL($filter_data['include_user_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['exclude_user_id']) AND isset($filter_data['exclude_user_id'][0]) AND !in_array(-1, (array)$filter_data['exclude_user_id']) ) {
+			$query  .=	' AND uf.id not in ('. $this->getListSQL($filter_data['exclude_user_id'], $ph) .') ';
+		}
+
+		if ( isset($filter_data['user_status_id']) AND isset($filter_data['user_status_id'][0]) AND !in_array(-1, (array)$filter_data['user_status_id']) ) {
+			$query  .=	' AND uf.status_id in ('. $this->getListSQL($filter_data['user_status_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['user_group_id']) AND isset($filter_data['user_group_id'][0]) AND !in_array(-1, (array)$filter_data['user_group_id']) ) {
+			if ( isset($filter_data['include_user_subgroups']) AND (bool)$filter_data['include_user_subgroups'] == TRUE ) {
+				$uglf = new UserGroupListFactory();
+				$filter_data['user_group_id'] = $uglf->getByCompanyIdAndGroupIdAndSubGroupsArray( $company_id, $filter_data['user_group_id'], TRUE);
+			}
+			$query  .=	' AND uf.group_id in ('. $this->getListSQL($filter_data['user_group_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['default_branch_id']) AND isset($filter_data['default_branch_id'][0]) AND !in_array(-1, (array)$filter_data['default_branch_id']) ) {
+			$query  .=	' AND uf.default_branch_id in ('. $this->getListSQL($filter_data['default_branch_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['default_department_id']) AND isset($filter_data['default_department_id'][0]) AND !in_array(-1, (array)$filter_data['default_department_id']) ) {
+			$query  .=	' AND uf.default_department_id in ('. $this->getListSQL($filter_data['default_department_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['user_title_id']) AND isset($filter_data['user_title_id'][0]) AND !in_array(-1, (array)$filter_data['user_title_id']) ) {
+			$query  .=	' AND uf.title_id in ('. $this->getListSQL($filter_data['user_title_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['punch_branch_id']) AND isset($filter_data['punch_branch_id'][0]) AND !in_array(-1, (array)$filter_data['punch_branch_id']) ) {
+			$query  .=	' AND a.branch_id in ('. $this->getListSQL($filter_data['punch_branch_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['punch_department_id']) AND isset($filter_data['punch_department_id'][0]) AND !in_array(-1, (array)$filter_data['punch_department_id']) ) {
+			$query  .=	' AND a.department_id in ('. $this->getListSQL($filter_data['punch_department_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['pay_period_id']) AND isset($filter_data['pay_period_id'][0]) AND !in_array(-1, (array)$filter_data['pay_period_id']) ) {
+			$query .= 	' AND b.pay_period_id in ('. $this->getListSQL($filter_data['pay_period_id'], $ph) .') ';
+		}
+
+		if ( isset($filter_data['start_date']) AND trim($filter_data['start_date']) != '' ) {
+			$ph[] = $this->db->BindDate($filter_data['start_date']);
+			$query  .=	' AND b.date_stamp >= ?';
+		}
+		if ( isset($filter_data['end_date']) AND trim($filter_data['end_date']) != '' ) {
+			$ph[] = $this->db->BindDate($filter_data['end_date']);
+			$query  .=	' AND b.date_stamp <= ?';
+		}
+
+		$query .= '
+						AND ( a.deleted = 0 AND b.deleted = 0 AND pcf.deleted = 0 )
+					';
+
+		$query .= $this->getSortSQL( $order, FALSE );
+		$this->rs = $this->db->Execute($query, $ph);
+
+		return $this;
+	}
+
+	function getAPIActiveShiftReportByCompanyIdAndArrayCriteria( $company_id, $filter_data, $limit = NULL, $page = NULL, $where = NULL, $order = NULL ) {
+		if ( $company_id == '') {
+			return FALSE;
+		}
+
+		if ( !is_array($order) ) {
+			//Use Filter Data ordering if its set.
+			if ( isset($filter_data['sort_column']) AND $filter_data['sort_order']) {
+				$order = array(Misc::trimSortPrefix($filter_data['sort_column']) => $filter_data['sort_order']);
+			}
+		}
+
+		if ( !is_array($order) ) {
+			//Use Filter Data ordering if its set.
+			if ( isset($filter_data['sort_column']) AND $filter_data['sort_order']) {
+				$order = array(Misc::trimSortPrefix($filter_data['sort_column']) => $filter_data['sort_order']);
+			}
+		}
+
+		//$additional_order_fields = array('b.name', 'c.name', 'd.name', 'e.name');
+		$additional_order_fields = array('first_name', 'last_name', 'date_stamp','time_stamp','type_id','status_id','branch','department','default_branch','default_department','group','title');
+
+		$sort_column_aliases = array(
+									 'status' => 'status_id',
+									 'type' => 'type_id',
+									 );
+
+		$order = $this->getColumnsFromAliases( $order, $sort_column_aliases );
+
+		if ( $order == NULL ) {
+			$order = array( 'c.pay_period_id' => 'asc','c.user_id' => 'asc', 'a.time_stamp' => 'asc', 'a.punch_control_id' => 'asc', 'a.status_id' => 'asc' );
+			$strict = FALSE;
+		} else {
+			$strict = FALSE;
+		}
+		//Debug::Arr($order,'Order Data:', __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Arr($filter_data,'Filter Data:', __FILE__, __LINE__, __METHOD__,10);
+
+		if ( isset($filter_data['exclude_user_ids']) ) {
+			$filter_data['exclude_id'] = $filter_data['exclude_user_ids'];
+		}
+/*
+		if ( isset($filter_data['user_id']) ) {
+			$filter_data['id'] = $filter_data['user_id'];
+		}
+		if ( isset($filter_data['include_user_ids']) ) {
+			$filter_data['id'] = $filter_data['include_user_ids'];
+		}
+*/
+		if ( isset($filter_data['user_status_ids']) ) {
+			$filter_data['status_id'] = $filter_data['user_status_ids'];
+		}
+		if ( isset($filter_data['user_title_ids']) ) {
+			$filter_data['title_id'] = $filter_data['user_title_ids'];
+		}
+		if ( isset($filter_data['group_ids']) ) {
+			$filter_data['group_id'] = $filter_data['group_ids'];
+		}
+		if ( isset($filter_data['branch_ids']) ) {
+			$filter_data['default_branch_id'] = $filter_data['branch_ids'];
+		}
+		if ( isset($filter_data['department_ids']) ) {
+			$filter_data['default_department_id'] = $filter_data['department_ids'];
+		}
+		if ( isset($filter_data['punch_branch_ids']) ) {
+			$filter_data['punch_branch_id'] = $filter_data['punch_branch_ids'];
+		}
+		if ( isset($filter_data['punch_department_ids']) ) {
+			$filter_data['punch_department_id'] = $filter_data['punch_department_ids'];
+		}
+/*
+		if ( isset($filter_data['exclude_job_ids']) ) {
+			$filter_data['exclude_id'] = $filter_data['exclude_job_ids'];
+		}
+		if ( isset($filter_data['include_job_ids']) ) {
+			$filter_data['include_job_id'] = $filter_data['include_job_ids'];
+		}
+		if ( isset($filter_data['job_group_ids']) ) {
+			$filter_data['job_group_id'] = $filter_data['job_group_ids'];
+		}
+		if ( isset($filter_data['job_item_ids']) ) {
+			$filter_data['job_item_id'] = $filter_data['job_item_ids'];
+		}
+*/
+		$uf = new UserFactory();
+		$udf = new UserDateFactory();
+		$pcf = new PunchControlFactory();
+		$uwf = new UserWageFactory();
+		$sf = new StationFactory();
+		$bf = new BranchFactory();
+		$df = new DepartmentFactory();
+		$ugf = new UserGroupFactory();
+		$utf = new UserTitleFactory();
+
+		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
+			$jf = new JobFactory();
+			$jif = new JobItemFactory();
+		}
+
+		$ph = array(
+					'company_id' => $company_id,
+					);
+
+		$query = '
+					select
+							a.id as id,
+							a.punch_control_id as punch_control_id,
+							a.type_id as type_id,
+							a.status_id as status_id,
+							a.time_stamp as time_stamp,
+							a.actual_time_stamp as actual_time_stamp,
+							a.original_time_stamp as original_time_stamp,
+
+							a.created_by as created_by,
+							a.created_date as created_date,
+							a.updated_by as updated_by,
+							a.updated_date as updated_date,
+
+							b.user_date_id as user_date_id,
+							b.branch_id as branch_id,
+							j.name as branch,
+							b.department_id as department_id,
+							k.name as department,
+							b.job_id as job_id,
+							r.name as job,
+							b.job_item_id as job_item_id,
+							s.name as job_item,
+							b.quantity as quantity_id,
+							b.bad_quantity as bad_quantity_id,
+							b.total_time as total_time,
+							b.actual_total_time as actual_total_time,
+							b.meal_policy_id as meal_policy_id,
+							b.other_id1 as other_id1,
+							b.other_id2 as other_id2,
+							b.other_id3 as other_id3,
+							b.other_id4 as other_id4,
+							b.other_id5 as other_id5,
+							b.note as note,
+
+							c.user_id as user_id,
+							c.date_stamp as date_stamp,
+							c.pay_period_id as pay_period_id,
+
+							d.first_name as first_name,
+							d.last_name as last_name,
+							d.status_id as user_status_id,
+							d.group_id as group_id,
+							g.name as group,
+							d.title_id as title_id,
+							h.name as title,
+							d.default_branch_id as default_branch_id,
+							e.name as default_branch,
+							d.default_department_id as default_department_id,
+							f.name as default_department,
+							d.created_by as user_created_by,
+
+							l.type_id as station_type_id,
+							l.station_id as station_station_id,
+							l.source as station_source,
+							l.description as station_description,
+
+							w.id as user_wage_id,
+							w.effective_date as user_wage_effective_date,
+
+							y.first_name as created_by_first_name,
+							y.middle_name as created_by_middle_name,
+							y.last_name as created_by_last_name,
+							z.first_name as updated_by_first_name,
+							z.middle_name as updated_by_middle_name,
+							z.last_name as updated_by_last_name
+							';
+
+		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
+			$query .= ',
+						r.name as job_name,
+						r.status_id as job_status_id,
+						r.manual_id as job_manual_id,
+						r.branch_id as job_branch_id,
+						r.department_id as job_department_id,
+						r.group_id as job_group_id';
+		}
+
+		$query .= '
+					from 	(
+								select tmp2_d.id, max(tmp2_a.id) as punch_id, max(tmp2_a.time_stamp) as max_punch_time_stamp
+								from 	'. $this->getTable() .' as tmp2_a
+								LEFT JOIN '. $pcf->getTable() .' as tmp2_b ON tmp2_a.punch_control_id = tmp2_b.id
+								LEFT JOIN '. $udf->getTable() .' as tmp2_c ON tmp2_b.user_date_id = tmp2_c.id
+								LEFT JOIN '. $uf->getTable() .' as tmp2_d ON tmp2_c.user_id = tmp2_d.id
+								WHERE tmp2_d.company_id = ?';
+
+								if ( isset($filter_data['start_date']) AND trim($filter_data['start_date']) != '' ) {
+									$ph[] = $this->db->BindDate($filter_data['start_date']);
+									$query  .=	' AND tmp2_c.date_stamp >= ?';
+								}
+								if ( isset($filter_data['end_date']) AND trim($filter_data['end_date']) != '' ) {
+									$ph[] = $this->db->BindDate($filter_data['end_date']);
+									$query  .=	' AND tmp2_c.date_stamp <= ?';
+								}
+
+								$query .= '
+									AND tmp2_a.time_stamp is not null
+									AND ( tmp2_a.deleted = 0 AND tmp2_b.deleted = 0 AND tmp2_c.deleted = 0 )
+								group by tmp2_d.id
+							) as tmp_a
+							LEFT JOIN '. $this->getTable() .' as a ON tmp_a.punch_id = a.id
+							LEFT JOIN '. $pcf->getTable() .' as b ON a.punch_control_id = b.id
+							LEFT JOIN '. $udf->getTable() .' as c ON b.user_date_id = c.id
+							LEFT JOIN '. $uf->getTable() .' as d ON c.user_id = d.id
+
+							LEFT JOIN '. $bf->getTable() .' as e ON ( d.default_branch_id = e.id AND e.deleted = 0)
+							LEFT JOIN '. $df->getTable() .' as f ON ( d.default_department_id = f.id AND f.deleted = 0)
+							LEFT JOIN '. $ugf->getTable() .' as g ON ( d.group_id = g.id AND g.deleted = 0 )
+							LEFT JOIN '. $utf->getTable() .' as h ON ( d.title_id = h.id AND h.deleted = 0 )
+
+							LEFT JOIN '. $bf->getTable() .' as j ON ( b.branch_id = j.id AND j.deleted = 0)
+							LEFT JOIN '. $df->getTable() .' as k ON ( b.department_id = k.id AND k.deleted = 0)
+
+							LEFT JOIN '. $sf->getTable() .' as l ON a.station_id = l.id
+
+							LEFT JOIN '. $uwf->getTable() .' as w ON w.id = (select w.id
+																		from '. $uwf->getTable() .' as w
+																		where w.user_id = c.user_id
+																			and w.effective_date <= c.date_stamp
+																			and w.deleted = 0
+																			order by w.effective_date desc LiMiT 1)
+
+							LEFT JOIN '. $uf->getTable() .' as y ON ( a.created_by = y.id AND y.deleted = 0 )
+							LEFT JOIN '. $uf->getTable() .' as z ON ( a.updated_by = z.id AND z.deleted = 0 )
+					';
+		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
+			$query .= '	LEFT JOIN '. $jf->getTable() .' as r ON b.job_id = r.id';
+			$query .= '	LEFT JOIN '. $jif->getTable() .' as s ON b.job_item_id = s.id';
+		}
+
+		$ph[] = $company_id;
+		$query .= '	WHERE d.company_id = ?';
+
+		if ( isset($filter_data['permission_children_ids']) AND isset($filter_data['permission_children_ids'][0]) AND !in_array(-1, (array)$filter_data['permission_children_ids']) ) {
+			$query  .=	' AND d.id in ('. $this->getListSQL($filter_data['permission_children_ids'], $ph) .') ';
+		}
+		if ( isset($filter_data['id']) AND isset($filter_data['id'][0]) AND !in_array(-1, (array)$filter_data['id']) ) {
+			$query  .=	' AND a.id in ('. $this->getListSQL($filter_data['id'], $ph) .') ';
+		}
+		if ( isset($filter_data['exclude_id']) AND isset($filter_data['exclude_id'][0]) AND !in_array(-1, (array)$filter_data['exclude_id']) ) {
+			$query  .=	' AND d.id not in ('. $this->getListSQL($filter_data['exclude_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['user_id']) AND isset($filter_data['user_id'][0]) AND !in_array(-1, (array)$filter_data['user_id']) ) {
+			$query  .=	' AND c.user_id in ('. $this->getListSQL($filter_data['user_id'], $ph) .') ';
+		}
+
+		if ( isset($filter_data['user_status_id']) AND isset($filter_data['user_status_id'][0]) AND !in_array(-1, (array)$filter_data['user_status_id']) ) {
+			$query  .=	' AND d.status_id in ('. $this->getListSQL($filter_data['user_status_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['group_id']) AND isset($filter_data['group_id'][0]) AND !in_array(-1, (array)$filter_data['group_id']) ) {
+			if ( isset($filter_data['include_subgroups']) AND (bool)$filter_data['include_subgroups'] == TRUE ) {
+				$uglf = new UserGroupListFactory();
+				$filter_data['group_id'] = $uglf->getByCompanyIdAndGroupIdAndSubGroupsArray( $company_id, $filter_data['group_id'], TRUE);
+			}
+			$query  .=	' AND d.group_id in ('. $this->getListSQL($filter_data['group_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['default_branch_id']) AND isset($filter_data['default_branch_id'][0]) AND !in_array(-1, (array)$filter_data['default_branch_id']) ) {
+			$query  .=	' AND d.default_branch_id in ('. $this->getListSQL($filter_data['default_branch_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['default_department_id']) AND isset($filter_data['default_department_id'][0]) AND !in_array(-1, (array)$filter_data['default_department_id']) ) {
+			$query  .=	' AND d.default_department_id in ('. $this->getListSQL($filter_data['default_department_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['title_id']) AND isset($filter_data['title_id'][0]) AND !in_array(-1, (array)$filter_data['title_id']) ) {
+			$query  .=	' AND d.title_id in ('. $this->getListSQL($filter_data['title_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['branch_id']) AND isset($filter_data['branch_id'][0]) AND !in_array(-1, (array)$filter_data['branch_id']) ) {
+			$query  .=	' AND b.branch_id in ('. $this->getListSQL($filter_data['branch_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['department_id']) AND isset($filter_data['department_id'][0]) AND !in_array(-1, (array)$filter_data['department_id']) ) {
+			$query  .=	' AND b.department_id in ('. $this->getListSQL($filter_data['department_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['status_id']) AND isset($filter_data['status_id'][0]) AND !in_array(-1, (array)$filter_data['status_id']) ) {
+			$query  .=	' AND a.status_id in ('. $this->getListSQL($filter_data['status_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['type_id']) AND isset($filter_data['type_id'][0]) AND !in_array(-1, (array)$filter_data['type_id']) ) {
+			$query  .=	' AND a.type_id in ('. $this->getListSQL($filter_data['type_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['pay_period_ids']) AND isset($filter_data['pay_period_ids'][0]) AND !in_array(-1, (array)$filter_data['pay_period_ids']) ) {
+			$query .= 	' AND c.pay_period_id in ('. $this->getListSQL($filter_data['pay_period_ids'], $ph) .') ';
+		}
+
+
+		//Use the job_id in the punch_control table so we can filter by '0' or No Job
+		if ( isset($filter_data['include_job_id']) AND isset($filter_data['include_job_id'][0]) AND !in_array(-1, (array)$filter_data['include_job_id']) ) {
+			$query  .=	' AND b.job_id in ('. $this->getListSQL($filter_data['include_job_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['exclude_job_id']) AND isset($filter_data['exclude_job_id'][0]) AND !in_array(-1, (array)$filter_data['exclude_job_id']) ) {
+			$query  .=	' AND b.job_id not in ('. $this->getListSQL($filter_data['exclude_job_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['job_group_id']) AND isset($filter_data['job_group_id'][0]) AND !in_array(-1, (array)$filter_data['job_group_id']) ) {
+			if ( isset($filter_data['include_job_subgroups']) AND (bool)$filter_data['include_job_subgroups'] == TRUE ) {
+				$uglf = new UserGroupListFactory();
+				$filter_data['job_group_id'] = $uglf->getByCompanyIdAndGroupIdAndjob_subgroupsArray( $company_id, $filter_data['job_group_id'], TRUE);
+			}
+			$query  .=	' AND r.group_id in ('. $this->getListSQL($filter_data['job_group_id'], $ph) .') ';
+		}
+
+		if ( isset($filter_data['job_item_id']) AND isset($filter_data['job_item_id'][0]) AND !in_array(-1, (array)$filter_data['job_item_id']) ) {
+			$query  .=	' AND b.job_item_id in ('. $this->getListSQL($filter_data['job_item_id'], $ph) .') ';
+		}
+
+		if ( isset($filter_data['start_date']) AND trim($filter_data['start_date']) != '' ) {
+			$ph[] = $this->db->BindDate($filter_data['start_date']);
+			$query  .=	' AND c.date_stamp >= ?';
+		}
+		if ( isset($filter_data['end_date']) AND trim($filter_data['end_date']) != '' ) {
+			$ph[] = $this->db->BindDate($filter_data['end_date']);
+			$query  .=	' AND c.date_stamp <= ?';
+		}
+
+		$query .= 	'
+						AND (a.deleted = 0 AND b.deleted = 0 AND c.deleted = 0 AND d.deleted = 0)
+					';
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
+
+		//Debug::Arr($ph,'Query: '. $query, __FILE__, __LINE__, __METHOD__,10);
+
+		if ($limit == NULL) {
+			$this->rs = $this->db->Execute($query, $ph);
+		} else {
+			$this->rs = $this->db->PageExecute($query, $limit, $page, $ph);
+		}
+
+		return $this;
+	}
+
 	function getAPISearchByCompanyIdAndArrayCriteria( $company_id, $filter_data, $limit = NULL, $page = NULL, $where = NULL, $order = NULL ) {
 		if ( $company_id == '') {
 			return FALSE;
@@ -1891,9 +2396,6 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
 
-		Debug::Text('Query: '. $query, __FILE__, __LINE__, __METHOD__,10);
-		Debug::Arr($ph,'PlaceHolders:', __FILE__, __LINE__, __METHOD__,10);
-
 		if ($limit == NULL) {
 			$this->rs = $this->db->Execute($query, $ph);
 		} else {
