@@ -415,14 +415,14 @@ class Form941Report extends Report {
 	}
 
 	//Get raw data for report
-	function _getData() {
+	function _getData( $format = NULL ) {
 		$this->tmp_data = array( 'pay_stub_entry' => array() );
 
 		$columns = $this->getColumnConfig();
 		$filter_data = $this->getFilterConfig();
 		$form_data = $this->formatFormConfig();
 
-		$pself = new PayStubEntryListFactory();
+		$pself = TTnew( 'PayStubEntryListFactory' );
 		$pself->getAPIReportByCompanyIdAndArrayCriteria( $this->getUserObject()->getCompany(), $filter_data );
 		if ( $pself->getRecordCount() > 0 ) {
 			foreach( $pself as $pse_obj ) {
@@ -512,7 +512,7 @@ class Form941Report extends Report {
 		//Debug::Arr($this->tmp_data, 'Tmp Raw Data: ', __FILE__, __LINE__, __METHOD__,10);
 
 		//Get user data for joining.
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$ulf->getAPISearchByCompanyIdAndArrayCriteria( $this->getUserObject()->getCompany(), $filter_data );
 		Debug::Text(' User Total Rows: '. $ulf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
 		$this->getProgressBarObject()->start( $this->getAMFMessageID(), $ulf->getRecordCount(), NULL, TTi18n::getText('Retrieving Data...') );
@@ -531,20 +531,22 @@ class Form941Report extends Report {
 
 		//Merge time data with user data
 		$key=0;
-		foreach( $this->tmp_data['pay_stub_entry'] as $user_id => $level_1 ) {
-			foreach( $level_1 as $date_stamp => $row ) {
-				$date_columns = TTDate::getReportDates( NULL, $date_stamp, FALSE, $this->getUserObject() );
-				$processed_data  = array(
-										'pay_period' => array('sort' => $row['pay_period_start_date'], 'display' => TTDate::getDate('DATE', $row['pay_period_start_date'] ).' -> '. TTDate::getDate('DATE', $row['pay_period_end_date'] ) ),
-										);
+		if ( isset($this->tmp_data['pay_stub_entry']) ) {
+			foreach( $this->tmp_data['pay_stub_entry'] as $user_id => $level_1 ) {
+				foreach( $level_1 as $date_stamp => $row ) {
+					$date_columns = TTDate::getReportDates( NULL, $date_stamp, FALSE, $this->getUserObject() );
+					$processed_data  = array(
+											'pay_period' => array('sort' => $row['pay_period_start_date'], 'display' => TTDate::getDate('DATE', $row['pay_period_start_date'] ).' -> '. TTDate::getDate('DATE', $row['pay_period_end_date'] ) ),
+											);
 
-				$this->data[] = array_merge( $this->tmp_data['user'][$user_id], $row, $date_columns, $processed_data );
+					$this->data[] = array_merge( $this->tmp_data['user'][$user_id], $row, $date_columns, $processed_data );
 
-				$this->getProgressBarObject()->set( $this->getAMFMessageID(), $key );
-				$key++;
+					$this->getProgressBarObject()->set( $this->getAMFMessageID(), $key );
+					$key++;
+				}
 			}
+			unset($this->tmp_data, $row, $date_columns, $processed_data, $level_1, $level_2, $level_3);
 		}
-		unset($this->tmp_data, $row, $date_columns, $processed_data, $level_1, $level_2, $level_3);
 		//Debug::Arr($this->data, 'preProcess Data: ', __FILE__, __LINE__, __METHOD__,10);
 
 		return TRUE;
@@ -666,7 +668,6 @@ class Form941Report extends Report {
 
 		$output = $this->getFormObject()->output( 'PDF' );
 
-
 		return $output;
 	}
 
@@ -674,7 +675,7 @@ class Form941Report extends Report {
 		if ( $format == 'pdf_form' OR $format == 'pdf_form_print' ) {
 			return $this->_outputPDFForm( $format );
 		} else {
-			return $this->_pdf();
+			return parent::_output( $format );
 		}
 
 	}
