@@ -551,13 +551,13 @@ class InvoiceTransactionSummaryReport extends Report {
 	}
 
 	//Get raw data for report
-	function _getData() {
+	function _getData( $format = NULL ) {
 		$this->tmp_data = array('transaction' => array() );
 
 		$columns = $this->getColumnConfig();
 		$filter_data = $this->getFilterConfig();
 
-		$crlf = new CurrencyListFactory();
+		$crlf = TTnew( 'CurrencyListFactory' );
 		$crlf->getByCompanyId( $this->getUserObject()->getCompany() );
 		$currency_options = $crlf->getArrayByListFactory( $crlf, FALSE, TRUE );
 		Debug::Arr($currency_options, 'Currency Options: ', __FILE__, __LINE__, __METHOD__,10);
@@ -574,11 +574,11 @@ class InvoiceTransactionSummaryReport extends Report {
 			$currency_convert_to_base = TRUE;
 		}
 
-		$cf = new ClientFactory();
-		$pf = new ProductFactory();
-		$if = new InvoiceFactory();
+		$cf = TTnew( 'ClientFactory' );
+		$pf = TTnew( 'ProductFactory' );
+		$if = TTnew( 'InvoiceFactory' );
 
-		$tlf = new TransactionListFactory();
+		$tlf = TTnew( 'TransactionListFactory' );
 		$tlf->getTransactionReportByCompanyIdAndArrayCriteria( $this->getUserObject()->getCompany(), $filter_data );
 		Debug::Text('Total Transaction Rows: '. $tlf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
 		$this->getProgressBarObject()->start( $this->getAMFMessageID(), $tlf->getRecordCount(), NULL, TTi18n::getText('Retrieving Data...') );
@@ -692,7 +692,10 @@ class InvoiceTransactionSummaryReport extends Report {
 
 	//PreProcess data such as calculating additional columns from raw data etc...
 	function _preProcess() {
-		$this->data = $this->tmp_data['transaction'];
+		if ( isset($this->tmp_data['transaction']) ) {
+			$this->data = $this->tmp_data['transaction'];
+		}
+
 		return TRUE;
 	}
 }
