@@ -46,6 +46,7 @@ class Report {
 
 	public $title = NULL;
 	public $file_name = 'report';
+	public $file_mime_type = 'application/pdf';
 
 	protected $config = array(
 								'other' => array(
@@ -334,7 +335,10 @@ class Report {
 				$params = array();
 				if ( isset($data['time_period']['pay_period_schedule_id']) ) {
 					$params = array('pay_period_schedule_id' => $data['time_period']['pay_period_schedule_id'] );
+				} elseif ( isset($data['time_period']['pay_period_id']) ) {
+					$params = array('pay_period_id' => $data['time_period']['pay_period_id'] );
 				}
+
 				$time_period_dates = TTDate::getTimePeriodDates($data['time_period']['time_period'], NULL, $this->getUserObject(), $params );
 				if ( $time_period_dates != FALSE ) {
 					if ( isset($time_period_dates['start_date']) ) {
@@ -518,9 +522,9 @@ class Report {
 		}
 
 		if ( is_object( $this->getUserObject() ) ) {
-			$urdf = new UserReportDataFactory();
+			$urdf = TTnew( 'UserReportDataFactory' );
 
-			$urdlf = new UserReportDataListFactory();
+			$urdlf = TTnew( 'UserReportDataListFactory' );
 			$urdlf->getByCompanyIdAndScriptAndDefault( $this->getUserObject()->getCompany(), get_class($this) );
 			if ( $urdlf->getRecordCount() > 0 ) {
 				$urdf->setID( $urdlf->getCurrent()->getID() );
@@ -547,7 +551,7 @@ class Report {
 			return FALSE;
 		}
 
-		$urdlf = new UserReportDataListFactory();
+		$urdlf = TTnew( 'UserReportDataListFactory' );
 		$urdlf->getByCompanyIdAndScriptAndDefault( $this->getUserObject()->getCompany(), get_class($this) );
 		if ( $urdlf->getRecordCount() > 0 ) {
 			Debug::Text('Found Company Report Setup!', __FILE__, __LINE__, __METHOD__,10);
@@ -617,6 +621,15 @@ class Report {
 		return FALSE;
 	}
 
+	//Returns the default file name if none is specified.
+	function getFileName() {
+		return $this->file_name.'_'.date('Y_m_d').'.pdf';
+	}
+	//Returns the default file mime type if none is specified.
+	function getFileMimeType() {
+		return $this->file_mime_type;
+	}
+
 	//Return options from sub-class for things like columns, sorting columns, grouping columns, sub-total columns, etc...
 	function getOptions($name, $params = NULL) {
 		if ( $params == NULL OR $params == '') {
@@ -644,10 +657,10 @@ class Report {
 	}
 
 	//PreProcess data such as calculating additional columns (Day of Week, Year Quarter, combined multiple columns together, etc...) from raw data etc...
-	function preProcess() {
+	function preProcess( $format = NULL ) {
 
 		$this->profiler->startTimer( 'preProcess' );
-		$this->_preProcess();
+		$this->_preProcess( $format );
 		$this->profiler->stopTimer( 'preProcess' );
 		Debug::Text(' Memory Usage: Current: '. memory_get_usage() .' Peak: '. memory_get_peak_usage(), __FILE__, __LINE__, __METHOD__,10);
 
@@ -791,14 +804,14 @@ class Report {
 	//sometimes there are columns postProcess needs that grouping will drop. For example when two or three columns are required to postProcess into a single column.
 	//If group_by on that single column happens before postProcess, all the necessary data will be lost.
 	//This will have to be one of the restrictions, that postProcess can only use a *SINGLE* column at a time, as its not guaranteed to have more than that due to grouping.
-	function postProcess() {
+	function postProcess( $format = NULL ) {
 		//Append Total record to the end.
 		if ( isset($this->total_row) AND is_array($this->total_row) ) {
 			$this->data[] = $this->total_row;
 		}
 
 		$this->profiler->startTimer( 'postProcess' );
-		$this->_postProcess();
+		$this->_postProcess( $format );
 		$this->profiler->stopTimer( 'postProcess' );
 		Debug::Text(' Memory Usage: Current: '. memory_get_usage() .' Peak: '. memory_get_peak_usage(), __FILE__, __LINE__, __METHOD__,10);
 
@@ -844,10 +857,13 @@ class Report {
 	}
 
 	function getTimePeriodFormatOptions( $format_options = array() ) {
-		//$report_date_columns = Misc::trimSortPrefix( TTDate::getReportDateOptions() );
 		$report_date_columns = Misc::trimSortPrefix( $this->getOptions('date_columns') );
-		foreach( $report_date_columns as $column => $name ) {
-			$format_options[$column] = 'report_date';
+		if ( is_array($report_date_columns) ) {
+			foreach( $report_date_columns as $column => $name ) {
+				$format_options[$column] = 'report_date';
+			}
+		} else {
+			Debug::Text('No Report Date columns...', __FILE__, __LINE__, __METHOD__,10);
 		}
 
 		return $format_options;
@@ -946,7 +962,7 @@ class Report {
 				$config = $this->getFilterConfig();
 				if ( isset($config['pay_period_id']) AND is_array($config['pay_period_id']) ) {
 					//Pay Period based
-					$pplf = new PayPeriodListFactory();
+					$pplf = TTnew( 'PayPeriodListFactory' );
 					$pplf->getByCompanyId( $this->getUserObject()->getCompany() );
 					$pay_period_options = Misc::trimSortPrefix( $pplf->getArrayByListFactory( $pplf, FALSE, TRUE ) );
 
@@ -1060,8 +1076,7 @@ class Report {
 
 	function getOutput( $format = NULL ) {
 		//Get format from getMiscOptions().
-		//Formats: CSV, HTML, PDF
-		//For now just create HTML, then use DOMPDF to convert to PDF, but I think we will want a direct to PDF step to speed it up.
+		//Formats: RAW (PHP ARRAY), CSV, HTML, PDF
 
 		if ( $this->checkPermissions() == FALSE ) {
 			Debug::Text('Invalid permissions!', __FILE__, __LINE__, __METHOD__,10);
@@ -1075,8 +1090,8 @@ class Report {
 
 		$this->_preOutput( $format );
 
-		$this->getData();
-		$this->preProcess();
+		$this->getData( $format );
+		$this->preProcess( $format );
 		$this->group();
 		$this->sort(); //Sort needs to come before subTotal, as subTotal will need to re-sort the data in order to fit the sub-totals in.
 		$this->Total();
@@ -1088,7 +1103,7 @@ class Report {
 			$this->chart();
 		}
 
-		$this->postProcess();
+		$this->postProcess( $format );
 
 		$retval = $this->_output( $format );
 
@@ -1096,9 +1111,17 @@ class Report {
 
 		$this->getProgressBarObject()->stop( $this->getAMFMessageID() );
 
-		Debug::Text(' Total Time: '. (microtime(TRUE)-$this->start_time) .' Memory Usage: Current: '. memory_get_usage() .' Peak: '. memory_get_peak_usage() , __FILE__, __LINE__, __METHOD__,10);
+		Debug::Text(' Format: '. $format .' Total Time: '. (microtime(TRUE)-$this->start_time) .' Memory Usage: Current: '. memory_get_usage() .' Peak: '. memory_get_peak_usage() , __FILE__, __LINE__, __METHOD__,10);
 
-		return $retval;
+		if ( $format != 'raw' AND ( !is_array($retval) OR !isset($retval['file_name']) OR !isset($retval['mime_type']) ) ) {
+			return array(
+						 'data' => $retval,
+						 'file_name' => $this->getFileName(),
+						 'mime_type' => $this->getFileMimeType(),
+						 );
+		} else {
+			return $retval; //Array with file_name and mime_types
+		}
 	}
 
 	function _preOutput( $format = NULL ) {
@@ -1106,12 +1129,27 @@ class Report {
 	}
 
 	function _output( $format = NULL ) {
+		Debug::Text('Format: '. $format, __FILE__, __LINE__, __METHOD__,10);
 		if ( $format == 'raw' ) {
 			//Should we rekey this array so the order can be presevered, which is critical to outputting it properly?
 			return array_values( $this->data );
+		} elseif ( $format == 'csv' ) {
+			$column_config = $this->getColumnConfig();
+			foreach( $column_config as $column_name => $column_data ) {
+				$columns[$column_name] = $column_name;
+			}
+			//Debug::Arr($columns, 'Columns:  '. $format, __FILE__, __LINE__, __METHOD__,10);
+			return array(
+						 'data' => Misc::Array2CSV( $this->data, $columns, FALSE, TRUE ),
+						 'file_name' => $this->file_name.'_'.date('Y_m_d').'.csv',
+						 'mime_type' => 'text/csv',
+						 );
 		} else {
+			Debug::Text('Exporting PDF format: '. $format, __FILE__, __LINE__, __METHOD__,10);
 			return $this->_pdf();
 		}
+
+		return FALSE;
 	}
 
 	function _postOutput( $format = NULL ) {
@@ -1121,7 +1159,7 @@ class Report {
 	function email( $output ) {
 		Debug::Text('Emailing report...', __FILE__, __LINE__, __METHOD__,10);
 
-		if ( $output != ''
+		if ( is_array($output) AND isset($output['data']) AND $output['data'] != ''
 				AND is_object( $this->getUserObject() )
 				AND ( $this->getUserObject()->getHomeEmail() != FALSE OR $this->getUserObject()->getWorkEmail() != FALSE ) ) {
 
@@ -1160,7 +1198,8 @@ class Report {
 			$mail->setHeaders( $headers );
 
 			@$mail->getMIMEObject()->setHTMLBody($body);
-			$mail->getMIMEObject()->addAttachment($output, 'application/pdf', $this->file_name.'.pdf', FALSE, 'base64');
+			//$mail->getMIMEObject()->addAttachment($output, 'application/pdf', $this->file_name.'.pdf', FALSE, 'base64');
+			$mail->getMIMEObject()->addAttachment($output['data'], $output['mime_type'], $output['file_name'], FALSE, 'base64');
 
 			$mail->setBody( $mail->getMIMEObject()->get( $mail->default_mime_config ) );
 			$retval = $mail->Send();
@@ -1273,6 +1312,7 @@ class Report {
 
 		$prev_width = $this->pdf->getLineWidth();
 		$this->pdf->setLineWidth( $width );
+		$this->pdf->setDrawColor(0); //Black
 		$this->pdf->setFillColor(0); //Black
 
 		$this->pdf->Line( $this->pdf->getX(), $this->pdf->getY(), $this->pdf->getPageWidth()-$margins['right'], $this->pdf->getY() );
@@ -1395,8 +1435,10 @@ class Report {
 
 		if ( is_array($columns) AND count($columns) > 0 ) {
 			$this->pdf->SetFont($this->config['other']['default_font'],'B', $this->_pdf_fontSize(10) );
-
+			$this->pdf->setTextColor(0);
+			$this->pdf->setDrawColor(0);
 			$this->pdf->setFillColor(240); //Grayscale only.
+
 			$column_widths = $this->_pdf_getTableColumnWidths( array_intersect_key($column_options, $columns), $header_layout );
 			foreach( $columns as $column => $tmp ) {
 				if ( isset($column_options[$column]) AND isset($column_widths[$column]) ) {
@@ -1421,6 +1463,8 @@ class Report {
 		$margins = $this->pdf->getMargins();
 
 		$this->pdf->SetFont($this->config['other']['default_font'], '', $this->_pdf_fontSize(8) );
+		$this->pdf->setTextColor(0);
+		$this->pdf->setDrawColor(0);
 
 		//Save x,y and restore after footer is set.
 		$x = $this->pdf->getX();
@@ -1622,6 +1666,8 @@ class Report {
 
 				//Reset all styles/fills after page break.
 				$this->pdf->SetFont($this->config['other']['default_font'],'', $this->_pdf_fontSize(8) );
+				$this->pdf->SetTextColor(0);
+				$this->pdf->SetDrawColor(0);
 				if ( $r % 2 == 0 ) {
 					$this->pdf->setFillColor(255);
 				} else {
@@ -1655,11 +1701,10 @@ class Report {
 						if ( isset($row[$column]) ) {
 							$value = $row[$column];
 						} else {
-							$value = '';
+							$value = ''; //This needs to be a space, otherwise cells won't be drawn and background colors won't be shown either.
 						}
 
 						//Debug::Text(' Row: '. $key .' Column: '. $column .'('.$c.') Value: '. $value .' Count Cols: '. count($row) .' Sub Total Columns: '. $total_row_sub_total_columns, __FILE__, __LINE__, __METHOD__,10);
-
 						//Debug::Text(' Row: '. $key .' Column: '. $column .'('.$c.') Value: '. $value .' Count Cols: '. count($row), __FILE__, __LINE__, __METHOD__,10);
 						$cell_width = ( isset($column_widths[$column]) ) ? $column_widths[$column] : 30;
 
@@ -1694,9 +1739,10 @@ class Report {
 						} else {
 							//Don't show duplicate data in cells that are next to one another. But always show data after a sub-total.
 							//Only do this for static columns as well.
-							if ( $this->config['other']['show_duplicate_values'] == FALSE AND $new_page == FALSE AND !isset($prev_row['_subtotal']) AND isset($prev_row[$column]) AND isset($row[$column]) AND $prev_row[$column] === $row[$column] AND isset($static_column_options[$column]) ) {
-								//$value = '"';
-								$value = $this->config['other']['duplicate_value_placeholder'];
+							//Make sure we don't remove duplicate values in pay stub reports, so if the value is a FLOAT then never replace it.
+							if ( $this->config['other']['show_duplicate_values'] == FALSE AND $new_page == FALSE AND !isset($prev_row['_subtotal']) AND isset($prev_row[$column]) AND isset($row[$column]) AND !is_float($row[$column]) AND $prev_row[$column] === $row[$column] AND isset($static_column_options[$column]) ) {
+								//This needs to be a space otherwise cell background colors won't be shown.
+								$value = ( $this->config['other']['duplicate_value_placeholder'] != '' ) ? $this->config['other']['duplicate_value_placeholder'] : ' ';
 							}
 						}
 
@@ -1708,7 +1754,28 @@ class Report {
 							$this->pdf->setX( $this->pdf->getX()+$cell_width );
 						} else {
 							$blank_row = FALSE;
-							$this->pdf->Cell( $cell_width, $this->_pdf_fontSize( $row_layout['height'] ), $value, $row_layout['border'], 0, $row_layout['align'], $row_layout['fill'], '', $row_layout['stretch'] );
+
+							//Row formatting...
+							if ( isset($row['_fontcolor']) AND is_array($row['_fontcolor']) ) {
+								$this->pdf->setTextColor( $row['_fontcolor'][0], $row['_fontcolor'][1], $row['_fontcolor'][2] );
+							} else {
+								$this->pdf->setTextColor(0);
+							}
+							if ( isset($row['_drawcolor']) AND is_array($row['_drawcolor']) ) {
+								$this->pdf->setDrawColor( $row['_drawcolor'][0], $row['_drawcolor'][1], $row['_drawcolor'][2] );
+							} else {
+								$this->pdf->setDrawColor(0);
+							}
+							if ( isset($row['_bgcolor']) AND is_array($row['_bgcolor']) ) {
+								$this->pdf->setFillColor( $row['_bgcolor'][0], $row['_bgcolor'][1], $row['_bgcolor'][2] );
+							}
+							if ( isset($row['_border']) ) {
+								$border = $row['_border'];
+							} else {
+								$border = $row_layout['border'];
+							}
+
+							$this->pdf->Cell( $cell_width, $this->_pdf_fontSize( $row_layout['height'] ), $value, $border, 0, $row_layout['align'], $row_layout['fill'], '', $row_layout['stretch'] );
 						}
 
 						$c++;
@@ -1791,4 +1858,32 @@ class ReportPDF extends Report {
 	}
 
 }
+
+//For advanced reports that require cell background colors, borders, formatting etc...
+//Use objects for the cell data, which can then be checked and handled separately.
+//Make them all static objects for faster access?
+//Need to be able to overload specific formatting classes that will only ever be used by one report.
+/*
+ReportFormatter
+	ReportTable (ReportObjectTableFormatter)
+		ReportTableHeader
+		ReportTableFooter
+	ReportColumn (ReportObjectColumnFormatter)
+	ReportRow (ReportObjectRowFormatter)
+	ReportCell (ReportObjectCellFormatter)
+		ReportCell<Type> (ie: ReportCellCurrency, ReportCellPercent, ReportCellNumeric, ReportCellMyCustomType)
+
+
+//I think all the objects need to be seperate from one another, so we can pass objects around efficiently, then the main processor can handle inheritance that way.
+//This might still be too heavy weight for what we need.
+$report = new ReportFormatter();
+$table = $report->addTable();
+	$table->addColumn();
+	$table->addColumn();
+$row = $table->addRow();
+	$row->addCell()
+	$row->addCell()
+	$row->addCell()
+
+*/
 ?>
