@@ -112,7 +112,7 @@ class TimesheetDetailReport extends Report {
 										'-1050-title' => TTi18n::gettext('Title'),
 										'-1060-province' => TTi18n::gettext('Province/State'),
 										'-1070-country' => TTi18n::gettext('Country'),
-										'-1080-group' => TTi18n::gettext('Group'),
+										'-1080-user_group' => TTi18n::gettext('Group'),
 										'-1090-default_branch' => TTi18n::gettext('Default Branch'),
 										'-1100-default_department' => TTi18n::gettext('Default Department'),
 										'-1110-currency' => TTi18n::gettext('Currency'),
@@ -171,7 +171,7 @@ class TimesheetDetailReport extends Report {
 			case 'overtime_columns':
 				//Get all Overtime policies.
 				$retval = array();
-				$otplf = new OverTimePolicyListFactory();
+				$otplf = TTnew( 'OverTimePolicyListFactory' );
 				$otplf->getByCompanyId( $this->getUserObject()->getCompany() );
 				if ( $otplf->getRecordCount() > 0 ) {
 					foreach( $otplf as $otp_obj ) {
@@ -184,7 +184,7 @@ class TimesheetDetailReport extends Report {
 			case 'premium_columns':
 				$retval = array();
 				//Get all Premium policies.
-				$pplf = new PremiumPolicyListFactory();
+				$pplf = TTnew( 'PremiumPolicyListFactory' );
 				$pplf->getByCompanyId( $this->getUserObject()->getCompany() );
 				if ( $pplf->getRecordCount() > 0 ) {
 					foreach( $pplf as $pp_obj ) {
@@ -197,7 +197,7 @@ class TimesheetDetailReport extends Report {
 			case 'absence_columns':
 				$retval = array();
 				//Get all Absence Policies.
-				$aplf = new AbsencePolicyListFactory();
+				$aplf = TTnew( 'AbsencePolicyListFactory' );
 				$aplf->getByCompanyId( $this->getUserObject()->getCompany() );
 				if ( $aplf->getRecordCount() > 0 ) {
 					foreach( $aplf as $ap_obj ) {
@@ -260,15 +260,15 @@ class TimesheetDetailReport extends Report {
 										'-1100-by_employee+regular+regular_wage+overtime+overtime_wage+premium+premium_wage+absence+absence_wage' => TTi18n::gettext('All Time+Wage by Employee'),
 
 										'-1110-by_date_by_full_name+regular+regular_wage' => TTi18n::gettext('Regular Time+Wage by Date/Employee'),
-										'-1120-by_date_by_full_name+overtime+overtime_wage' => TTi18n::gettext('Overtime+Wage by Pay Date/Employee'),
-										'-1130-by_date_by_full_name+premium+premium_wage' => TTi18n::gettext('Premium Time+Wage by Pay Date/Employee'),
-										'-1140-by_date_by_full_name+absence+absence_wage' => TTi18n::gettext('Absence Time+Wage by Pay Date/Employee'),
+										'-1120-by_date_by_full_name+overtime+overtime_wage' => TTi18n::gettext('Overtime+Wage by Date/Employee'),
+										'-1130-by_date_by_full_name+premium+premium_wage' => TTi18n::gettext('Premium Time+Wage by Date/Employee'),
+										'-1140-by_date_by_full_name+absence+absence_wage' => TTi18n::gettext('Absence Time+Wage by Date/Employee'),
 										'-1150-by_date_by_full_name+regular+regular_wage+overtime+overtime_wage+premium+premium_wage+absence+absence_wage' => TTi18n::gettext('All Time+Wage by Date/Employee'),
 
 										'-1160-by_full_name_by_date+regular+regular_wage' => TTi18n::gettext('Regular Time+Wage by Employee/Date'),
-										'-1170-by_full_name_by_date+overtime+overtime_wage' => TTi18n::gettext('Overtime+Wage by Pay Employee/Date'),
-										'-1180-by_full_name_by_date+premium+premium_wage' => TTi18n::gettext('Premium Time+Wage by Pay Employee/Date'),
-										'-1190-by_full_name_by_date+absence+absence_wage' => TTi18n::gettext('Absence Time+Wage by Pay Employee/Date'),
+										'-1170-by_full_name_by_date+overtime+overtime_wage' => TTi18n::gettext('Overtime+Wage by Employee/Date'),
+										'-1180-by_full_name_by_date+premium+premium_wage' => TTi18n::gettext('Premium Time+Wage by Employee/Date'),
+										'-1190-by_full_name_by_date+absence+absence_wage' => TTi18n::gettext('Absence Time+Wage by Employee/Date'),
 										'-1200-by_full_name_by_date+regular+regular_wage+overtime+overtime_wage+premium+premium_wage+absence+absence_wage' => TTi18n::gettext('All Time+Wage by Employee/Date'),
 
 										'-1210-by_branch+regular+regular_wage' => TTi18n::gettext('Regular Time+Wage by Branch'),
@@ -343,6 +343,11 @@ class TimesheetDetailReport extends Report {
 										'-1890-by_branch_by_department_by_pay_period+absence+absence_wage' => TTi18n::gettext('Absence Time+Wage by Pay Branch/Department/Pay Period'),
 										'-1900-by_branch_by_department_by_pay_period+regular+regular_wage+overtime+overtime_wage+premium+premium_wage+absence+absence_wage' => TTi18n::gettext('All Time+Wage by Branch/Department/Pay Period'),
 
+										'-1910-by_full_name_by_dow+regular+regular_wage' => TTi18n::gettext('Regular Time+Wage by Employee/Day of Week'),
+										'-1920-by_full_name_by_dow+overtime+overtime_wage' => TTi18n::gettext('Overtime+Wage by Pay Employee/Day of Week'),
+										'-1930-by_full_name_by_dow+premium+premium_wage' => TTi18n::gettext('Premium Time+Wage by Pay Employee/Day of Week'),
+										'-1940-by_full_name_by_dow+absence+absence_wage' => TTi18n::gettext('Absence Time+Wage by Pay Employee/Day of Week'),
+										'-1950-by_full_name_by_dow+regular+regular_wage+overtime+overtime_wage+premium+premium_wage+absence+absence_wage' => TTi18n::gettext('All Time+Wage by Employee/Day of Week'),
 							   );
 
 				break;
@@ -581,7 +586,18 @@ class TimesheetDetailReport extends Report {
 											$retval['sort'][] = array('full_name' => 'asc');
 											$retval['sort'][] = array('date_stamp' => 'asc');
 											break;
+										case 'by_full_name_by_dow':
+											$retval['columns'][] = 'full_name';
+											$retval['columns'][] = 'date_dow';
 
+											$retval['group'][] = 'full_name';
+											$retval['group'][] = 'date_dow';
+
+											$retval['sub_total'][] = 'full_name';
+
+											$retval['sort'][] = array('full_name' => 'asc');
+											$retval['sort'][] = array('date_dow' => 'asc');
+											break;
 									}
 								}
 							}
@@ -629,7 +645,7 @@ class TimesheetDetailReport extends Report {
 		//Take into account wage groups!
 
 		//Get all Overtime policies.
-		$otplf = new OverTimePolicyListFactory();
+		$otplf = TTnew( 'OverTimePolicyListFactory' );
 		$otplf->getByCompanyId( $this->getUserObject()->getCompany() );
 		if ( $otplf->getRecordCount() > 0 ) {
 			foreach( $otplf as $otp_obj ) {
@@ -639,7 +655,7 @@ class TimesheetDetailReport extends Report {
 		}
 
 		//Get all Premium policies.
-		$pplf = new PremiumPolicyListFactory();
+		$pplf = TTnew( 'PremiumPolicyListFactory' );
 		$pplf->getByCompanyId( $this->getUserObject()->getCompany() );
 		if ( $pplf->getRecordCount() > 0 ) {
 			foreach( $pplf as $pp_obj ) {
@@ -648,7 +664,7 @@ class TimesheetDetailReport extends Report {
 		}
 
 		//Get all Absence Policies.
-		$aplf = new AbsencePolicyListFactory();
+		$aplf = TTnew( 'AbsencePolicyListFactory' );
 		$aplf->getByCompanyId( $this->getUserObject()->getCompany() );
 		if ( $aplf->getRecordCount() > 0 ) {
 			foreach( $aplf as $ap_obj ) {
@@ -664,7 +680,7 @@ class TimesheetDetailReport extends Report {
 	}
 
 	//Get raw data for report
-	function _getData() {
+	function _getData( $format = NULL ) {
 		$this->tmp_data = array('user_date_total' => array(), 'user' => array(), 'verified_timesheet' => array(), 'punch_rows' => array() );
 
 		$columns = $this->getColumnConfig();
@@ -672,7 +688,7 @@ class TimesheetDetailReport extends Report {
 		$policy_hourly_rates = $this->getPolicyHourlyRates();
 
 		if ( $this->getPermissionObject()->Check('punch','view') == FALSE OR $this->getPermissionObject()->Check('wage','view') == FALSE ) {
-			$hlf = new HierarchyListFactory();
+			$hlf = TTnew( 'HierarchyListFactory' );
 			$permission_children_ids = $wage_permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $this->getUserObject()->getCompany(), $this->getUserObject()->getID() );
 			Debug::Arr($permission_children_ids,'Permission Children Ids:', __FILE__, __LINE__, __METHOD__,10);
 		} else {
@@ -707,7 +723,7 @@ class TimesheetDetailReport extends Report {
 
 		$pay_period_ids = array();
 
-		$udtlf = new UserDateTotalListFactory();
+		$udtlf = TTnew( 'UserDateTotalListFactory' );
 		$udtlf->getTimesheetDetailReportByCompanyIdAndArrayCriteria( $this->getUserObject()->getCompany(), $filter_data );
 		Debug::Text(' Total Rows: '. $udtlf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
 		$this->getProgressBarObject()->start( $this->getAMFMessageID(), $udtlf->getRecordCount(), NULL, TTi18n::getText('Retrieving Data...') );
@@ -796,7 +812,7 @@ class TimesheetDetailReport extends Report {
 		//Debug::Arr($this->tmp_data['user_date_total'], 'User Date Total Raw Data: ', __FILE__, __LINE__, __METHOD__,10);
 
 		//Get user data for joining.
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$ulf->getAPISearchByCompanyIdAndArrayCriteria( $this->getUserObject()->getCompany(), $filter_data );
 		Debug::Text(' User Total Rows: '. $ulf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
 		$this->getProgressBarObject()->start( $this->getAMFMessageID(), $ulf->getRecordCount(), NULL, TTi18n::getText('Retrieving Data...') );
@@ -813,7 +829,7 @@ class TimesheetDetailReport extends Report {
 		//Get verified timesheets for all pay periods considered in report.
 		$pay_period_ids = array_keys( $pay_period_ids );
 		if ( isset($pay_period_ids) AND count($pay_period_ids) > 0 ) {
-			$pptsvlf = new PayPeriodTimeSheetVerifyListFactory();
+			$pptsvlf = TTnew( 'PayPeriodTimeSheetVerifyListFactory' );
 			$pptsvlf->getByPayPeriodIdAndCompanyId( $pay_period_ids, $this->getUserObject()->getCompany() );
 			if ( $pptsvlf->getRecordCount() > 0 ) {
 				foreach( $pptsvlf as $pptsv_obj ) {
@@ -834,38 +850,40 @@ class TimesheetDetailReport extends Report {
 
 		//Merge time data with user data
 		$key=0;
-		foreach( $this->tmp_data['user_date_total'] as $user_id => $level_1 ) {
-			if ( isset($this->tmp_data['user'][$user_id]) ) {
-				foreach( $level_1 as $date_stamp => $level_2 ) {
-					foreach( $level_2 as $branch => $level_3 ) {
-						foreach( $level_3 as $department => $row ) {
-							$date_columns = TTDate::getReportDates( NULL, $date_stamp, FALSE, $this->getUserObject() );
-							$processed_data  = array(
-													'branch' => $branch,
-													'department' => $department,
-													'pay_period' => array('sort' => $row['pay_period_start_date'], 'display' => TTDate::getDate('DATE', $row['pay_period_start_date'] ).' -> '. TTDate::getDate('DATE', $row['pay_period_end_date'] ) ),
-													);
+		if ( isset($this->tmp_data['user_date_total']) ) {
+			foreach( $this->tmp_data['user_date_total'] as $user_id => $level_1 ) {
+				if ( isset($this->tmp_data['user'][$user_id]) ) {
+					foreach( $level_1 as $date_stamp => $level_2 ) {
+						foreach( $level_2 as $branch => $level_3 ) {
+							foreach( $level_3 as $department => $row ) {
+								$date_columns = TTDate::getReportDates( NULL, $date_stamp, FALSE, $this->getUserObject() );
+								$processed_data  = array(
+														'branch' => $branch,
+														'department' => $department,
+														'pay_period' => array('sort' => $row['pay_period_start_date'], 'display' => TTDate::getDate('DATE', $row['pay_period_start_date'] ).' -> '. TTDate::getDate('DATE', $row['pay_period_end_date'] ) ),
+														);
 
-							if ( isset( $this->tmp_data['verified_timesheet'][$user_id][$row['pay_period_id']]) ) {
-								$processed_data['verified_time_sheet'] = $this->tmp_data['verified_timesheet'][$user_id][$row['pay_period_id']]['status'];
-								$processed_data['verified_time_sheet_date'] = $this->tmp_data['verified_timesheet'][$user_id][$row['pay_period_id']]['created_date'];
-							} else {
-								$processed_data['verified_time_sheet'] = TTi18n::getText('No');
-								$processed_data['verified_time_sheet_date'] = FALSE;
+								if ( isset( $this->tmp_data['verified_timesheet'][$user_id][$row['pay_period_id']]) ) {
+									$processed_data['verified_time_sheet'] = $this->tmp_data['verified_timesheet'][$user_id][$row['pay_period_id']]['status'];
+									$processed_data['verified_time_sheet_date'] = $this->tmp_data['verified_timesheet'][$user_id][$row['pay_period_id']]['created_date'];
+								} else {
+									$processed_data['verified_time_sheet'] = TTi18n::getText('No');
+									$processed_data['verified_time_sheet_date'] = FALSE;
+								}
+
+								$this->data[] = array_merge( $this->tmp_data['user'][$user_id], $row, $date_columns, $processed_data );
+
+								$this->form_data[$user_id]['data'][] = array_merge( $row, $date_columns, $processed_data );
+
+								$this->getProgressBarObject()->set( $this->getAMFMessageID(), $key );
+								$key++;
 							}
-
-							$this->data[] = array_merge( $this->tmp_data['user'][$user_id], $row, $date_columns, $processed_data );
-
-							$this->form_data[$user_id]['data'][] = array_merge( $row, $date_columns, $processed_data );
-
-							$this->getProgressBarObject()->set( $this->getAMFMessageID(), $key );
-							$key++;
 						}
 					}
 				}
 			}
+			unset($this->tmp_data, $row, $date_columns, $processed_data, $level_1, $level_2, $level_3);
 		}
-		unset($this->tmp_data, $row, $date_columns, $processed_data, $level_1, $level_2, $level_3);
 		//Debug::Arr($this->data, 'preProcess Data: ', __FILE__, __LINE__, __METHOD__,10);
 
 		return TRUE;
@@ -1337,7 +1355,7 @@ class TimesheetDetailReport extends Report {
 
 			$filter_data = $this->getFilterConfig();
 
-			$plf = new PunchListFactory();
+			$plf = TTnew( 'PunchListFactory' );
 			$plf->getSearchByCompanyIdAndArrayCriteria( $this->getUserObject()->getCompany(), $filter_data);
 			if ( $plf->getRecordCount() > 0 ) {
 				foreach( $plf as $p_obj ) {
@@ -1462,7 +1480,7 @@ class TimesheetDetailReport extends Report {
 				OR $format == 'pdf_timesheet_detail' OR $format == 'pdf_timesheet_detail_print' ) {
 			return $this->_outputPDFTimesheet( $format );
 		} else {
-			return $this->_pdf();
+			return parent::_output( $format );
 		}
 	}
 
