@@ -112,7 +112,7 @@ class TimesheetSummaryReport extends Report {
 										'-1050-title' => TTi18n::gettext('Title'),
 										'-1060-province' => TTi18n::gettext('Province/State'),
 										'-1070-country' => TTi18n::gettext('Country'),
-										'-1080-group' => TTi18n::gettext('Group'),
+										'-1080-user_group' => TTi18n::gettext('Group'),
 										'-1090-default_branch' => TTi18n::gettext('Default Branch'),
 										'-1100-default_department' => TTi18n::gettext('Default Department'),
 										'-1110-currency' => TTi18n::gettext('Currency'),
@@ -170,7 +170,7 @@ class TimesheetSummaryReport extends Report {
 			case 'overtime_columns':
 				//Get all Overtime policies.
 				$retval = array();
-				$otplf = new OverTimePolicyListFactory();
+				$otplf = TTnew( 'OverTimePolicyListFactory' );
 				$otplf->getByCompanyId( $this->getUserObject()->getCompany() );
 				if ( $otplf->getRecordCount() > 0 ) {
 					foreach( $otplf as $otp_obj ) {
@@ -183,7 +183,7 @@ class TimesheetSummaryReport extends Report {
 			case 'premium_columns':
 				$retval = array();
 				//Get all Premium policies.
-				$pplf = new PremiumPolicyListFactory();
+				$pplf = TTnew( 'PremiumPolicyListFactory' );
 				$pplf->getByCompanyId( $this->getUserObject()->getCompany() );
 				if ( $pplf->getRecordCount() > 0 ) {
 					foreach( $pplf as $pp_obj ) {
@@ -196,7 +196,7 @@ class TimesheetSummaryReport extends Report {
 			case 'absence_columns':
 				$retval = array();
 				//Get all Absence Policies.
-				$aplf = new AbsencePolicyListFactory();
+				$aplf = TTnew( 'AbsencePolicyListFactory' );
 				$aplf->getByCompanyId( $this->getUserObject()->getCompany() );
 				if ( $aplf->getRecordCount() > 0 ) {
 					foreach( $aplf as $ap_obj ) {
@@ -635,7 +635,7 @@ class TimesheetSummaryReport extends Report {
 		$policy_rates = array();
 
 		//Get all Overtime policies.
-		$otplf = new OverTimePolicyListFactory();
+		$otplf = TTnew( 'OverTimePolicyListFactory' );
 		$otplf->getByCompanyId( $this->getUserObject()->getCompany() );
 		if ( $otplf->getRecordCount() > 0 ) {
 			foreach( $otplf as $otp_obj ) {
@@ -645,7 +645,7 @@ class TimesheetSummaryReport extends Report {
 		}
 
 		//Get all Premium policies.
-		$pplf = new PremiumPolicyListFactory();
+		$pplf = TTnew( 'PremiumPolicyListFactory' );
 		$pplf->getByCompanyId( $this->getUserObject()->getCompany() );
 		if ( $pplf->getRecordCount() > 0 ) {
 			foreach( $pplf as $pp_obj ) {
@@ -654,7 +654,7 @@ class TimesheetSummaryReport extends Report {
 		}
 
 		//Get all Absence Policies.
-		$aplf = new AbsencePolicyListFactory();
+		$aplf = TTnew( 'AbsencePolicyListFactory' );
 		$aplf->getByCompanyId( $this->getUserObject()->getCompany() );
 		if ( $aplf->getRecordCount() > 0 ) {
 			foreach( $aplf as $ap_obj ) {
@@ -670,7 +670,7 @@ class TimesheetSummaryReport extends Report {
 	}
 
 	//Get raw data for report
-	function _getData() {
+	function _getData( $format = NULL ) {
 		$this->tmp_data = array('user_date_total' => array(), 'user' => array(), 'verified_timesheet' => array() );
 
 		$columns = $this->getColumnConfig();
@@ -678,7 +678,7 @@ class TimesheetSummaryReport extends Report {
 		$policy_hourly_rates = $this->getPolicyHourlyRates();
 
 		if ( $this->getPermissionObject()->Check('punch','view') == FALSE OR $this->getPermissionObject()->Check('wage','view') == FALSE ) {
-			$hlf = new HierarchyListFactory();
+			$hlf = TTnew( 'HierarchyListFactory' );
 			$permission_children_ids = $wage_permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $this->getUserObject()->getCompany(), $this->getUserObject()->getID() );
 			Debug::Arr($permission_children_ids,'Permission Children Ids:', __FILE__, __LINE__, __METHOD__,10);
 		} else {
@@ -713,7 +713,7 @@ class TimesheetSummaryReport extends Report {
 
 		$pay_period_ids = array();
 
-		$udtlf = new UserDateTotalListFactory();
+		$udtlf = TTnew( 'UserDateTotalListFactory' );
 		$udtlf->getTimesheetSummaryReportByCompanyIdAndArrayCriteria( $this->getUserObject()->getCompany(), $filter_data );
 		Debug::Text(' Total Rows: '. $udtlf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
 		$this->getProgressBarObject()->start( $this->getAMFMessageID(), $udtlf->getRecordCount(), NULL, TTi18n::getText('Retrieving Data...') );
@@ -799,7 +799,7 @@ class TimesheetSummaryReport extends Report {
 		//Debug::Arr($this->tmp_data['user_date_total'], 'User Date Total Raw Data: ', __FILE__, __LINE__, __METHOD__,10);
 
 		//Get user data for joining.
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$ulf->getAPISearchByCompanyIdAndArrayCriteria( $this->getUserObject()->getCompany(), $filter_data );
 		Debug::Text(' User Total Rows: '. $ulf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
 		$this->getProgressBarObject()->start( $this->getAMFMessageID(), $ulf->getRecordCount(), NULL, TTi18n::getText('Retrieving Data...') );
@@ -812,7 +812,7 @@ class TimesheetSummaryReport extends Report {
 		//Get verified timesheets for all pay periods considered in report.
 		$pay_period_ids = array_keys( $pay_period_ids );
 		if ( isset($pay_period_ids) AND count($pay_period_ids) > 0 ) {
-			$pptsvlf = new PayPeriodTimeSheetVerifyListFactory();
+			$pptsvlf = TTnew( 'PayPeriodTimeSheetVerifyListFactory' );
 			$pptsvlf->getByPayPeriodIdAndCompanyId( $pay_period_ids, $this->getUserObject()->getCompany() );
 			if ( $pptsvlf->getRecordCount() > 0 ) {
 				foreach( $pptsvlf as $pptsv_obj ) {
@@ -824,8 +824,7 @@ class TimesheetSummaryReport extends Report {
 			}
 		}
 
-
-		Debug::Arr($this->tmp_data, 'TMP Data: ', __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Arr($this->tmp_data, 'TMP Data: ', __FILE__, __LINE__, __METHOD__,10);
 		return TRUE;
 	}
 
@@ -835,36 +834,38 @@ class TimesheetSummaryReport extends Report {
 
 		//Merge time data with user data
 		$key=0;
-		foreach( $this->tmp_data['user_date_total'] as $user_id => $level_1 ) {
-			if ( isset($this->tmp_data['user'][$user_id]) ) {
-				foreach( $level_1 as $date_stamp => $level_2 ) {
-					foreach( $level_2 as $branch => $level_3 ) {
-						foreach( $level_3 as $department => $row ) {
-							$date_columns = TTDate::getReportDates( NULL, $date_stamp, FALSE, $this->getUserObject() );
-							$processed_data  = array(
-													'branch' => $branch,
-													'department' => $department,
-													'pay_period' => array('sort' => $row['pay_period_start_date'], 'display' => TTDate::getDate('DATE', $row['pay_period_start_date'] ).' -> '. TTDate::getDate('DATE', $row['pay_period_end_date'] ) ),
-													);
+		if ( isset($this->tmp_data['user_date_total']) ) {
+			foreach( $this->tmp_data['user_date_total'] as $user_id => $level_1 ) {
+				if ( isset($this->tmp_data['user'][$user_id]) ) {
+					foreach( $level_1 as $date_stamp => $level_2 ) {
+						foreach( $level_2 as $branch => $level_3 ) {
+							foreach( $level_3 as $department => $row ) {
+								$date_columns = TTDate::getReportDates( NULL, $date_stamp, FALSE, $this->getUserObject() );
+								$processed_data  = array(
+														'branch' => $branch,
+														'department' => $department,
+														'pay_period' => array('sort' => $row['pay_period_start_date'], 'display' => TTDate::getDate('DATE', $row['pay_period_start_date'] ).' -> '. TTDate::getDate('DATE', $row['pay_period_end_date'] ) ),
+														);
 
-							if ( isset( $this->tmp_data['verified_timesheet'][$user_id][$row['pay_period_id']]) ) {
-								$processed_data['verified_time_sheet'] = $this->tmp_data['verified_timesheet'][$user_id][$row['pay_period_id']]['status'];
-								$processed_data['verified_time_sheet_date'] = $this->tmp_data['verified_timesheet'][$user_id][$row['pay_period_id']]['created_date'];
-							} else {
-								$processed_data['verified_time_sheet'] = TTi18n::getText('No');
-								$processed_data['verified_time_sheet_date'] = FALSE;
+								if ( isset( $this->tmp_data['verified_timesheet'][$user_id][$row['pay_period_id']]) ) {
+									$processed_data['verified_time_sheet'] = $this->tmp_data['verified_timesheet'][$user_id][$row['pay_period_id']]['status'];
+									$processed_data['verified_time_sheet_date'] = $this->tmp_data['verified_timesheet'][$user_id][$row['pay_period_id']]['created_date'];
+								} else {
+									$processed_data['verified_time_sheet'] = TTi18n::getText('No');
+									$processed_data['verified_time_sheet_date'] = FALSE;
+								}
+
+								$this->data[] = array_merge( $this->tmp_data['user'][$user_id], $row, $date_columns, $processed_data );
+
+								$this->getProgressBarObject()->set( $this->getAMFMessageID(), $key );
+								$key++;
 							}
-
-							$this->data[] = array_merge( $this->tmp_data['user'][$user_id], $row, $date_columns, $processed_data );
-
-							$this->getProgressBarObject()->set( $this->getAMFMessageID(), $key );
-							$key++;
 						}
 					}
 				}
 			}
+			unset($this->tmp_data, $row, $date_columns, $processed_data, $level_1, $level_2, $level_3);
 		}
-		unset($this->tmp_data, $row, $date_columns, $processed_data, $level_1, $level_2, $level_3);
 		//Debug::Arr($this->data, 'preProcess Data: ', __FILE__, __LINE__, __METHOD__,10);
 
 		return TRUE;
