@@ -118,7 +118,7 @@ class UserSummaryReport extends Report {
 										'-1050-title' => TTi18n::gettext('Title'),
 										'-1060-province' => TTi18n::gettext('Province/State'),
 										'-1070-country' => TTi18n::gettext('Country'),
-										'-1080-group' => TTi18n::gettext('Group'),
+										'-1080-user_group' => TTi18n::gettext('Group'),
 										'-1090-default_branch' => TTi18n::gettext('Branch'), //abbreviate for space
 										'-1100-default_department' => TTi18n::gettext('Department'), //abbreviate for space
 										'-1110-currency' => TTi18n::gettext('Currency'),
@@ -221,7 +221,7 @@ class UserSummaryReport extends Report {
 										'-1050-by_employee+bank' => TTi18n::gettext('Bank Information By Employee'),
 										'-1060-by_employee+preference' => TTi18n::gettext('Preferences By Employee'),
 										//'-1020-by_employee+deduction' => TTi18n::gettext('Deductions By Employee'),
-										'-1070-by_employee+birth_date' => TTi18n::gettext('Birth Days By Employee'),
+										'-1070-by_employee+birth_date' => TTi18n::gettext('Birthdays By Employee'),
 
 										'-1080-by_branch_by_employee+contact' => TTi18n::gettext('Contact Information By Branch/Employee'),
 										'-1090-by_branch_by_employee+address' => TTi18n::gettext('Addresses By Branch/Employee'),
@@ -330,7 +330,7 @@ class UserSummaryReport extends Report {
 
 							$retval['columns'][] = 'birth-date_stamp';
 
-							$retval['group'][] = 'birth-date_month';
+							//$retval['group'][] = 'birth-date_month';
 
 							$retval['sub_total'][] = 'birth-date_month';
 
@@ -346,7 +346,7 @@ class UserSummaryReport extends Report {
 							$retval['columns'][] = 'default_branch';
 							$retval['columns'][] = 'default_department';
 							$retval['columns'][] = 'title';
-							$retval['columns'][] = 'group';
+							$retval['columns'][] = 'user_group';
 
 							$retval['columns'][] = 'first_name';
 							$retval['columns'][] = 'last_name';
@@ -358,7 +358,7 @@ class UserSummaryReport extends Report {
 							$retval['sort'][] = array('default_branch' => 'asc');
 							$retval['sort'][] = array('default_department' => 'asc');
 							$retval['sort'][] = array('title' => 'asc');
-							$retval['sort'][] = array('group' => 'asc');
+							$retval['sort'][] = array('user_group' => 'asc');
 							$retval['sort'][] = array('last_name' => 'asc');
 							$retval['sort'][] = array('first_name' => 'asc');
 							//$retval['sort'][] = array('hire-date_month' => 'asc');
@@ -667,14 +667,14 @@ class UserSummaryReport extends Report {
 	}
 
 	//Get raw data for report
-	function _getData() {
+	function _getData( $format = NULL ) {
 		$this->tmp_data = array('user' => array(), 'user_preference' => array(), 'user_wage' => array(),  'user_bank' => array(), 'user_deduction' => array(), 'total_user' => array() );
 
 		$columns = $this->getColumnConfig();
 		$filter_data = $this->getFilterConfig();
 
 		if ( $this->getPermissionObject()->Check('user','view') == FALSE OR $this->getPermissionObject()->Check('wage','view') == FALSE ) {
-			$hlf = new HierarchyListFactory();
+			$hlf = TTnew( 'HierarchyListFactory' );
 			$permission_children_ids = $wage_permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $this->getUserObject()->getCompany(), $this->getUserObject()->getID() );
 			Debug::Arr($permission_children_ids,'Permission Children Ids:', __FILE__, __LINE__, __METHOD__,10);
 		} else {
@@ -708,7 +708,7 @@ class UserSummaryReport extends Report {
 		//Debug::Arr($wage_permission_children_ids, 'Wage Children: '. count($wage_permission_children_ids), __FILE__, __LINE__, __METHOD__,10);
 
 		//Get user data for joining.
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$ulf->getAPISearchByCompanyIdAndArrayCriteria( $this->getUserObject()->getCompany(), $filter_data );
 		Debug::Text(' User Rows: '. $ulf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
 		$this->getProgressBarObject()->start( $this->getAMFMessageID(), $ulf->getRecordCount(), NULL, TTi18n::getText('Retrieving Data...') );
@@ -727,7 +727,7 @@ class UserSummaryReport extends Report {
 
 
 		//Get user preference data for joining.
-		$uplf = new UserPreferenceListFactory();
+		$uplf = TTnew( 'UserPreferenceListFactory' );
 		$uplf->getAPISearchByCompanyIdAndArrayCriteria( $this->getUserObject()->getCompany(), $filter_data );
 		Debug::Text(' User Preference Rows: '. $ulf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
 		$this->getProgressBarObject()->start( $this->getAMFMessageID(), $uplf->getRecordCount(), NULL, TTi18n::getText('Retrieving Data...') );
@@ -738,7 +738,7 @@ class UserSummaryReport extends Report {
 
 		//Get user wage data for joining.
 		$filter_data['wage_group_id'] = 0; //Use default wage groups only.
-		$uwlf = new UserWageListFactory();
+		$uwlf = TTnew( 'UserWageListFactory' );
 		$uwlf->getAPILastWageSearchByCompanyIdAndArrayCriteria( $this->getUserObject()->getCompany(), $filter_data );
 		Debug::Text(' User Wage Rows: '. $uwlf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
 		$this->getProgressBarObject()->start( $this->getAMFMessageID(), $ulf->getRecordCount(), NULL, TTi18n::getText('Retrieving Data...') );
@@ -751,7 +751,7 @@ class UserSummaryReport extends Report {
 
 
 		//Get user bank data for joining.
-		$balf = new BankAccountListFactory();
+		$balf = TTnew( 'BankAccountListFactory' );
 		$balf->getAPISearchByCompanyIdAndArrayCriteria( $this->getUserObject()->getCompany(), $filter_data );
 		Debug::Text(' User Bank Rows: '. $balf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
 		$this->getProgressBarObject()->start( $this->getAMFMessageID(), $balf->getRecordCount(), NULL, TTi18n::getText('Retrieving Data...') );
@@ -769,43 +769,45 @@ class UserSummaryReport extends Report {
 		$this->getProgressBarObject()->start( $this->getAMFMessageID(), count($this->tmp_data['user']), NULL, TTi18n::getText('Pre-Processing Data...') );
 
 		$key=0;
-		foreach( $this->tmp_data['user'] as $user_id => $row ) {
-			if ( isset($row['hire_date']) ) {
-				$hire_date_columns = TTDate::getReportDates( 'hire', $row['hire_date'], FALSE, $this->getUserObject() );
-			} else {
-				$hire_date_columns = array();
-			}
+		if ( isset($this->tmp_data['user']) ) {
+			foreach( $this->tmp_data['user'] as $user_id => $row ) {
+				if ( isset($row['hire_date']) ) {
+					$hire_date_columns = TTDate::getReportDates( 'hire', $row['hire_date'], FALSE, $this->getUserObject() );
+				} else {
+					$hire_date_columns = array();
+				}
 
-			if ( isset($row['termination_date']) ) {
-				$termination_date_columns = TTDate::getReportDates( 'termination', $row['termination_date'], FALSE, $this->getUserObject() );
-			} else {
-				$termination_date_columns = array();
-			}
-			if ( isset($row['birth_date']) ) {
-				$birth_date_columns = TTDate::getReportDates( 'birth', $row['birth_date'], FALSE, $this->getUserObject() );
-			} else {
-				$birth_date_columns = array();
-			}
+				if ( isset($row['termination_date']) ) {
+					$termination_date_columns = TTDate::getReportDates( 'termination', $row['termination_date'], FALSE, $this->getUserObject() );
+				} else {
+					$termination_date_columns = array();
+				}
+				if ( isset($row['birth_date']) ) {
+					$birth_date_columns = TTDate::getReportDates( 'birth', $row['birth_date'], FALSE, $this->getUserObject() );
+				} else {
+					$birth_date_columns = array();
+				}
 
-			$processed_data = array();
-			if ( isset($this->tmp_data['user_preference'][$user_id]) ) {
-				$processed_data = array_merge( $processed_data, $this->tmp_data['user_preference'][$user_id] );
-			}
-			if ( isset($this->tmp_data['user_bank'][$user_id]) ) {
-				$processed_data = array_merge( $processed_data, $this->tmp_data['user_bank'][$user_id] );
-			}
-			if ( isset($this->tmp_data['user_wage'][$user_id]) ) {
-				$processed_data = array_merge( $processed_data, $this->tmp_data['user_wage'][$user_id] );
-			}
+				$processed_data = array();
+				if ( isset($this->tmp_data['user_preference'][$user_id]) ) {
+					$processed_data = array_merge( $processed_data, $this->tmp_data['user_preference'][$user_id] );
+				}
+				if ( isset($this->tmp_data['user_bank'][$user_id]) ) {
+					$processed_data = array_merge( $processed_data, $this->tmp_data['user_bank'][$user_id] );
+				}
+				if ( isset($this->tmp_data['user_wage'][$user_id]) ) {
+					$processed_data = array_merge( $processed_data, $this->tmp_data['user_wage'][$user_id] );
+				}
 
-			$this->data[] = array_merge( $row, $hire_date_columns, $termination_date_columns, $birth_date_columns, $processed_data );
-
-			$this->getProgressBarObject()->set( $this->getAMFMessageID(), $key );
-			$key++;
+				$this->data[] = array_merge( $row, $hire_date_columns, $termination_date_columns, $birth_date_columns, $processed_data );
 
+				$this->getProgressBarObject()->set( $this->getAMFMessageID(), $key );
+				$key++;
+			}
+			unset($this->tmp_data, $row, $date_columns, $user_id, $hire_date_columns, $termination_date_columns, $birth_date_columns, $processed_data );
 		}
-
 		//Debug::Arr($this->data, 'preProcess Data: ', __FILE__, __LINE__, __METHOD__,10);
+		
 		return TRUE;
 	}
 }
