@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: RequestFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4356 $
+ * $Id: RequestFactory.class.php 4356 2011-03-10 20:02:15Z ipso $
+ * $Date: 2011-03-10 12:02:15 -0800 (Thu, 10 Mar 2011) $
  */
 
 /**
@@ -55,11 +55,11 @@ class RequestFactory extends Factory {
 		switch( $name ) {
 			case 'type':
 				$retval = array(
-										10 => TTi18n::gettext('Missed Punch'),
-										20 => TTi18n::gettext('Time Adjustment'),
-										30 => TTi18n::gettext('Absence (incl. Vacation)'),
-										40 => TTi18n::gettext('Schedule Adjustment'),
-										100 => TTi18n::gettext('Other'),
+										10 => TTi18n::gettext('Missed Punch'), 				//request_punch
+										20 => TTi18n::gettext('Punch Adjustment'), 			//request_punch_adjust
+										30 => TTi18n::gettext('Absence (incl. Vacation)'), 	//request_absence
+										40 => TTi18n::gettext('Schedule Adjustment'), 		//request_schedule
+										100 => TTi18n::gettext('Other'), 					//request_other
 									);
 				break;
 			case 'status':
@@ -79,7 +79,7 @@ class RequestFactory extends Factory {
 										'-1010-first_name' => TTi18n::gettext('First Name'),
 										'-1020-last_name' => TTi18n::gettext('Last Name'),
 										'-1060-title' => TTi18n::gettext('Title'),
-										'-1070-group' => TTi18n::gettext('Group'),
+										'-1070-user_group' => TTi18n::gettext('Group'),
 										'-1080-default_branch' => TTi18n::gettext('Branch'),
 										'-1090-default_department' => TTi18n::gettext('Department'),
 
@@ -93,6 +93,9 @@ class RequestFactory extends Factory {
 										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
 							);
 				break;
+			case 'list_columns':
+				$retval = Misc::arrayIntersectByKey( array('date_stamp','status','type'), Misc::trimSortPrefix( $this->getOptions('columns') ) );
+				break;
 			case 'default_display_columns': //Columns that are displayed by default.
 				$retval = array(
 								'first_name',
@@ -125,12 +128,13 @@ class RequestFactory extends Factory {
 										'last_name' => FALSE,
 										'default_branch' => FALSE,
 										'default_department' => FALSE,
-										'group' => FALSE,
+										'user_group' => FALSE,
 										'title' => FALSE,
 
 										'date_stamp' => FALSE,
 										'type_id' => 'Type',
 										'type' => FALSE,
+										'hierarchy_type_id' => 'HierarchyTypeId',
 										'status_id' => 'Status',
 										'status' => FALSE,
 										'authorized' => 'Authorized',
@@ -142,24 +146,36 @@ class RequestFactory extends Factory {
 	}
 
 	function getUserDateObject() {
-		if ( is_object($this->user_date_obj) ) {
+		if ( is_object( $this->user_date_obj ) ) {
 			return $this->user_date_obj;
 		} else {
-			$udlf = new UserDateListFactory();
-			$this->user_date_obj = $udlf->getById( $this->getUserDateID() )->getCurrent();
+			$udlf = TTnew( 'UserDateListFactory' );
+			$udlf->getById( $this->getUserDateID() );
+			if ( $udlf->getRecordCount() > 0 ) {
+				$this->user_date_obj = $udlf->getCurrent();
+				return $this->user_date_obj;
+			}
 
-			return $this->user_date_obj;
+			return FALSE;
 		}
 	}
 
 	//Used for authorizationFactory
 	function getUserObject() {
-		return $this->getUserDateObject()->getUserObject();
+		if ( is_object($this->getUserDateObject()) ) {
+			return $this->getUserDateObject()->getUserObject();
+		}
+
+		return FALSE;
 	}
 
 	//Used for authorizationFactory
 	function getUser() {
-		return $this->getUserDateObject()->getUser();
+		if ( is_object($this->getUserDateObject()) ) {
+			return $this->getUserDateObject()->getUser();
+		}
+
+		return FALSE;
 	}
 
 	function setUserDate($user_id, $date) {
@@ -184,7 +200,7 @@ class RequestFactory extends Factory {
 	function setUserDateID($id = NULL) {
 		$id = trim($id);
 
-		$udlf = new UserDateListFactory();
+		$udlf = TTnew( 'UserDateListFactory' );
 
 		if (  $this->Validator->isResultSetWithRows(	'user_date',
 														$udlf->getByID($id),
@@ -198,6 +214,38 @@ class RequestFactory extends Factory {
 		return FALSE;
 	}
 
+	//Convert hierarchy type_ids back to request type_ids.
+	function getTypeIdFromHierarchyTypeId( $type_id ) {
+		//Make sure we support an array of type_ids.
+		if ( is_array($type_id) ) {
+			foreach( $type_id as $request_type_id ) {
+				$retval[] = ( $request_type_id >= 1000 AND $request_type_id < 2000 ) ? (int)$request_type_id-1000 : (int)$request_type_id;
+			}
+		} else {
+			$retval = ( $request_type_id >= 1000 AND $request_type_id < 2000 ) ? (int)$type_id-1000 : (int)$type_id;
+			Debug::text('Hierarchy Type ID: '. $type_id .' Request Type ID: '. $retval, __FILE__, __LINE__, __METHOD__,10);
+		}
+
+		return $retval;
+	}
+	function getHierarchyTypeId( $type_id = NULL ) {
+		if ( $type_id == '' ) {
+			$type_id = $this->getType();
+		}
+
+		//Make sure we support an array of type_ids.
+		if ( is_array($type_id) ) {
+			foreach( $type_id as $request_type_id ) {
+				$retval[] = (int)$request_type_id+1000;
+			}
+		} else {
+			$retval = (int)$type_id+1000;
+			Debug::text('Request Type ID: '. $type_id .' Hierarchy Type ID: '. $retval, __FILE__, __LINE__, __METHOD__,10);
+		}
+
+		return $retval;
+	}
+
 	function getType() {
 		if ( isset($this->data['type_id']) ) {
 			return $this->data['type_id'];
@@ -328,8 +376,8 @@ class RequestFactory extends Factory {
 		}
 
 		//Check to make sure this user has superiors to send a request too, otherwise we can't save the request.
-		$hlf = new HierarchyListFactory();
-		$request_parent_level_user_ids = $hlf->getHierarchyParentByCompanyIdAndUserIdAndObjectTypeID( $this->getUserObject()->getCompany(), $this->getUser(), 50, TRUE, FALSE ); //Request - Immediate parents only.
+		$hlf = TTnew( 'HierarchyListFactory' );
+		$request_parent_level_user_ids = $hlf->getHierarchyParentByCompanyIdAndUserIdAndObjectTypeID( $this->getUserObject()->getCompany(), $this->getUser(), $this->getHierarchyTypeId(), TRUE, FALSE ); //Request - Immediate parents only.
 		Debug::Arr($request_parent_level_user_ids, 'Check for Superiors: ', __FILE__, __LINE__, __METHOD__,10);
 
 		if ( !is_array($request_parent_level_user_ids) OR count($request_parent_level_user_ids) == 0 ) {
@@ -344,8 +392,8 @@ class RequestFactory extends Factory {
 	function preSave() {
 		//If this is a new request, find the current authorization level to assign to it.
 		if ( $this->isNew() == TRUE ) {
-			$hlf = new HierarchyListFactory();
-			$hierarchy_arr = $hlf->getHierarchyParentByCompanyIdAndUserIdAndObjectTypeID( $this->getUserObject()->getCompany(), $this->getUserObject()->getID(), 50, FALSE);
+			$hlf = TTnew( 'HierarchyListFactory' );
+			$hierarchy_arr = $hlf->getHierarchyParentByCompanyIdAndUserIdAndObjectTypeID( $this->getUserObject()->getCompany(), $this->getUserObject()->getID(), $this->getHierarchyTypeId(), FALSE);
 
 			$hierarchy_highest_level = 99;
 			if ( is_array( $hierarchy_arr ) ) {
@@ -369,17 +417,17 @@ class RequestFactory extends Factory {
 	function postSave() {
 		//Save message here after we have the request_id.
 		if ( $this->getMessage() !== FALSE ) {
-			$mcf = new MessageControlFactory();
+			$mcf = TTnew( 'MessageControlFactory' );
 			$mcf->StartTransaction();
 
-			$hlf = new HierarchyListFactory();
-			$request_parent_level_user_ids = $hlf->getHierarchyParentByCompanyIdAndUserIdAndObjectTypeID( $this->getUserObject()->getCompany(), $this->getUser(), 50, TRUE, FALSE ); //Request - Immediate parents only.
+			$hlf = TTnew( 'HierarchyListFactory' );
+			$request_parent_level_user_ids = $hlf->getHierarchyParentByCompanyIdAndUserIdAndObjectTypeID( $this->getUserObject()->getCompany(), $this->getUser(), $this->getHierarchyTypeId(), TRUE, FALSE ); //Request - Immediate parents only.
 			Debug::Arr($request_parent_level_user_ids, 'Sending message to current direct Superiors: ', __FILE__, __LINE__, __METHOD__,10);
 
-			$mcf = new MessageControlFactory();
+			$mcf = TTnew( 'MessageControlFactory' );
 			$mcf->setFromUserId( $this->getUser() );
 			$mcf->setToUserId( $request_parent_level_user_ids );
-			$mcf->setObjectType( 50 );
+			$mcf->setObjectType( 50 ); //Messages don't break out request types like hierarchies do.
 			$mcf->setObject( $this->getID() );
 			$mcf->setParent( 0 );
 			$mcf->setSubject( Option::getByKey( $this->getType(), $this->getOptions('type') ) .' '. TTi18n::gettext('request from') .': '. $this->getUserObject()->getFullName(TRUE) );
@@ -392,19 +440,17 @@ class RequestFactory extends Factory {
 			} else {
 				$mcf->FailTransaction();
 			}
+		}
 
-/*
-			$mf = new MessageFactory();
-			$mf->setObjectType( 50 ); //Request
-			$mf->setObject( $this->getID() );
-			$mf->setParent( 0 );
-			$mf->setPriority();
-			$mf->setStatus(10); //UnRead
-			$mf->setBody( $this->getMessage() );
-			if ( $mf->isValid() ) {
-				return $mf->Save();
+		if ( $this->getDeleted() == TRUE ) {
+			Debug::Text('Delete authorization history for this request...'. $this->getId(), __FILE__, __LINE__, __METHOD__,10);
+			$alf = TTnew( 'AuthorizationListFactory' );
+			$alf->getByObjectTypeAndObjectId( $this->getHierarchyTypeId(), $this->getId() );
+			foreach( $alf as $authorization_obj ) {
+				Debug::Text('Deleting authorization ID: '. $authorization_obj->getID(), __FILE__, __LINE__, __METHOD__,10);
+				$authorization_obj->setDeleted(TRUE);
+				$authorization_obj->Save();
 			}
-*/
 		}
 
 		return TRUE;
@@ -453,7 +499,7 @@ class RequestFactory extends Factory {
 		return FALSE;
 	}
 
-	function getObjectAsArray( $include_columns = NULL ) {
+	function getObjectAsArray( $include_columns = NULL, $permission_children_ids = FALSE ) {
 		$variable_function_map = $this->getVariableToFunctionMap();
 		if ( is_array( $variable_function_map ) ) {
 			foreach( $variable_function_map as $variable => $function_stub ) {
@@ -464,7 +510,7 @@ class RequestFactory extends Factory {
 						case 'first_name':
 						case 'last_name':
 						case 'title':
-						case 'group':
+						case 'user_group':
 						case 'default_branch':
 						case 'default_department':
 						case 'user_id':
@@ -490,6 +536,7 @@ class RequestFactory extends Factory {
 					}
 				}
 			}
+			$this->getPermissionColumns( &$data, $this->getColumn( 'user_id' ), $this->getCreatedBy(), $permission_children_ids, $include_columns );
 			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
 		}
 
@@ -497,7 +544,7 @@ class RequestFactory extends Factory {
 	}
 
 	function addLog( $log_action ) {
-		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Request - Type').': '. $this->getType(), NULL, $this->getTable() );
+		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Request - Type').': '. Option::getByKey( $this->getType(), $this->getOptions('type') ), NULL, $this->getTable(), $this );
 	}
 }
 ?>
