@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3928 $
- * $Id: RequestListFactory.class.php 3928 2010-11-11 20:29:54Z ipso $
- * $Date: 2010-11-11 12:29:54 -0800 (Thu, 11 Nov 2010) $
+ * $Revision: 4356 $
+ * $Id: RequestListFactory.class.php 4356 2011-03-10 20:02:15Z ipso $
+ * $Date: 2011-03-10 12:02:15 -0800 (Thu, 10 Mar 2011) $
  */
 
 /**
@@ -400,7 +400,7 @@ class RequestListFactory extends RequestFactory implements IteratorAggregate {
 
 		$strict_order = TRUE;
 		if ( $order == NULL ) {
-			$order = array('b.date_stamp' => 'desc', 'c.last_name' => 'asc' );
+			$order = array('a.type_id' => 'asc', 'b.date_stamp' => 'desc', 'c.last_name' => 'asc' );
 			$strict_order = FALSE;
 		}
 
@@ -439,6 +439,67 @@ class RequestListFactory extends RequestFactory implements IteratorAggregate {
 		return $this;
 	}
 
+	function getByHierarchyLevelMapAndTypeAndStatusAndNotAuthorized($hierarchy_level_map, $type_id, $status,  $limit = NULL, $page = NULL, $where = NULL, $order = NULL) {
+		if ( $hierarchy_level_map == '') {
+			return FALSE;
+		}
+
+		if ( $status == '') {
+			return FALSE;
+		}
+
+		$additional_sort_fields = array( 'date_stamp', 'user_id' );
+
+		$sort_column_aliases = array(
+									 'date_stamp' => 'date_stamp',
+									 'user_id' => 'c.last_name',
+									 );
+
+		$order = $this->getColumnsFromAliases( $order, $sort_column_aliases );
+
+		$strict_order = TRUE;
+		if ( $order == NULL ) {
+			$order = array('b.date_stamp' => 'desc', 'c.last_name' => 'asc' );
+			$strict_order = FALSE;
+		}
+
+		$af = new AuthorizationFactory();
+		$udf = new UserDateFactory();
+		$uf = new UserFactory();
+		$huf = new HierarchyUserFactory();
+
+		$ph = array(
+					'status' => $status,
+					'type_id' => $type_id
+					);
+
+		$query = '
+					select 	a.*
+					from	'. $this->getTable() .' as a,
+							'. $udf->getTable() .' as b,
+							'. $uf->getTable() .' as c,
+							'. $huf->getTable() .' as z
+					where	a.user_date_id = b.id
+						AND b.user_id = z.user_id
+						AND b.user_id = c.id
+						AND	a.status_id = ?
+						AND	a.type_id = ?
+						AND a.authorized = 0
+						AND ( '. HierarchyLevelFactory::convertHierarchyLevelMapToSQL( $hierarchy_level_map ) .' )
+						AND ( a.deleted = 0 AND b.deleted = 0 AND c.deleted = 0 )
+				';
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order, $strict_order, $additional_sort_fields );
+
+		if ($limit == NULL) {
+			$this->rs = $this->db->Execute($query, $ph);
+		} else {
+			$this->rs = $this->db->PageExecute($query, $limit, $page, $ph);
+		}
+
+		return $this;
+	}
+
 /*
 	function getByUserIdListAndStatusAndNotAuthorized($id, $status, $parent_level_user_ids, $current_level_user_ids, $limit = NULL, $page = NULL, $where = NULL, $order = NULL) {
 		$key = Option::getByValue($status, $this->getOptions('status') );
@@ -658,8 +719,6 @@ class RequestListFactory extends RequestFactory implements IteratorAggregate {
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order );
 
-		Debug::Text('Query: '. $query, __FILE__, __LINE__, __METHOD__,10);
-
 		if ($limit == NULL) {
 			$this->rs = $this->db->Execute($query, $ph);
 		} else {
@@ -681,7 +740,14 @@ class RequestListFactory extends RequestFactory implements IteratorAggregate {
 			}
 		}
 
-		$additional_order_fields = array();
+		$additional_order_fields = array('date_stamp', 'user_status_id','last_name', 'first_name', 'default_branch', 'default_department', 'user_group', 'title' );
+
+		$sort_column_aliases = array(
+									 'status' => 'status_id',
+									 'type' => 'type_id',
+									 );
+		$order = $this->getColumnsFromAliases( $order, $sort_column_aliases );
+
 		if ( $order == NULL ) {
 			$order = array( 'status_id' => 'asc', 'type_id' => 'asc', 'date_stamp' => 'desc', );
 			$strict = FALSE;
@@ -695,7 +761,7 @@ class RequestListFactory extends RequestFactory implements IteratorAggregate {
 			$strict = TRUE;
 		}
 		//Debug::Arr($order,'Order Data:', __FILE__, __LINE__, __METHOD__,10);
-		//Debug::Arr($filter_data,'Filter Data:', __FILE__, __LINE__, __METHOD__,10);
+		Debug::Arr($filter_data,'Filter Data:', __FILE__, __LINE__, __METHOD__,10);
 
 		$uf = new UserFactory();
 		$bf = new BranchFactory();
@@ -703,13 +769,17 @@ class RequestListFactory extends RequestFactory implements IteratorAggregate {
 		$ugf = new UserGroupFactory();
 		$utf = new UserTitleFactory();
 		$udf = new UserDateFactory();
+		$huf = new HierarchyUserFactory();
 
 		$ph = array(
 					'company_id' => $company_id,
 					);
 
+		//Need to make this return DISTINCT records only, because if the same child is assigned to multiple hierarchies,
+		//the join to table HUF will force it to return one row for each hierarchy they are a child of. This prevents that.
 		$query = '
-					select 	a.*,
+					select 	DISTINCT
+							a.*,
 							b.first_name as first_name,
 							b.last_name as last_name,
 							b.country as country,
@@ -722,14 +792,16 @@ class RequestListFactory extends RequestFactory implements IteratorAggregate {
 							c.name as default_branch,
 							d.id as default_department_id,
 							d.name as default_department,
-							e.id as group_id,
-							e.name as group,
+							e.id as user_group_id,
+							e.name as user_group,
 							f.id as title_id,
 							f.name as title
 					from 	'. $this->getTable() .' as a
 						LEFT JOIN '. $udf->getTable() .' as udf ON ( a.user_date_id = udf.id AND udf.deleted = 0 )
 						LEFT JOIN '. $uf->getTable() .' as b ON ( udf.user_id = b.id AND b.deleted = 0 )
 
+						LEFT JOIN '. $huf->getTable() .' as huf ON ( udf.user_id = huf.user_id )
+
 						LEFT JOIN '. $bf->getTable() .' as c ON ( b.default_branch_id = c.id AND c.deleted = 0)
 						LEFT JOIN '. $df->getTable() .' as d ON ( b.default_department_id = d.id AND d.deleted = 0)
 						LEFT JOIN '. $ugf->getTable() .' as e ON ( b.group_id = e.id AND e.deleted = 0 )
@@ -739,16 +811,16 @@ class RequestListFactory extends RequestFactory implements IteratorAggregate {
 					';
 
 		if ( isset($filter_data['permission_children_ids']) AND isset($filter_data['permission_children_ids'][0]) AND !in_array(-1, (array)$filter_data['permission_children_ids']) ) {
-			$query  .=	' AND a.user_id in ('. $this->getListSQL($filter_data['permission_children_ids'], $ph) .') ';
+			$query  .=	' AND udf.user_id in ('. $this->getListSQL($filter_data['permission_children_ids'], $ph) .') ';
 		}
 		if ( isset($filter_data['user_id']) AND isset($filter_data['user_id'][0]) AND !in_array(-1, (array)$filter_data['user_id']) ) {
-			$query  .=	' AND a.user_id in ('. $this->getListSQL($filter_data['user_id'], $ph) .') ';
+			$query  .=	' AND udf.user_id in ('. $this->getListSQL($filter_data['user_id'], $ph) .') ';
 		}
 		if ( isset($filter_data['id']) AND isset($filter_data['id'][0]) AND !in_array(-1, (array)$filter_data['id']) ) {
 			$query  .=	' AND a.id in ('. $this->getListSQL($filter_data['id'], $ph) .') ';
 		}
 		if ( isset($filter_data['exclude_id']) AND isset($filter_data['exclude_id'][0]) AND !in_array(-1, (array)$filter_data['exclude_id']) ) {
-			$query  .=	' AND a.user_id not in ('. $this->getListSQL($filter_data['exclude_id'], $ph) .') ';
+			$query  .=	' AND udf.user_id not in ('. $this->getListSQL($filter_data['exclude_id'], $ph) .') ';
 		}
 		if ( isset($filter_data['type_id']) AND isset($filter_data['type_id'][0]) AND !in_array(-1, (array)$filter_data['type_id']) ) {
 			$query  .=	' AND a.type_id in ('. $this->getListSQL($filter_data['type_id'], $ph) .') ';
@@ -780,6 +852,17 @@ class RequestListFactory extends RequestFactory implements IteratorAggregate {
 			$query  .=	' AND b.province in ('. $this->getListSQL($filter_data['province'], $ph) .') ';
 		}
 
+		//Handle authorize list criteria here.
+		if ( isset($filter_data['authorized']) AND isset($filter_data['authorized'][0]) AND !in_array(-1, (array)$filter_data['authorized']) ) {
+			$query  .=	' AND a.authorized in ('. $this->getListSQL($filter_data['authorized'], $ph) .') ';
+		}
+		if ( isset($filter_data['hierarchy_level_map']) AND is_array($filter_data['hierarchy_level_map']) ) {
+			$query  .= ' AND  huf.id IS NOT NULL '; //Make sure the user maps to a hierarchy.
+			$query  .= ' AND ( '. HierarchyLevelFactory::convertHierarchyLevelMapToSQL( $filter_data['hierarchy_level_map'], 'a.', 'huf.', 'a.type_id' ) .' )';
+		} elseif ( isset($filter_data['hierarchy_level_map']) AND $filter_data['hierarchy_level_map'] == FALSE ) {
+			//If hierarchy_level_map is not an array, don't return any requests.
+			$query  .= ' AND  huf.id = -1 '; //Make sure the user maps to a hierarchy.
+		}
 
 		if ( isset($filter_data['created_by']) AND isset($filter_data['created_by'][0]) AND !in_array(-1, (array)$filter_data['created_by']) ) {
 			$query  .=	' AND a.created_by in ('. $this->getListSQL($filter_data['created_by'], $ph) .') ';
@@ -794,6 +877,7 @@ class RequestListFactory extends RequestFactory implements IteratorAggregate {
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
 
+		Debug::Arr($ph,'Query: '. $query, __FILE__, __LINE__, __METHOD__,10);
 		if ($limit == NULL) {
 			$this->rs = $this->db->Execute($query, $ph);
 		} else {
