@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3928 $
- * $Id: RecurringScheduleControlFactory.class.php 3928 2010-11-11 20:29:54Z ipso $
- * $Date: 2010-11-11 12:29:54 -0800 (Thu, 11 Nov 2010) $
+ * $Revision: 4265 $
+ * $Id: RecurringScheduleControlFactory.class.php 4265 2011-02-18 00:49:20Z ipso $
+ * $Date: 2011-02-17 16:49:20 -0800 (Thu, 17 Feb 2011) $
  */
 
 /**
@@ -64,7 +64,7 @@ class RecurringScheduleControlFactory extends Factory {
 										'-1070-auto_fill' => TTi18n::gettext('Auto Pilot'),
 
 										'-1090-title' => TTi18n::gettext('Title'),
-										'-1099-group' => TTi18n::gettext('Group'),
+										'-1099-user_group' => TTi18n::gettext('Group'),
 										'-1100-default_branch' => TTi18n::gettext('Branch'),
 										'-1110-default_department' => TTi18n::gettext('Department'),
 
@@ -74,6 +74,9 @@ class RecurringScheduleControlFactory extends Factory {
 										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
 							);
 				break;
+			case 'list_columns':
+				$retval = Misc::arrayIntersectByKey( $this->getOptions('default_display_columns'), Misc::trimSortPrefix( $this->getOptions('columns') ) );
+				break;
 			case 'default_display_columns': //Columns that are displayed by default.
 				$retval = array(
 								'first_name',
@@ -106,7 +109,7 @@ class RecurringScheduleControlFactory extends Factory {
 										'last_name' => FALSE,
 										'default_branch' => FALSE,
 										'default_department' => FALSE,
-										'group' => FALSE,
+										'user_group' => FALSE,
 										'title' => FALSE,
 										'recurring_schedule_template_control_id' => 'RecurringScheduleTemplateControl',
 										'recurring_schedule_template_control' => FALSE,
@@ -131,7 +134,7 @@ class RecurringScheduleControlFactory extends Factory {
 	function setCompany($id) {
 		$id = trim($id);
 
-		$clf = new CompanyListFactory();
+		$clf = TTnew( 'CompanyListFactory' );
 
 		if ( $this->Validator->isResultSetWithRows(	'company',
 													$clf->getByID($id),
@@ -156,7 +159,7 @@ class RecurringScheduleControlFactory extends Factory {
 	function setRecurringScheduleTemplateControl($id) {
 		$id = trim($id);
 
-		$rstclf = new RecurringScheduleTemplateControlListFactory();
+		$rstclf = TTnew( 'RecurringScheduleTemplateControlListFactory' );
 
 		if ( $this->Validator->isResultSetWithRows(	'recurring_schedule_template_control_id',
 													$rstclf->getByID($id),
@@ -268,7 +271,7 @@ class RecurringScheduleControlFactory extends Factory {
 	}
 
 	function getUser() {
-		$rsulf = new RecurringScheduleUserListFactory();
+		$rsulf = TTnew( 'RecurringScheduleUserListFactory' );
 		$rsulf->getByRecurringScheduleControlId( $this->getId() );
 		foreach ($rsulf as $obj) {
 			$list[] = $obj->getUser();
@@ -288,7 +291,7 @@ class RecurringScheduleControlFactory extends Factory {
 		if ( is_array($ids) ) {
 			if ( !$this->isNew() ) {
 				//If needed, delete mappings first.
-				$rsulf = new RecurringScheduleUserListFactory();
+				$rsulf = TTnew( 'RecurringScheduleUserListFactory' );
 				$rsulf->getByRecurringScheduleControlId( $this->getId() );
 
 				$tmp_ids = array();
@@ -310,7 +313,7 @@ class RecurringScheduleControlFactory extends Factory {
 			}
 
 			//Insert new mappings.
-			$ulf = new UserListFactory();
+			$ulf = TTnew( 'UserListFactory' );
 
 			foreach ($ids as $id) {
 				if ( isset($ids) AND !in_array($id, $tmp_ids) ) {
@@ -318,7 +321,7 @@ class RecurringScheduleControlFactory extends Factory {
 					if ( $ulf->getRecordCount() > 0 ) {
 						$obj = $ulf->getCurrent();
 
-						$rsuf = new RecurringScheduleUserFactory();
+						$rsuf = TTnew( 'RecurringScheduleUserFactory' );
 						$rsuf->setRecurringScheduleControl( $this->getId() );
 						$rsuf->setUser( $id );
 
@@ -409,7 +412,7 @@ class RecurringScheduleControlFactory extends Factory {
 		Debug::text('Start Date: '. TTDate::getDate('DATE+TIME', $start_date) .'('.$start_date.') End Date: '. TTDate::getDate('DATE+TIME', $end_date) .'('.$end_date.')', __FILE__, __LINE__, __METHOD__, 10);
 
 		//Get week data
-		$rstlf = new RecurringScheduleTemplateListFactory();
+		$rstlf = TTnew( 'RecurringScheduleTemplateListFactory' );
 		$rstlf->getByRecurringScheduleTemplateControlId( $this->getRecurringScheduleTemplateControl() )->getCurrent();
 		$max_week = 1;
 		$weeks = array();
@@ -534,7 +537,11 @@ class RecurringScheduleControlFactory extends Factory {
 		return FALSE;
 	}
 
-	function getObjectAsArray( $include_columns = NULL ) {
+	function getObjectAsArray( $include_columns = NULL, $permission_children_ids = FALSE  ) {
+		//
+		//When using the Recurring Schedule view, it returns the user list for every single row and runs out of memory at about 1000 rows.
+		//Need to make the 'user' column explicitly defined instead perhaps?
+		//
 		$variable_function_map = $this->getVariableToFunctionMap();
 		if ( is_array( $variable_function_map ) ) {
 			foreach( $variable_function_map as $variable => $function_stub ) {
@@ -545,7 +552,7 @@ class RecurringScheduleControlFactory extends Factory {
 						case 'first_name':
 						case 'last_name':
 						case 'title':
-						case 'group':
+						case 'user_group':
 						case 'default_branch':
 						case 'default_department':
 						case 'recurring_schedule_template_control':
@@ -566,6 +573,7 @@ class RecurringScheduleControlFactory extends Factory {
 
 				}
 			}
+			$this->getPermissionColumns( &$data, $this->getColumn( 'user_id' ), $this->getCreatedBy(), $permission_children_ids, $include_columns );
 			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
 		}
 
