@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3526 $
- * $Id: RecurringScheduleControlListFactory.class.php 3526 2010-04-26 22:03:24Z ipso $
- * $Date: 2010-04-26 15:03:24 -0700 (Mon, 26 Apr 2010) $
+ * $Revision: 4265 $
+ * $Id: RecurringScheduleControlListFactory.class.php 4265 2011-02-18 00:49:20Z ipso $
+ * $Date: 2011-02-17 16:49:20 -0800 (Thu, 17 Feb 2011) $
  */
 
 /**
@@ -153,8 +153,6 @@ class RecurringScheduleControlListFactory extends RecurringScheduleControlFactor
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order, $strict, $additional_sort_fields );
 
-		//Debug::Text('Query: '. $query, __FILE__, __LINE__, __METHOD__,10);
-
 		if ($limit == NULL) {
 			$this->rs = $this->db->Execute($query, $ph);
 		} else {
@@ -429,8 +427,6 @@ class RecurringScheduleControlListFactory extends RecurringScheduleControlFactor
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
 
-		Debug::Text('Query: '. $query, __FILE__, __LINE__, __METHOD__,10);
-
 		if ($limit == NULL) {
 			$this->rs = $this->db->Execute($query, $ph);
 		} else {
@@ -452,7 +448,7 @@ class RecurringScheduleControlListFactory extends RecurringScheduleControlFactor
 			}
 		}
 
-		$additional_order_fields = array();
+		$additional_order_fields = array('recurring_schedule_template_control', 'recurring_schedule_template_control_description');
 		if ( $order == NULL ) {
 			$order = array( 'recurring_schedule_template_control_id' => 'asc', );
 			$strict = FALSE;
@@ -484,6 +480,9 @@ class RecurringScheduleControlListFactory extends RecurringScheduleControlFactor
 					where	a.company_id = ?
 					';
 
+		if ( isset($filter_data['permission_children_ids']) AND isset($filter_data['permission_children_ids'][0]) AND !in_array(-1, (array)$filter_data['permission_children_ids']) ) {
+			$query  .=	' AND a.created_by in ('. $this->getListSQL($filter_data['permission_children_ids'], $ph) .') ';
+		}
 		if ( isset($filter_data['id']) AND isset($filter_data['id'][0]) AND !in_array(-1, (array)$filter_data['id']) ) {
 			$query  .=	' AND a.id in ('. $this->getListSQL($filter_data['id'], $ph) .') ';
 		}
@@ -525,7 +524,7 @@ class RecurringScheduleControlListFactory extends RecurringScheduleControlFactor
 			}
 		}
 
-		$additional_order_fields = array();
+		$additional_order_fields = array('first_name', 'last_name', 'title','user_group', 'default_branch', 'default_department', 'recurring_schedule_template_control', 'recurring_schedule_template_control_description');
 		if ( $order == NULL ) {
 			$order = array( 'recurring_schedule_template_control_id' => 'asc', );
 			$strict = FALSE;
@@ -568,7 +567,7 @@ class RecurringScheduleControlListFactory extends RecurringScheduleControlFactor
 							d.id as default_department_id,
 							d.name as default_department,
 							e.id as group_id,
-							e.name as group,
+							e.name as user_group,
 							f.id as title_id,
 							f.name as title
 					from 	'. $this->getTable() .' as a
@@ -579,7 +578,6 @@ class RecurringScheduleControlListFactory extends RecurringScheduleControlFactor
 						LEFT JOIN '. $df->getTable() .' as d ON ( b.default_department_id = d.id AND d.deleted = 0)
 						LEFT JOIN '. $ugf->getTable() .' as e ON ( b.group_id = e.id AND e.deleted = 0 )
 						LEFT JOIN '. $utf->getTable() .' as f ON ( b.title_id = f.id AND f.deleted = 0 )
-
 					where	a.company_id = ?
 					';
 
