@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3764 $
- * $Id: RecurringScheduleTemplateControlFactory.class.php 3764 2010-08-13 18:07:55Z ipso $
- * $Date: 2010-08-13 11:07:55 -0700 (Fri, 13 Aug 2010) $
+ * $Revision: 4401 $
+ * $Id: RecurringScheduleTemplateControlFactory.class.php 4401 2011-03-19 20:29:26Z ipso $
+ * $Date: 2011-03-19 13:29:26 -0700 (Sat, 19 Mar 2011) $
  */
 
 /**
@@ -61,10 +61,15 @@ class RecurringScheduleTemplateControlFactory extends Factory {
 										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
 							);
 				break;
+			case 'list_columns':
+				$retval = Misc::arrayIntersectByKey( $this->getOptions('default_display_columns'), Misc::trimSortPrefix( $this->getOptions('columns') ) );
+				break;
 			case 'default_display_columns': //Columns that are displayed by default.
 				$retval = array(
 								'name',
 								'description',
+								'updated_date',
+								'updated_by',
 								);
 				break;
 			case 'unique_columns': //Columns that are unique, and disabled for mass editing.
@@ -101,7 +106,7 @@ class RecurringScheduleTemplateControlFactory extends Factory {
 	function setCompany($id) {
 		$id = trim($id);
 
-		$clf = new CompanyListFactory();
+		$clf = TTnew( 'CompanyListFactory' );
 
 		if ( $this->Validator->isResultSetWithRows(	'company',
 													$clf->getByID($id),
@@ -210,6 +215,7 @@ class RecurringScheduleTemplateControlFactory extends Factory {
 
 				}
 			}
+			$this->getPermissionColumns( &$data, $this->getCreatedBy(), $this->getCreatedBy(), FALSE, $include_columns );
 			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
 		}
 
