@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: RecurringScheduleTemplateFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4670 $
+ * $Id: RecurringScheduleTemplateFactory.class.php 4670 2011-05-13 19:32:19Z ipso $
+ * $Date: 2011-05-13 12:32:19 -0700 (Fri, 13 May 2011) $
  */
 
 /**
@@ -80,6 +80,9 @@ class RecurringScheduleTemplateFactory extends Factory {
 										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
 							);
 				break;
+			case 'list_columns':
+				$retval = Misc::arrayIntersectByKey( $this->getOptions('default_display_columns'), Misc::trimSortPrefix( $this->getOptions('columns') ) );
+				break;
 			case 'default_display_columns': //Columns that are displayed by default.
 				$retval = array(
 								'week',
@@ -142,7 +145,7 @@ class RecurringScheduleTemplateFactory extends Factory {
 		if ( is_object($this->schedule_policy_obj) ) {
 			return $this->schedule_policy_obj;
 		} else {
-			$splf = new SchedulePolicyListFactory();
+			$splf = TTnew( 'SchedulePolicyListFactory' );
 			$splf->getById( $this->getSchedulePolicyID() );
 			if ( $splf->getRecordCount() > 0 ) {
 				$this->schedule_policy_obj = $splf->getCurrent();
@@ -163,7 +166,7 @@ class RecurringScheduleTemplateFactory extends Factory {
 	function setRecurringScheduleTemplateControl($id) {
 		$id = trim($id);
 
-		$rstclf = new RecurringScheduleTemplateControlListFactory();
+		$rstclf = TTnew( 'RecurringScheduleTemplateControlListFactory' );
 
 		if ( $this->Validator->isResultSetWithRows(	'recurring_schedule_template_control',
 													$rstclf->getByID($id),
@@ -348,9 +351,16 @@ class RecurringScheduleTemplateFactory extends Factory {
 	function getTotalTime() {
 		if ( $this->getSchedulePolicyObject() != FALSE ) {
 			if ( $this->getSchedulePolicyObject()->getMealPolicyObject() != FALSE ) {
-				$total_time = ( $this->getEndTime() - $this->getStartTime() ) - $this->getSchedulePolicyObject()->getMealPolicyObject()->getAmount();
-				//Debug::Text('Meal Policy Deduct Amount: '. $this->getSchedulePolicyObject()->getMealPolicyObject()->getAmount() .' Total Time: '. TTDate::getTimeUnit( $total_time ), __FILE__, __LINE__, __METHOD__,10);
-				return $total_time;
+				if ( $this->getSchedulePolicyObject()->getMealPolicyObject()->getType() == 10
+						OR $this->getSchedulePolicyObject()->getMealPolicyObject()->getType() == 20 ) {
+					$total_time = ( $this->getEndTime() - $this->getStartTime() );
+
+					if ( $total_time > $this->getSchedulePolicyObject()->getMealPolicyObject()->getTriggerTime() ) {
+						$total_time -= $this->getSchedulePolicyObject()->getMealPolicyObject()->getAmount();
+					}
+
+					return $total_time;
+				}
 			}
 		}
 
@@ -373,7 +383,7 @@ class RecurringScheduleTemplateFactory extends Factory {
 			$id = NULL;
 		}
 
-		$splf = new SchedulePolicyListFactory();
+		$splf = TTnew( 'SchedulePolicyListFactory' );
 
 		if ( $id == NULL
 				OR
@@ -400,7 +410,7 @@ class RecurringScheduleTemplateFactory extends Factory {
 	function setBranch($id) {
 		$id = trim($id);
 
-		$blf = new BranchListFactory();
+		$blf = TTnew( 'BranchListFactory' );
 
 		Debug::text('Branch ID: '. $id ,__FILE__, __LINE__, __METHOD__, 10);
 
@@ -429,7 +439,7 @@ class RecurringScheduleTemplateFactory extends Factory {
 	function setDepartment($id) {
 		$id = trim($id);
 
-		$dlf = new DepartmentListFactory();
+		$dlf = TTnew( 'DepartmentListFactory' );
 
 		//-1 is for user default department.
 		if (  $id == 0 OR $id == -1
@@ -461,7 +471,7 @@ class RecurringScheduleTemplateFactory extends Factory {
 		}
 
 		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
-			$jlf = new JobListFactory();
+			$jlf = TTnew( 'JobListFactory' );
 		}
 
 		if (  $id == NULL
@@ -493,7 +503,7 @@ class RecurringScheduleTemplateFactory extends Factory {
 		}
 
 		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
-			$jilf = new JobItemListFactory();
+			$jilf = TTnew( 'JobItemListFactory' );
 		}
 
 		if (  $id == NULL
@@ -537,7 +547,7 @@ class RecurringScheduleTemplateFactory extends Factory {
 		$start_date_week = TTDate::getBeginWeekEpoch( $recurring_schedule_control_start_date, 0 ); //Start week on Sunday to match Recurring Schedule.
 		//Debug::text('Week of Start Date: '. $start_date_week ,__FILE__, __LINE__, __METHOD__, 10);
 
-		$apf = new AbsencePolicyFactory();
+		$apf = TTnew( 'AbsencePolicyFactory' );
 		$absence_policy_paid_type_options = $apf->getOptions('paid_type');
 
 		for ( $i=$start_date; $i <= $end_date; $i+=(86400+43200)) {
@@ -580,7 +590,8 @@ class RecurringScheduleTemplateFactory extends Factory {
 						//Loop over each employees shift for this day and check for conflicts
 						foreach( $shifts_index[$iso_date_stamp][$this->getColumn('user_id')] as $shift_key ) {
 							if ( isset($shifts[$iso_date_stamp][$shift_key]) ) {
-								if ( TTDate::isTimeOverLap( ( defined('TIMETREX_API') ) ? TTDate::strtotime($shifts[$iso_date_stamp][$shift_key]['start_date']) : $shifts[$iso_date_stamp][$shift_key]['start_date'], ( defined('TIMETREX_API') ) ? TTDate::strtotime($shifts[$iso_date_stamp][$shift_key]['end_date']) : $shifts[$iso_date_stamp][$shift_key]['end_date'], $start_time, $end_time ) == TRUE ) {
+								//Must use parseDateTime() when called from the API due to date formats that strtotime() fails on.
+								if ( TTDate::isTimeOverLap( ( defined('TIMETREX_API') ) ? TTDate::parseDateTime($shifts[$iso_date_stamp][$shift_key]['start_date']) : $shifts[$iso_date_stamp][$shift_key]['start_date'], ( defined('TIMETREX_API') ) ? TTDate::parseDateTime($shifts[$iso_date_stamp][$shift_key]['end_date']) : $shifts[$iso_date_stamp][$shift_key]['end_date'], $start_time, $end_time ) == TRUE ) {
 									//Debug::text('&nbsp;&nbsp;Found overlapping recurring schedules! User ID: '. $this->getColumn('user_id') .' Start Time: '. $start_time,__FILE__, __LINE__, __METHOD__, 10);
 									continue 2;
 								}
@@ -607,7 +618,7 @@ class RecurringScheduleTemplateFactory extends Factory {
 						//We have to assume they are eligible, because we really won't know
 						//if they will have worked enough days or not. We could assume they
 						//work whatever their schedule is, but chances are they will be eligible then anyways.
-						Debug::text('&nbsp;&nbsp;Found Holiday on this day...',__FILE__, __LINE__, __METHOD__, 10);
+						//Debug::text('&nbsp;&nbsp;Found Holiday on this day...',__FILE__, __LINE__, __METHOD__, 10);
 						$status_id = $holiday_data[$iso_date_stamp]['status_id'];
 						if ( isset($holiday_data[$iso_date_stamp]['absence_policy_id']) ) {
 							$absence_policy_id = $holiday_data[$iso_date_stamp]['absence_policy_id'];
@@ -632,23 +643,28 @@ class RecurringScheduleTemplateFactory extends Factory {
 														'user_id' => $this->getColumn('user_id'),
 														'user_created_by' => $this->getColumn('user_created_by'),
 														'user_full_name' => Misc::getFullName( $this->getColumn('first_name'), NULL, $this->getColumn('last_name'), FALSE, FALSE ),
-
+														'first_name' => $this->getColumn('first_name'),
+														'last_name' => $this->getColumn('last_name'),
 														'title_id' => $this->getColumn('title_id'),
+														'title' => $this->getColumn('title'),
 														'group_id' => $this->getColumn('group_id'),
+														'group' => $this->getColumn('group'),
 														'default_branch_id' => $this->getColumn('default_branch_id'),
-														'default_branch' => Option::getByKey($this->getColumn('default_branch_id'), $branch_options, NULL ),
+														'default_branch' => $this->getColumn('default_branch'),
+														//'default_branch' => Option::getByKey($this->getColumn('default_branch_id'), $branch_options, NULL ),
 														'default_department_id' => $this->getColumn('default_department_id'),
-														'default_department' =>  Option::getByKey($this->getColumn('default_department_id'), $department_options, NULL ),
+														'default_department' => $this->getColumn('default_department'),
+														//'default_department' =>  Option::getByKey($this->getColumn('default_department_id'), $department_options, NULL ),
 
 														'job_id' => $this->getJob(),
-														'job_name' => $this->getColumn('job_name'),
+														'job' => $this->getColumn('job'),
 														'job_status_id' => $this->getColumn('job_status_id'),
 														'job_manual_id' => $this->getColumn('job_manual_id'),
 														'job_branch_id' => $this->getColumn('job_branch_id'),
 														'job_department_id' => $this->getColumn('job_department_id'),
 														'job_group_id' => $this->getColumn('job_group_id'),
 														'job_item_id' => $this->getJobItem(),
-														'job_item_name' => $this->getColumn('job_item_name'),
+														'job_item' => $this->getColumn('job_item'),
 
 														'type_id' => 20, //Recurring
 														'status_id' => $status_id,
@@ -672,9 +688,13 @@ class RecurringScheduleTemplateFactory extends Factory {
 														'absence_policy_id' => $absence_policy_id,
 														'absence_policy' => $absence_policy,
 														'branch_id' => $this->getColumn('schedule_branch_id'),
-														'branch' => Option::getByKey($this->getColumn('schedule_branch_id'), $branch_options, NULL ),
+														'branch' => $this->getColumn('schedule_branch'),
+														//'branch' => Option::getByKey($this->getColumn('schedule_branch_id'), $branch_options, NULL ),
 														'department_id' => $this->getColumn('schedule_department_id'),
-														'department' =>  Option::getByKey($this->getColumn('schedule_department_id'), $department_options, NULL ),
+														'department' => $this->getColumn('schedule_department'),
+														//'department' =>  Option::getByKey($this->getColumn('schedule_department_id'), $department_options, NULL ),
+
+														'created_by_id' => $this->getColumn('recurring_schedule_control_created_by'), //Whoever created the recurring schedule control object is consider the owner.
 														);
 					$shifts_index[$iso_date_stamp][$this->getColumn('user_id')][] = $this->getColumn('user_id').$start_time;
 
@@ -805,7 +825,7 @@ class RecurringScheduleTemplateFactory extends Factory {
 	}
 
 	function addLog( $log_action ) {
-		return TTLog::addEntry( $this->getRecurringScheduleTemplateControl(), $log_action, TTi18n::getText('Recurring Schedule Week'), NULL, $this->getTable(), $this );
+		return TTLog::addEntry( $this->getRecurringScheduleTemplateControl(), $log_action, TTi18n::getText('Recurring Schedule Week').': '. $this->getWeek(), NULL, $this->getTable(), $this );
 	}
 }
 ?>
