@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3680 $
- * $Id: RecurringScheduleTemplateListFactory.class.php 3680 2010-06-29 18:19:32Z ipso $
- * $Date: 2010-06-29 11:19:32 -0700 (Tue, 29 Jun 2010) $
+ * $Revision: 4550 $
+ * $Id: RecurringScheduleTemplateListFactory.class.php 4550 2011-04-19 19:09:38Z ipso $
+ * $Date: 2011-04-19 12:09:38 -0700 (Tue, 19 Apr 2011) $
  */
 
 /**
@@ -149,7 +149,7 @@ class RecurringScheduleTemplateListFactory extends RecurringScheduleTemplateFact
 				$order = array(Misc::trimSortPrefix($filter_data['sort_column']) => $filter_data['sort_order']);
 			}
 		}
-		Debug::Arr($order,'aOrder Data:', __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Arr($order,'aOrder Data:', __FILE__, __LINE__, __METHOD__,10);
 
 
 		$additional_order_fields = array('name', 'description', 'last_name');
@@ -181,6 +181,12 @@ class RecurringScheduleTemplateListFactory extends RecurringScheduleTemplateFact
 		if ( isset($filter_data['default_department_ids']) ) {
 			$filter_data['default_department_id'] = $filter_data['default_department_ids'];
 		}
+		if ( isset($filter_data['branch_ids']) ) {
+			$filter_data['schedule_branch_id'] = $filter_data['branch_ids'];
+		}
+		if ( isset($filter_data['department_ids']) ) {
+			$filter_data['schedule_department_id'] = $filter_data['department_ids'];
+		}
 		if ( isset($filter_data['schedule_branch_ids']) ) {
 			$filter_data['schedule_branch_id'] = $filter_data['schedule_branch_ids'];
 		}
@@ -209,6 +215,10 @@ class RecurringScheduleTemplateListFactory extends RecurringScheduleTemplateFact
 		$rscf = new RecurringScheduleControlFactory();
 		$rsuf = new RecurringScheduleUserFactory();
 		$rstcf = new RecurringScheduleTemplateControlFactory();
+		$bf = new BranchFactory();
+		$df = new DepartmentFactory();
+		$ugf = new UserGroupFactory();
+		$utf = new UserTitleFactory();
 
 		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
 			$jf = new JobFactory();
@@ -225,7 +235,10 @@ class RecurringScheduleTemplateListFactory extends RecurringScheduleTemplateFact
 							cb.user_id as user_id,
 
 							CASE WHEN a.branch_id = -1 THEN d.default_branch_id ELSE a.branch_id END as schedule_branch_id,
+							CASE WHEN a.branch_id = -1 THEN bf.name ELSE bfb.name END as schedule_branch,
 							CASE WHEN a.department_id = -1 THEN d.default_department_id ELSE a.department_id END as schedule_department_id,
+							CASE WHEN a.department_id = -1 THEN df.name ELSE dfb.name END as schedule_department,
+
 							c.start_date as recurring_schedule_control_start_date,
 							c.end_date as recurring_schedule_control_end_date,
 							c.start_week as recurring_schedule_control_start_week,
@@ -235,26 +248,33 @@ class RecurringScheduleTemplateListFactory extends RecurringScheduleTemplateFact
 							d.first_name as first_name,
 							d.last_name as last_name,
 							d.default_branch_id as default_branch_id,
+							bf.name as default_branch,
 							d.default_department_id as default_department_id,
+							df.name as default_department,
 							d.title_id as title_id,
+							utf.name as title,
 							d.group_id as group_id,
+							ugf.name as group,
 							d.created_by as user_created_by,
 							d.hire_date as hire_date,
 							d.termination_date as termination_date,
 
 							uw.id as user_wage_id,
 							uw.hourly_rate as user_wage_hourly_rate,
-							uw.effective_date as user_wage_effective_date';
+							uw.effective_date as user_wage_effective_date,
+
+							c.created_by as recurring_schedule_control_created_by
+							';
 		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
 			$query .= ',
-						x.name as job_name,
+						x.name as job,
 						x.status_id as job_status_id,
 						x.manual_id as job_manual_id,
 						x.branch_id as job_branch_id,
 						x.department_id as job_department_id,
 						x.group_id as job_group_id,
 
-						y.name as job_item_name,
+						y.name as job_item,
 						y.manual_id as job_item_manual_id,
 						y.group_id as job_item_group_id';
 		}
@@ -270,6 +290,14 @@ class RecurringScheduleTemplateListFactory extends RecurringScheduleTemplateFact
 						LEFT JOIN '. $rscf->getTable() .' as c ON a.recurring_schedule_template_control_id = c.recurring_schedule_template_control_id
 						LEFT JOIN '. $rsuf->getTable() .' as cb ON c.id = cb.recurring_schedule_control_id
 						LEFT JOIN '. $uf->getTable() .' as d ON cb.user_id = d.id
+
+						LEFT JOIN '. $bf->getTable() .' as bf ON ( d.default_branch_id = bf.id AND bf.deleted = 0)
+						LEFT JOIN '. $bf->getTable() .' as bfb ON ( a.branch_id = bfb.id AND bfb.deleted = 0)
+						LEFT JOIN '. $df->getTable() .' as df ON ( d.default_department_id = df.id AND df.deleted = 0)
+						LEFT JOIN '. $df->getTable() .' as dfb ON ( a.department_id = dfb.id AND dfb.deleted = 0)
+						LEFT JOIN '. $ugf->getTable() .' as ugf ON ( d.group_id = ugf.id AND ugf.deleted = 0 )
+						LEFT JOIN '. $utf->getTable() .' as utf ON ( d.title_id = utf.id AND utf.deleted = 0 )
+
 						LEFT JOIN '. $uwf->getTable() .' as uw ON uw.id = (select uwb.id
 																	from '. $uwf->getTable() .' as uwb
 																	where uwb.user_id = cb.user_id
@@ -325,6 +353,22 @@ class RecurringScheduleTemplateListFactory extends RecurringScheduleTemplateFact
 			$query  .=	' AND d.title_id in ('. $this->getListSQL($filter_data['title_id'], $ph) .') ';
 		}
 
+		//Use the job_id in the schedule table so we can filter by '0' or No Job
+		if ( isset($filter_data['job_id']) AND isset($filter_data['job_id'][0]) AND !in_array(-1, (array)$filter_data['job_id']) ) {
+			$query  .=	' AND a.job_id in ('. $this->getListSQL($filter_data['job_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['job_group_id']) AND isset($filter_data['job_group_id'][0]) AND !in_array(-1, (array)$filter_data['job_group_id']) ) {
+			if ( isset($filter_data['include_job_subgroups']) AND (bool)$filter_data['include_job_subgroups'] == TRUE ) {
+				$uglf = new UserGroupListFactory();
+				$filter_data['job_group_id'] = $uglf->getByCompanyIdAndGroupIdAndjob_subgroupsArray( $company_id, $filter_data['job_group_id'], TRUE);
+			}
+			$query  .=	' AND x.group_id in ('. $this->getListSQL($filter_data['job_group_id'], $ph) .') ';
+		}
+
+		if ( isset($filter_data['job_item_id']) AND isset($filter_data['job_item_id'][0]) AND !in_array(-1, (array)$filter_data['job_item_id']) ) {
+			$query  .=	' AND a.job_item_id in ('. $this->getListSQL($filter_data['job_item_id'], $ph) .') ';
+		}
+
 		if ( isset($filter_data['start_date']) AND trim($filter_data['start_date']) != ''
 				AND isset($filter_data['end_date']) AND trim($filter_data['end_date']) != '') {
 			$start_date_stamp = $this->db->BindDate( $filter_data['start_date'] );
@@ -377,8 +421,6 @@ class RecurringScheduleTemplateListFactory extends RecurringScheduleTemplateFact
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
 
-		Debug::Text('Query: '. $query, __FILE__, __LINE__, __METHOD__,10);
-
 		if ($limit == NULL) {
 			$this->rs = $this->db->Execute($query, $ph);
 		} else {
@@ -447,6 +489,9 @@ class RecurringScheduleTemplateListFactory extends RecurringScheduleTemplateFact
 					where	b.company_id = ?
 					';
 
+		if ( isset($filter_data['permission_children_ids']) AND isset($filter_data['permission_children_ids'][0]) AND !in_array(-1, (array)$filter_data['permission_children_ids']) ) {
+			$query  .=	' AND a.created_by in ('. $this->getListSQL($filter_data['permission_children_ids'], $ph) .') ';
+		}
 		if ( isset($filter_data['id']) AND isset($filter_data['id'][0]) AND !in_array(-1, (array)$filter_data['id']) ) {
 			$query  .=	' AND a.id in ('. $this->getListSQL($filter_data['id'], $ph) .') ';
 		}
