@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: ScheduleFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4670 $
+ * $Id: ScheduleFactory.class.php 4670 2011-05-13 19:32:19Z ipso $
+ * $Date: 2011-05-13 12:32:19 -0700 (Fri, 13 May 2011) $
  */
 
 /**
@@ -88,6 +88,14 @@ class ScheduleFactory extends Factory {
 										'-2020-updated_by' => TTi18n::gettext('Updated By'),
 										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
 							);
+
+				if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
+					$retval['-1180-job'] = TTi18n::gettext('Job');
+					$retval['-1190-job_item'] = TTi18n::gettext('Task');
+				}
+				break;
+			case 'list_columns':
+				$retval = Misc::arrayIntersectByKey( $this->getOptions('default_display_columns'), Misc::trimSortPrefix( $this->getOptions('columns') ) );
 				break;
 			case 'default_display_columns': //Columns that are displayed by default.
 				$retval = array(
@@ -116,8 +124,13 @@ class ScheduleFactory extends Factory {
 								'branch',
 								'department',
 								);
-				break;
 
+				if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
+					$retval[] = 'job';
+					$retval[] = 'job_item';
+
+				}
+				break;
 		}
 
 		return $retval;
@@ -159,7 +172,9 @@ class ScheduleFactory extends Factory {
 										'department_id' => 'Department',
 										'department' => FALSE,
 										'job_id' => 'Job',
+										'job' => FALSE,
 										'job_item_id' => 'JobItem',
+										'job_item' => FALSE,
 										'total_time' => 'TotalTime',
 										'deleted' => 'Deleted',
 										);
@@ -170,7 +185,7 @@ class ScheduleFactory extends Factory {
 		if ( is_object($this->schedule_policy_obj) ) {
 			return $this->schedule_policy_obj;
 		} else {
-			$splf = new SchedulePolicyListFactory();
+			$splf = TTnew( 'SchedulePolicyListFactory' );
 			$splf->getById( $this->getSchedulePolicyID() );
 			if ( $splf->getRecordCount() > 0 ) {
 				$this->schedule_policy_obj = $splf->getCurrent();
@@ -185,7 +200,7 @@ class ScheduleFactory extends Factory {
 		if ( is_object($this->absence_policy_obj) ) {
 			return $this->absence_policy_obj;
 		} else {
-			$aplf = new AbsencePolicyListFactory();
+			$aplf = TTnew( 'AbsencePolicyListFactory' );
 			$aplf->getById( $this->getAbsencePolicyID() );
 			if ( $aplf->getRecordCount() > 0 ) {
 				$this->absence_policy_obj = $aplf->getCurrent();
@@ -199,7 +214,7 @@ class ScheduleFactory extends Factory {
 		if ( is_object($this->user_date_obj) ) {
 			return $this->user_date_obj;
 		} else {
-			$udlf = new UserDateListFactory();
+			$udlf = TTnew( 'UserDateListFactory' );
 			$udlf->getById( $this->getUserDateID() );
 			if ( $udlf->getRecordCount() > 0 ) {
 				$this->user_date_obj = $udlf->getCurrent();
@@ -218,7 +233,7 @@ class ScheduleFactory extends Factory {
 	function setUser($id) {
 		$id = (int)trim($id);
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 
 		if ( $id > 0 AND
 				$this->Validator->isResultSetWithRows(	'user_id',
@@ -237,13 +252,13 @@ class ScheduleFactory extends Factory {
 		//Get pay period start/continuous time
 		//FIXME: Add proper schedule support for new_day_trigger_time.
 		/*
-		$ppslf = new PayPeriodScheduleListFactory();
+		$ppslf = TTnew( 'PayPeriodScheduleListFactory' );
 		$ppslf->getByUserId( $user_id );
 		if ( $ppslf->getRecordCount() == 1 ) {
 			$pps_obj = $ppslf->getCurrent();
 			Debug::Text(' Pay Period Schedule Maximum Shift Time: '. $pps_obj->getMaximumShiftTime(), __FILE__, __LINE__, __METHOD__,10);
 
-			$plf = new PunchListFactory();
+			$plf = TTnew( 'PunchListFactory' );
 			$plf->getFirstPunchByUserIDAndEpoch( $user_id, $epoch, $pps_obj->getMaximumShiftTime() );
 
 			if ( $plf->getRecordCount() > 0 ) {
@@ -277,7 +292,7 @@ class ScheduleFactory extends Factory {
 
 	function getUserDateID() {
 		if ( isset($this->data['user_date_id']) ) {
-			return $this->data['user_date_id'];
+			return (int)$this->data['user_date_id'];
 		}
 
 		return FALSE;
@@ -286,7 +301,7 @@ class ScheduleFactory extends Factory {
 	function setUserDateID($id, $skip_check = FALSE ) {
 		$id = (int)trim($id);
 
-		$udlf = new UserDateListFactory();
+		$udlf = TTnew( 'UserDateListFactory' );
 
 		if (  	$skip_check == TRUE
 				OR
@@ -440,7 +455,7 @@ class ScheduleFactory extends Factory {
 			$id = NULL;
 		}
 
-		$splf = new SchedulePolicyListFactory();
+		$splf = TTnew( 'SchedulePolicyListFactory' );
 
 		if ( $id == NULL
 				OR
@@ -471,7 +486,7 @@ class ScheduleFactory extends Factory {
 			$id = NULL;
 		}
 
-		$aplf = new AbsencePolicyListFactory();
+		$aplf = TTnew( 'AbsencePolicyListFactory' );
 
 		if (	$id == NULL
 				OR
@@ -497,7 +512,7 @@ class ScheduleFactory extends Factory {
 	function setBranch($id) {
 		$id = trim($id);
 
-		$blf = new BranchListFactory();
+		$blf = TTnew( 'BranchListFactory' );
 
 		if (  $id == 0
 				OR
@@ -523,7 +538,7 @@ class ScheduleFactory extends Factory {
 	function setDepartment($id) {
 		$id = trim($id);
 
-		$dlf = new DepartmentListFactory();
+		$dlf = TTnew( 'DepartmentListFactory' );
 
 		if (  $id == 0
 				OR
@@ -554,7 +569,7 @@ class ScheduleFactory extends Factory {
 		}
 
 		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
-			$jlf = new JobListFactory();
+			$jlf = TTnew( 'JobListFactory' );
 		}
 
 		if (  $id == 0
@@ -586,7 +601,7 @@ class ScheduleFactory extends Factory {
 		}
 
 		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
-			$jilf = new JobItemListFactory();
+			$jilf = TTnew( 'JobItemListFactory' );
 		}
 
 		if (  $id == 0
@@ -714,7 +729,6 @@ class ScheduleFactory extends Factory {
 		return $ret_arr;
 	}
 
-
 	function getScheduleArray( $filter_data )  {
 		global $current_user, $current_user_prefs;
 
@@ -732,20 +746,24 @@ class ScheduleFactory extends Factory {
 		$filter_data['start_date'] = TTDate::getBeginDayEpoch( $filter_data['start_date'] );
 		$filter_data['end_date'] = TTDate::getEndDayEpoch( $filter_data['end_date'] );
 
-		$blf = new BranchListFactory();
-		$branch_options = $blf->getByCompanyIdArray( $current_user->getCompany(), FALSE );
+		//$blf = TTnew( 'BranchListFactory' );
+		//$branch_options = $blf->getByCompanyIdArray( $current_user->getCompany(), FALSE );
+		$branch_options = array(); //No longer needed, use SQL instead.
 
-		$dlf = new DepartmentListFactory();
-		$department_options = $dlf->getByCompanyIdArray( $current_user->getCompany(), FALSE );
+		//$dlf = TTnew( 'DepartmentListFactory' );
+		//$department_options = $dlf->getByCompanyIdArray( $current_user->getCompany(), FALSE );
+		$department_options = array(); //No longer needed, use SQL instead.
 
-		$apf = new AbsencePolicyFactory();
+		$apf = TTnew( 'AbsencePolicyFactory' );
 		$absence_policy_paid_type_options = $apf->getOptions('paid_type');
 
-		$slf = new ScheduleListFactory();
+		$slf = TTnew( 'ScheduleListFactory' );
 		$slf->getSearchByCompanyIdAndArrayCriteria( $current_user->getCompany(), $filter_data );
 		Debug::text('Found Scheduled Rows: '. $slf->getRecordCount(), __FILE__, __LINE__, __METHOD__, 10);
 		Debug::Arr($absence_policy_paid_type_options, 'Paid Absences: ', __FILE__, __LINE__, __METHOD__, 10);
 		if ( $slf->getRecordCount() > 0 ) {
+			$this->getProgressBarObject()->start( $this->getAMFMessageID(), $slf->getRecordCount(), NULL, TTi18n::getText('Processing Committed Shifts...') );
+
 			foreach( $slf as $s_obj ) {
 				//Debug::text('Schedule ID: '. $s_obj->getId() .' User ID: '. $s_obj->getColumn('user_id') .' Start Time: '. $s_obj->getStartTime(), __FILE__, __LINE__, __METHOD__, 10);
 				if ( $s_obj->getAbsencePolicyID() > 0 AND is_object($s_obj->getAbsencePolicyObject()) ) {
@@ -774,24 +792,28 @@ class ScheduleFactory extends Factory {
 													'user_id' => (int)$s_obj->getColumn('user_id'),
 													'user_created_by' => (int)$s_obj->getColumn('user_created_by'),
 													'user_full_name' => Misc::getFullName( $s_obj->getColumn('first_name'), NULL, $s_obj->getColumn('last_name'), FALSE, FALSE ),
-													//'first_name' => $s_obj->getColumn('first_name'),
-													//'last_name' => $s_obj->getColumn('last_name'),
+													'first_name' => $s_obj->getColumn('first_name'),
+													'last_name' => $s_obj->getColumn('last_name'),
 													'title_id' => $s_obj->getColumn('title_id'),
+													'title' => $s_obj->getColumn('title'),
 													'group_id' => $s_obj->getColumn('group_id'),
+													'group' => $s_obj->getColumn('group'),
 													'default_branch_id' => $s_obj->getColumn('default_branch_id'),
-													'default_branch' => Option::getByKey($s_obj->getColumn('default_branch_id'), $branch_options, NULL ),
+													'default_branch' => $s_obj->getColumn('default_branch'),
+													//'default_branch' => Option::getByKey($s_obj->getColumn('default_branch_id'), $branch_options, NULL ),
 													'default_department_id' => $s_obj->getColumn('default_department_id'),
-													'default_department' =>  Option::getByKey($s_obj->getColumn('default_department_id'), $department_options, NULL ),
+													'default_department' => $s_obj->getColumn('default_department'),
+													//'default_department' =>  Option::getByKey($s_obj->getColumn('default_department_id'), $department_options, NULL ),
 
 													'job_id' => $s_obj->getColumn('job_id'),
-													'job_name' => $s_obj->getColumn('job_name'),
+													'job' => $s_obj->getColumn('job'),
 													'job_status_id' => $s_obj->getColumn('job_status_id'),
 													'job_manual_id' => $s_obj->getColumn('job_manual_id'),
 													'job_branch_id' => $s_obj->getColumn('job_branch_id'),
 													'job_department_id' => $s_obj->getColumn('job_department_id'),
 													'job_group_id' => $s_obj->getColumn('job_group_id'),
 													'job_item_id' => $s_obj->getColumn('job_item_id'),
-													'job_item_name' => $s_obj->getColumn('job_item_name'),
+													'job_item' => $s_obj->getColumn('job_item'),
 
 													'type_id' => 10, //Committed
 													'status_id' => (int)$s_obj->getStatus(),
@@ -811,14 +833,22 @@ class ScheduleFactory extends Factory {
 													'absence_policy_id' => (int)$s_obj->getAbsencePolicyID(),
 													'absence_policy' => $absence_policy_name,
 													'branch_id' => (int)$s_obj->getBranch(),
-													'branch' => Option::getByKey($s_obj->getBranch(), $branch_options, NULL ),
+													'branch' => $s_obj->getColumn('branch'),
+													//'branch' => Option::getByKey($s_obj->getBranch(), $branch_options, NULL ),
 													'department_id' => (int)$s_obj->getDepartment(),
-													'department' =>  Option::getByKey($s_obj->getDepartment(), $department_options, NULL ),
+													'department' => $s_obj->getColumn('department'),
+													//'department' => Option::getByKey($s_obj->getDepartment(), $department_options, NULL ),
+
+													'created_by_id' => $s_obj->getCreatedBy(),
 												);
 				$schedule_shifts_index[$iso_date_stamp][$s_obj->getColumn('user_id')][] = $s_obj->getColumn('user_id').$s_obj->getStartTime();
 				unset($absence_policy_name);
+
+				$this->getProgressBarObject()->set( $this->getAMFMessageID(), $slf->getCurrentRow() );
 			}
 
+			$this->getProgressBarObject()->stop( $this->getAMFMessageID() );
+
 			//Debug::Arr($schedule_shifts, 'Committed Schedule Shifts: ', __FILE__, __LINE__, __METHOD__, 10);
 			//Debug::Arr($schedule_shifts_index, 'Committed Schedule Shifts Index: ', __FILE__, __LINE__, __METHOD__, 10);
 		} else {
@@ -830,7 +860,7 @@ class ScheduleFactory extends Factory {
 		//FIXME: What if there are two holiday policies, one that defaults to working, and another that defaults to not working, and they are assigned
 		//to two different groups of employees? For that matter what if the holiday policy isn't assigned to a specific user at all.
 		$holiday_data = array();
-		$hlf = new HolidayListFactory();
+		$hlf = TTnew( 'HolidayListFactory' );
 		$hlf->getByCompanyIdAndStartDateAndEndDate( $current_user->getCompany(), $filter_data['start_date'], $filter_data['end_date'] );
 		Debug::text('Found Holiday Rows: '. $hlf->getRecordCount(), __FILE__, __LINE__, __METHOD__, 10);
 		foreach( $hlf as $h_obj ) {
@@ -844,16 +874,28 @@ class ScheduleFactory extends Factory {
 
 		$recurring_schedule_shifts = array();
 		$recurring_schedule_shifts_index = array();
-		$rstlf = new RecurringScheduleTemplateListFactory();
-		$rstlf->getSearchByCompanyIdAndArrayCriteria( $current_user->getCompany(), $filter_data );
-		Debug::text('Found Recurring Schedule Template Rows: '. $rstlf->getRecordCount(), __FILE__, __LINE__, __METHOD__, 10);
-		if ( $rstlf->getRecordCount() > 0 ) {
-			foreach( $rstlf as $rst_obj ) {
-				//Debug::text('Recurring Schedule Template ID: '. $rst_obj->getID() , __FILE__, __LINE__, __METHOD__, 10);
-				$rst_obj->getShifts( $filter_data['start_date'], $filter_data['end_date'], $holiday_data, $branch_options, $department_options, &$schedule_shifts, &$schedule_shifts_index );
+
+		//If they just want to see absence shifts, ignore recurring schedules completely.
+		if ( !(isset($filter_data['status_id']) AND in_array( 20, (array)$filter_data['status_id'] )) ) {
+			$rstlf = TTnew( 'RecurringScheduleTemplateListFactory' );
+			$rstlf->getSearchByCompanyIdAndArrayCriteria( $current_user->getCompany(), $filter_data );
+			Debug::text('Found Recurring Schedule Template Rows: '. $rstlf->getRecordCount(), __FILE__, __LINE__, __METHOD__, 10);
+			if ( $rstlf->getRecordCount() > 0 ) {
+				$this->getProgressBarObject()->start( $this->getAMFMessageID(), $rstlf->getRecordCount(), NULL, TTi18n::getText('Processing Recurring Shifts...') );
+
+				foreach( $rstlf as $rst_obj ) {
+					//Debug::text('Recurring Schedule Template ID: '. $rst_obj->getID() , __FILE__, __LINE__, __METHOD__, 10);
+					$rst_obj->getShifts( $filter_data['start_date'], $filter_data['end_date'], $holiday_data, $branch_options, $department_options, &$schedule_shifts, &$schedule_shifts_index );
+
+					$this->getProgressBarObject()->set( $this->getAMFMessageID(), $rstlf->getCurrentRow() );
+				}
+
+				$this->getProgressBarObject()->stop( $this->getAMFMessageID() );
+			} else {
+				Debug::text('DID NOT find Recurring Schedule for this time period: ', __FILE__, __LINE__, __METHOD__, 10);
 			}
 		} else {
-			Debug::text('DID NOT find Recurring Schedule for this time period: ', __FILE__, __LINE__, __METHOD__, 10);
+			Debug::text('Skipping recurring schedule check due to status_id filter...', __FILE__, __LINE__, __METHOD__, 10);
 		}
 		//Debug::Arr($schedule_shifts, 'Schedule Shifts: ', __FILE__, __LINE__, __METHOD__, 10);
 		unset($schedule_shifts_index, $recurring_schedule_shifts_index);
@@ -1091,7 +1133,7 @@ class ScheduleFactory extends Factory {
 		if ( $group_schedule == FALSE ) {
 			$valid_schedules = 0;
 
-			$sf = new ScheduleFactory();
+			$sf = TTnew( 'ScheduleFactory' );
 			$tmp_schedule_shifts = $sf->getScheduleArray( $filter_data );
 			//Re-arrange array by user_id->date
 			if ( is_array($tmp_schedule_shifts) ) {
@@ -1183,7 +1225,7 @@ class ScheduleFactory extends Factory {
 						continue; //Skip to next user.
 					}
 
-					$ulf = new UserListFactory();
+					$ulf = TTnew( 'UserListFactory' );
 					$ulf->getByIdAndCompanyId( $user_id, $current_user->getCompany() );
 					if ( $ulf->getRecordCount() != 1 ) {
 						continue;
@@ -1260,7 +1302,7 @@ class ScheduleFactory extends Factory {
 		} else {
 			$valid_schedules = 1;
 
-			$sf = new ScheduleFactory();
+			$sf = TTnew( 'ScheduleFactory' );
 			$raw_schedule_shifts = $sf->getScheduleArray( $filter_data );
 			if ( is_array($raw_schedule_shifts) ) {
 				foreach( $raw_schedule_shifts as $day_epoch => $day_schedule_shifts ) {
@@ -1324,18 +1366,13 @@ class ScheduleFactory extends Factory {
 				foreach ( $tmp_schedule_shifts as $day_epoch => $day_tmp_schedule_shift ) {
 					foreach ( $day_tmp_schedule_shift as $branch => $department_schedule_shifts ) {
 						foreach ( $department_schedule_shifts as $department => $department_schedule_shift ) {
-							$sort = new arr_multisort();
-							$sort->setArray($department_schedule_shift);
-							$sort->addColumn('last_name', 1); //Sort by last name so its easier for employees to find their shifts.
-							$department_schedule_shift = $sort->Sort();
-							unset($sort);
-
+							$department_schedule_shift = Sort::multiSort( $department_schedule_shift, 'last_name' );
 							$this->schedule_shifts[$day_epoch][$branch][$department] = $department_schedule_shift;
 						}
 					}
 				}
 			}
-			//print_r($this->schedule_shifts);
+			//Debug::Arr($this->schedule_shifts, 'Schedule Shifts: ', __FILE__, __LINE__, __METHOD__,10);
 
 			$calendar_array = TTDate::getCalendarArray($filter_data['start_date'], $filter_data['end_date'], $start_week_day );
 			//var_dump($calendar_array);
@@ -1441,7 +1478,7 @@ class ScheduleFactory extends Factory {
 		if ( $this->getEnableOverwrite() == FALSE AND $this->getDeleted() == FALSE AND is_object( $this->getUserDateObject() ) ) {
 			Debug::Text('User Date ID: '. $this->getUserDateID() .' User ID: '. $this->getUserDateObject()->getUser(), __FILE__, __LINE__, __METHOD__,10);
 			//Make sure we're not conflicting with any other schedule shifts.
-			$slf = new ScheduleListFactory();
+			$slf = TTnew( 'ScheduleListFactory' );
 			$conflicting_schedule_shift_obj = $slf->getConflictingByUserIdAndStartDateAndEndDate( $this->getUserDateObject()->getUser(), $this->getStartTime(), $this->getEndTime() );
 
 			if ( is_object($conflicting_schedule_shift_obj) ) {
@@ -1475,7 +1512,7 @@ class ScheduleFactory extends Factory {
 
 		if ( $this->getEnableOverwrite() == TRUE AND $this->isNew() == TRUE ) {
 			//Delete any conflicting schedule shift before saving.
-			$slf = new ScheduleListFactory();
+			$slf = TTnew( 'ScheduleListFactory' );
 			$slf->getConflictingByUserIdAndStartDateAndEndDate( $this->getUserDateObject()->getUser(), $this->getStartTime(), $this->getEndTime() );
 			if ( $slf->getRecordCount() > 0 ) {
 				Debug::Text('Found Conflicting Shift!!', __FILE__, __LINE__, __METHOD__,10);
@@ -1496,8 +1533,6 @@ class ScheduleFactory extends Factory {
 	}
 
 	function postSave() {
-		Debug::text(' postSave()', __FILE__, __LINE__, __METHOD__,10);
-
 		if ( $this->getEnableReCalculateDay() == TRUE ) {
 			//Calculate total time. Mainly for docked.
 			//Calculate entire week as Over Schedule (Weekly) OT policy needs to be reapplied if the schedule changes.
@@ -1538,9 +1573,9 @@ class ScheduleFactory extends Factory {
 							break;
 						case 'start_time':
 							if ( method_exists( $this, $function ) ) {
-								Debug::text('..aaSetting start time from EPOCH: "'. $data[$key]  .'"', __FILE__, __LINE__, __METHOD__,10);
+								Debug::text('..Setting start time from EPOCH: "'. $data[$key]  .'"', __FILE__, __LINE__, __METHOD__,10);
 
-								if ( isset($data['date_stamp']) AND $data['date_stamp'] != '' AND isset($data['start_date']) AND strlen($data['start_date']) > strlen($data[$key]) ) {
+								if ( isset($data['date_stamp']) AND $data['date_stamp'] != '' AND isset($data[$key]) AND $data[$key] != '' ) {
 									Debug::text(' aSetting start time... "'. $data['date_stamp'].' '.$data[$key] .'"', __FILE__, __LINE__, __METHOD__,10);
 									$this->$function( TTDate::parseDateTime( $data['date_stamp'].' '.$data[$key] ) ); //Prefix date_stamp onto start_time
 								} elseif ( isset($data[$key]) AND $data[$key] != '' ) {
@@ -1557,7 +1592,9 @@ class ScheduleFactory extends Factory {
 							break;
 						case 'end_time':
 							if ( method_exists( $this, $function ) ) {
-								if ( isset($data['date_stamp']) AND $data['date_stamp'] != '' AND isset($data['end_date']) AND strlen($data['end_date']) > strlen($data[$key]) ) {
+								Debug::text('..xSetting end time from EPOCH: "'. $data[$key]  .'"', __FILE__, __LINE__, __METHOD__,10);
+
+								if ( isset($data['date_stamp']) AND $data['date_stamp'] != '' AND isset($data[$key]) AND $data[$key] != '' ) {
 									Debug::text(' aSetting end time... "'. $data['date_stamp'].' '.$data[$key] .'"', __FILE__, __LINE__, __METHOD__,10);
 									$this->$function( TTDate::parseDateTime( $data['date_stamp'].' '.$data[$key] ) ); //Prefix date_stamp onto end_time
 								} elseif ( isset($data[$key]) AND $data[$key] != '' ) {
@@ -1582,7 +1619,7 @@ class ScheduleFactory extends Factory {
 			}
 
 			$this->setTotalTime( $this->calcTotalTime() ); //Calculate total time immediately after. This is required for proper audit logging too.
-
+			$this->setEnableReCalculateDay(TRUE); //This is needed for Absence schedules to carry over to the timesheet.
 			$this->setCreatedAndUpdatedColumns( $data );
 
 			return TRUE;
@@ -1591,8 +1628,8 @@ class ScheduleFactory extends Factory {
 		return FALSE;
 	}
 
-	function getObjectAsArray( $include_columns = NULL ) {
-		$uf = new UserFactory();
+	function getObjectAsArray( $include_columns = NULL, $permission_children_ids = FALSE  ) {
+		$uf = TTnew( 'UserFactory' );
 
 		$variable_function_map = $this->getVariableToFunctionMap();
 		if ( is_array( $variable_function_map ) ) {
@@ -1618,6 +1655,8 @@ class ScheduleFactory extends Factory {
 						case 'pay_period_id':
 						case 'branch':
 						case 'department':
+						case 'job':
+						case 'job_item':
 							$data[$variable] = $this->getColumn( $variable );
 							break;
 						case 'status':
@@ -1630,7 +1669,7 @@ class ScheduleFactory extends Factory {
 							$data[$variable] = Option::getByKey( (int)$this->getColumn( 'user_status_id' ), $uf->getOptions( 'status' ) );
 							break;
 						case 'date_stamp':
-							$data[$variable] = TTDate::getAPIDate( 'DATE', TTDate::parseDateTime( $this->getColumn( 'date_stamp' ) ) );
+							$data[$variable] = TTDate::getAPIDate( 'DATE', strtotime( $this->getColumn( 'date_stamp' ) ) );
 							break;
 						case 'start_date':
 							$data[$variable] = TTDate::getAPIDate( 'DATE+TIME', $this->getStartTime() ); //Include both date+time
@@ -1653,6 +1692,7 @@ class ScheduleFactory extends Factory {
 
 				}
 			}
+			$this->getPermissionColumns( &$data, $this->getColumn( 'user_id' ), $this->getCreatedBy(), $permission_children_ids, $include_columns );
 			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
 		}
 
