@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3786 $
- * $Id: ScheduleListFactory.class.php 3786 2010-08-17 22:15:45Z ipso $
- * $Date: 2010-08-17 15:15:45 -0700 (Tue, 17 Aug 2010) $
+ * $Revision: 4673 $
+ * $Id: ScheduleListFactory.class.php 4673 2011-05-13 21:18:06Z ipso $
+ * $Date: 2011-05-13 14:18:06 -0700 (Fri, 13 May 2011) $
  */
 
 /**
@@ -587,10 +587,20 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 			}
 		}
 
-		//$additional_order_fields = array('b.name', 'c.name', 'd.name', 'e.name');
-		$additional_order_fields = array();
+		$additional_order_fields = array('pay_period_id', 'user_id', 'last_name');
+
+		$sort_column_aliases = array(
+									 'pay_period' => 'udf.pay_period',
+									 'user_id' => 'udf.user_id',
+									 'status_id' => 'a.status_id',
+									 'last_name' => 'uf.last_name',
+									 'first_name' => 'uf.first_name',
+									 );
+
+		$order = $this->getColumnsFromAliases( $order, $sort_column_aliases );
 		if ( $order == NULL ) {
-			$order = array( 'udf.pay_period_id' => 'asc','udf.user_id' => 'asc', 'a.start_time' => 'asc' );
+			//$order = array( 'udf.pay_period_id' => 'asc','udf.user_id' => 'asc', 'a.start_time' => 'asc' );
+			$order = array( 'uf.last_name' => 'asc', 'a.start_time' => 'asc' );
 			$strict = FALSE;
 		} else {
 			$strict = TRUE;
@@ -605,7 +615,7 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 			$filter_data['id'] = $filter_data['include_user_ids'];
 		}
 		if ( isset($filter_data['user_status_ids']) ) {
-			$filter_data['status_id'] = $filter_data['user_status_ids'];
+			$filter_data['user_status_id'] = $filter_data['user_status_ids'];
 		}
 		if ( isset($filter_data['user_title_ids']) ) {
 			$filter_data['title_id'] = $filter_data['user_title_ids'];
@@ -619,8 +629,14 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 		if ( isset($filter_data['default_department_ids']) ) {
 			$filter_data['default_department_id'] = $filter_data['default_department_ids'];
 		}
-		if ( isset($filter_data['schedule_status_ids']) ) {
-			$filter_data['schedule_status_id'] = $filter_data['schedule_status_ids'];
+		if ( isset($filter_data['status_ids']) ) {
+			$filter_data['status_id'] = $filter_data['status_ids'];
+		}
+		if ( isset($filter_data['branch_ids']) ) {
+			$filter_data['schedule_branch_id'] = $filter_data['branch_ids'];
+		}
+		if ( isset($filter_data['department_ids']) ) {
+			$filter_data['schedule_department_id'] = $filter_data['department_ids'];
 		}
 		if ( isset($filter_data['schedule_branch_ids']) ) {
 			$filter_data['schedule_branch_id'] = $filter_data['schedule_branch_ids'];
@@ -670,7 +686,9 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 
 							a.user_date_id as user_date_id,
 							a.branch_id as branch_id,
+							bfb.name as branch,
 							a.department_id as department_id,
+							dfb.name as department,
 							a.job_id as job_id,
 							a.job_item_id as job_item_id,
 							a.total_time as total_time,
@@ -701,14 +719,14 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 
 		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
 			$query .= ',
-						x.name as job_name,
+						x.name as job,
 						x.status_id as job_status_id,
 						x.manual_id as job_manual_id,
 						x.branch_id as job_branch_id,
 						x.department_id as job_department_id,
 						x.group_id as job_group_id,
 
-						y.name as job_item_name,
+						y.name as job_item,
 						y.manual_id as job_item_manual_id,
 						y.group_id as job_item_group_id';
 		}
@@ -718,7 +736,9 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 							LEFT JOIN '. $udf->getTable() .' as udf ON a.user_date_id = udf.id
 							LEFT JOIN '. $uf->getTable() .' as uf ON udf.user_id = uf.id
 							LEFT JOIN '. $bf->getTable() .' as bf ON ( uf.default_branch_id = bf.id AND bf.deleted = 0)
+							LEFT JOIN '. $bf->getTable() .' as bfb ON ( a.branch_id = bfb.id AND bfb.deleted = 0)
 							LEFT JOIN '. $df->getTable() .' as df ON ( uf.default_department_id = df.id AND df.deleted = 0)
+							LEFT JOIN '. $df->getTable() .' as dfb ON ( a.department_id = dfb.id AND dfb.deleted = 0)
 							LEFT JOIN '. $ugf->getTable() .' as ugf ON ( uf.group_id = ugf.id AND ugf.deleted = 0 )
 							LEFT JOIN '. $utf->getTable() .' as utf ON ( uf.title_id = utf.id AND utf.deleted = 0 )
 							LEFT JOIN '. $apf->getTable() .' as apf ON a.absence_policy_id = apf.id
@@ -745,8 +765,8 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 		if ( isset($filter_data['exclude_id']) AND isset($filter_data['exclude_id'][0]) AND !in_array(-1, (array)$filter_data['exclude_id']) ) {
 			$query  .=	' AND uf.id not in ('. $this->getListSQL($filter_data['exclude_id'], $ph) .') ';
 		}
-		if ( isset($filter_data['status_id']) AND isset($filter_data['status_id'][0]) AND !in_array(-1, (array)$filter_data['status_id']) ) {
-			$query  .=	' AND uf.status_id in ('. $this->getListSQL($filter_data['status_id'], $ph) .') ';
+		if ( isset($filter_data['user_status_id']) AND isset($filter_data['user_status_id'][0]) AND !in_array(-1, (array)$filter_data['user_status_id']) ) {
+			$query  .=	' AND uf.status_id in ('. $this->getListSQL($filter_data['user_status_id'], $ph) .') ';
 		}
 		if ( isset($filter_data['group_id']) AND isset($filter_data['group_id'][0]) AND !in_array(-1, (array)$filter_data['group_id']) ) {
 			if ( isset($filter_data['include_subgroups']) AND (bool)$filter_data['include_subgroups'] == TRUE ) {
@@ -770,8 +790,8 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 		if ( isset($filter_data['schedule_department_id']) AND isset($filter_data['schedule_department_id'][0]) AND !in_array(-1, (array)$filter_data['schedule_department_id']) ) {
 			$query  .=	' AND a.department_id in ('. $this->getListSQL($filter_data['schedule_department_id'], $ph) .') ';
 		}
-		if ( isset($filter_data['schedule_status_id']) AND isset($filter_data['schedule_status_id'][0]) AND !in_array(-1, (array)$filter_data['schedule_status_id']) ) {
-			$query  .=	' AND a.status_id in ('. $this->getListSQL($filter_data['schedule_status_id'], $ph) .') ';
+		if ( isset($filter_data['status_id']) AND isset($filter_data['status_id'][0]) AND !in_array(-1, (array)$filter_data['status_id']) ) {
+			$query  .=	' AND a.status_id in ('. $this->getListSQL($filter_data['status_id'], $ph) .') ';
 		}
 		if ( isset($filter_data['schedule_policy_id']) AND isset($filter_data['schedule_policy_id'][0]) AND !in_array(-1, (array)$filter_data['schedule_policy_id']) ) {
 			$query  .=	' AND a.schedule_policy_id in ('. $this->getListSQL($filter_data['schedule_policy_id'], $ph) .') ';
@@ -780,13 +800,9 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 			$query .= 	' AND udf.pay_period_id in ('. $this->getListSQL($filter_data['pay_period_ids'], $ph) .') ';
 		}
 
-
 		//Use the job_id in the schedule table so we can filter by '0' or No Job
-		if ( isset($filter_data['include_job_id']) AND isset($filter_data['include_job_id'][0]) AND !in_array(-1, (array)$filter_data['include_job_id']) ) {
-			$query  .=	' AND a.job_id in ('. $this->getListSQL($filter_data['include_job_id'], $ph) .') ';
-		}
-		if ( isset($filter_data['exclude_job_id']) AND isset($filter_data['exclude_job_id'][0]) AND !in_array(-1, (array)$filter_data['exclude_job_id']) ) {
-			$query  .=	' AND a.job_id not in ('. $this->getListSQL($filter_data['exclude_job_id'], $ph) .') ';
+		if ( isset($filter_data['job_id']) AND isset($filter_data['job_id'][0]) AND !in_array(-1, (array)$filter_data['job_id']) ) {
+			$query  .=	' AND a.job_id in ('. $this->getListSQL($filter_data['job_id'], $ph) .') ';
 		}
 		if ( isset($filter_data['job_group_id']) AND isset($filter_data['job_group_id'][0]) AND !in_array(-1, (array)$filter_data['job_group_id']) ) {
 			if ( isset($filter_data['include_job_subgroups']) AND (bool)$filter_data['include_job_subgroups'] == TRUE ) {
@@ -797,7 +813,7 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 		}
 
 		if ( isset($filter_data['job_item_id']) AND isset($filter_data['job_item_id'][0]) AND !in_array(-1, (array)$filter_data['job_item_id']) ) {
-			$query  .=	' AND b.job_item_id in ('. $this->getListSQL($filter_data['job_item_id'], $ph) .') ';
+			$query  .=	' AND a.job_item_id in ('. $this->getListSQL($filter_data['job_item_id'], $ph) .') ';
 		}
 
 
@@ -816,7 +832,7 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
 
-		Debug::text('Query: '. $query, __FILE__, __LINE__, __METHOD__, 10);
+		Debug::Arr($ph,'Query: '. $query, __FILE__, __LINE__, __METHOD__,10);
 
 		if ($limit == NULL) {
 			$this->rs = $this->db->Execute($query, $ph);
@@ -1085,7 +1101,7 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 			$filter_data['id'] = $filter_data['include_user_ids'];
 		}
 		if ( isset($filter_data['user_status_ids']) ) {
-			$filter_data['status_id'] = $filter_data['user_status_ids'];
+			$filter_data['user_status_id'] = $filter_data['user_status_ids'];
 		}
 		if ( isset($filter_data['user_title_ids']) ) {
 			$filter_data['title_id'] = $filter_data['user_title_ids'];
@@ -1130,6 +1146,7 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 		}
 
 		$spf = new SchedulePolicyFactory();
+		$apf = new AbsencePolicyFactory();
 		$uf = new UserFactory();
 		$bf = new BranchFactory();
 		$df = new DepartmentFactory();
@@ -1198,12 +1215,17 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 
 		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
 			$query .= ',
-						w.name as job_name,
+						w.name as job,
 						w.status_id as job_status_id,
 						w.manual_id as job_manual_id,
 						w.branch_id as job_branch_id,
 						w.department_id as job_department_id,
-						w.group_id as job_group_id';
+						w.group_id as job_group_id,
+
+						x.name as job_item,
+						x.manual_id as job_item_manual_id,
+						x.group_id as job_item_group_id
+						';
 		}
 
 		$query .= '
@@ -1328,7 +1350,308 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
 
-		Debug::text('Query: '. $query, __FILE__, __LINE__, __METHOD__, 10);
+		if ($limit == NULL) {
+			$this->rs = $this->db->Execute($query, $ph);
+		} else {
+			$this->rs = $this->db->PageExecute($query, $limit, $page, $ph);
+		}
+
+		return $this;
+	}
+
+	function getScheduleSummaryReportByCompanyIdAndArrayCriteria( $company_id, $filter_data, $limit = NULL, $page = NULL, $where = NULL, $order = NULL ) {
+		if ( $company_id == '') {
+			return FALSE;
+		}
+
+		if ( !is_array($order) ) {
+			//Use Filter Data ordering if its set.
+			if ( isset($filter_data['sort_column']) AND $filter_data['sort_order']) {
+				$order = array(Misc::trimSortPrefix($filter_data['sort_column']) => $filter_data['sort_order']);
+			}
+		}
+
+		$additional_order_fields = array('schedule_policy_id', 'schedule_policy', 'first_name', 'last_name', 'user_status_id', 'group_id', 'group', 'title_id', 'title', 'default_branch_id', 'default_branch', 'default_department_id', 'default_department', 'total_time', 'date_stamp', 'pay_period_id', );
+
+		$sort_column_aliases = array(
+									 'updated_date' => 'a.updated_date',
+									 'created_date' => 'a.created_date',
+									 );
+
+		$order = $this->getColumnsFromAliases( $order, $sort_column_aliases );
+
+		if ( $order == NULL ) {
+			$order = array( 'c.pay_period_id' => 'asc','c.user_id' => 'asc', 'a.start_time' => 'asc' );
+			$strict = FALSE;
+		} else {
+			$strict = TRUE;
+		}
+		//Debug::Arr($order,'Order Data:', __FILE__, __LINE__, __METHOD__,10);
+		Debug::Arr($filter_data,'Filter Data:', __FILE__, __LINE__, __METHOD__,10);
+
+		if ( isset($filter_data['exclude_user_ids']) ) {
+			$filter_data['exclude_id'] = $filter_data['exclude_user_ids'];
+		}
+		if ( isset($filter_data['include_user_ids']) ) {
+			$filter_data['id'] = $filter_data['include_user_ids'];
+		}
+		if ( isset($filter_data['user_status_ids']) ) {
+			$filter_data['user_status_id'] = $filter_data['user_status_ids'];
+		}
+		if ( isset($filter_data['user_title_ids']) ) {
+			$filter_data['title_id'] = $filter_data['user_title_ids'];
+		}
+		if ( isset($filter_data['group_ids']) ) {
+			$filter_data['group_id'] = $filter_data['group_ids'];
+		}
+		if ( isset($filter_data['default_branch_ids']) ) {
+			$filter_data['default_branch_id'] = $filter_data['default_branch_ids'];
+		}
+		if ( isset($filter_data['default_department_ids']) ) {
+			$filter_data['default_department_id'] = $filter_data['default_department_ids'];
+		}
+		if ( isset($filter_data['branch_ids']) ) {
+			$filter_data['branch_id'] = $filter_data['branch_ids'];
+		}
+		if ( isset($filter_data['department_ids']) ) {
+			$filter_data['department_id'] = $filter_data['department_ids'];
+		}
+
+		if ( isset($filter_data['exclude_job_ids']) ) {
+			$filter_data['exclude_id'] = $filter_data['exclude_job_ids'];
+		}
+		if ( isset($filter_data['include_job_ids']) ) {
+			$filter_data['include_job_id'] = $filter_data['include_job_ids'];
+		}
+		if ( isset($filter_data['job_group_ids']) ) {
+			$filter_data['job_group_id'] = $filter_data['job_group_ids'];
+		}
+		if ( isset($filter_data['job_item_ids']) ) {
+			$filter_data['job_item_id'] = $filter_data['job_item_ids'];
+		}
+		if ( isset($filter_data['pay_period_ids']) ) {
+			$filter_data['pay_period_id'] = $filter_data['pay_period_ids'];
+		}
+
+		if ( isset($filter_data['start_time']) ) {
+			$filter_data['start_date'] = $filter_data['start_time'];
+		}
+		if ( isset($filter_data['end_time']) ) {
+			$filter_data['end_date'] = $filter_data['end_time'];
+		}
+
+		$spf = new SchedulePolicyFactory();
+		$apf = new AbsencePolicyFactory();
+		$uf = new UserFactory();
+		$bf = new BranchFactory();
+		$df = new DepartmentFactory();
+		$ugf = new UserGroupFactory();
+		$utf = new UserTitleFactory();
+		$udf = new UserDateFactory();
+		$ppf = new PayPeriodFactory();
+		$uwf = new UserWageFactory();
+
+		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
+			$jf = new JobFactory();
+			$jif = new JobItemFactory();
+		}
+
+		$ph = array(
+					'company_id' => $company_id,
+					);
+
+		//"group" is a reserved word in MySQL.
+		$query = '
+					select
+							a.id as id,
+							a.id as schedule_id,
+							a.status_id as status_id,
+							a.start_time as start_time,
+							a.end_time as end_time,
+
+							a.user_date_id as user_date_id,
+							a.branch_id as branch_id,
+							j.name as branch,
+							a.department_id as department_id,
+							k.name as department,
+							a.job_id as job_id,
+							a.job_item_id as job_item_id,
+							a.total_time as total_time,
+							a.schedule_policy_id as schedule_policy_id,
+							i.name as schedule_policy,
+
+							a.absence_policy_id as absence_policy_id,
+							apf.name as absence_policy,
+							apf.type_id as absence_policy_type_id,
+
+							c.user_id as user_id,
+							c.date_stamp as date_stamp,
+							ppf.id as pay_period_id,
+							ppf.start_date as pay_period_start_date,
+							ppf.end_date as pay_period_end_date,
+							ppf.transaction_date as pay_period_transaction_date,
+
+							c.pay_period_id as pay_period_id,
+
+							d.first_name as first_name,
+							d.last_name as last_name,
+							d.status_id as user_status_id,
+							d.group_id as group_id,
+							g.name as "group",
+							d.title_id as title_id,
+							h.name as title,
+							d.default_branch_id as default_branch_id,
+							e.name as default_branch,
+							d.default_department_id as default_department_id,
+							f.name as default_department,
+							d.created_by as user_created_by,
+
+							m.id as user_wage_id,
+							m.hourly_rate as user_wage_hourly_rate,
+							m.effective_date as user_wage_effective_date,
+
+							y.first_name as created_by_first_name,
+							y.middle_name as created_by_middle_name,
+							y.last_name as created_by_last_name,
+							z.first_name as updated_by_first_name,
+							z.middle_name as updated_by_middle_name,
+							z.last_name as updated_by_last_name';
+
+		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
+			$query .= ',
+						w.name as job_name,
+						w.status_id as job_status_id,
+						w.manual_id as job_manual_id,
+						w.branch_id as job_branch_id,
+						w.department_id as job_department_id,
+						w.group_id as job_group_id';
+		}
+
+		$query .= '
+					from 	'. $this->getTable() .' as a
+							LEFT JOIN '. $spf->getTable() .' as i ON ( a.schedule_policy_id = i.id AND i.deleted = 0)
+							LEFT JOIN '. $apf->getTable() .' as apf ON ( a.absence_policy_id = apf.id AND apf.deleted = 0)
+							LEFT JOIN '. $udf->getTable() .' as c ON a.user_date_id = c.id
+							LEFT JOIN '. $ppf->getTable() .' as ppf ON c.pay_period_id = ppf.id
+							LEFT JOIN '. $uf->getTable() .' as d ON c.user_id = d.id
+
+							LEFT JOIN '. $bf->getTable() .' as e ON ( d.default_branch_id = e.id AND e.deleted = 0)
+							LEFT JOIN '. $df->getTable() .' as f ON ( d.default_department_id = f.id AND f.deleted = 0)
+							LEFT JOIN '. $ugf->getTable() .' as g ON ( d.group_id = g.id AND g.deleted = 0 )
+							LEFT JOIN '. $utf->getTable() .' as h ON ( d.title_id = h.id AND h.deleted = 0 )
+
+							LEFT JOIN '. $bf->getTable() .' as j ON ( a.branch_id = j.id AND j.deleted = 0)
+							LEFT JOIN '. $df->getTable() .' as k ON ( a.department_id = k.id AND k.deleted = 0)
+
+							LEFT JOIN '. $uwf->getTable() .' as m ON m.id = (select m.id
+																		from '. $uwf->getTable() .' as m
+																		where m.user_id = c.user_id
+																			and m.effective_date <= c.date_stamp
+																			and m.deleted = 0
+																			order by m.effective_date desc limit 1)
+					';
+		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
+			$query .= '	LEFT JOIN '. $jf->getTable() .' as w ON a.job_id = w.id';
+			$query .= '	LEFT JOIN '. $jif->getTable() .' as x ON a.job_item_id = x.id';
+		}
+
+		$query .= '
+						LEFT JOIN '. $uf->getTable() .' as y ON ( a.created_by = y.id AND y.deleted = 0 )
+						LEFT JOIN '. $uf->getTable() .' as z ON ( a.updated_by = z.id AND z.deleted = 0 )
+					WHERE d.company_id = ?';
+
+		if ( isset($filter_data['permission_children_ids']) AND isset($filter_data['permission_children_ids'][0]) AND !in_array(-1, (array)$filter_data['permission_children_ids']) ) {
+			$query  .=	' AND d.id in ('. $this->getListSQL($filter_data['permission_children_ids'], $ph) .') ';
+		}
+		if ( isset($filter_data['id']) AND isset($filter_data['id'][0]) AND !in_array(-1, (array)$filter_data['id']) ) {
+			$query  .=	' AND a.id in ('. $this->getListSQL($filter_data['id'], $ph) .') ';
+		}
+		if ( isset($filter_data['exclude_id']) AND isset($filter_data['exclude_id'][0]) AND !in_array(-1, (array)$filter_data['exclude_id']) ) {
+			$query  .=	' AND d.id not in ('. $this->getListSQL($filter_data['exclude_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['user_id']) AND isset($filter_data['user_id'][0]) AND !in_array(-1, (array)$filter_data['user_id']) ) {
+			$query  .=	' AND c.user_id in ('. $this->getListSQL($filter_data['user_id'], $ph) .') ';
+		}
+
+		if ( isset($filter_data['user_status_id']) AND isset($filter_data['user_status_id'][0]) AND !in_array(-1, (array)$filter_data['user_status_id']) ) {
+			$query  .=	' AND d.status_id in ('. $this->getListSQL($filter_data['user_status_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['group_id']) AND isset($filter_data['group_id'][0]) AND !in_array(-1, (array)$filter_data['group_id']) ) {
+			if ( isset($filter_data['include_subgroups']) AND (bool)$filter_data['include_subgroups'] == TRUE ) {
+				$uglf = new UserGroupListFactory();
+				$filter_data['group_id'] = $uglf->getByCompanyIdAndGroupIdAndSubGroupsArray( $company_id, $filter_data['group_id'], TRUE);
+			}
+			$query  .=	' AND d.group_id in ('. $this->getListSQL($filter_data['group_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['default_branch_id']) AND isset($filter_data['default_branch_id'][0]) AND !in_array(-1, (array)$filter_data['default_branch_id']) ) {
+			$query  .=	' AND d.default_branch_id in ('. $this->getListSQL($filter_data['default_branch_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['default_department_id']) AND isset($filter_data['default_department_id'][0]) AND !in_array(-1, (array)$filter_data['default_department_id']) ) {
+			$query  .=	' AND d.default_department_id in ('. $this->getListSQL($filter_data['default_department_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['title_id']) AND isset($filter_data['title_id'][0]) AND !in_array(-1, (array)$filter_data['title_id']) ) {
+			$query  .=	' AND d.title_id in ('. $this->getListSQL($filter_data['title_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['branch_id']) AND isset($filter_data['branch_id'][0]) AND !in_array(-1, (array)$filter_data['branch_id']) ) {
+			$query  .=	' AND a.branch_id in ('. $this->getListSQL($filter_data['branch_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['department_id']) AND isset($filter_data['department_id'][0]) AND !in_array(-1, (array)$filter_data['department_id']) ) {
+			$query  .=	' AND a.department_id in ('. $this->getListSQL($filter_data['department_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['status_id']) AND isset($filter_data['status_id'][0]) AND !in_array(-1, (array)$filter_data['status_id']) ) {
+			$query  .=	' AND a.status_id in ('. $this->getListSQL($filter_data['status_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['schedule_policy_id']) AND isset($filter_data['schedule_policy_id'][0]) AND !in_array(-1, (array)$filter_data['schedule_policy_id']) ) {
+			$query  .=	' AND a.schedule_policy_id in ('. $this->getListSQL($filter_data['schedule_policy_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['pay_period_id']) AND isset($filter_data['pay_period_id'][0]) AND !in_array(-1, (array)$filter_data['pay_period_id']) ) {
+			$query .= 	' AND c.pay_period_id in ('. $this->getListSQL($filter_data['pay_period_id'], $ph) .') ';
+		}
+
+
+		//Use the job_id in the schedule table so we can filter by '0' or No Job
+		if ( isset($filter_data['include_job_id']) AND isset($filter_data['include_job_id'][0]) AND !in_array(-1, (array)$filter_data['include_job_id']) ) {
+			$query  .=	' AND a.job_id in ('. $this->getListSQL($filter_data['include_job_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['exclude_job_id']) AND isset($filter_data['exclude_job_id'][0]) AND !in_array(-1, (array)$filter_data['exclude_job_id']) ) {
+			$query  .=	' AND a.job_id not in ('. $this->getListSQL($filter_data['exclude_job_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['job_group_id']) AND isset($filter_data['job_group_id'][0]) AND !in_array(-1, (array)$filter_data['job_group_id']) ) {
+			if ( isset($filter_data['include_job_subgroups']) AND (bool)$filter_data['include_job_subgroups'] == TRUE ) {
+				$uglf = new UserGroupListFactory();
+				$filter_data['job_group_id'] = $uglf->getByCompanyIdAndGroupIdAndjob_subgroupsArray( $company_id, $filter_data['job_group_id'], TRUE);
+			}
+			$query  .=	' AND w.group_id in ('. $this->getListSQL($filter_data['job_group_id'], $ph) .') ';
+		}
+
+		if ( isset($filter_data['job_item_id']) AND isset($filter_data['job_item_id'][0]) AND !in_array(-1, (array)$filter_data['job_item_id']) ) {
+			$query  .=	' AND b.job_item_id in ('. $this->getListSQL($filter_data['job_item_id'], $ph) .') ';
+		}
+
+
+		if ( isset($filter_data['start_date']) AND trim($filter_data['start_date']) != '' ) {
+			$ph[] = $this->db->BindTimeStamp($filter_data['start_date']);
+			$query  .=	' AND a.start_time >= ?';
+		}
+		if ( isset($filter_data['end_date']) AND trim($filter_data['end_date']) != '' ) {
+			$ph[] = $this->db->BindTimeStamp($filter_data['end_date']);
+			$query  .=	' AND a.start_time <= ?';
+		}
+
+		if ( isset($filter_data['created_by']) AND isset($filter_data['created_by'][0]) AND !in_array(-1, (array)$filter_data['created_by']) ) {
+			$query  .=	' AND a.created_by in ('. $this->getListSQL($filter_data['created_by'], $ph) .') ';
+		}
+		if ( isset($filter_data['updated_by']) AND isset($filter_data['updated_by'][0]) AND !in_array(-1, (array)$filter_data['updated_by']) ) {
+			$query  .=	' AND a.updated_by in ('. $this->getListSQL($filter_data['updated_by'], $ph) .') ';
+		}
+
+		$query .= 	'
+						AND (a.deleted = 0 AND c.deleted = 0 AND d.deleted = 0)
+					';
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
+
+		Debug::Arr($ph,'Query: '. $query, __FILE__, __LINE__, __METHOD__,10);
 
 		if ($limit == NULL) {
 			$this->rs = $this->db->Execute($query, $ph);
