@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3013 $
- * $Id: TimeTrexSoapServer.class.php 3013 2009-11-11 17:03:07Z ipso $
- * $Date: 2009-11-11 09:03:07 -0800 (Wed, 11 Nov 2009) $
+ * $Revision: 4104 $
+ * $Id: TimeTrexSoapServer.class.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 
 /**
@@ -86,7 +86,7 @@ class TimeTrexSoapServer extends TimeTrexSoapServerUnAuthenticated {
 			return FALSE;
 		}
 
-		$slf = new StationListFactory();
+		$slf = TTnew( 'StationListFactory' );
 		$slf->getByStationIdandCompanyId( $station_id, $this->getCompanyObject()->getId() );
 		$current_station = $slf->getCurrent();
 		unset($slf);
@@ -95,14 +95,14 @@ class TimeTrexSoapServer extends TimeTrexSoapServerUnAuthenticated {
 	}
 
 	function getCompanyObject() {
-		$clf = new CompanyListFactory();
+		$clf = TTnew( 'CompanyListFactory' );
 		$current_company = $clf->getByID( $this->getUserObject()->getCompany() )->getCurrent();
 
 		return $current_company;
 	}
 
 	function getScheduleShiftObject() {
-		$sslf = new ScheduleShiftListFactory();
+		$sslf = TTnew( 'ScheduleShiftListFactory' );
 		$schedule_shift_obj = $sslf->getByUserIdAndCurrentScheduleShift( $this->getUserObject()->getId() )->getCurrent();
 
 		Debug::text('Schedule Shift ID: '. $schedule_shift_obj->getId(), __FILE__, __LINE__, __METHOD__, 10);
@@ -176,7 +176,7 @@ class TimeTrexSoapServer extends TimeTrexSoapServerUnAuthenticated {
 			$source = NULL;
 		}
 
-		$slf = new StationListFactory();
+		$slf = TTnew( 'StationListFactory' );
 		$slf->getByStationIdandCompanyId( $station, $this->getCompanyObject()->getId() );
 		$current_station = $slf->getCurrent();
 		unset($slf);
@@ -184,7 +184,7 @@ class TimeTrexSoapServer extends TimeTrexSoapServerUnAuthenticated {
 		if ( $current_station->isNew() ) {
 			Debug::text('Station not found... Adding new one...', __FILE__, __LINE__, __METHOD__, 10);
 
-			$sf = new StationFactory();
+			$sf = TTnew( 'StationFactory' );
 
 			$sf->setCompany( $this->getCompanyObject()->getId() );
 			$sf->setStatus( 'ENABLED' );
@@ -229,7 +229,7 @@ class TimeTrexSoapServer extends TimeTrexSoapServerUnAuthenticated {
 		//Take into account the station allowed employees, as well as child employees.
 		//This is important for companies with many thousands of employees.
 		if ( $this->getPermissionObject()->Check('user','enroll') OR $this->getPermissionObject()->Check('user','enroll_child') ) {
-			$ulf = new UserListFactory();
+			$ulf = TTnew( 'UserListFactory' );
 			$user_list = $ulf->getByCompanyIdArray( $this->getUserObject()->getCompany(), FALSE, FALSE);
 
 			//For ease in Java.
@@ -249,7 +249,7 @@ class TimeTrexSoapServer extends TimeTrexSoapServerUnAuthenticated {
 		$type = strtolower($type);
 		$number = trim($number);
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 
 		if ( version_compare( $this->getClientVersion(), '2.7.0', '<' ) ) {
 			Debug::text('aVersion: '. $this->getClientVersion(), __FILE__, __LINE__, __METHOD__, 10);
@@ -291,12 +291,12 @@ class TimeTrexSoapServer extends TimeTrexSoapServerUnAuthenticated {
 									break;
 							}
 
-							$uilf = new UserIdentificationListFactory();
+							$uilf = TTnew( 'UserIdentificationListFactory' );
 							$uilf->getByUserIdAndTypeIdAndNumber($enroll_user_obj->getID(), 20, $number );
 							if ( $uilf->getRecordCount() > 0 ) {
 								$uif = $uilf->getCurrent();
 							} else {
-								$uif = new UserIdentificationFactory();
+								$uif = TTnew( 'UserIdentificationFactory' );
 							}
 
 							if ( $id == '' AND $uilf->getRecordCount() > 0 ) {
@@ -327,7 +327,7 @@ class TimeTrexSoapServer extends TimeTrexSoapServerUnAuthenticated {
 						break;
 					case 'ibutton':
 						//Remove ibutton from current user.
-						$uilf = new UserIdentificationListFactory();
+						$uilf = TTnew( 'UserIdentificationListFactory' );
 						$uilf->getByCompanyIdAndTypeIdAndValue( $this->getUserObject()->getCompany(), 10, $id );
 						if ( $uilf->getRecordCount() > 0 ) {
 							foreach( $uilf as $ui_obj ) {
@@ -348,12 +348,12 @@ class TimeTrexSoapServer extends TimeTrexSoapServerUnAuthenticated {
 
 							$enroll_user_obj = $enroll_user_obj->getCurrent();
 
-							$uilf = new UserIdentificationListFactory();
+							$uilf = TTnew( 'UserIdentificationListFactory' );
 							$uilf->getByUserIdAndTypeIdAndNumber($enroll_user_obj->getID(), 10, 0 );
 							if ( $uilf->getRecordCount() > 0 ) {
 								$uif = $uilf->getCurrent();
 							} else {
-								$uif = new UserIdentificationFactory();
+								$uif = TTnew( 'UserIdentificationFactory' );
 							}
 							$uif->setUser( $enroll_user_obj->getId() );
 							$uif->setType( 10 ); //iButton
@@ -421,7 +421,7 @@ class TimeTrexSoapServer extends TimeTrexSoapServerUnAuthenticated {
 				Debug::text('Enroller User ID : '. $user_id .' FOUND', __FILE__, __LINE__, __METHOD__, 10);
 
 				//Checking to see if value is enrolled for a different user first.
-				$uilf = new UserIdentificationListFactory();
+				$uilf = TTnew( 'UserIdentificationListFactory' );
 				$uilf->getByCompanyIdAndTypeIdAndValue( $this->getUserObject()->getCompany(), $type, $id );
 				if ( $uilf->getRecordCount() > 0 ) {
 					foreach( $uilf as $ui_obj ) {
@@ -438,12 +438,12 @@ class TimeTrexSoapServer extends TimeTrexSoapServerUnAuthenticated {
 
 				$enroll_user_obj = $ulf->getCurrent();
 
-				$uilf = new UserIdentificationListFactory();
+				$uilf = TTnew( 'UserIdentificationListFactory' );
 				$uilf->getByUserIdAndTypeIdAndNumber($enroll_user_obj->getID(), $type, $number );
 				if ( $uilf->getRecordCount() > 0 ) {
 					$uif = $uilf->getCurrent();
 				} else {
-					$uif = new UserIdentificationFactory();
+					$uif = TTnew( 'UserIdentificationFactory' );
 				}
 
 				if ( $id == '' AND $uilf->getRecordCount() > 0 ) {
@@ -492,10 +492,10 @@ class TimeTrexSoapServer extends TimeTrexSoapServerUnAuthenticated {
 
 		$epoch = TTDate::getTime();
 
-		$slf = new ScheduleListFactory();
+		$slf = TTnew( 'ScheduleListFactory' );
 
 		//Get last punch for this day, for this user.
-		$plf = new PunchListFactory();
+		$plf = TTnew( 'PunchListFactory' );
 		$plf->getPreviousPunchByUserIDAndEpoch( $this->getUserObject()->getId(), $epoch );
 		if ( $plf->getRecordCount() > 0 ) {
 			$prev_punch_obj = $plf->getCurrent();
@@ -656,25 +656,25 @@ class TimeTrexSoapServer extends TimeTrexSoapServerUnAuthenticated {
 		}
 
 		//Get options.
-		$blf = new BranchListFactory();
+		$blf = TTnew( 'BranchListFactory' );
 		$blf->getByCompanyId( $this->getCompanyObject()->getId() );
 		$branch_options = $blf->getArrayByListFactory( $blf, TRUE, FALSE );
 
-		$dlf = new DepartmentListFactory();
+		$dlf = TTnew( 'DepartmentListFactory' );
 		$dlf->getByCompanyId( $this->getCompanyObject()->getId() );
 		$department_options = $dlf->getArrayByListFactory( $dlf, TRUE, FALSE);
 
 		$job_options = array();
 		$job_item_options = array();
 		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
-			$jlf = new JobListFactory();
+			$jlf = TTnew( 'JobListFactory' );
 			$job_options = $jlf->getByCompanyIdAndUserIdAndStatusArray( $this->getCompanyObject()->getId(),  $this->getUserObject()->getId(), array(10), TRUE );
 
-			$jilf = new JobItemListFactory();
+			$jilf = TTnew( 'JobItemListFactory' );
 			$job_item_options = $jilf->getByCompanyIdArray( $this->getCompanyObject()->getId(), TRUE );
 		}
 
-		$pf = new PunchFactory();
+		$pf = TTnew( 'PunchFactory' );
 
 		//Select box options;
 		$data['status_options'] = $pf->getOptions('status');
@@ -732,7 +732,7 @@ class TimeTrexSoapServer extends TimeTrexSoapServerUnAuthenticated {
 		$punch_full_time_stamp = TTDate::parseDateTime($data['date_stamp'].' '.$data['time_stamp']);
 		Debug::Text(' Punch Full TimeStamp: '. date('r'. $punch_full_time_stamp) .' ('.$punch_full_time_stamp.') TimeZone: '. $this->getUserObject()->getUserPreferenceObject()->getTimeZone(), __FILE__, __LINE__, __METHOD__,10);
 
-		$pf = new PunchFactory();
+		$pf = TTnew( 'PunchFactory' );
 		$pf->StartTransaction();
 
 		//Set User before setTimeStamp so rounding can be done properly.
@@ -771,7 +771,7 @@ class TimeTrexSoapServer extends TimeTrexSoapServerUnAuthenticated {
 			}
 
 			if ( $pf->Save( FALSE ) == TRUE ) {
-				$pcf = new PunchControlFactory();
+				$pcf = TTnew( 'PunchControlFactory' );
 				$pcf->setId( $pf->getPunchControlID() );
 				$pcf->setPunchObject( $pf );
 
