@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: TimeTrexSoapServerUnAuthenticated.class.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4104 $
+ * $Id: TimeTrexSoapServerUnAuthenticated.class.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 
 /**
@@ -119,7 +119,7 @@ class TimeTrexSoapServerUnAuthenticated {
 			return FALSE;
 		}
 
-		$slf = new StationListFactory();
+		$slf = TTnew( 'StationListFactory' );
 		$slf->getByStationId( $_GET['StationID'] );
 		$current_station = $slf->getCurrent();
 		unset($slf);
@@ -209,7 +209,7 @@ class TimeTrexSoapServerUnAuthenticated {
 		}
 
 /*
-		$slf = new StationListFactory();
+		$slf = TTnew( 'StationListFactory' );
 		$slf->getByStationID( $station_id );
 		if ( $slf->getRecordCount() > 0 ) {
 			Debug::Text('Found Station!!', __FILE__, __LINE__, __METHOD__,10);
@@ -266,7 +266,7 @@ class TimeTrexSoapServerUnAuthenticated {
 		}
 
 		//Gets all users allowed to punch in/out from this station
-		$slf = new StationListFactory();
+		$slf = TTnew( 'StationListFactory' );
 		$slf->getByStationID( $station_id );
 		if ( $slf->getRecordCount() > 0 ) {
 
@@ -277,26 +277,26 @@ class TimeTrexSoapServerUnAuthenticated {
 
 			if ( $company_id != FALSE ){
 
-				$ulf = new UserListFactory();
+				$ulf = TTnew( 'UserListFactory' );
 				$modified_arr['user_modified'] = $ulf->getIsModifiedByCompanyIdAndDate( $company_id, $last_check_epoch);
 				Debug::Text('Are Users Modified: '. (int)$modified_arr['user_modified'], __FILE__, __LINE__, __METHOD__,10);
 
-				$blf = new BranchListFactory();
+				$blf = TTnew( 'BranchListFactory' );
 				$modified_arr['branch_modified'] = $blf->getIsModifiedByCompanyIdAndDate( $company_id, $last_check_epoch);
 				Debug::Text('Are Branches Modified: '. (int)$modified_arr['branch_modified'] , __FILE__, __LINE__, __METHOD__,10);
 
-				$dlf = new DepartmentListFactory();
+				$dlf = TTnew( 'DepartmentListFactory' );
 				$modified_arr['department_modified'] = $dlf->getIsModifiedByCompanyIdAndDate( $company_id, $last_check_epoch);
 				Debug::Text('Are Departments Modified: '. (int)$modified_arr['department_modified'] , __FILE__, __LINE__, __METHOD__,10);
 
 				if ( version_compare( $this->getClientVersion(), '2.7.0', '>=' ) ) {
-					$uilf = new UserIdentificationListFactory();
+					$uilf = TTnew( 'UserIdentificationListFactory' );
 					$modified_arr['user_identifiers_modified'] = $uilf->getIsModifiedByCompanyIdAndDate( $company_id, $last_check_epoch);
 					Debug::Text('Are User Identifiers Modified: '. (int)$modified_arr['user_identifiers_modified'] , __FILE__, __LINE__, __METHOD__,10);
 				}
 
 				if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
-					$jlf = new JobListFactory();
+					$jlf = TTnew( 'JobListFactory' );
 					$modified_arr['job_modified'] = $jlf->getIsModifiedByCompanyIdAndDate( $company_id, $last_check_epoch);
 					Debug::Text('Are Jobs Modified: '. (int)$modified_arr['job_modified'], __FILE__, __LINE__, __METHOD__,10);
 					if ( $modified_arr['job_modified'] == TRUE ) {
@@ -306,12 +306,12 @@ class TimeTrexSoapServerUnAuthenticated {
 				}
 
 				if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
-					$jilf = new JobItemListFactory();
+					$jilf = TTnew( 'JobItemListFactory' );
 					$modified_arr['job_item_modified'] = $jilf->getIsModifiedByCompanyIdAndDate( $company_id, $last_check_epoch);
 					Debug::Text('Are Job Items Modified: '. (int)$modified_arr['job_item_modified'], __FILE__, __LINE__, __METHOD__,10);
 				}
 
-				$oflf = new OtherFieldListFactory();
+				$oflf = TTnew( 'OtherFieldListFactory' );
 				$modified_arr['other_field_modified'] = $oflf->getIsModifiedByCompanyIdAndDate( $company_id, $last_check_epoch);
 				Debug::Text('Are Other Fields Modified: '. (int)$modified_arr['other_field_modified'], __FILE__, __LINE__, __METHOD__,10);
 
@@ -356,7 +356,7 @@ class TimeTrexSoapServerUnAuthenticated {
 		$permission = new Permission();
 
 		//Gets all users allowed to punch in/out from this station
-		$slf = new StationListFactory();
+		$slf = TTnew( 'StationListFactory' );
 		$slf->getByStationID( $station_id );
 		if ( $slf->getRecordCount() > 0 ) {
 			Debug::Text('Found Station!!', __FILE__, __LINE__, __METHOD__,10);
@@ -366,7 +366,7 @@ class TimeTrexSoapServerUnAuthenticated {
 			if ( $company_id != FALSE ){
 				Debug::Text('Found Company: '. $company_id, __FILE__, __LINE__, __METHOD__,10);
 
-				$ulf = new UserListFactory();
+				$ulf = TTnew( 'UserListFactory' );
 				$ulf->getByCompanyId( $company_id );
 				if ( $ulf->getRecordCount() > 0 ) {
 					Debug::Text('Found Users '. $ulf->getRecordCount() .' for Company: '. $company_id, __FILE__, __LINE__, __METHOD__,10);
@@ -399,7 +399,7 @@ class TimeTrexSoapServerUnAuthenticated {
 							$finger_print_4 = FALSE;
 
 							//Get User identification rows for ibutton and fingerprints.
-							$uilf = new UserIdentificationListFactory();
+							$uilf = TTnew( 'UserIdentificationListFactory' );
 							$uilf->getByUserIdAndTypeId( $u_obj->getId(), array(10,20) ); //iButton and Griaule Fingerprints.
 							//Debug::Text('User Identication Records: '. $uilf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
 							if ( $uilf->getRecordCount() > 0 ) {
@@ -484,14 +484,14 @@ class TimeTrexSoapServerUnAuthenticated {
 		}
 
 		//Gets all users allowed to punch in/out from this station
-		$slf = new StationListFactory();
+		$slf = TTnew( 'StationListFactory' );
 		$slf->getByStationID( $station_id );
 		if ( $slf->getRecordCount() > 0 ) {
 			$s_obj = $slf->getCurrent();
 			$company_id = $s_obj->getCompany();
 
 			if ( $company_id != FALSE ){
-				$uilf = new UserIdentificationListFactory();
+				$uilf = TTnew( 'UserIdentificationListFactory' );
 
 				if ( version_compare( $this->getClientVersion(), '3.0.0', '>=' ) ) {
 					$uilf->getByCompanyIdAndTypeId( $company_id, array(10,25,30,40) ); //iButtons, LIBFP Fingerprints, Barcodes, Proximity Cards
@@ -529,14 +529,14 @@ class TimeTrexSoapServerUnAuthenticated {
 		}
 
 		//Gets all users allowed to punch in/out from this station
-		$slf = new StationListFactory();
+		$slf = TTnew( 'StationListFactory' );
 		$slf->getByStationID( $station_id );
 		if ( $slf->getRecordCount() > 0 ) {
 			$s_obj = $slf->getCurrent();
 			$company_id = $s_obj->getCompany();
 
 			if ( $company_id != FALSE ){
-				$blf = new BranchListFactory();
+				$blf = TTnew( 'BranchListFactory' );
 				$blf->getByCompanyIdAndStatus( $company_id, 10 );
 				if ( $blf->getRecordCount() > 0 ) {
 					$x=0;
@@ -567,14 +567,14 @@ class TimeTrexSoapServerUnAuthenticated {
 		}
 
 		//Gets all users allowed to punch in/out from this station
-		$slf = new StationListFactory();
+		$slf = TTnew( 'StationListFactory' );
 		$slf->getByStationID( $station_id );
 		if ( $slf->getRecordCount() > 0 ) {
 			$s_obj = $slf->getCurrent();
 			$company_id = $s_obj->getCompany();
 
 			if ( $company_id != FALSE ) {
-				$dlf = new DepartmentListFactory();
+				$dlf = TTnew( 'DepartmentListFactory' );
 				$dlf->getByCompanyIdAndStatus( $company_id, 10 );
 				if ( $dlf->getRecordCount() > 0 ) {
 					$x=0;
@@ -608,7 +608,7 @@ class TimeTrexSoapServerUnAuthenticated {
 			return FALSE;
 		}
 
-		$slf = new StationListFactory();
+		$slf = TTnew( 'StationListFactory' );
 		$slf->getByStationID( $station_id );
 		if ( $slf->getRecordCount() > 0 ) {
 			$s_obj = $slf->getCurrent();
@@ -617,7 +617,7 @@ class TimeTrexSoapServerUnAuthenticated {
 
 			if ( $company_id != FALSE ) {
 				//Gets all users allowed to punch in/out from this station
-				$jlf = new JobListFactory();
+				$jlf = TTnew( 'JobListFactory' );
 				//$jlf->getByCompanyIdAndUserIdAndStatus( $company_id,  $current_user->getId(), array(10), TRUE );
 				$jlf->getByStatusIdAndCompanyId( 10, $company_id);
 				if ( $jlf->getRecordCount() > 0 ) {
@@ -657,7 +657,7 @@ class TimeTrexSoapServerUnAuthenticated {
 			return FALSE;
 		}
 
-		$slf = new StationListFactory();
+		$slf = TTnew( 'StationListFactory' );
 		$slf->getByStationID( $station_id );
 		if ( $slf->getRecordCount() > 0 ) {
 			$s_obj = $slf->getCurrent();
@@ -666,7 +666,7 @@ class TimeTrexSoapServerUnAuthenticated {
 
 			if ( $company_id != FALSE ) {
 				//Gets all users allowed to punch in/out from this station
-				$jlf = new JobListFactory();
+				$jlf = TTnew( 'JobListFactory' );
 				$job_to_user_map = $jlf->getJobToUserMapByCompanyIdAndStatus( $company_id, 10 );
 				if ( is_array($job_to_user_map) ) {
 					foreach( $job_to_user_map as $key => $arr ) {
@@ -682,7 +682,7 @@ class TimeTrexSoapServerUnAuthenticated {
 				}
 
 				/*
-				$jualf = new JobUserAllowListFactory();
+				$jualf = TTnew( 'JobUserAllowListFactory' );
 				$jualf->getByCompanyIdAndStatus( $company_id, 10);
 				if ( $jualf->getRecordCount() > 0 ) {
 					$x=0;
@@ -720,7 +720,7 @@ class TimeTrexSoapServerUnAuthenticated {
 			return FALSE;
 		}
 
-		$slf = new StationListFactory();
+		$slf = TTnew( 'StationListFactory' );
 		$slf->getByStationID( $station_id );
 		if ( $slf->getRecordCount() > 0 ) {
 			$s_obj = $slf->getCurrent();
@@ -729,7 +729,7 @@ class TimeTrexSoapServerUnAuthenticated {
 
 			if ( $company_id != FALSE ) {
 				//Gets all users allowed to punch in/out from this station
-				$jilf = new JobItemListFactory();
+				$jilf = TTnew( 'JobItemListFactory' );
 				$jilf->getByCompanyId( $company_id );
 				if ( $jilf->getRecordCount() > 0 ) {
 					$x=0;
@@ -768,7 +768,7 @@ class TimeTrexSoapServerUnAuthenticated {
 			return FALSE;
 		}
 
-		$slf = new StationListFactory();
+		$slf = TTnew( 'StationListFactory' );
 		$slf->getByStationID( $station_id );
 		if ( $slf->getRecordCount() > 0 ) {
 			$s_obj = $slf->getCurrent();
@@ -777,7 +777,7 @@ class TimeTrexSoapServerUnAuthenticated {
 
 			if ( $company_id != FALSE ) {
 				//Gets all users allowed to punch in/out from this station
-				$jilf = new JobItemListFactory();
+				$jilf = TTnew( 'JobItemListFactory' );
 				$job_to_job_item_map = $jilf->getJobToJobItemMapByCompanyIdAndStatus( $company_id, 10 );
 				if ( is_array($job_to_job_item_map) ) {
 					foreach( $job_to_job_item_map as $key => $arr ) {
@@ -792,7 +792,7 @@ class TimeTrexSoapServerUnAuthenticated {
 					}
 				}
 /*
-				$jialf = new JobItemAllowListFactory();
+				$jialf = TTnew( 'JobItemAllowListFactory' );
 				$jialf->getByCompanyIdAndStatus( $company_id, 10);
 				if ( $jialf->getRecordCount() > 0 ) {
 					$x=0;
@@ -826,7 +826,7 @@ class TimeTrexSoapServerUnAuthenticated {
 			return FALSE;
 		}
 
-		$slf = new StationListFactory();
+		$slf = TTnew( 'StationListFactory' );
 		$slf->getByStationID( $station_id );
 		if ( $slf->getRecordCount() > 0 ) {
 			$s_obj = $slf->getCurrent();
@@ -834,7 +834,7 @@ class TimeTrexSoapServerUnAuthenticated {
 			Debug::Text('Company ID: '. $company_id, __FILE__, __LINE__, __METHOD__,10);
 
 			if ( $company_id != FALSE ) {
-				$oflf = new OtherFieldListFactory();
+				$oflf = TTnew( 'OtherFieldListFactory' );
 				$retval = $oflf->getByCompanyIdAndTypeIdArray( $company_id, 15 );
 
 				return $retval;
@@ -884,7 +884,7 @@ class TimeTrexSoapServerUnAuthenticated {
 			Debug::Text('Station ID: '. $station_id, __FILE__, __LINE__, __METHOD__,10);
 			if ( $station_id != 'no_station_id' ) {
 				//Get Company Short name for station_id
-				$slf = new StationListFactory();
+				$slf = TTnew( 'StationListFactory' );
 				$slf->getByStationID( $station_id );
 				if ( $slf->getRecordCount() > 0 ) {
 					$s_obj = $slf->getCurrent();
@@ -1018,7 +1018,7 @@ class TimeTrexSoapServerUnAuthenticated {
 			Debug::Text('Row Key: '. $row_key .' Date: '. $punch_row['date_stamp'] .' Time: '. $punch_row['time_stamp'] .' Station ID: '. $punch_row['station_id'], __FILE__, __LINE__, __METHOD__,10);
 
 			if ( isset( $punch_row['station_id'] ) )  {
-				$slf = new StationListFactory();
+				$slf = TTnew( 'StationListFactory' );
 				$slf->getByStationId( $punch_row['station_id'] );
 				if ( $slf->getRecordCount() > 0 ) {
 					Debug::Text('Found Station Data...', __FILE__, __LINE__, __METHOD__,10);
@@ -1031,7 +1031,7 @@ class TimeTrexSoapServerUnAuthenticated {
 			}
 
 			if ( isset( $punch_row['user_id'] ) AND $punch_row['user_id'] != '' ) {
-				$ulf = new UserListFactory();
+				$ulf = TTnew( 'UserListFactory' );
 				$ulf->getById( $punch_row['user_id'] );
 				if ( $ulf->getRecordCount() > 0 ) {
 					$current_user = $ulf->getCurrent();
@@ -1067,10 +1067,10 @@ class TimeTrexSoapServerUnAuthenticated {
 
 			$fail_transaction = FALSE;
 
-			$pf = new PunchFactory();
+			$pf = TTnew( 'PunchFactory' );
 			$pf->StartTransaction();
 
-			$slf = new ScheduleListFactory();
+			$slf = TTnew( 'ScheduleListFactory' );
 
 			//Auto Punch
 			if ( ( isset($punch_row['status_id']) AND $punch_row['status_id'] == 0 )
@@ -1081,7 +1081,7 @@ class TimeTrexSoapServerUnAuthenticated {
 					OR ( isset($punch_row['job_item_id']) AND $punch_row['job_item_id'] == 0 )
 					) {
 
-				$plf = new PunchListFactory();
+				$plf = TTnew( 'PunchListFactory' );
 				$plf->getPreviousPunchByUserIDAndEpoch( $punch_row['user_id'], $punch_full_time_stamp );
 				if ($plf->getRecordCount() > 0 ) {
 					Debug::Text(' Found Previous Punch within Continuous Time from now: ', __FILE__, __LINE__, __METHOD__,10);
@@ -1257,7 +1257,7 @@ class TimeTrexSoapServerUnAuthenticated {
 			if ( $pf->isValid() == TRUE ) {
 
 				if ( $pf->Save( FALSE ) == TRUE ) {
-					$pcf = new PunchControlFactory();
+					$pcf = TTnew( 'PunchControlFactory' );
 					$pcf->setId( $pf->getPunchControlID() );
 					$pcf->setPunchObject( $pf );
 
