@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: UserDeductionFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4359 $
+ * $Id: UserDeductionFactory.class.php 4359 2011-03-14 18:30:27Z ipso $
+ * $Date: 2011-03-14 11:30:27 -0700 (Mon, 14 Mar 2011) $
  */
 
 /**
@@ -65,6 +65,9 @@ class UserDeductionFactory extends Factory {
 										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
 							);
 				break;
+			case 'list_columns':
+				$retval = Misc::arrayIntersectByKey( $this->getOptions('default_display_columns'), Misc::trimSortPrefix( $this->getOptions('columns') ) );
+				break;
 			case 'default_display_columns': //Columns that are displayed by default.
 				$retval = array(
 								'manual_id',
@@ -112,7 +115,7 @@ class UserDeductionFactory extends Factory {
 		if ( is_object($this->user_obj) ) {
 			return $this->user_obj;
 		} else {
-			$ulf = new UserListFactory();
+			$ulf = TTnew( 'UserListFactory' );
 			$this->user_obj = $ulf->getById( $this->getUser() )->getCurrent();
 
 			return $this->user_obj;
@@ -123,7 +126,7 @@ class UserDeductionFactory extends Factory {
 		if ( is_object($this->company_deduction_obj) ) {
 			return $this->company_deduction_obj;
 		} else {
-			$cdlf = new CompanyDeductionListFactory();
+			$cdlf = TTnew( 'CompanyDeductionListFactory' );
 			$this->company_deduction_obj = $cdlf->getById( $this->getCompanyDeduction() )->getCurrent();
 
 			return $this->company_deduction_obj;
@@ -134,7 +137,7 @@ class UserDeductionFactory extends Factory {
 		if ( is_object($this->pay_stub_entry_account_link_obj) ) {
 			return $this->pay_stub_entry_account_link_obj;
 		} else {
-			$pseallf = new PayStubEntryAccountLinkListFactory();
+			$pseallf = TTnew( 'PayStubEntryAccountLinkListFactory' );
 			$pseallf->getByCompanyID( $this->getUserObject()->getCompany() );
 			if ( $pseallf->getRecordCount() > 0 ) {
 				$this->pay_stub_entry_account_link_obj = $pseallf->getCurrent();
@@ -155,7 +158,7 @@ class UserDeductionFactory extends Factory {
 	function setUser($id) {
 		$id = trim($id);
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 
 		if ( $this->Validator->isResultSetWithRows(	'user',
 															$ulf->getByID($id),
@@ -200,7 +203,7 @@ class UserDeductionFactory extends Factory {
 		$id = trim($id);
 
 		Debug::Text('ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
-		$cdlf = new CompanyDeductionListFactory();
+		$cdlf = TTnew( 'CompanyDeductionListFactory' );
 
 		if (	(
 					$id != 0
@@ -1036,29 +1039,44 @@ class UserDeductionFactory extends Factory {
 
 					$pd_obj->setEnableCPPAndEIDeduction(TRUE);
 
-					//$pself = new PayStubEntryListFactory();
+					//$pself = TTnew( 'PayStubEntryListFactory' );
 					if ( $this->getPayStubEntryAccountLinkObject()->getEmployeeCPP() != '' ) {
 						Debug::Text('Found Employee CPP account link!: ', __FILE__, __LINE__, __METHOD__,10);
 
-						//$ytd_cpp_arr = $pself->getYTDAmountSumByUserIdAndEntryNameIDAndYear( $this->getUser(), $this->getPayStubEntryAccountLinkObject()->getEmployeeCPP(), $pay_period_obj->getTransactionDate() );
+						//Check to see if CPP was calculated on the CURRENT pay stub, if not assume they are CPP exempt.
+						//Single this calculation formula doesn't know directly if the user was CPP exempt or not, we have to assume it by
+						//the calculate CPP on the current pay stub. However if the CPP calculation is done AFTER this, it may mistakenly assume they are exempt.
+						//Make sure we handle the maximum CPP contribution cases properly as well.
+						$current_cpp = $pay_stub_obj->getSumByEntriesArrayAndTypeIDAndPayStubAccountID( 'current', NULL, $this->getPayStubEntryAccountLinkObject()->getEmployeeCPP() );
+						if ( isset($current_cpp['amount']) AND $current_cpp['amount'] == 0 ) {
+							Debug::Text('Current CPP: '. $current_cpp['amount'] .' Setting CPP exempt in Federal Income Tax calculation...', __FILE__, __LINE__, __METHOD__,10);
+							$pd_obj->setCPPExempt( TRUE );
+						}
+
 						$ytd_cpp_arr = $pay_stub_obj->getSumByEntriesArrayAndTypeIDAndPayStubAccountID( 'previous', NULL, $this->getPayStubEntryAccountLinkObject()->getEmployeeCPP() );
 
 						Debug::text('YTD CPP Contribution: '. $ytd_cpp_arr['ytd_amount'], __FILE__, __LINE__, __METHOD__,10);
 
 						$pd_obj->setYearToDateCPPContribution( $ytd_cpp_arr['ytd_amount'] );
-						unset($ytd_cpp_arr);
+						unset($ytd_cpp_arr, $current_cpp );
 					}
 
 					if ( $this->getPayStubEntryAccountLinkObject()->getEmployeeEI() != '' ) {
 						Debug::Text('Found Employee EI account link!: ', __FILE__, __LINE__, __METHOD__,10);
 
-						//$ytd_ei_arr = $pself->getYTDAmountSumByUserIdAndEntryNameIDAndYear( $this->getUser(), $this->getPayStubEntryAccountLinkObject()->getEmployeeEI(), $pay_period_obj->getTransactionDate() );
+						//See comment above regarding CPP exempt.
+						$current_ei = $pay_stub_obj->getSumByEntriesArrayAndTypeIDAndPayStubAccountID( 'current', NULL, $this->getPayStubEntryAccountLinkObject()->getEmployeeEI() );
+						if ( isset($current_ei['amount']) AND $current_ei['amount'] == 0 ) {
+							Debug::Text('Current EI: '. $current_ei['amount'] .' Setting EI exempt in Federal Income Tax calculation...', __FILE__, __LINE__, __METHOD__,10);
+							$pd_obj->setEIExempt( TRUE );
+						}
+
 						$ytd_ei_arr = $pay_stub_obj->getSumByEntriesArrayAndTypeIDAndPayStubAccountID( 'previous', NULL, $this->getPayStubEntryAccountLinkObject()->getEmployeeEI() );
 
 						Debug::text('YTD EI Contribution: '. $ytd_ei_arr['ytd_amount'], __FILE__, __LINE__, __METHOD__,10);
 
 						$pd_obj->setYearToDateEIContribution( $ytd_ei_arr['ytd_amount'] );
-						unset($ytd_ei_arr);
+						unset($ytd_ei_arr, $current_ei);
 					}
 				} elseif ( $this->getCompanyDeductionObject()->getCountry() == 'US' ) {
 					//US
@@ -1121,28 +1139,44 @@ class UserDeductionFactory extends Factory {
 
 					$pd_obj->setEnableCPPAndEIDeduction(TRUE);
 
-					//$pself = new PayStubEntryListFactory();
+					//$pself = TTnew( 'PayStubEntryListFactory' );
 					if ( $this->getPayStubEntryAccountLinkObject()->getEmployeeCPP() != '' ) {
 						Debug::Text('Found Employee CPP account link!: ', __FILE__, __LINE__, __METHOD__,10);
 
+						//Check to see if CPP was calculated on the CURRENT pay stub, if not assume they are CPP exempt.
+						//Single this calculation formula doesn't know directly if the user was CPP exempt or not, we have to assume it by
+						//the calculate CPP on the current pay stub. However if the CPP calculation is done AFTER this, it may mistakenly assume they are exempt.
+						//Make sure we handle the maximum CPP contribution cases properly as well.
+						$current_cpp = $pay_stub_obj->getSumByEntriesArrayAndTypeIDAndPayStubAccountID( 'current', NULL, $this->getPayStubEntryAccountLinkObject()->getEmployeeCPP() );
+						if ( isset($current_cpp['amount']) AND $current_cpp['amount'] == 0 ) {
+							Debug::Text('Current CPP: '. $current_cpp['amount'] .' Setting CPP exempt in Provincial Income Tax calculation...', __FILE__, __LINE__, __METHOD__,10);
+							$pd_obj->setCPPExempt( TRUE );
+						}
+
 						$ytd_cpp_arr = $pay_stub_obj->getSumByEntriesArrayAndTypeIDAndPayStubAccountID( 'previous', NULL, $this->getPayStubEntryAccountLinkObject()->getEmployeeCPP() );
 
 						Debug::text('YTD CPP Contribution: '. $ytd_cpp_arr['ytd_amount'], __FILE__, __LINE__, __METHOD__,10);
 
 						$pd_obj->setYearToDateCPPContribution( $ytd_cpp_arr['ytd_amount'] );
-						unset($ytd_cpp_arr);
+						unset($ytd_cpp_arr, $current_cpp);
 					}
 
 					if ( $this->getPayStubEntryAccountLinkObject()->getEmployeeEI() != '' ) {
 						Debug::Text('Found Employee EI account link!: ', __FILE__, __LINE__, __METHOD__,10);
 
-						//$ytd_ei_arr = $pself->getYTDAmountSumByUserIdAndEntryNameIDAndYear( $this->getUser(), $this->getPayStubEntryAccountLinkObject()->getEmployeeEI(), $pay_period_obj->getTransactionDate() );
+						//See comment above regarding CPP exempt.
+						$current_ei = $pay_stub_obj->getSumByEntriesArrayAndTypeIDAndPayStubAccountID( 'current', NULL, $this->getPayStubEntryAccountLinkObject()->getEmployeeEI() );
+						if ( isset($current_ei['amount']) AND $current_ei['amount'] == 0 ) {
+							Debug::Text('Current EI: '. $current_ei['amount'] .' Setting EI exempt in Provincial Income Tax calculation...', __FILE__, __LINE__, __METHOD__,10);
+							$pd_obj->setEIExempt( TRUE );
+						}
+
 						$ytd_ei_arr = $pay_stub_obj->getSumByEntriesArrayAndTypeIDAndPayStubAccountID( 'previous', NULL, $this->getPayStubEntryAccountLinkObject()->getEmployeeEI() );
 
 						Debug::text('YTD EI Contribution: '. $ytd_ei_arr['ytd_amount'], __FILE__, __LINE__, __METHOD__,10);
 
 						$pd_obj->setYearToDateEIContribution( $ytd_ei_arr['ytd_amount'] );
-						unset($ytd_ei_arr);
+						unset($ytd_ei_arr, $current_ei);
 					}
 
 					$retval = $pd_obj->getProvincialPayPeriodDeductions();
@@ -1150,7 +1184,7 @@ class UserDeductionFactory extends Factory {
 					Debug::Text('US Pay Period Deductions...', __FILE__, __LINE__, __METHOD__,10);
 
 					//Need to set Federal settings here.
-					$udlf = new UserDeductionListFactory();
+					$udlf = TTnew( 'UserDeductionListFactory' );
 					$udlf->getByUserIdAndCountryID( $user_id, $this->getCompanyDeductionObject()->getCountry() );
 					if ( $udlf->getRecordCount() > 0 ) {
 						Debug::Text('Found Federal User Deduction...', __FILE__, __LINE__, __METHOD__,10);
