@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3764 $
- * $Id: UserDeductionListFactory.class.php 3764 2010-08-13 18:07:55Z ipso $
- * $Date: 2010-08-13 11:07:55 -0700 (Fri, 13 Aug 2010) $
+ * $Revision: 4265 $
+ * $Id: UserDeductionListFactory.class.php 4265 2011-02-18 00:49:20Z ipso $
+ * $Date: 2011-02-17 16:49:20 -0800 (Thu, 17 Feb 2011) $
  */
 
 /**
@@ -467,9 +467,6 @@ class UserDeductionListFactory extends UserDeductionFactory implements IteratorA
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
 
-		Debug::Text('Query: '. $query, __FILE__, __LINE__, __METHOD__,10);
-		Debug::Arr($ph,'Place Holders:', __FILE__, __LINE__, __METHOD__,10);
-
 		if ($limit == NULL) {
 			$this->rs = $this->db->Execute($query, $ph);
 		} else {
