@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: UserDefaultFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4674 $
+ * $Id: UserDefaultFactory.class.php 4674 2011-05-13 21:19:07Z ipso $
+ * $Date: 2011-05-13 14:19:07 -0700 (Fri, 13 May 2011) $
  */
 
 /**
@@ -90,7 +90,7 @@ class UserDefaultFactory extends Factory {
 		if ( is_object($this->company_obj) ) {
 			return $this->company_obj;
 		} else {
-			$clf = new CompanyListFactory();
+			$clf = TTnew( 'CompanyListFactory' );
 			$this->company_obj = $clf->getById( $this->getCompany() )->getCurrent();
 
 			return $this->company_obj;
@@ -102,7 +102,7 @@ class UserDefaultFactory extends Factory {
 			return $this->title_obj;
 		} else {
 
-			$utlf = new UserTitleListFactory();
+			$utlf = TTnew( 'UserTitleListFactory' );
 			$utlf->getById( $this->getTitle() );
 
 			if ( $utlf->getRecordCount() == 1 ) {
@@ -126,7 +126,7 @@ class UserDefaultFactory extends Factory {
 		$id = trim($id);
 
 		Debug::Text('Company ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
-		$clf = new CompanyListFactory();
+		$clf = TTnew( 'CompanyListFactory' );
 
 		if ( $this->Validator->isResultSetWithRows(	'company',
 													$clf->getByID($id),
@@ -151,7 +151,7 @@ class UserDefaultFactory extends Factory {
 	function setPermissionControl($id) {
 		$id = trim($id);
 
-		$pclf = new PermissionControlListFactory();
+		$pclf = TTnew( 'PermissionControlListFactory' );
 
 		if (  $this->Validator->isResultSetWithRows(		'permission_control_id',
 															$pclf->getByID($id),
@@ -175,7 +175,7 @@ class UserDefaultFactory extends Factory {
 	function setPayPeriodSchedule($id) {
 		$id = trim($id);
 
-		$ppslf = new PayPeriodScheduleListFactory();
+		$ppslf = TTnew( 'PayPeriodScheduleListFactory' );
 
 		if ( $id == 0
 				OR $this->Validator->isResultSetWithRows(	'pay_period_schedule_id',
@@ -200,7 +200,7 @@ class UserDefaultFactory extends Factory {
 	function setPolicyGroup($id) {
 		$id = trim($id);
 
-		$pglf = new PolicyGroupListFactory();
+		$pglf = TTnew( 'PolicyGroupListFactory' );
 
 		if ( $id == 0
 				OR $this->Validator->isResultSetWithRows(	'policy_group_id',
@@ -253,7 +253,7 @@ class UserDefaultFactory extends Factory {
 		$id = trim($id);
 
 		Debug::Text('Title ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
-		$utlf = new UserTitleListFactory();
+		$utlf = TTnew( 'UserTitleListFactory' );
 
 		if (
 				$id == 0
@@ -282,7 +282,7 @@ class UserDefaultFactory extends Factory {
 		$id = trim($id);
 
 		Debug::Text('Branch ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
-		$blf = new BranchListFactory();
+		$blf = TTnew( 'BranchListFactory' );
 
 		if (
 				$id == 0
@@ -311,7 +311,7 @@ class UserDefaultFactory extends Factory {
 		$id = trim($id);
 
 		Debug::Text('Department ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
-		$dlf = new DepartmentListFactory();
+		$dlf = TTnew( 'DepartmentListFactory' );
 
 		if (
 				$id == 0
@@ -340,7 +340,7 @@ class UserDefaultFactory extends Factory {
 		$id = trim($id);
 
 		Debug::Text('Currency ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
-		$culf = new CurrencyListFactory();
+		$culf = TTnew( 'CurrencyListFactory' );
 
 		if (
 				$this->Validator->isResultSetWithRows(	'currency',
@@ -403,7 +403,7 @@ class UserDefaultFactory extends Factory {
 
 		Debug::Text('Country: '. $this->getCountry() .' Province: '. $province, __FILE__, __LINE__, __METHOD__,10);
 
-		$cf = new CompanyFactory();
+		$cf = TTnew( 'CompanyFactory' );
 
 		$options_arr = $cf->getOptions('province');
 		if ( isset($options_arr[$this->getCountry()]) ) {
@@ -435,7 +435,7 @@ class UserDefaultFactory extends Factory {
 	function setCountry($country) {
 		$country = trim($country);
 
-		$cf = new CompanyFactory();
+		$cf = TTnew( 'CompanyFactory' );
 
 		if ( $this->Validator->inArrayKey(		'country',
 												$country,
@@ -594,7 +594,7 @@ class UserDefaultFactory extends Factory {
 	}
 	function setDateFormat($date_format) {
 		$date_format = trim($date_format);
-		$upf = new UserPreferenceFactory();
+		$upf = TTnew( 'UserPreferenceFactory' );
 
 		if ( $this->Validator->inArrayKey(	'date_format',
 											$date_format,
@@ -619,7 +619,7 @@ class UserDefaultFactory extends Factory {
 	function setTimeFormat($time_format) {
 		$time_format = trim($time_format);
 
-		$upf = new UserPreferenceFactory();
+		$upf = TTnew( 'UserPreferenceFactory' );
 
 		$key = Option::getByValue($time_format, $upf->getOptions('time_format') );
 		if ($key !== FALSE) {
@@ -647,19 +647,14 @@ class UserDefaultFactory extends Factory {
 		return FALSE;
 	}
 	function setTimeZone($time_zone) {
-		$time_zone = trim($time_zone);
-
-		$upf = new UserPreferenceFactory();
-
-		$key = Option::getByValue($time_zone, $upf->getOptions('time_zone') );
-		if ($key !== FALSE) {
-			$time_zone = $key;
-		}
+		$time_zone = Misc::trimSortPrefix( trim($time_zone) );
 
+		$upf = TTnew( 'UserPreferenceFactory' );
+		
 		if ( $this->Validator->inArrayKey(	'time_zone',
 											$time_zone,
 											TTi18n::gettext('Incorrect time zone'),
-											$upf->getOptions('time_zone')) ) {
+											Misc::trimSortPrefix( $upf->getOptions('time_zone') ) ) ) {
 
 			$this->data['time_zone'] = $time_zone;
 
@@ -680,7 +675,7 @@ class UserDefaultFactory extends Factory {
 	function setTimeUnitFormat($time_unit_format) {
 		$time_unit_format = trim($time_unit_format);
 
-		$upf = new UserPreferenceFactory();
+		$upf = TTnew( 'UserPreferenceFactory' );
 
 		$key = Option::getByValue($time_unit_format, $upf->getOptions('time_unit_format') );
 		if ($key !== FALSE) {
@@ -735,7 +730,7 @@ class UserDefaultFactory extends Factory {
 	function setStartWeekDay($value) {
 		$value = trim($value);
 
-		$upf = new UserPreferenceFactory();
+		$upf = TTnew( 'UserPreferenceFactory' );
 
 		$key = Option::getByValue($value, $upf->getOptions('start_week_day') );
 		if ($key !== FALSE) {
@@ -786,7 +781,7 @@ class UserDefaultFactory extends Factory {
 
 	*/
 	function getCompanyDeduction() {
-		$udcdlf = new UserDefaultCompanyDeductionListFactory();
+		$udcdlf = TTnew( 'UserDefaultCompanyDeductionListFactory' );
 		$udcdlf->getByUserDefaultId( $this->getId() );
 		foreach ($udcdlf as $obj) {
 			$list[] = $obj->getCompanyDeduction();
@@ -803,7 +798,7 @@ class UserDefaultFactory extends Factory {
 		if ( is_array($ids) ) {
 			if ( !$this->isNew() ) {
 				//If needed, delete mappings first.
-				$udcdlf = new UserDefaultCompanyDeductionListFactory();
+				$udcdlf = TTnew( 'UserDefaultCompanyDeductionListFactory' );
 				$udcdlf->getByUserDefaultId( $this->getId() );
 
 				$tmp_ids = array();
@@ -827,12 +822,12 @@ class UserDefaultFactory extends Factory {
 			}
 
 			//Insert new mappings.
-			//$lf = new UserListFactory();
-			$cdlf = new CompanyDeductionListFactory();
+			//$lf = TTnew( 'UserListFactory' );
+			$cdlf = TTnew( 'CompanyDeductionListFactory' );
 
 			foreach ($ids as $id) {
 				if ( $id != FALSE AND isset($ids) AND !in_array($id, $tmp_ids) ) {
-					$udcdf = new UserDefaultCompanyDeductionFactory();
+					$udcdf = TTnew( 'UserDefaultCompanyDeductionFactory' );
 					$udcdf->setUserDefault( $this->getId() );
 					$udcdf->setCompanyDeduction( $id );
 
@@ -896,7 +891,7 @@ class UserDefaultFactory extends Factory {
 
 
 	function getObjectAsArray( $include_columns = NULL ) {
-		$uf = new UserFactory();
+		$uf = TTnew( 'UserFactory' );
 
 		$variable_function_map = $this->getVariableToFunctionMap();
 		if ( is_array( $variable_function_map ) ) {
