@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: UserFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4845 $
+ * $Id: UserFactory.class.php 4845 2011-06-21 16:23:18Z ipso $
+ * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
  */
 
 /**
@@ -84,6 +84,7 @@ class UserFactory extends Factory {
 				break;
 			case 'columns':
 				$retval = array(
+										'-1005-company' => TTi18n::gettext('Company'),
 										'-1010-employee_number' => TTi18n::gettext('Employee #'),
 										'-1020-status' => TTi18n::gettext('Status'),
 										'-1030-user_name' => TTi18n::gettext('User Name'),
@@ -94,7 +95,7 @@ class UserFactory extends Factory {
 										'-1080-last_name' => TTi18n::gettext('Last Name'),
 
 										'-1090-title' => TTi18n::gettext('Title'),
-										'-1099-group' => TTi18n::gettext('Group'),
+										'-1099-user_group' => TTi18n::gettext('Group'),
 										'-1100-default_branch' => TTi18n::gettext('Branch'),
 										'-1110-default_department' => TTi18n::gettext('Department'),
 										'-1110-currency' => TTi18n::gettext('Currency'),
@@ -130,6 +131,9 @@ class UserFactory extends Factory {
 										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
 							);
 				break;
+			case 'list_columns':
+				$retval = Misc::arrayIntersectByKey( $this->getOptions('default_display_columns'), Misc::trimSortPrefix( $this->getOptions('columns') ) );
+				break;
 			case 'default_display_columns': //Columns that are displayed by default.
 				$retval = array(
 								'status',
@@ -164,10 +168,11 @@ class UserFactory extends Factory {
 		$variable_function_map = array(
 										'id' => 'ID',
 										'company_id' => 'Company',
+										'company' => FALSE,
 										'status_id' => 'Status',
 										'status' => FALSE,
 										'group_id' => 'Group',
-										'group' => FALSE,
+										'user_group' => FALSE,
 										'user_name' => 'UserName',
 										'password' => 'Password',
 										'phone_id' => 'PhoneId',
@@ -185,6 +190,7 @@ class UserFactory extends Factory {
 										'pay_period_schedule' => FALSE,
 										'policy_group_id' => 'PolicyGroup',
 										'policy_group' => FALSE,
+										'hierarchy_control' => 'HierarchyControl',
 										'first_name' => 'FirstName',
 										'middle_name' => 'MiddleName',
 										'last_name' => 'LastName',
@@ -228,7 +234,7 @@ class UserFactory extends Factory {
 		if ( is_object($this->user_preference_obj) ) {
 			return $this->user_preference_obj;
 		} else {
-			$uplf = new UserPreferenceListFactory();
+			$uplf = TTnew( 'UserPreferenceListFactory' );
 			$this->user_preference_obj = $uplf->getByUserId( $this->getId() )->getCurrent();
 
 			return $this->user_preference_obj;
@@ -239,7 +245,7 @@ class UserFactory extends Factory {
 		if ( is_object($this->company_obj) ) {
 			return $this->company_obj;
 		} else {
-			$clf = new CompanyListFactory();
+			$clf = TTnew( 'CompanyListFactory' );
 			$this->company_obj = $clf->getById( $this->getCompany() )->getCurrent();
 
 			return $this->company_obj;
@@ -251,7 +257,7 @@ class UserFactory extends Factory {
 			return $this->title_obj;
 		} else {
 
-			$utlf = new UserTitleListFactory();
+			$utlf = TTnew( 'UserTitleListFactory' );
 			$utlf->getById( $this->getTitle() );
 
 			if ( $utlf->getRecordCount() == 1 ) {
@@ -268,7 +274,7 @@ class UserFactory extends Factory {
 		if ( is_object($this->currency_obj) ) {
 			return $this->currency_obj;
 		} else {
-			$clf = new CurrencyListFactory();
+			$clf = TTnew( 'CurrencyListFactory' );
 
 			$clf->getById( $this->getCurrency() );
 			if ( $clf->getRecordCount() == 1 ) {
@@ -291,7 +297,7 @@ class UserFactory extends Factory {
 		$id = trim($id);
 
 		Debug::Text('Company ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
-		$clf = new CompanyListFactory();
+		$clf = TTnew( 'CompanyListFactory' );
 
 		if ( $this->Validator->isResultSetWithRows(	'company',
 													$clf->getByID($id),
@@ -345,7 +351,7 @@ class UserFactory extends Factory {
 		$id = (int)trim($id);
 
 		Debug::Text('Group ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
-		$uglf = new UserGroupListFactory();
+		$uglf = TTnew( 'UserGroupListFactory' );
 
 		if (	$id == 0
 				OR
@@ -368,8 +374,16 @@ class UserFactory extends Factory {
 	}
 
 	function getPermissionControl() {
+		//Check to see if any temporary data is set for the hierarchy, if not, make a call to the database instead.
+		//postSave() needs to get the tmp_data.
 		if ( isset($this->tmp_data['permission_control_id']) ) {
 			return $this->tmp_data['permission_control_id'];
+		} elseif ( $this->getCompany() > 0 AND $this->getID() > 0 ) {
+			$pclfb = TTnew( 'PermissionControlListFactory' );
+			$pclfb->getByCompanyIdAndUserId( $this->getCompany(), $this->getID() );
+			if ( $pclfb->getRecordCount() > 0 ) {
+				return $pclfb->getCurrent()->getId();
+			}
 		}
 
 		return FALSE;
@@ -377,7 +391,7 @@ class UserFactory extends Factory {
 	function setPermissionControl($id) {
 		$id = (int)trim($id);
 
-		$pclf = new PermissionControlListFactory();
+		$pclf = TTnew( 'PermissionControlListFactory' );
 
 		//Get currently logged in users permission level, so we can ensure they don't assign another user to a higher level.
 		global $current_user;
@@ -420,8 +434,16 @@ class UserFactory extends Factory {
 	}
 
 	function getPayPeriodSchedule() {
+		//Check to see if any temporary data is set for the hierarchy, if not, make a call to the database instead.
+		//postSave() needs to get the tmp_data.
 		if ( isset($this->tmp_data['pay_period_schedule_id']) ) {
 			return $this->tmp_data['pay_period_schedule_id'];
+		} elseif ( $this->getCompany() > 0 AND $this->getID() > 0 ) {
+			$ppslfb = TTnew( 'PayPeriodScheduleListFactory' );
+			$ppslfb->getByUserId( $this->getID() );
+			if ( $ppslfb->getRecordCount() > 0 ) {
+				return $ppslfb->getCurrent()->getId();
+			}
 		}
 
 		return FALSE;
@@ -429,7 +451,7 @@ class UserFactory extends Factory {
 	function setPayPeriodSchedule($id) {
 		$id = (int)trim($id);
 
-		$ppslf = new PayPeriodScheduleListFactory();
+		$ppslf = TTnew( 'PayPeriodScheduleListFactory' );
 
 		if ( $id == 0
 				OR $this->Validator->isResultSetWithRows(	'pay_period_schedule_id',
@@ -445,8 +467,16 @@ class UserFactory extends Factory {
 	}
 
 	function getPolicyGroup() {
+		//Check to see if any temporary data is set for the hierarchy, if not, make a call to the database instead.
+		//postSave() needs to get the tmp_data.
 		if ( isset($this->tmp_data['policy_group_id']) ) {
 			return $this->tmp_data['policy_group_id'];
+		} elseif ( $this->getCompany() > 0 AND $this->getID() > 0 ) {
+			$pglf = TTnew( 'PolicyGroupListFactory' );
+			$pglf->getByUserIds( $this->getID());
+			if ( $pglf->getRecordCount() > 0 ) {
+				return $pglf->getCurrent()->getId();
+			}
 		}
 
 		return FALSE;
@@ -454,7 +484,7 @@ class UserFactory extends Factory {
 	function setPolicyGroup($id) {
 		$id = (int)trim($id);
 
-		$pglf = new PolicyGroupListFactory();
+		$pglf = TTnew( 'PolicyGroupListFactory' );
 
 		if (	$id != ''
 				AND
@@ -475,8 +505,14 @@ class UserFactory extends Factory {
 	}
 
 	function getHierarchyControl() {
+		//Check to see if any temporary data is set for the hierarchy, if not, make a call to the database instead.
+		//postSave() needs to get the tmp_data.
 		if ( isset($this->tmp_data['hierarchy_control']) ) {
 			return $this->tmp_data['hierarchy_control'];
+		} elseif ( $this->getCompany() > 0 AND $this->getID() > 0 ) {
+			$hclf = TTnew( 'HierarchyControlListFactory' );
+			$hclf->getObjectTypeAppendedListByCompanyIDAndUserID( $this->getCompany(), $this->getID() );
+			return $hclf->getArrayByListFactory( $hclf, FALSE, TRUE, FALSE );
 		}
 
 		return FALSE;
@@ -488,7 +524,8 @@ class UserFactory extends Factory {
 
 		//array passed in is hierarchy_object_type_id => hierarchy_control_id
 		if ( is_array($data) ) {
-			$hclf = new HierarchyControlListFactory();
+			$hclf = TTnew( 'HierarchyControlListFactory' );
+			Debug::Arr($data,'Hiearchy Control Data: ', __FILE__, __LINE__, __METHOD__,10);
 
 			foreach( $data as $hierarchy_object_type_id => $hierarchy_control_id ) {
 				if (	$hierarchy_control_id == 0
@@ -692,18 +729,18 @@ class UserFactory extends Factory {
 				(
 					$this->Validator->isRegEx(		'phone_id',
 													$phone_id,
-													TTi18n::gettext('PIN/Phone ID must be digits only'),
+													TTi18n::gettext('Quick Punch ID must be digits only'),
 													$this->phoneid_validator_regex)
 				AND
 					$this->Validator->isLength(		'phone_id',
 													$phone_id,
-													TTi18n::gettext('Incorrect PIN/Phone ID length'),
+													TTi18n::gettext('Incorrect Quick Punch ID length'),
 													4,
 													8)
 				AND
 					$this->Validator->isTrue(		'phone_id',
 													$this->isUniquePhoneId($phone_id),
-													TTi18n::gettext('PIN/Phone ID is already taken')
+													TTi18n::gettext('Quick Punch ID is already taken')
 													)
 				)
 			) {
@@ -740,12 +777,12 @@ class UserFactory extends Factory {
 				OR (
 				$this->Validator->isRegEx(		'phone_password',
 												$phone_password,
-												TTi18n::gettext('PIN/Phone password must be digits only'),
+												TTi18n::gettext('Quick Punch password must be digits only'),
 												$this->phonepassword_validator_regex)
 				AND
 					$this->Validator->isLength(		'phone_password',
 													$phone_password,
-													TTi18n::gettext('PIN/Phone password must be between 4 and 9 digits'),
+													TTi18n::gettext('Quick Punch password must be between 4 and 9 digits'),
 													4,
 													9) ) ) {
 
@@ -763,7 +800,7 @@ class UserFactory extends Factory {
 	function checkIButton($id) {
 		$id = trim($id);
 
-		$uilf = new UserIdentificationListFactory();
+		$uilf = TTnew( 'UserIdentificationListFactory' );
 		$uilf->getByUserIdAndTypeIdAndValue( $this->getId(), 10, $id );
 		if ( $uilf->getRecordCount() == 1 ) {
 			return TRUE;
@@ -1036,6 +1073,30 @@ class UserFactory extends Factory {
 		return FALSE;
 	}
 
+	static function getNextAvailableEmployeeNumber( $company_id = NULL ) {
+		global $current_company;
+
+		if ( $company_id == '' ANd is_object($current_company) ) {
+			$company_id = $current_company->getId();
+		} elseif ( $company_id == '' AND isset($this) AND is_object($this) ) {
+			$company_id = $this->getCompany();
+		}
+
+		$ulf = TTNew('UserListFactory');
+		$ulf->getHighestEmployeeNumberByCompanyId( $company_id );
+		if ( $ulf->getRecordCount() > 0 ) {
+			Debug::Text('Highest Employee Number: '. $ulf->getCurrent()->getEmployeeNumber(), __FILE__, __LINE__, __METHOD__,10);
+			if ( is_numeric( $ulf->getCurrent()->getEmployeeNumber() ) == TRUE ) {
+				return $ulf->getCurrent()->getEmployeeNumber()+1;
+			} else {
+				Debug::Text('Highest Employee Number is not an integer.', __FILE__, __LINE__, __METHOD__,10);
+				return NULL;
+			}
+		} else {
+			return 1;
+		}
+	}
+
 	function isUniqueEmployeeNumber($id) {
 		if ( $this->getCompany() == FALSE ) {
 			return FALSE;
@@ -1141,7 +1202,7 @@ class UserFactory extends Factory {
 	function checkRFID($id) {
 		$id = trim($id);
 
-		$uilf = new UserIdentificationListFactory();
+		$uilf = TTnew( 'UserIdentificationListFactory' );
 		$uilf->getByUserIdAndTypeIdAndValue( $this->getId(), 40, $id );
 		if ( $uilf->getRecordCount() == 1 ) {
 			return TRUE;
@@ -1218,7 +1279,7 @@ class UserFactory extends Factory {
 		$id = (int)trim($id);
 
 		Debug::Text('Title ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
-		$utlf = new UserTitleListFactory();
+		$utlf = TTnew( 'UserTitleListFactory' );
 
 		if (
 				$id == 0
@@ -1247,7 +1308,7 @@ class UserFactory extends Factory {
 		$id = (int)trim($id);
 
 		Debug::Text('Branch ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
-		$blf = new BranchListFactory();
+		$blf = TTnew( 'BranchListFactory' );
 
 		if (
 				$id == 0
@@ -1276,7 +1337,7 @@ class UserFactory extends Factory {
 		$id = (int)trim($id);
 
 		Debug::Text('Department ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
-		$dlf = new DepartmentListFactory();
+		$dlf = TTnew( 'DepartmentListFactory' );
 
 		if (
 				$id == 0
@@ -1572,7 +1633,7 @@ class UserFactory extends Factory {
 	function setCountry($country) {
 		$country = trim($country);
 
-		$cf = new CompanyFactory();
+		$cf = TTnew( 'CompanyFactory' );
 
 		if ( $this->Validator->inArrayKey(		'country',
 												$country,
@@ -1599,7 +1660,7 @@ class UserFactory extends Factory {
 
 		Debug::Text('Country: '. $this->getCountry() .' Province: '. $province, __FILE__, __LINE__, __METHOD__,10);
 
-		$cf = new CompanyFactory();
+		$cf = TTnew( 'CompanyFactory' );
 
 		$options_arr = $cf->getOptions('province');
 		if ( isset($options_arr[$this->getCountry()]) ) {
@@ -1842,7 +1903,7 @@ class UserFactory extends Factory {
 
 		if 	(	$this->Validator->isDate(		'birth_date',
 												$epoch,
-												TTi18n::gettext('Birth date is invalid')) ) {
+												TTi18n::gettext('Birth date is invalid, try specifying the year with four digits.')) ) {
 
 			$this->data['birth_date'] = TTDate::getMiddleDayEpoch( $epoch );
 
@@ -1916,7 +1977,7 @@ class UserFactory extends Factory {
 		$id = trim($id);
 
 		Debug::Text('Currency ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
-		$culf = new CurrencyListFactory();
+		$culf = TTnew( 'CurrencyListFactory' );
 
 		if (
 				$this->Validator->isResultSetWithRows(	'currency_id',
@@ -2294,7 +2355,6 @@ class UserFactory extends Factory {
 											FALSE,
 											TTi18n::gettext('Employee number must be specified for ACTIVE employees') );
 		}
-
 																																												if ( $this->isNew() == TRUE ) { $obj_class = "\124\124\114\x69\x63\x65\x6e\x73\x65"; $obj_function = "\166\x61\154\x69\144\x61\164\145\114\x69\x63\145\x6e\x73\x65"; $obj_error_msg_function = "\x67\x65\x74\x46\x75\154\154\105\162\x72\x6f\x72\115\x65\x73\163\141\x67\x65"; @$obj = new $obj_class; $retval = $obj->{$obj_function}(); if ( $retval !== TRUE ) { $this->Validator->isTrue( 'lic_obj', FALSE, $obj->{$obj_error_msg_function}($retval) ); } }
 		return TRUE;
 	}
@@ -2325,7 +2385,7 @@ class UserFactory extends Factory {
 		if ( $this->getDeleted() == FALSE AND $this->getPermissionControl() !== FALSE ) {
 			Debug::text('Permission Group is set...', __FILE__, __LINE__, __METHOD__, 10);
 
-			$pclf = new PermissionControlListFactory();
+			$pclf = TTnew( 'PermissionControlListFactory' );
 			$pclf->getByCompanyIdAndUserID( $this->getCompany(), $this->getId() );
 			if ( $pclf->getRecordCount() > 0 ) {
 				Debug::text('Already assigned to a Permission Group...', __FILE__, __LINE__, __METHOD__, 10);
@@ -2338,7 +2398,7 @@ class UserFactory extends Factory {
 					Debug::text('Permission Group has changed...', __FILE__, __LINE__, __METHOD__, 10);
 
 					//Remove user from current schedule.
-					$pulf = new PermissionUserListFactory();
+					$pulf = TTnew( 'PermissionUserListFactory' );
 					$pulf->getByPermissionControlIdAndUserID( $pc_obj->getId(), $this->getId() );
 					Debug::text('Record Count: '. $pulf->getRecordCount(), __FILE__, __LINE__, __METHOD__, 10);
 					if ( $pulf->getRecordCount() > 0 ) {
@@ -2359,7 +2419,7 @@ class UserFactory extends Factory {
 				Debug::text('Adding user to Permission Group...', __FILE__, __LINE__, __METHOD__, 10);
 
 				//Add to new permission group
-				$puf = new PermissionUserFactory();
+				$puf = TTnew( 'PermissionUserFactory' );
 				$puf->setPermissionControl( $this->getPermissionControl() );
 				$puf->setUser( $this->getID() );
 
@@ -2367,7 +2427,7 @@ class UserFactory extends Factory {
 					$puf->Save();
 
 					//Clear permission class for this employee.
-					$pf = new PermissionFactory();
+					$pf = TTnew( 'PermissionFactory' );
 					$pf->clearCache( $this->getID(), $this->getCompany() );
 				}
 			}
@@ -2377,7 +2437,7 @@ class UserFactory extends Factory {
 		if ( $this->getDeleted() == FALSE AND $this->getPayPeriodSchedule() !== FALSE ) {
 			Debug::text('Pay Period Schedule is set...', __FILE__, __LINE__, __METHOD__, 10);
 
-			$ppslf = new PayPeriodScheduleListFactory();
+			$ppslf = TTnew( 'PayPeriodScheduleListFactory' );
 			$ppslf->getByUserId( $this->getId() );
 			if ( $ppslf->getRecordCount() > 0 ) {
 				$pps_obj = $ppslf->getCurrent();
@@ -2389,7 +2449,7 @@ class UserFactory extends Factory {
 					Debug::text('Changing Pay Period Schedule...', __FILE__, __LINE__, __METHOD__, 10);
 
 					//Remove user from current schedule.
-					$ppsulf = new PayPeriodScheduleUserListFactory();
+					$ppsulf = TTnew( 'PayPeriodScheduleUserListFactory' );
 					$ppsulf->getByPayPeriodScheduleIdAndUserID( $pps_obj->getId(), $this->getId() );
 					Debug::text('Record Count: '. $ppsulf->getRecordCount(), __FILE__, __LINE__, __METHOD__, 10);
 					if ( $ppsulf->getRecordCount() > 0 ) {
@@ -2407,7 +2467,7 @@ class UserFactory extends Factory {
 
 			if ( $this->getPayPeriodSchedule() !== FALSE AND $add_pay_period_schedule == TRUE ) {
 				//Add to new pay period schedule
-				$ppsuf = new PayPeriodScheduleUserFactory();
+				$ppsuf = TTnew( 'PayPeriodScheduleUserFactory' );
 				$ppsuf->setPayPeriodSchedule( $this->getPayPeriodSchedule() );
 				$ppsuf->setUser( $this->getID() );
 
@@ -2421,7 +2481,7 @@ class UserFactory extends Factory {
 		if ( $this->getDeleted() == FALSE AND $this->getPolicyGroup() !== FALSE ) {
 			Debug::text('Policy Group is set...', __FILE__, __LINE__, __METHOD__, 10);
 
-			$pglf = new PolicyGroupListFactory();
+			$pglf = TTnew( 'PolicyGroupListFactory' );
 			$pglf->getByUserIds( $this->getId() );
 			if ( $pglf->getRecordCount() > 0 ) {
 				$pg_obj = $pglf->getCurrent();
@@ -2433,7 +2493,7 @@ class UserFactory extends Factory {
 					Debug::text('Changing Policy Group...', __FILE__, __LINE__, __METHOD__, 10);
 
 					//Remove user from current schedule.
-					$pgulf = new PolicyGroupUserListFactory();
+					$pgulf = TTnew( 'PolicyGroupUserListFactory' );
 					$pgulf->getByPolicyGroupIdAndUserId( $pg_obj->getId(), $this->getId() );
 					Debug::text('Record Count: '. $pgulf->getRecordCount(), __FILE__, __LINE__, __METHOD__, 10);
 					if ( $pgulf->getRecordCount() > 0 ) {
@@ -2451,7 +2511,7 @@ class UserFactory extends Factory {
 
 			if ( $this->getPolicyGroup() !== FALSE AND $add_policy_group == TRUE ) {
 				//Add to new policy group
-				$pguf = new PolicyGroupUserFactory();
+				$pguf = TTnew( 'PolicyGroupUserFactory' );
 				$pguf->setPolicyGroup( $this->getPolicyGroup() );
 				$pguf->setUser( $this->getID() );
 
@@ -2469,7 +2529,7 @@ class UserFactory extends Factory {
 			//Debug::Arr($hierarchy_control_data, 'Setting hierarchy control data...', __FILE__, __LINE__, __METHOD__, 10);
 
 			if ( is_array( $hierarchy_control_data ) ) {
-				$hclf = new HierarchyControlListFactory();
+				$hclf = TTnew( 'HierarchyControlListFactory' );
 				$hclf->getObjectTypeAppendedListByCompanyIDAndUserID( $this->getCompany(), $this->getID() );
 				$existing_hierarchy_control_data = array_unique( array_values( (array)$hclf->getArrayByListFactory( $hclf, FALSE, TRUE, FALSE ) ) );
 				//Debug::Arr($existing_hierarchy_control_data, 'Existing hierarchy control data...', __FILE__, __LINE__, __METHOD__, 10);
@@ -2481,7 +2541,7 @@ class UserFactory extends Factory {
 				if ( is_array($hierarchy_control_delete_diff) ) {
 					foreach( $hierarchy_control_delete_diff as $hierarchy_control_id ) {
 						if ( $hierarchy_control_id != 0 ) {
-							$hulf = new HierarchyUserListFactory();
+							$hulf = TTnew( 'HierarchyUserListFactory' );
 							$hulf->getByHierarchyControlAndUserID( $hierarchy_control_id, $this->getID() );
 							if ( $hulf->getRecordCount() > 0 ) {
 								Debug::text('Deleting user from hierarchy control ID: '. $hierarchy_control_id, __FILE__, __LINE__, __METHOD__, 10);
@@ -2499,7 +2559,7 @@ class UserFactory extends Factory {
 					foreach( $hierarchy_control_add_diff as $hierarchy_control_id ) {
 						Debug::text('Hierarchy data changed...', __FILE__, __LINE__, __METHOD__, 10);
 						if ( $hierarchy_control_id != 0 ) {
-							$huf = new HierarchyUserFactory();
+							$huf = TTnew( 'HierarchyUserFactory' );
 							$huf->setHierarchyControl( $hierarchy_control_id );
 							$huf->setUser( $this->getId() );
 							if ( $huf->isValid() ) {
@@ -2514,7 +2574,7 @@ class UserFactory extends Factory {
 		}
 
 		if ( isset($this->is_new) AND $this->is_new == TRUE ) {
-			$udlf = new UserDefaultListFactory();
+			$udlf = TTnew( 'UserDefaultListFactory' );
 			$udlf->getByCompanyId( $this->getCompany() );
 			if ( $udlf->getRecordCount() > 0 ) {
 				Debug::Text('Using User Defaults', __FILE__, __LINE__, __METHOD__,10);
@@ -2525,7 +2585,7 @@ class UserFactory extends Factory {
 				$company_deduction_ids = $udf_obj->getCompanyDeduction();
 				if ( is_array($company_deduction_ids) AND count($company_deduction_ids) > 0 ) {
 					foreach( $company_deduction_ids as $company_deduction_id ) {
-						$udf = new UserDeductionFactory();
+						$udf = TTnew( 'UserDeductionFactory' );
 						$udf->setUser( $this->getId() );
 						$udf->setCompanyDeduction( $company_deduction_id );
 						if ( $udf->isValid() ) {
@@ -2536,13 +2596,16 @@ class UserFactory extends Factory {
 				unset($company_deduction_ids, $company_deduction_id, $udf);
 
 				Debug::text('Inserting Default Prefs...', __FILE__, __LINE__, __METHOD__, 10);
-				$upf = new UserPreferenceFactory();
+				$upf = TTnew( 'UserPreferenceFactory' );
 				$upf->setUser( $this->getId() );
 				$upf->setLanguage( $udf_obj->getLanguage() );
 				$upf->setDateFormat( $udf_obj->getDateFormat() );
 				$upf->setTimeFormat( $udf_obj->getTimeFormat() );
 				$upf->setTimeUnitFormat( $udf_obj->getTimeUnitFormat() );
-				$upf->setTimeZone( $udf_obj->getTimeZone() );
+
+				$upf->setTimeZone( $upf->getLocationTimeZone( $this->getCountry(), $this->getProvince(), $this->getWorkPhone(), $this->getHomePhone(), $udf_obj->getTimeZone() ) );
+				Debug::text('Time Zone: '. $upf->getTimeZone(), __FILE__, __LINE__, __METHOD__,9);
+
 				$upf->setItemsPerPage( $udf_obj->getItemsPerPage() );
 				$upf->setStartWeekDay( $udf_obj->getStartWeekDay() );
 				$upf->setEnableEmailNotificationException( $udf_obj->getEnableEmailNotificationException() );
@@ -2561,13 +2624,13 @@ class UserFactory extends Factory {
 			//Delete any accruals for them as well.
 
 			//Pay Period Schedule
-			$ppslf = new PayPeriodScheduleListFactory();
+			$ppslf = TTnew( 'PayPeriodScheduleListFactory' );
 			$ppslf->getByUserId( $this->getId() );
 			if ( $ppslf->getRecordCount() > 0 ) {
 				$pps_obj = $ppslf->getCurrent();
 
 				//Remove user from current schedule.
-				$ppsulf = new PayPeriodScheduleUserListFactory();
+				$ppsulf = TTnew( 'PayPeriodScheduleUserListFactory' );
 				$ppsulf->getByPayPeriodScheduleIdAndUserID( $pps_obj->getId(), $this->getId() );
 				Debug::text('Record Count: '. $ppsulf->getRecordCount(), __FILE__, __LINE__, __METHOD__, 10);
 				if ( $ppsulf->getRecordCount() > 0 ) {
@@ -2579,12 +2642,12 @@ class UserFactory extends Factory {
 			}
 
 			//Policy Group
-			$pglf = new PolicyGroupListFactory();
+			$pglf = TTnew( 'PolicyGroupListFactory' );
 			$pglf->getByUserIds( $this->getId() );
 			if ( $pglf->getRecordCount() > 0 ) {
 				$pg_obj = $pglf->getCurrent();
 
-				$pgulf = new PolicyGroupUserListFactory();
+				$pgulf = TTnew( 'PolicyGroupUserListFactory' );
 				$pgulf->getByPolicyGroupIdAndUserId( $pg_obj->getId(), $this->getId() );
 				Debug::text('Record Count: '. $pgulf->getRecordCount(), __FILE__, __LINE__, __METHOD__, 10);
 				if ( $pgulf->getRecordCount() > 0 ) {
@@ -2596,11 +2659,11 @@ class UserFactory extends Factory {
 			}
 
 			//Hierarchy
-			$hclf = new HierarchyControlListFactory();
+			$hclf = TTnew( 'HierarchyControlListFactory' );
 			$hclf->getByCompanyId( $this->getCompany() );
 			if ( $hclf->getRecordCount() > 0 ) {
 				foreach( $hclf as $hc_obj ) {
-					$hf = new HierarchyListFactory();
+					$hf = TTnew( 'HierarchyListFactory' );
 					$hf->setUser( $this->getID() );
 					$hf->setHierarchyControl( $hc_obj->getId() );
 					$hf->Delete();
@@ -2610,7 +2673,7 @@ class UserFactory extends Factory {
 			}
 
 			//Accrual balances
-			$alf = new AccrualListFactory();
+			$alf = TTnew( 'AccrualListFactory' );
 			$alf->getByUserIdAndCompanyId( $this->getId(), $this->getCompany() );
 			if ( $alf->getRecordCount()> 0 ) {
 				foreach( $alf as $a_obj ) {
@@ -2622,17 +2685,17 @@ class UserFactory extends Factory {
 			}
 
 			//Station employee critiera
-			$siuf = new StationIncludeUserFactory();
-			$seuf = new StationExcludeUserFactory();
+			$siuf = TTnew( 'StationIncludeUserFactory' );
+			$seuf = TTnew( 'StationExcludeUserFactory' );
 
-			$query = 'delete from '. $siuf->getTable() .' where user_id = '. $this->getId();
+			$query = 'delete from '. $siuf->getTable() .' where user_id = '. (int)$this->getId();
 			$this->db->Execute($query);
 
-			$query = 'delete from '. $seuf->getTable() .' where user_id = '. $this->getId();
+			$query = 'delete from '. $seuf->getTable() .' where user_id = '. (int)$this->getId();
 			$this->db->Execute($query);
 
 			//Job employee criteria
-			$cgmlf = new CompanyGenericMapListFactory();
+			$cgmlf = TTnew( 'CompanyGenericMapListFactory' );
 			$cgmlf->getByCompanyIDAndObjectTypeAndMapID( $this->getCompany(), array(1040,1050), $this->getID() );
 			if ( $cgmlf->getRecordCount() > 0 ) {
 				foreach( $cgmlf as $cgm_obj ) {
@@ -2645,6 +2708,10 @@ class UserFactory extends Factory {
 		return TRUE;
 	}
 
+	function getMapURL() {
+		return Misc::getMapURL( $this->getAddress1(), $this->getAddress2(), $this->getCity(), $this->getProvince(), $this->getPostalCode(), $this->getCountry() );
+	}
+
 	//Support setting created_by,updated_by especially for importing data.
 	//Make sure data is set based on the getVariableToFunctionMap order.
 	function setObjectFromArray( $data ) {
@@ -2706,19 +2773,40 @@ class UserFactory extends Factory {
 								$data[$variable] = Option::getByKey( $this->$function(), $this->getOptions( $variable ) );
 							}
 							break;
+						case 'company':
 						case 'title':
-						case 'group':
+						case 'user_group':
 						case 'currency':
 						case 'default_branch':
 						case 'default_department':
-						case 'permission_control_id':
 						case 'permission_control':
-						case 'pay_period_schedule_id':
 						case 'pay_period_schedule':
-						case 'policy_group_id':
 						case 'policy_group':
 							$data[$variable] = $this->getColumn( $variable );
 							break;
+						//The below fields may be set if APISearch ListFactory is used to obtain the data originally,
+						//but if it isn't, use the explicit function to get the data instead.
+						case 'permission_control_id':
+							$data[$variable] = $this->getColumn( $variable );
+							if ( $data[$variable] == FALSE ) {
+								$data[$variable] = $this->getPermissionControl();
+							}
+							break;
+						case 'pay_period_schedule_id':
+							$data[$variable] = $this->getColumn( $variable );
+							if ( $data[$variable] == FALSE ) {
+								$data[$variable] = $this->getPayPeriodSchedule();
+							}
+							break;
+						case 'policy_group_id':
+							$data[$variable] = $this->getColumn( $variable );
+							if ( $data[$variable] == FALSE ) {
+								$data[$variable] = $this->getPolicyGroup();
+							}
+							break;
+						case 'hierarchy_control':
+							$data[$variable] = $this->getHierarchyControl();
+							break;
 						case 'password': //Don't return password
 							break;
 						case 'sin':
