@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3061 $
- * $Id: UserGenericDataFactory.class.php 3061 2009-11-13 17:38:19Z ipso $
- * $Date: 2009-11-13 09:38:19 -0800 (Fri, 13 Nov 2009) $
+ * $Revision: 4265 $
+ * $Id: UserGenericDataFactory.class.php 4265 2011-02-18 00:49:20Z ipso $
+ * $Date: 2011-02-17 16:49:20 -0800 (Thu, 17 Feb 2011) $
  */
 
 /**
@@ -70,7 +70,7 @@ class UserGenericDataFactory extends Factory {
 	function setCompany($id) {
 		$id = trim($id);
 
-		$clf = new CompanyListFactory();
+		$clf = TTnew( 'CompanyListFactory' );
 
 		if ( $this->Validator->isResultSetWithRows(			'company',
 															$clf->getByID($id),
@@ -94,7 +94,7 @@ class UserGenericDataFactory extends Factory {
 	function setUser($id) {
 		$id = trim($id);
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 
 		if ( $this->Validator->isResultSetWithRows(	'user',
 															$ulf->getByID($id),
@@ -167,8 +167,6 @@ class UserGenericDataFactory extends Factory {
 
 		$query .= ' AND deleted = 0';
 		$name_id = $this->db->GetOne($query, $ph);
-		Debug::Text($query,'Query: '. $name , __FILE__, __LINE__, __METHOD__,10);
-
 		Debug::Arr($name_id,'Unique Name: '. $name , __FILE__, __LINE__, __METHOD__,10);
 
 		if ( $name_id === FALSE ) {
@@ -246,7 +244,7 @@ class UserGenericDataFactory extends Factory {
 	function preSave() {
 		if ( $this->getDefault() == TRUE ) {
 			//Remove default flag from all other entries.
-			$ugdlf = new UserGenericDataListFactory();
+			$ugdlf = TTnew( 'UserGenericDataListFactory' );
 			if ( $this->getUser() == FALSE ) {
 				$ugdlf->getByCompanyIdAndScriptAndDefault( $this->getUser(), $this->getScript(), TRUE );
 			} else {
@@ -286,7 +284,7 @@ class UserGenericDataFactory extends Factory {
 
 		$retarr = array();
 
-		$ugdlf = new UserGenericDataListFactory();
+		$ugdlf = TTnew( 'UserGenericDataListFactory' );
 		if ( isset($saved_search_id) AND $saved_search_id != 0 AND $saved_search_id != '' ) {
 			$ugdlf->getByUserIdAndId( $current_user->getId(), $saved_search_id );
 		} else {
@@ -326,8 +324,8 @@ class UserGenericDataFactory extends Factory {
 
 		$saved_search_id = FALSE;
 
-		$ugdlf = new UserGenericDataListFactory();
-		$ugdf = new UserGenericDataFactory();
+		$ugdlf = TTnew( 'UserGenericDataListFactory' );
+		$ugdf = TTnew( 'UserGenericDataFactory' );
 		if ( $action == 'search_form_update' OR $action == 'search_form_save' ) {
 			Debug::Text('Save Report!', __FILE__, __LINE__, __METHOD__,10);
 
@@ -398,7 +396,7 @@ class UserGenericDataFactory extends Factory {
 
 		$retarr = array();
 
-		$ugdlf = new UserGenericDataListFactory();
+		$ugdlf = TTnew( 'UserGenericDataListFactory' );
 		if ( isset($saved_search_id) AND $saved_search_id != 0 AND $saved_search_id != '' ) {
 			$ugdlf->getByUserIdAndId( $current_user->getId(), $saved_search_id );
 		} else {
@@ -431,8 +429,8 @@ class UserGenericDataFactory extends Factory {
 
 		$saved_report_id = FALSE;
 
-		$ugdlf = new UserGenericDataListFactory();
-		$ugdf = new UserGenericDataFactory();
+		$ugdlf = TTnew( 'UserGenericDataListFactory' );
+		$ugdf = TTnew( 'UserGenericDataFactory' );
 		if ( $action == 'save' OR $action == 'update' ) {
 			Debug::Text('Save Report!', __FILE__, __LINE__, __METHOD__,10);
 
