@@ -56,11 +56,11 @@ class UserIdentificationFactory extends Factory {
 			case 'type':
 				$retval = array(
 											10 	=> TTi18n::gettext('iButton'),
-											20	=> TTi18n::gettext('Griaule Fingerprint'),
-											25	=> TTi18n::gettext('LibFingerPrint'),
+											20	=> TTi18n::gettext('USB Fingerprint'),
+											//25	=> TTi18n::gettext('LibFingerPrint'),
 											30	=> TTi18n::gettext('Barcode'), //For barcode readers and USB proximity card readers.
 											40	=> TTi18n::gettext('Proximity Card'), //Mainly for proximity cards on timeclocks.
-											100	=> TTi18n::gettext('ZK Fingerprint'), //TimeClocks
+											100	=> TTi18n::gettext('TimeClock FingerPrint'), //TimeClocks
 									);
 				break;
 
@@ -73,7 +73,7 @@ class UserIdentificationFactory extends Factory {
 		if ( is_object($this->user_obj) ) {
 			return $this->user_obj;
 		} else {
-			$ulf = new UserListFactory();
+			$ulf = TTnew( 'UserListFactory' );
 			$this->user_obj = $ulf->getById( $this->getUser() )->getCurrent();
 
 			return $this->user_obj;
@@ -86,7 +86,7 @@ class UserIdentificationFactory extends Factory {
 	function setUser($id) {
 		$id = trim($id);
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 
 		if ( $id == 0
 				OR $this->Validator->isResultSetWithRows(	'user',
@@ -171,7 +171,7 @@ class UserIdentificationFactory extends Factory {
 					'value' => (string)$value,
 					);
 
-		$uf = new UserFactory();
+		$uf = TTnew( 'UserFactory' );
 
 		$query = 'select a.id
 					from '. $this->getTable() .' as a,
