@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: UserListFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4644 $
+ * $Id: UserListFactory.class.php 4644 2011-05-05 23:54:00Z ipso $
+ * $Date: 2011-05-05 16:54:00 -0700 (Thu, 05 May 2011) $
  */
 
 /**
@@ -291,8 +291,6 @@ class UserListFactory extends UserFactory implements IteratorAggregate {
 
 		$this->rs = $this->db->Execute($query, $ph);
 
-		Debug::Text('Query: '. $query, __FILE__, __LINE__, __METHOD__,10);
-
 		return $this;
 	}
 
@@ -420,7 +418,6 @@ class UserListFactory extends UserFactory implements IteratorAggregate {
 					where 	currency_id = ?
 						AND deleted = 0';
 
-		Debug::text('Query: '. $query, __FILE__, __LINE__, __METHOD__, 10);
 		$this->rs = $this->db->Execute($query, $ph);
 
 		return $this;
@@ -447,7 +444,6 @@ class UserListFactory extends UserFactory implements IteratorAggregate {
 						AND group_id = ?
 						AND deleted = 0';
 
-		Debug::text('Query: '. $query, __FILE__, __LINE__, __METHOD__, 10);
 		$this->rs = $this->db->Execute($query, $ph);
 
 		return $this;
@@ -474,7 +470,6 @@ class UserListFactory extends UserFactory implements IteratorAggregate {
 						AND ibutton_id = ?
 						AND deleted = 0';
 
-		Debug::text('Query: '. $query, __FILE__, __LINE__, __METHOD__, 10);
 		$this->rs = $this->db->Execute($query, $ph);
 
 		return $this;
@@ -501,7 +496,6 @@ class UserListFactory extends UserFactory implements IteratorAggregate {
 						AND rf_id = ?
 						AND deleted = 0';
 
-		//Debug::text('Query: '. $query, __FILE__, __LINE__, __METHOD__, 10);
 		$this->rs = $this->db->Execute($query, $ph);
 
 		return $this;
@@ -528,7 +522,6 @@ class UserListFactory extends UserFactory implements IteratorAggregate {
 						AND employee_number = ?
 						AND deleted = 0';
 
-		//Debug::text('Query: '. $query, __FILE__, __LINE__, __METHOD__, 10);
 		$this->rs = $this->db->Execute($query, $ph);
 
 		return $this;
@@ -618,7 +611,6 @@ class UserListFactory extends UserFactory implements IteratorAggregate {
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order, $strict );
 
-		//Debug::text('Query: '. $query, __FILE__, __LINE__, __METHOD__, 10);
 		if ($limit == NULL) {
 			$this->rs = $this->db->Execute($query, $ph);
 		} else {
@@ -724,7 +716,6 @@ class UserListFactory extends UserFactory implements IteratorAggregate {
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order, $strict );
 
-		//Debug::text('Query: '. $query, __FILE__, __LINE__, __METHOD__, 10);
 		if ($limit == NULL) {
 			$this->rs = $this->db->Execute($query, $ph);
 		} else {
@@ -1520,9 +1511,6 @@ class UserListFactory extends UserFactory implements IteratorAggregate {
 					';
 		$query .= $this->getSortSQL( $order, $strict );
 
-//		Debug::Arr($ph, 'PH: ', __FILE__, __LINE__, __METHOD__,10);
-		Debug::text('Query: '. $query, __FILE__, __LINE__, __METHOD__,10);
-
 		$this->rs = $this->db->Execute($query, $ph);
 
 		return $this;
@@ -1591,7 +1579,8 @@ class UserListFactory extends UserFactory implements IteratorAggregate {
 		//$additional_order_fields = array('b.name', 'c.name', 'd.name', 'e.name');
 		$additional_order_fields = array(	'default_branch',
 											'default_department',
-											'group',
+											'sex',
+											'user_group',
 											'title',
 											'currency',
 											'permission_control',
@@ -1602,6 +1591,7 @@ class UserListFactory extends UserFactory implements IteratorAggregate {
 		$sort_column_aliases = array(
 									 'type' => 'type_id',
 									 'status' => 'status_id',
+									 'sex' => 'sex_id',
 									 );
 
 		$order = $this->getColumnsFromAliases( $order, $sort_column_aliases );
@@ -1628,6 +1618,7 @@ class UserListFactory extends UserFactory implements IteratorAggregate {
 		Debug::Arr($order,'Order Data:', __FILE__, __LINE__, __METHOD__,10);
 		//Debug::Arr($filter_data,'Filter Data:', __FILE__, __LINE__, __METHOD__,10);
 
+		$compf = new CompanyFactory();
 		$bf = new BranchFactory();
 		$df = new DepartmentFactory();
 		$ugf = new UserGroupFactory();
@@ -1646,9 +1637,10 @@ class UserListFactory extends UserFactory implements IteratorAggregate {
 
 		$query = '
 					select 	a.*,
+							compf.name as company,
 							b.name as default_branch,
 							c.name as default_department,
-							d.name as group,
+							d.name as user_group,
 							e.name as title,
 							f.name as currency,
 							g.id as permission_control_id,
@@ -1664,6 +1656,7 @@ class UserListFactory extends UserFactory implements IteratorAggregate {
 							z.middle_name as updated_by_middle_name,
 							z.last_name as updated_by_last_name
 					from 	'. $this->getTable() .' as a
+						LEFT JOIN '. $compf->getTable() .' as compf ON ( a.company_id = compf.id AND compf.deleted = 0)
 						LEFT JOIN '. $bf->getTable() .' as b ON ( a.default_branch_id = b.id AND b.deleted = 0)
 						LEFT JOIN '. $df->getTable() .' as c ON ( a.default_department_id = c.id AND c.deleted = 0)
 						LEFT JOIN '. $ugf->getTable() .' as d ON ( a.group_id = d.id AND d.deleted = 0 )
@@ -1713,8 +1706,8 @@ class UserListFactory extends UserFactory implements IteratorAggregate {
 			}
 			$query  .=	' AND a.group_id in ('. $this->getListSQL($filter_data['group_id'], $ph) .') ';
 		}
-		if ( isset($filter_data['group']) AND trim($filter_data['group']) != '' ) {
-			$ph[] = strtolower(trim($filter_data['group']));
+		if ( isset($filter_data['user_group']) AND trim($filter_data['user_group']) != '' ) {
+			$ph[] = strtolower(trim($filter_data['user_group']));
 			$query  .=	' AND lower(d.name) LIKE ?';
 		}
 
@@ -1848,8 +1841,6 @@ class UserListFactory extends UserFactory implements IteratorAggregate {
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
 
-		Debug::Text('Query: '. $query, __FILE__, __LINE__, __METHOD__,10);
-
 		if ($limit == NULL) {
 			$this->rs = $this->db->Execute($query, $ph);
 		} else {
