@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: UserPreferenceListFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4845 $
+ * $Id: UserPreferenceListFactory.class.php 4845 2011-06-21 16:23:18Z ipso $
+ * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
  */
 
 /**
@@ -210,7 +210,19 @@ class UserPreferenceListFactory extends UserPreferenceFactory implements Iterato
 			$filter_data['exclude_id'] = $filter_data['exclude_user_id'];
 		}
 
-		$additional_order_fields = array();
+		$additional_order_fields = array('user_status_id','last_name', 'first_name', 'default_branch', 'default_department', 'user_group', 'title' );
+
+		$sort_column_aliases = array(
+									'user_status' => 'user_status_id',
+									'type' => 'type_id',
+									'language_display' => 'language',
+									'start_week_day_display' => 'start_week_day',
+									'date_format_display' => 'date_format',
+									'time_format_display' => 'time_format',
+									'time_unit_format_display' => 'time_unit_format',
+									'time_zone_display' => 'time_zone',
+									);
+		$order = $this->getColumnsFromAliases( $order, $sort_column_aliases );
 		if ( $order == NULL ) {
 			$order = array( 'last_name' => 'asc' );
 			$strict = FALSE;
@@ -245,7 +257,7 @@ class UserPreferenceListFactory extends UserPreferenceFactory implements Iterato
 							b.default_department_id as default_department_id,
 							df.name as default_department,
 							b.group_id as group_id,
-							ugf.name as group,
+							ugf.name as user_group,
 							b.title_id as title_id,
 							utf.name as title,
 
@@ -301,6 +313,32 @@ class UserPreferenceListFactory extends UserPreferenceFactory implements Iterato
 			$query  .=	' AND b.title_id in ('. $this->getListSQL($filter_data['title_id'], $ph) .') ';
 		}
 
+		if ( isset($filter_data['status_id']) AND isset($filter_data['status_id'][0]) AND !in_array(-1, (array)$filter_data['status_id']) ) {
+			$query  .=	' AND b.status_id in ('. $this->getListSQL($filter_data['status_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['country']) AND isset($filter_data['country'][0]) AND !in_array(-1, (array)$filter_data['country']) ) {
+			$query  .=	' AND b.country in ('. $this->getListSQL($filter_data['country'], $ph) .') ';
+		}
+		if ( isset($filter_data['province']) AND isset($filter_data['province'][0]) AND !in_array( -1, (array)$filter_data['province']) AND !in_array( '00', (array)$filter_data['province']) ) {
+			$query  .=	' AND b.province in ('. $this->getListSQL($filter_data['province'], $ph) .') ';
+		}
+		if ( isset($filter_data['user_name']) AND trim($filter_data['user_name']) != '' ) {
+			$ph[] = strtolower(trim($filter_data['user_name']));
+			$query  .=	' AND lower(b.user_name) LIKE ?';
+		}
+		if ( isset($filter_data['first_name']) AND trim($filter_data['first_name']) != '' ) {
+			$ph[] = strtolower(trim($filter_data['first_name']));
+			$query  .=	' AND lower(b.first_name) LIKE ?';
+		}
+		if ( isset($filter_data['last_name']) AND trim($filter_data['last_name']) != '' ) {
+			$ph[] = strtolower(trim($filter_data['last_name']));
+			$query  .=	' AND lower(b.last_name) LIKE ?';
+		}
+		if ( isset($filter_data['employee_number']) AND trim($filter_data['employee_number']) != '' ) {
+			$ph[] = trim($filter_data['employee_number']);
+			$query  .=	' AND b.employee_number LIKE ?';
+		}
+
 		if ( isset($filter_data['created_by']) AND isset($filter_data['created_by'][0]) AND !in_array(-1, (array)$filter_data['created_by']) ) {
 			$query  .=	' AND a.created_by in ('. $this->getListSQL($filter_data['created_by'], $ph) .') ';
 		}
