@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: UserWageFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4845 $
+ * $Id: UserWageFactory.class.php 4845 2011-06-21 16:23:18Z ipso $
+ * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
  */
 
 /**
@@ -82,7 +82,7 @@ class UserWageFactory extends Factory {
 										'-1080-weekly_time' => TTi18n::gettext('Average Time/Week'),
 
 										'-1090-title' => TTi18n::gettext('Title'),
-										'-1099-group' => TTi18n::gettext('Group'),
+										'-1099-user_group' => TTi18n::gettext('Group'),
 										'-1100-default_branch' => TTi18n::gettext('Branch'),
 										'-1110-default_department' => TTi18n::gettext('Department'),
 
@@ -94,6 +94,9 @@ class UserWageFactory extends Factory {
 										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
 							);
 				break;
+			case 'list_columns':
+				$retval = Misc::arrayIntersectByKey( $this->getOptions('default_display_columns'), Misc::trimSortPrefix( $this->getOptions('columns') ) );
+				break;
 			case 'default_display_columns': //Columns that are displayed by default.
 				$retval = array(
 								'first_name',
@@ -134,7 +137,7 @@ class UserWageFactory extends Factory {
 
 											'default_branch' => FALSE,
 											'default_department' => FALSE,
-											'group' => FALSE,
+											'user_group' => FALSE,
 											'title' => FALSE,
 
 											'deleted' => 'Deleted',
@@ -146,7 +149,7 @@ class UserWageFactory extends Factory {
 		if ( is_object($this->user_obj) ) {
 			return $this->user_obj;
 		} else {
-			$ulf = new UserListFactory();
+			$ulf = TTnew( 'UserListFactory' );
 			$ulf->getById( $this->getUser() );
 			if ( $ulf->getRecordCount() == 1 ) {
 				$this->user_obj = $ulf->getCurrent();
@@ -162,7 +165,7 @@ class UserWageFactory extends Factory {
 			return $this->wage_group_obj;
 		} else {
 
-			$wglf = new WageGroupListFactory();
+			$wglf = TTnew( 'WageGroupListFactory' );
 			$wglf->getById( $this->getWageGroup() );
 
 			if ( $wglf->getRecordCount() == 1 ) {
@@ -181,7 +184,7 @@ class UserWageFactory extends Factory {
 	function setUser($id) {
 		$id = trim($id);
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 
 		if ( $id == 0
 				OR $this->Validator->isResultSetWithRows(	'user',
@@ -207,7 +210,7 @@ class UserWageFactory extends Factory {
 		$id = trim($id);
 
 		Debug::Text('Wage Group ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
-		$wglf = new WageGroupListFactory();
+		$wglf = TTnew( 'WageGroupListFactory' );
 
 		if (
 				$id == 0
@@ -375,7 +378,7 @@ class UserWageFactory extends Factory {
 
 		$must_validate = FALSE;
 
-		$uwlf = new UserWageListFactory();
+		$uwlf = TTnew( 'UserWageListFactory' );
 		$uwlf->getByUserIdAndGroupIDAndBeforeDate( $this->getUser(), 0, $epoch );
 		//Debug::text(' Total Rows: '. $uwlf->getRecordCount() .' User: '. $this->getUser() .' Epoch: '. $epoch , __FILE__, __LINE__, __METHOD__,10);
 
@@ -474,7 +477,7 @@ class UserWageFactory extends Factory {
 			return FALSE;
 		}
 
-		$clf = new CurrencyListFactory();
+		$clf = TTnew( 'CurrencyListFactory' );
 		$clf->getByCompanyIdAndBase( $this->getUserObject()->getCompany(), TRUE );
 		if ( $clf->getRecordCount() > 0 ) {
 			$base_currency_obj = $clf->getCurrent();
@@ -572,7 +575,7 @@ class UserWageFactory extends Factory {
 		return $hourly_wage;
 	}
 
-	static function proRateSalary($salary, $wage_effective_date, $prev_wage_effective_date, $pp_start_date, $pp_end_date ) {
+	static function proRateSalary($salary, $wage_effective_date, $prev_wage_effective_date, $pp_start_date, $pp_end_date, $termination_date ) {
 		$prev_wage_effective_date = (int)$prev_wage_effective_date;
 
 		if ( $wage_effective_date < $pp_start_date ) {
@@ -582,6 +585,12 @@ class UserWageFactory extends Factory {
 		$total_pay_period_days = ceil( TTDate::getDayDifference( $pp_start_date, $pp_end_date) );
 
 		if ( $prev_wage_effective_date == 0 ) {
+			//ProRate salary to termination date if its in the middle of a pay period.
+			if ( $termination_date != '' AND $termination_date > 0 AND $termination_date < $pp_end_date ) {
+				Debug::text(' Setting PP end date to Termination Date: '. TTDate::GetDate('DATE', $termination_date) , __FILE__, __LINE__, __METHOD__,10);
+				$pp_end_date = $termination_date;
+			}
+
 			Debug::text(' Using Pay Period End Date: '. TTDate::GetDate('DATE', $pp_end_date) , __FILE__, __LINE__, __METHOD__,10);
 			$total_wage_effective_days = ceil( TTDate::getDayDifference( $wage_effective_date, $pp_end_date) );
 		} else {
@@ -633,10 +642,10 @@ class UserWageFactory extends Factory {
 
 		$retval = FALSE;
 
-		$pseallf = new PayStubEntryAccountLinkListFactory();
+		$pseallf = TTnew( 'PayStubEntryAccountLinkListFactory' );
 		$pseallf->getByCompanyID( $company_id );
 		if ( $pseallf->getRecordCount() > 0 ) {
-			$pself = new PayStubEntryListFactory();
+			$pself = TTnew( 'PayStubEntryListFactory' );
 			$total_gross = $pself->getAmountSumByUserIdAndEntryNameIdAndStartDateAndEndDate($user_id, $pseallf->getCurrent()->getTotalGross(), $start_epoch, $end_epoch );
 			$total_employer_deductions = $pself->getAmountSumByUserIdAndEntryNameIdAndStartDateAndEndDate($user_id, $pseallf->getCurrent()->getTotalEmployerDeduction(), $start_epoch, $end_epoch );
 
@@ -704,7 +713,7 @@ class UserWageFactory extends Factory {
 		return FALSE;
 	}
 
-	function getObjectAsArray( $include_columns = NULL ) {
+	function getObjectAsArray( $include_columns = NULL, $permission_children_ids = FALSE ) {
 		$variable_function_map = $this->getVariableToFunctionMap();
 		if ( is_array( $variable_function_map ) ) {
 			foreach( $variable_function_map as $variable => $function_stub ) {
@@ -722,7 +731,7 @@ class UserWageFactory extends Factory {
 						case 'first_name':
 						case 'last_name':
 						case 'title':
-						case 'group':
+						case 'user_group':
 						case 'currency':
 						case 'default_branch':
 						case 'default_department':
@@ -744,6 +753,7 @@ class UserWageFactory extends Factory {
 					}
 				}
 			}
+			$this->getPermissionColumns( &$data, $this->getID(), $this->getCreatedBy(), $permission_children_ids, $include_columns );
 			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
 		}
 
