@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: UserWageListFactory.class.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4455 $
+ * $Id: UserWageListFactory.class.php 4455 2011-03-28 19:18:22Z ipso $
+ * $Date: 2011-03-28 12:18:22 -0700 (Mon, 28 Mar 2011) $
  */
 
 /**
@@ -591,6 +591,48 @@ class UserWageListFactory extends UserWageFactory implements IteratorAggregate {
 		return $this;
 	}
 
+	function getByWageGroupIDAndCompanyId($wage_group_id, $company_id, $limit = NULL, $page = NULL, $where = NULL, $order = NULL) {
+		if ( empty($wage_group_id) ) {
+			return FALSE;
+		}
+
+		if ( empty($company_id) ) {
+			return FALSE;
+		}
+
+		if ( $order == NULL ) {
+			$order = array( 'b.effective_date' => 'desc');
+			$strict = FALSE;
+		} else {
+			$strict = TRUE;
+		}
+
+		$uf = new UserFactory();
+
+		$ph = array(
+					'company_id' => $company_id,
+					'wage_group_id' => $wage_group_id,
+					);
+
+		$query = '
+					select 	*
+					from	'. $uf->getTable() .' as a,
+							'. $this->getTable() .' as b
+					where	a.id = b.user_id
+						AND a.company_id = ?
+						AND	b.wage_group_id = ?
+						AND b.deleted = 0';
+		$query .= $this->getSortSQL( $order, $strict );
+
+		if ($limit == NULL) {
+			$this->rs = $this->db->Execute($query, $ph);
+		} else {
+			$this->rs = $this->db->PageExecute($query, $limit, $page, $ph);
+		}
+
+		return $this;
+	}
+
 	function getAPISearchByCompanyIdAndArrayCriteria( $company_id, $filter_data, $limit = NULL, $page = NULL, $where = NULL, $order = NULL ) {
 		if ( $company_id == '') {
 			return FALSE;
@@ -603,7 +645,13 @@ class UserWageListFactory extends UserWageFactory implements IteratorAggregate {
 			}
 		}
 
-		$additional_order_fields = array( 'wage_group' );
+		$additional_order_fields = array('user_status_id','last_name', 'first_name', 'default_branch', 'default_department', 'user_group', 'title', 'wage_group');
+
+		$sort_column_aliases = array(
+									'user_status' => 'user_status_id',
+									'type' => 'type_id',
+									);
+		$order = $this->getColumnsFromAliases( $order, $sort_column_aliases );
 		if ( $order == NULL ) {
 			$order = array( 'effective_date' => 'desc', 'wage_group_id' => 'asc', 'type_id' => 'asc', );
 			$strict = FALSE;
@@ -642,7 +690,7 @@ class UserWageListFactory extends UserWageFactory implements IteratorAggregate {
 							d.id as default_department_id,
 							d.name as default_department,
 							e.id as group_id,
-							e.name as group,
+							e.name as user_group,
 							f.id as title_id,
 							f.name as title,
 							g.id as currency_id,
@@ -823,7 +871,7 @@ class UserWageListFactory extends UserWageFactory implements IteratorAggregate {
 							d.id as default_department_id,
 							d.name as default_department,
 							e.id as group_id,
-							e.name as group,
+							e.name as user_group,
 							f.id as title_id,
 							f.name as title,
 							g.id as currency_id,
