@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: Data.class.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4845 $
+ * $Id: Data.class.php 4845 2011-06-21 16:23:18Z ipso $
+ * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
  */
 
 /**
@@ -52,6 +52,22 @@ class PayrollDeduction_CA_Data extends PayrollDeduction_Base {
 		Claim Code Basic Amounts
 	*/
 	var $basic_claim_code_options = array(
+							1309503600 => array( //01-Jul-2011: Some of these are only changed for the last 6mths in the year.
+										'CA' => 10527, //Federal
+										'BC' => 11088,
+										'AB' => 16977,
+										'SK' => 14535,
+										'MB' => 8634,
+										'QC' => 0,
+										'ON' => 9104,
+										'NL' => 7989,
+										'NB' => 8953,
+										'NS' => 8731,
+										'PE' => 7708,
+										'NT' => 12919,
+										'YT' => 10527,
+										'NU' => 11878,
+										),
 							1293868800 => array( //01-Jan-2011
 										'CA' => 10527, //Federal
 										'BC' => 11088,
