@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: Data.class.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4175 $
+ * $Id: Data.class.php 4175 2011-01-26 17:59:17Z ipso $
+ * $Date: 2011-01-26 09:59:17 -0800 (Wed, 26 Jan 2011) $
  */
 
 /*
@@ -62,7 +62,7 @@ C:21-Dec-10-NOCHANGE-	'KS' => 'Kansas',		- http://www.ksrevenue.org/forms-btwh.h
 C:21-Dec-10-NOCHANGE-	'KY' => 'Kentucky', 	- http://revenue.ky.gov/business/whtax.htm
 C:21-Dec-10-NOCHANGE-	'LA' => 'Louisiana',	- http://www.revenue.louisiana.gov/sections/publications/tm.asp
 C:21-Dec-10				'ME' => 'Maine',		- http://www.state.me.us/revenue/forms/with/2010.htm -- Check each year on the right of the page.
-C:21-Dec-10-NOCHANGE-	'MD' => 'Maryland',		- http://business.marylandtaxes.com/taxinfo/withholding/default.asp - Use non-residents tables, minus 1.25%, manually calculate each bracket. FIX county taxes...
+C:21-Dec-10-NOCHANGE-	'MD' => 'Maryland',		- http://business.marylandtaxes.com/taxinfo/withholding/default.asp - Use non-residents tables, *minus 1.25%*, manually calculate each bracket. See MD.class.php for more information.
 C:21-Dec-10-NOCHANGE-	'MA' => 'Massachusetts' - http://www.mass.gov/?pageID=dorterminal&L=3&L0=Home&L1=Businesses&L2=Current+Tax+Year+Information&sid=Ador&b=terminalcontent&f=dor_business_buspubs&csid=Ador
 C:21-Dec-10-NOCHANGE-	'MI' => 'Michigan',		- http://www.michigan.gov/documents/treasury/446_2007_176836_7.pdf *Michigan Income Tax Withholding Guide
 C:21-Dec-10				'MN' => 'Minnesota',	- http://taxes.state.mn.us/withholding/pages/index.aspx *2011 Computer Formula
@@ -281,6 +281,7 @@ class PayrollDeduction_US_Data extends PayrollDeduction_Base {
 													where effective_date <= '. $epoch .'
 														AND country = '. $this->db->qstr($country).'
 														AND state is NULL
+														AND district is NULL
 														AND ( status = 0
 															OR status = '. $federal_status .' )
 													ORDER BY effective_date DESC
@@ -296,6 +297,7 @@ class PayrollDeduction_US_Data extends PayrollDeduction_Base {
 													where effective_date <= '. $epoch .'
 														AND country = '. $this->db->qstr($country).'
 														AND state = '. $this->db->qstr($state) .'
+														AND district is NULL
 														AND ( status = 0
 															OR status = '. $state_status .' )
 													ORDER BY effective_date DESC
