@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: MD.class.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4111 $
+ * $Id: MD.class.php 4111 2011-01-07 18:36:36Z ipso $
+ * $Date: 2011-01-07 10:36:36 -0800 (Fri, 07 Jan 2011) $
  */
 
 /**
@@ -49,6 +49,11 @@ class PayrollDeduction_US_MD extends PayrollDeduction_US {
 								30 => TTi18n::gettext('Married (Filing Separately)'),
 								40 => TTi18n::gettext('Head of Household'),
 	*/
+
+	//
+	//I don't think will ever be 100% accurate, because the tax brackets completely change for each county, based on the county percent.
+	//We will need to have the county tax rate passed into this class so the proper calculations can be made.
+	//
 	var $state_options = array(
 								//01-Jan-09: No Changes
 								1199174400 => array( //2008
@@ -103,11 +108,27 @@ class PayrollDeduction_US_MD extends PayrollDeduction_US {
 
 		$retval = 0;
 
+		$county_rate = bcdiv( $this->getUserValue3(), 100);
+		if ( !is_numeric($county_rate) OR $county_rate < 0 ) {
+			$county_rate = 0;
+		}
+		Debug::text('County Rate: '. $county_rate, __FILE__, __LINE__, __METHOD__,10);
+
 		if ( $annual_income > 0 ) {
 			$rate = $this->getData()->getStateRate($annual_income);
 			$state_constant = $this->getData()->getStateConstant($annual_income);
 			$state_rate_income = $this->getData()->getStateRatePreviousIncome($annual_income);
 
+			//Modify rate/constant based on county rate, since it affects each tax bracket.
+
+			//Calculate the constant modifier, based on the county_rate percent difference from the state rate.
+			$constant_modifier = bcdiv( $county_rate, $rate ); //Percent that the constant needs to be modified by.
+			$county_constant = bcmul( $state_constant, $constant_modifier );
+			Debug::text('County: Rate: '. $county_rate .' Modifier Rate: '. $constant_modifier .' County Constant: '. $county_constant, __FILE__, __LINE__, __METHOD__,10);
+
+			$rate = bcadd( $rate, $county_rate );
+			$state_constant = bcadd( $state_constant, $county_constant );
+
 			Debug::text('Rate: '. $rate .' Constant: '. $state_constant .' Rate Income: '. $state_rate_income, __FILE__, __LINE__, __METHOD__,10);
 			$retval = bcadd( bcmul( bcsub( $annual_income, $state_rate_income ), $rate ), $state_constant );
 		}
