@@ -208,7 +208,7 @@ class UPS {
         if (isset($msg)) {
             PEAR::raiseError($msg, 0, PEAR_ERROR_DIE);
         }
-        $serializer = &new XML_Serializer;
+        $serializer = new XML_Serializer;
         $xml_array = array(
             'AccessLicenseNumber'   => $this->devkey,
             'UserId'                => $this->username,
@@ -379,7 +379,7 @@ class UPS {
             $msg  = 'Tracking number was not set or is invalid!';
             PEAR::raiseError($msg, 0, PEAR_ERROR_DIE);
         }
-        $serializer = &new XML_Serializer;
+        $serializer = new XML_Serializer;
         $customercontext = 'Request generated by PHP PEAR Services_UPS Package by Tim Batz';
         $xml_array = array(
             'Request' => array(
@@ -423,7 +423,7 @@ class UPS {
     function address_validation($city='', $postalcode='', $stateprovincecode='')
     {
         $this->_service = 'address validation';
-        $serializer =& new XML_Serializer;
+        $serializer = new XML_Serializer;
         $customercontext = 'Request generated by PHP PEAR Services_UPS Package by Tim Batz';
         $xml_array = array(
             'Request' => array(
@@ -484,7 +484,7 @@ class UPS {
     function rates_and_service_selection($shipper_arr, $ship_from_arr, $ship_to_arr, $shipment_arr, $request_option = 'shop' )
     {
         $this->_service = 'rates and services selection';
-        $serializer =& new XML_Serializer;
+        $serializer = new XML_Serializer;
 
         $customercontext = 'Request generated by PHP PEAR Services_UPS Package by Tim Batz';
         $xml_array['Request']['TransactionReference']['CustomerContext'] = $customercontext;
@@ -633,7 +633,7 @@ class UPS {
     function time_in_transit()
     {
         $this->service = 'time in transit';
-        $serializer =& new XML_Serializer;
+        $serializer = new XML_Serializer;
         $serializer->setOption('linebreak', '');
         $serializer->setOption('addDecl', true);
         $serializer->setOption('rootName', 'TimeInTransitRequest');
