@@ -12,6 +12,7 @@ $global_class_map = array(
     'APILogDetail' => 'api/core/APILogDetail.class.php',
 	'APIBranch' => 'api/company/APIBranch.class.php',
 	'APICompany' => 'api/company/APICompany.class.php',
+    'APIOtherField' => 'api/core/APIOtherField.class.php',
 	'APIWageGroup' => 'api/company/APIWageGroup.class.php',
     'APICompanyDeduction' => 'api/company/APICompanyDeduction.class.php',
     'APIUserDeduction' => 'api/users/APIUserDeduction.class.php',
@@ -29,6 +30,7 @@ $global_class_map = array(
 	'APIRecurringHoliday' => 'api/holiday/APIRecurringHoliday.class.php',
 	'APIPayStubEntryAccount' => 'api/pay_stub/APIPayStubEntryAccount.class.php',
 	'APIPayPeriod' => 'api/payperiod/APIPayPeriod.class.php',
+    'APIPayPeriodTimeSheetVerify' => 'api/payperiod/APIPayPeriodTimeSheetVerify.class.php',
 	'APIPayPeriodSchedule' => 'api/payperiod/APIPayPeriodSchedule.class.php',
 	'APIAbsencePolicy' => 'api/policy/APIAbsencePolicy.class.php',
     'APIAccrualBalance' => 'api/accrual/APIAccrualBalance.class.php',
@@ -54,6 +56,7 @@ $global_class_map = array(
     'APIRecurringScheduleTemplate' => 'api/schedule/APIRecurringScheduleTemplate.class.php',
     'APIRecurringScheduleControl' => 'api/schedule/APIRecurringScheduleControl.class.php',
 	'APIAuthentication' => 'api/unauthenticated/APIAuthentication.class.php',
+    'APIAuthorization' => 'api/core/APIAuthorization.class.php',
 	'APIUser' => 'api/users/APIUser.class.php',
 	'APIUserReportData' => 'api/users/APIUserReportData.class.php',
 	'APIUserGenericData' => 'api/users/APIUserGenericData.class.php',
@@ -85,9 +88,14 @@ $global_class_map = array(
     'APIReport' => 'api/report/APIReport.class.php',
     'APIReportSchedule' => 'api/report/APIReportSchedule.class.php',
     'APIUserSummaryReport' => 'api/report/APIUserSummaryReport.class.php',
+    'APIActiveShiftReport' => 'api/report/APIActiveShiftReport.class.php',
     'APITimesheetSummaryReport' => 'api/report/APITimesheetSummaryReport.class.php',
     'APITimesheetDetailReport' => 'api/report/APITimesheetDetailReport.class.php',
+    'APIPunchSummaryReport' => 'api/report/APIPunchSummaryReport.class.php',
+    'APIPayStubSummaryReport' => 'api/report/APIPayStubSummaryReport.class.php',
+    'APIScheduleSummaryReport' => 'api/report/APIScheduleSummaryReport.class.php',
     'APIInvoiceTransactionSummaryReport' => 'api/report/APIInvoiceTransactionSummaryReport.class.php',
+    'APIPayrollExportReport' => 'api/report/APIPayrollExportReport.class.php',
     'APIForm941Report' => 'api/report/APIForm941Report.class.php',
     'APITimeClockUnAuthenticated' => 'api/time_clock/APITimeClockUnAuthenticated.class.php',
     'APITimeClockUnAuthenticated_TTA8' => 'api/time_clock/APITimeClockUnAuthenticated_TTA8.class.php',
@@ -174,9 +182,14 @@ $global_class_map = array(
     'ReportScheduleFactory' => 'report/ReportScheduleFactory.class.php',
     'ReportScheduleListFactory' => 'report/ReportScheduleListFactory.class.php',
     'UserSummaryReport' => 'report/UserSummaryReport.class.php',
+    'ActiveShiftReport' => 'report/ActiveShiftReport.class.php',
     'TimesheetSummaryReport' => 'report/TimesheetSummaryReport.class.php',
     'TimesheetDetailReport' => 'report/TimesheetDetailReport.class.php',
+    'PunchSummaryReport' => 'report/PunchSummaryReport.class.php',
+    'ScheduleSummaryReport' => 'report/ScheduleSummaryReport.class.php',
+    'PayStubSummaryReport' => 'report/PayStubSummaryReport.class.php',
     'InvoiceTransactionSummaryReport' => 'report/InvoiceTransactionSummaryReport.class.php',
+    'PayrollExportReport' => 'report/PayrollExportReport.class.php',
     'Form941Report' => 'report/Form941Report.class.php',
 	'StationBranchFactory' => 'core/StationBranchFactory.class.php',
 	'StationBranchListFactory' => 'core/StationBranchListFactory.class.php',
