@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3641 $
- * $Id: Interface.inc.php 3641 2010-06-03 22:18:54Z ipso $
- * $Date: 2010-06-03 15:18:54 -0700 (Thu, 03 Jun 2010) $
+ * $Revision: 4312 $
+ * $Id: Interface.inc.php 4312 2011-02-28 00:42:55Z ipso $
+ * $Date: 2011-02-27 16:42:55 -0800 (Sun, 27 Feb 2011) $
  */
 if ( !isset($disable_cache_control) ) {
 	//Turn caching off.
@@ -97,7 +97,7 @@ if ( isset($authenticate) AND $authenticate === FALSE ) {
 		$current_user = $authentication->getObject();
 		Debug::text('User Authenticated: '. $current_user->getUserName() .' Created Date: '. $authentication->getCreatedDate(), __FILE__, __LINE__, __METHOD__, 10);
 
-		if ( PRIMARY_COMPANY_ID == $current_user->getCompany() ) {
+		if ( isset($primary_company) AND PRIMARY_COMPANY_ID == $current_user->getCompany() ) {
 			$current_company = $primary_company;
 		} else {
 			$current_company = $clf->getByID( $current_user->getCompany() )->getCurrent();
@@ -106,7 +106,7 @@ if ( isset($authenticate) AND $authenticate === FALSE ) {
 		//Check to make sure the logged in user's information is all up to date.
 		//Make sure they also have permissions to edit information, otherwise don't redirect them.
 		if ( $current_user->isInformationComplete() == FALSE
-				AND ( !stristr( $_SERVER['SCRIPT_NAME'], 'permissiondenied') AND !stristr( $_SERVER['SCRIPT_NAME'], 'logout') AND !stristr( $_SERVER['SCRIPT_NAME'], 'about') AND !stristr( $_SERVER['SCRIPT_NAME'], 'punch.php') AND !stristr( $_SERVER['SCRIPT_NAME'], 'ajax_server') AND !stristr( $_SERVER['SCRIPT_NAME'], 'global.js') AND !stristr( $_SERVER['SCRIPT_NAME'], 'menu.js') AND !stristr( $_SERVER['SCRIPT_NAME'], 'embeddeddocument') )
+				AND ( !stristr( $_SERVER['SCRIPT_NAME'], 'permissiondenied') AND !stristr( $_SERVER['SCRIPT_NAME'], 'logout') AND !stristr( $_SERVER['SCRIPT_NAME'], 'about') AND !stristr( $_SERVER['SCRIPT_NAME'], 'punch.php') AND !stristr( $_SERVER['SCRIPT_NAME'], 'ajax_server') AND !stristr( $_SERVER['SCRIPT_NAME'], 'global.js') AND !stristr( $_SERVER['SCRIPT_NAME'], 'menu.js') AND !stristr( $_SERVER['SCRIPT_NAME'], 'embeddeddocument') AND !stristr( $_SERVER['SCRIPT_NAME'], 'send_file') )
 				AND !isset($_GET['incomplete']) AND !isset($_POST['incomplete'])
 				AND ($permission->Check('user','enabled') AND ( $permission->Check('user','edit') OR $permission->Check('user','edit_own') OR $permission->Check('user','edit_child')) ) ) {
 			Redirect::Page( URLBuilder::getURL( array('id' => $current_user->getID(), 'incomplete' => 1 ), Environment::GetBaseURL().'users/EditUser.php') );
@@ -135,7 +135,7 @@ if ( isset($authenticate) AND $authenticate === FALSE ) {
 		 *  users language.
 		 */
 		Debug::text('Locale Cookie: '. TTi18n::getLocaleCookie() , __FILE__, __LINE__, __METHOD__, 10);
-		if ( TTi18n::getLocaleCookie() != '' AND $current_user_prefs->getLanguage() !== TTi18n::getLanguageFromLocale( TTi18n::getLocaleCookie() ) ) {
+		if ( $current_user_prefs->isNew() == FALSE AND TTi18n::getLocaleCookie() != '' AND $current_user_prefs->getLanguage() !== TTi18n::getLanguageFromLocale( TTi18n::getLocaleCookie() ) ) {
 			Debug::text('Changing User Preference Language to match cookie...', __FILE__, __LINE__, __METHOD__, 10);
 			$current_user_prefs->setLanguage( TTi18n::getLanguageFromLocale( TTi18n::getLocaleCookie() ) );
 			if ( $current_user_prefs->isValid() ) {
@@ -243,6 +243,10 @@ if ( isset($system_settings['system_version']) AND DEPLOYMENT_ON_DEMAND == FALSE
 	$smarty->assign('VERSION_MISMATCH', TRUE );
 }
 
+if ( isset($system_settings['tax_data_version']) AND (time()-strtotime($system_settings['tax_data_version'])) > (86400*475) ) { //~1yr and 3mths
+	$smarty->assign('VERSION_OUT_OF_DATE', TRUE );
+}
+
 if ( isset($system_settings) ) {
 	$smarty->assign_by_ref('system_settings', $system_settings );
 }
