@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: global.inc.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4845 $
+ * $Id: global.inc.php 4845 2011-06-21 16:23:18Z ipso $
+ * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
  */
 $global_script_start_time = microtime(true);
 
@@ -56,7 +56,7 @@ ini_set( 'max_execution_time', 1800 );
 //Check: http://ca3.php.net/manual/en/security.magicquotes.php#61188 for disabling magic_quotes_gpc
 ini_set( 'magic_quotes_runtime', 0 );
 
-define('APPLICATION_VERSION', '3.3.1' );
+define('APPLICATION_VERSION', '3.5.1' );
 
 /*
 	Config file inside webroot.
@@ -194,12 +194,19 @@ function __autoload( $name ) {
 	if ( isset($global_class_map[$name]) ) {
 		$file_name = Environment::getBasePath() . DIRECTORY_SEPARATOR .'classes'. DIRECTORY_SEPARATOR .'modules'. DIRECTORY_SEPARATOR . $global_class_map[$name];
 	} else {
-		$file_name = $name .'.class.php';
+		//If the class name contains "plugin", try to load classes directly from the plugins directory.
+		if ( strpos( $name, 'Plugin') === FALSE ) {
+			$file_name = $name .'.class.php';
+		} else {
+			$file_name = Environment::getBasePath() . DIRECTORY_SEPARATOR .'classes'. DIRECTORY_SEPARATOR .'modules'. DIRECTORY_SEPARATOR . 'plugins'  . DIRECTORY_SEPARATOR . str_replace('Plugin', '', $name ) .'.plugin.php';
+		}
 	}
 
 	//Use include_once() instead of require_once so the installer
 	//doesn't Fatal Error without displaying anything.
 	//include_once() is redundant in __autoload.
+	//Debug::Text('Autoloading Class: '. $name .' File: '. $file_name, __FILE__, __LINE__, __METHOD__,10);
+	//Debug::Arr(Debug::BackTrace(), 'Backtrace: ', __FILE__, __LINE__, __METHOD__,10);
 	@include( $file_name );
 
 	if ( isset($profiler) ) {
@@ -209,6 +216,51 @@ function __autoload( $name ) {
 	return TRUE;
 }
 
+//The basis for the plugin system, instantiate all classes through this, allowing the class to be overloaded on the fly by a class in the plugin directory.
+//ie: $uf = TTNew( 'UserFactory' ); OR $uf = TTNew( 'UserFactory', $arg1, $arg2, $arg3 );
+function TTnew( $class_name ) { //Unlimited arguments are supported.
+    global $config_vars;
+
+    //Check if the plugin system is enabled in the config.
+    if ( isset($config_vars['other']['enable_plugins']) AND $config_vars['other']['enable_plugins'] == 1 ) {
+        $plugin_class_name = $class_name.'Plugin';
+
+		//This improves performance greatly for classes with no plugins.
+		//But it may cause problems if the original class was somehow loaded before the plugin.
+		//However the plugin wouldn't apply to it anyways in that case.
+		//
+		//Due to a bug that would cause the plugin to not be properly loaded if both the Factory and ListFactory were loaded in the same script
+		//we need to always reload the plugin class if the current class relates to it.
+		$is_class_exists = class_exists( $class_name, FALSE );
+		if ( $is_class_exists == FALSE OR ( $is_class_exists == TRUE AND stripos( $plugin_class_name, $class_name ) !== FALSE ) ) {
+			if ( class_exists( $plugin_class_name, FALSE ) == FALSE ) {
+				//Class file needs to be loaded.
+				$plugin_directory = Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR .'modules'. DIRECTORY_SEPARATOR .'plugins';
+				$plugin_class_file_name = $plugin_directory . DIRECTORY_SEPARATOR . $class_name .'.plugin.php';
+				//Debug::Text('Plugin System enabled! Looking for class: '. $class_name .' in file: '. $plugin_class_file_name, __FILE__, __LINE__, __METHOD__,10);
+				if ( file_exists( $plugin_class_file_name ) ) {
+					@include_once( $plugin_class_file_name );
+					$class_name = $plugin_class_name;
+					Debug::Text('Found Plugin: '. $plugin_class_file_name .' Class: '. $class_name, __FILE__, __LINE__, __METHOD__,10);
+				}
+			} else {
+				//Class file is already loaded.
+				$class_name = $plugin_class_name;
+			}
+		}
+    }
+
+    if ( func_num_args() > 1 ) {
+        $params = func_get_args();
+        array_shift( $params ); //Eliminate the class name argument.
+
+		$reflection_class = new ReflectionClass($class_name);
+		return $reflection_class->newInstanceArgs($params);
+    } else {
+		return new $class_name();
+    }
+}
+
 //Function to force browsers to cache certain files.
 function forceCacheHeaders( $file_name = NULL, $mtime = NULL, $etag = NULL ) {
 	if ( $file_name == '' ) {
@@ -290,6 +342,7 @@ set_include_path(
 					'.' . PATH_SEPARATOR .
 					Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'modules'. DIRECTORY_SEPARATOR . 'core' .
 					PATH_SEPARATOR . Environment::getBasePath() .'classes' .
+					PATH_SEPARATOR . Environment::getBasePath() .'classes' . DIRECTORY_SEPARATOR .'plugins' .
 					//PATH_SEPARATOR . get_include_path() . //Don't include system include path, as it can cause conflicts with other packages bundled with TimeTrex. However the bundled PEAR.php must check for class_exists('PEAR') to prevent conflicts with PHPUnit.
 					PATH_SEPARATOR . Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR . 'pear' ); //Put PEAR path at the end so system installed PEAR is used first, this prevents require_once() from including PEAR from two directories, which causes a fatal error.
 
