@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2490 $
- * $Id: EditBranch.php 2490 2009-04-24 22:13:40Z ipso $
- * $Date: 2009-04-24 15:13:40 -0700 (Fri, 24 Apr 2009) $
+ * $Revision: 4104 $
+ * $Id: EditBranch.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -58,7 +58,7 @@ extract	(FormVariables::GetVariables(
 												'branch_data'
 												) ) );
 
-$bf = new BranchFactory();
+$bf = TTnew( 'BranchFactory' );
 
 $action = Misc::findSubmitButton();
 $action = strtolower($action);
@@ -104,7 +104,7 @@ switch ($action) {
 		if ( isset($id) ) {
 			BreadCrumb::setCrumb($title);
 
-			$blf = new BranchListFactory();
+			$blf = TTnew( 'BranchListFactory' );
 
 			$blf->GetByIdAndCompanyId($id, $current_company->getId() );
 
@@ -143,7 +143,7 @@ switch ($action) {
 		//Select box options;
 		$branch_data['status_options'] = $bf->getOptions('status');
 
-		$cf = new CompanyFactory();
+		$cf = TTnew( 'CompanyFactory' );
 		$branch_data['country_options'] = $cf->getOptions('country');
 		$branch_data['province_options'] = $cf->getOptions('province', $branch_data['country'] );
 
