@@ -60,7 +60,7 @@ extract	(FormVariables::GetVariables(
 												'group_data'
 												) ) );
 
-$wgf = new WageGroupFactory();
+$wgf = TTnew( 'WageGroupFactory' );
 
 $action = Misc::findSubmitButton();
 switch ($action) {
@@ -82,7 +82,7 @@ switch ($action) {
 		if ( isset($id) ) {
 			BreadCrumb::setCrumb($title);
 
-			$wglf = new WageGroupListFactory();
+			$wglf = TTnew( 'WageGroupListFactory' );
 
 			$wglf->GetByIdAndCompanyId($id, $current_company->getId() );
 
