@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2740 $
- * $Id: CurrencyList.php 2740 2009-08-19 20:21:50Z ipso $
- * $Date: 2009-08-19 13:21:50 -0700 (Wed, 19 Aug 2009) $
+ * $Revision: 4104 $
+ * $Id: CurrencyList.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -93,7 +93,7 @@ switch ($action) {
 			$delete = FALSE;
 		}
 
-		$clf = new CurrencyListFactory();
+		$clf = TTnew( 'CurrencyListFactory' );
 
 		if ( isset($ids) AND is_array($ids) ) {
 			foreach ($ids as $id) {
@@ -113,7 +113,7 @@ switch ($action) {
 
 	default:
 		BreadCrumb::setCrumb($title);
-		$clf = new CurrencyListFactory();
+		$clf = TTnew( 'CurrencyListFactory' );
 
 		$clf->getByCompanyId($current_company->getId(), $current_user_prefs->getItemsPerPage(),$page, NULL, $sort_array );
 
