@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 1246 $
- * $Id: EditCurrency.php 1246 2007-09-14 23:47:42Z ipso $
- * $Date: 2007-09-14 16:47:42 -0700 (Fri, 14 Sep 2007) $
+ * $Revision: 4104 $
+ * $Id: EditCurrency.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -59,7 +59,7 @@ extract	(FormVariables::GetVariables(
 												'data_saved',
 												) ) );
 
-$cf = new CurrencyFactory();
+$cf = TTnew( 'CurrencyFactory' );
 $action = Misc::findSubmitButton();
 $action = strtolower($action);
 switch ($action) {
@@ -106,7 +106,7 @@ switch ($action) {
 		if ( isset($id) ) {
 			BreadCrumb::setCrumb($title);
 
-			$clf = new CurrencyListFactory();
+			$clf = TTnew( 'CurrencyListFactory' );
 
 			$clf->getByIdAndCompanyId($id, $current_company->getId() );
 
