@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2108 $
- * $Id: DepartmentList.php 2108 2008-09-04 16:37:29Z ipso $
- * $Date: 2008-09-04 09:37:29 -0700 (Thu, 04 Sep 2008) $
+ * $Revision: 4104 $
+ * $Id: DepartmentList.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -83,7 +83,7 @@ switch ($action) {
 			$delete = FALSE;
 		}
 
-		$dlf = new DepartmentListFactory();
+		$dlf = TTnew( 'DepartmentListFactory' );
 
 		foreach ($ids as $id) {
 			$dlf->GetByIdAndCompanyId($id, $current_company->getId() );
@@ -103,7 +103,7 @@ switch ($action) {
 			$sort_array = array(Misc::trimSortPrefix($sort_column) => $sort_order);
 		}
 
-		$dlf = new DepartmentListFactory();
+		$dlf = TTnew( 'DepartmentListFactory' );
 		$dlf->GetByCompanyId($current_company->getId(), $current_user_prefs->getItemsPerPage(), $page, NULL, $sort_array );
 
 		$pager = new Pager($dlf);
