@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 1246 $
- * $Id: EditDepartmentBranchUser.php 1246 2007-09-14 23:47:42Z ipso $
- * $Date: 2007-09-14 16:47:42 -0700 (Fri, 14 Sep 2007) $
+ * $Revision: 4104 $
+ * $Id: EditDepartmentBranchUser.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -61,7 +61,7 @@ extract	(FormVariables::GetVariables(
 
 												) ) );
 
-$dbuf = new DepartmentBranchUserFactory();
+$dbuf = TTnew( 'DepartmentBranchUserFactory' );
 
 $action = Misc::findSubmitButton();
 switch ($action) {
@@ -71,10 +71,10 @@ switch ($action) {
 		Debug::Text('Department ID: '. $department_data['id'] , __FILE__, __LINE__, __METHOD__,10);
 
 
-		$dbulf = new DepartmentBranchUserListFactory();
+		$dbulf = TTnew( 'DepartmentBranchUserListFactory' );
 
 		//Delete all mappings first?
-		$dblf = new DepartmentBranchListFactory();
+		$dblf = TTnew( 'DepartmentBranchListFactory' );
 		$dblf->getByDepartmentId( $department_data['id'] );
 
 		foreach ($dblf as $department_branch) {
@@ -86,7 +86,7 @@ switch ($action) {
 			}
 		}
 
-		$dbulf = new DepartmentBranchUserListFactory();
+		$dbulf = TTnew( 'DepartmentBranchUserListFactory' );
 
 		if ( isset($department_data['branch_data']) AND is_array($department_data['branch_data']) ) {
 			foreach($department_data['branch_data'] as $branch_id => $user_ids) {
@@ -121,7 +121,7 @@ switch ($action) {
 	default:
 		BreadCrumb::setCrumb($title);
 
-		$dlf = new DepartmentListFactory();
+		$dlf = TTnew( 'DepartmentListFactory' );
 
 		$dlf->GetByIdAndCompanyId($id, $current_company->getId() );
 
@@ -130,7 +130,7 @@ switch ($action) {
 
 			$branch_data = array();
 
-			$dblf = new DepartmentBranchListFactory();
+			$dblf = TTnew( 'DepartmentBranchListFactory' );
 			$dblf->getByDepartmentId( $department->getId() );
 			foreach($dblf as $department_branch) {
 				$branch_id = $department_branch->getBranch();
@@ -138,7 +138,7 @@ switch ($action) {
 
 				if ( isset($id) ) {
 					//Get User ID's from database.
-					$dbulf = new DepartmentBranchUserListFactory();
+					$dbulf = TTnew( 'DepartmentBranchUserListFactory' );
 					$dbulf->getByDepartmentBranchId( $department_branch->getId() );
 
 					$department_branch_user_ids = array();
@@ -151,7 +151,7 @@ switch ($action) {
 					$department_branch_user_ids = $department_data['branch_data'][$branch_id];
 				}
 
-				$blf = new BranchListFactory();
+				$blf = TTnew( 'BranchListFactory' );
 				$blf->getById( $branch_id );
 				$branch = $blf->getIterator()->current();
 				$branch_data[$branch_id] = array(
