@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3384 $
- * $Id: global.js.php 3384 2010-03-03 19:47:53Z ipso $
- * $Date: 2010-03-03 11:47:53 -0800 (Wed, 03 Mar 2010) $
+ * $Revision: 4845 $
+ * $Id: global.js.php 4845 2011-06-21 16:23:18Z ipso $
+ * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
  */
 $disable_cache_control = TRUE;
 require_once('..'. DIRECTORY_SEPARATOR .'includes'. DIRECTORY_SEPARATOR.'global.inc.php');
@@ -53,7 +53,7 @@ require_once('..'. DIRECTORY_SEPARATOR .'includes'. DIRECTORY_SEPARATOR.'Interfa
 //So this file is updated each time they login.
 forceCacheHeaders( NULL, $authentication->getCreatedDate() );
 
-$pplf = new PayPeriodListFactory();
+$pplf = TTnew( 'PayPeriodListFactory' );
 $js_calendar_pay_period_dates = $pplf->getJSCalendarPayPeriodArray()
 ?>
 var TTProductEdition = <?php if ( isset($current_company) AND is_object($current_company) AND getTTProductEdition() >= $current_company->getProductEdition() ) { echo (int)$current_company->getProductEdition(); } else { echo (int)getTTProductEdition(); } ?>;
@@ -151,8 +151,9 @@ function isArray(obj) {
 function MoneyFormat( val ) {
 	if ( isNaN(val) == false ) {
 		//Floats are PITA, need to round to 4 decimal places, then to two to keep things consistent with PHP.
-		retval = Math.round( (Math.round( parseFloat( val )*10000)/10000)*100 )/100;
-		return retval.toFixed(2);
+		//PHP rounds 77.69500000000001 to 77.70, JS needs to do the same.
+		retval = Math.round( val * Math.pow(10, 2) ) / Math.pow(10, 2);
+		return parseFloat( retval ).toFixed(2);
 	}
 
 	return '';
@@ -514,7 +515,7 @@ function keyhandler(e) {
     }
 
     if ( code == 94 || code == 126 ) { //^ = 94 ~ == 126
-        //Start looking for barcode
+        //Start looking for barcode. This can cause problems if the user is entering text in a text input that contains a "~", especially confusing for password fields.
         //alert('Barcode Enabled: '+ code);
         enable_barcode = true;
 
