@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 1246 $
- * $Id: EditHelp.php 1246 2007-09-14 23:47:42Z ipso $
- * $Date: 2007-09-14 16:47:42 -0700 (Fri, 14 Sep 2007) $
+ * $Revision: 4104 $
+ * $Id: EditHelp.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -60,7 +60,7 @@ extract	(FormVariables::GetVariables(
 												'help_data'
 												) ) );
 
-$hf = new HelpFactory();
+$hf = TTnew( 'HelpFactory' );
 		
 switch ($action) {
 	case 'submit':
@@ -92,7 +92,7 @@ switch ($action) {
 		if ( isset($id) ) {
 			BreadCrumb::setCrumb($title);
 			
-			$hlf = new HelpListFactory();
+			$hlf = TTnew( 'HelpListFactory' );
 			
 			$hlf->getById($id);
 			
