@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 1246 $
- * $Id: EditHelpGroupControl.php 1246 2007-09-14 23:47:42Z ipso $
- * $Date: 2007-09-14 16:47:42 -0700 (Fri, 14 Sep 2007) $
+ * $Revision: 4104 $
+ * $Id: EditHelpGroupControl.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -62,7 +62,7 @@ extract	(FormVariables::GetVariables(
 												'name'
 												) ) );
 
-$hgcf = new HelpGroupControlFactory();
+$hgcf = TTnew( 'HelpGroupControlFactory' );
 
 switch ($action) {
 	case 'submit':
@@ -81,7 +81,7 @@ switch ($action) {
 		}
 
 	default:
-		$hgclf = new HelpGroupControlListFactory();
+		$hgclf = TTnew( 'HelpGroupControlListFactory' );
 
 		if ( isset($script) AND !isset($id) ) {
 			Debug::Text('Script and Name were passed, attempt lookup!', __FILE__, __LINE__, __METHOD__,10);
