@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 1691 $
- * $Id: EditHierarchy.php 1691 2008-01-24 22:33:21Z ipso $
- * $Date: 2008-01-24 14:33:21 -0800 (Thu, 24 Jan 2008) $
+ * $Revision: 4104 $
+ * $Id: EditHierarchy.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -67,7 +67,7 @@ extract	(FormVariables::GetVariables(
 $ft = new FastTree($fast_tree_options);
 $ft->setTree( $hierarchy_id );
 
-$hf = new HierarchyFactory();
+$hf = TTnew( 'HierarchyFactory' );
 
 $redirect=0;
 
@@ -120,7 +120,7 @@ switch ($action) {
 			$user_data['user_id'] = $id;
 		}
 
-		$hlf = new HierarchyListFactory();
+		$hlf = TTnew( 'HierarchyListFactory' );
 
 		//$nodes = $hlf->FormatArray( $hlf->getByHierarchyControlId( $hierarchy_id ), 'TEXT', TRUE);
 		//$nodes = FastTree::FormatArray( $hlf->getByHierarchyControlId( $hierarchy_id ), 'TEXT', TRUE);
@@ -131,7 +131,7 @@ switch ($action) {
 		}
 
 		//Get include employee list.
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$ulf->getByCompanyId( $current_company->getId() );
 		$raw_user_options = $ulf->getArrayByListFactory( $ulf, FALSE, TRUE );
 		//$raw_user_list_options = UserListFactory::getByCompanyIdArray( $current_company->getId() );
