@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3403 $
- * $Id: HierarchyList.php 3403 2010-03-10 23:15:10Z ipso $
- * $Date: 2010-03-10 15:15:10 -0800 (Wed, 10 Mar 2010) $
+ * $Revision: 4104 $
+ * $Id: HierarchyList.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 //$_COOKIE['SessionID'] = '07bc520b3e90835ab586f0c585c4dd8f';
 //$_SERVER['REMOTE_ADDR'] = '192.168.1.100';
@@ -80,7 +80,7 @@ switch ($action) {
 		foreach ($ids as $id) {
 			Debug::Text(' Deleting ID: '. $id , __FILE__, __LINE__, __METHOD__,10);
 
-	        $hf = new HierarchyListFactory();
+	        $hf = TTnew( 'HierarchyListFactory' );
 			$hf->setUser( $id );
 			$hf->setHierarchyControl( $hierarchy_id );
 			$hf->Delete();
@@ -99,7 +99,7 @@ switch ($action) {
 	default:
 		BreadCrumb::setCrumb($title);
 
-		$hlf = new HierarchyListFactory();
+		$hlf = TTnew( 'HierarchyListFactory' );
 		//$nodes = $hlf->FormatArray( $hlf->getByHierarchyControlId( $hierarchy_id ), 'HTML' );
 		//$nodes = FastTree::FormatArray( $hlf->getByHierarchyControlId( $hierarchy_id ), 'HTML' );
 		$nodes = FastTree::FormatArray( $hlf->getByCompanyIdAndHierarchyControlId( $current_company->getId(), $hierarchy_id ), 'HTML' );
