@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3508 $
- * $Id: index.php 3508 2010-04-19 19:46:03Z ipso $
- * $Date: 2010-04-19 12:46:03 -0700 (Mon, 19 Apr 2010) $
+ * $Revision: 4845 $
+ * $Id: index.php 4845 2011-06-21 16:23:18Z ipso $
+ * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
  */
 require_once('../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -64,7 +64,7 @@ extract	(FormVariables::GetVariables(
 //Grab total number of exceptions for each severity level
 $exceptions = array();
 
-$elf = new ExceptionListFactory();
+$elf = TTnew( 'ExceptionListFactory' );
 $elf->getFlaggedExceptionsByUserIdAndPayPeriodStatus( $current_user->getId(), 10 );
 if ( $elf->getRecordCount() > 0 ) {
 	foreach($elf as $e_obj) {
@@ -76,7 +76,7 @@ $smarty->assign_by_ref('exceptions', $exceptions);
 
 
 //Grab list of recent requests
-$rlf = new RequestListFactory();
+$rlf = TTnew( 'RequestListFactory' );
 $rlf->getByUserIDAndCompanyId( $current_user->getId(), $current_company->getId(), 5, 1 );
 if ($rlf->getRecordCount() > 0 ) {
 	$status_options = $rlf->getOptions('status');
@@ -99,7 +99,7 @@ if ($rlf->getRecordCount() > 0 ) {
 $smarty->assign_by_ref('requests', $requests);
 
 //Grab list of unread messages
-$mclf = new MessageControlListFactory();
+$mclf = TTnew( 'MessageControlListFactory' );
 $mclf->getByCompanyIdAndUserIdAndFolder( $current_user->getCompany(), $current_user->getId(), 10, 5, 1 );
 if ( $mclf->getRecordCount() > 0 ) {
 	$object_name_options = $mclf->getOptions('object_name');
@@ -136,8 +136,8 @@ if ( $permission->Check('authorization','enabled')
 		AND $permission->Check('authorization','view')
 		AND $permission->Check('request','authorize') ) {
 
-	$hllf = new HierarchyLevelListFactory();
-	$request_levels = $hllf->getLevelsAndHierarchyControlIDsByUserIdAndObjectTypeID( $current_user->getId(), 50 );
+	$hllf = TTnew( 'HierarchyLevelListFactory' );
+	$request_levels = $hllf->getLevelsAndHierarchyControlIDsByUserIdAndObjectTypeID( $current_user->getId(), array(1010,1020,1030,1040,1100) );
 
 	$selected_levels['request'] = 1;
 	if ( isset($selected_levels['request']) AND isset($request_levels[$selected_levels['request']]) ) {
@@ -151,7 +151,7 @@ if ( $permission->Check('authorization','enabled')
 	}
 
 	if ( is_array($request_selected_level) ) {
-		$rlf = new RequestListFactory();
+		$rlf = TTnew( 'RequestListFactory' );
 		$rlf->getByHierarchyLevelMapAndStatusAndNotAuthorized($request_selected_level, 30);
 
 		$status_options = $rlf->getOptions('status');
