@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 1246 $
- * $Id: MaintenanceJobs.php 1246 2007-09-14 23:47:42Z ipso $
- * $Date: 2007-09-14 16:47:42 -0700 (Fri, 14 Sep 2007) $
+ * $Revision: 4104 $
+ * $Id: MaintenanceJobs.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 
@@ -60,7 +60,7 @@ if ( $install_obj->isInstallMode() == FALSE ) {
 	Redirect::Page( URLBuilder::getURL(NULL, 'install.php') );
 }
 
-$uf = new UserFactory();
+$uf = TTnew( 'UserFactory' );
 
 $action = Misc::findSubmitButton();
 switch ($action) {
