@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2997 $
- * $Id: Requirements.php 2997 2009-11-09 19:34:42Z ipso $
- * $Date: 2009-11-09 11:34:42 -0800 (Mon, 09 Nov 2009) $
+ * $Revision: 4296 $
+ * $Id: Requirements.php 4296 2011-02-24 23:14:33Z ipso $
+ * $Date: 2011-02-24 15:14:33 -0800 (Thu, 24 Feb 2011) $
  */
 @ini_set('display_errors', true);
 
@@ -58,12 +58,8 @@ extract	(FormVariables::GetVariables(
 												'external_installer',
 												) ) );
 
-if ( DEPLOYMENT_ON_DEMAND == FALSE ) {
-	$cache->clean(); //Clear all cache.
-}
-$smarty->clear_all_cache();
-
 $install_obj = new Install();
+$install_obj->cleanCacheDirectory();
 if ( $install_obj->isInstallMode() == FALSE ) {
 	Redirect::Page( URLBuilder::getURL(NULL, 'install.php') );
 }
