@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 1851 $
- * $Id: SystemSettings.php 1851 2008-05-08 23:04:49Z ipso $
- * $Date: 2008-05-08 16:04:49 -0700 (Thu, 08 May 2008) $
+ * $Revision: 4104 $
+ * $Id: SystemSettings.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 
@@ -78,12 +78,12 @@ switch ($action) {
 		$install_obj->writeConfigFile( $data );
 
 		//Write auto_update feature to system settings.
-		$sslf = new SystemSettingListFactory();
+		$sslf = TTnew( 'SystemSettingListFactory' );
 		$sslf->getByName('update_notify');
 		if ( $sslf->getRecordCount() == 1 ) {
 			$obj = $sslf->getCurrent();
 		} else {
-			$obj = new SystemSettingListFactory();
+			$obj = TTnew( 'SystemSettingListFactory' );
 		}
 
 		$obj->setName( 'update_notify' );
@@ -99,12 +99,12 @@ switch ($action) {
 		}
 
 		//Write anonymous_auto_update feature to system settings.
-		$sslf = new SystemSettingListFactory();
+		$sslf = TTnew( 'SystemSettingListFactory' );
 		$sslf->getByName('anonymous_update_notify');
 		if ( $sslf->getRecordCount() == 1 ) {
 			$obj = $sslf->getCurrent();
 		} else {
-			$obj = new SystemSettingListFactory();
+			$obj = TTnew( 'SystemSettingListFactory' );
 		}
 
 		$obj->setName( 'anonymous_update_notify' );
