@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3507 $
- * $Id: EditMessage.php 3507 2010-04-19 19:44:53Z ipso $
- * $Date: 2010-04-19 12:44:53 -0700 (Mon, 19 Apr 2010) $
+ * $Revision: 4206 $
+ * $Id: EditMessage.php 4206 2011-02-02 00:53:35Z ipso $
+ * $Date: 2011-02-01 16:53:35 -0800 (Tue, 01 Feb 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -62,9 +62,9 @@ extract	(FormVariables::GetVariables(
 												'data',
 												) ) );
 
-$mcf = new MessageControlFactory();
-$mrf = new MessageRecipientFactory();
-$msf = new MessageSenderFactory();
+$mcf = TTnew( 'MessageControlFactory' );
+$mrf = TTnew( 'MessageRecipientFactory' );
+$msf = TTnew( 'MessageSenderFactory' );
 
 $action = Misc::findSubmitButton();
 switch ($action) {
@@ -77,7 +77,7 @@ switch ($action) {
 		if ( is_array($filter_user_id) AND count($filter_user_id) > 0 AND ( isset($filter_user_id[0]) AND $filter_user_id[0] != 0 ) ) {
 			$mcf->StartTransaction();
 
-			$mcf = new MessageControlFactory();
+			$mcf = TTnew( 'MessageControlFactory' );
 			$mcf->setFromUserId( $current_user->getId() );
 			$mcf->setToUserId( $filter_user_id );
 			$mcf->setObjectType( 5 );
@@ -106,23 +106,23 @@ switch ($action) {
 			$filter_user_options = Misc::arrayIntersectByKey( (array)$filter_user_id, $user_options );
 		} else {
 			//Only allow sending to supervisors OR children.
-			$hlf = new HierarchyListFactory();
+			$hlf = TTnew( 'HierarchyListFactory' );
 
 			//FIXME: For supervisors, we may need to include supervisors at the same level
 			// Also how to handle cases where there are no To: recipients to select from.
 
 			//Get Parents
-			$request_parent_level_user_ids = $hlf->getHierarchyParentByCompanyIdAndUserIdAndObjectTypeID($current_company->getId(), $current_user->getId(), 50, FALSE, FALSE );
+			$request_parent_level_user_ids = $hlf->getHierarchyParentByCompanyIdAndUserIdAndObjectTypeID($current_company->getId(), $current_user->getId(), array(1010,1020,1030,1040,1100), FALSE, FALSE );
 			//Debug::Arr( $request_parent_level_user_ids, 'Request Parent Level Ids', __FILE__, __LINE__, __METHOD__,10);
 
 			//Get Children, in case the current user is a superior.
-			$request_child_level_user_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId(), 50);
+			$request_child_level_user_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId(), array(1010,1020,1030,1040,1100) );
 			//Debug::Arr( $request_child_level_user_ids, 'Request Child Level Ids', __FILE__, __LINE__, __METHOD__,10);
 
 			$request_user_ids = array_merge( (array)$request_parent_level_user_ids, (array)$request_child_level_user_ids );
 			//Debug::Arr( $request_user_ids, 'User Ids', __FILE__, __LINE__, __METHOD__,10);
 
-			$ulf = new UserListFactory();
+			$ulf = TTnew( 'UserListFactory' );
 			$ulf->getByIdAndCompanyId( $request_user_ids, $current_user->getCompany() );
 			$user_options = UserListFactory::getArrayByListFactory( $ulf, TRUE, FALSE);
 
