@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3550 $
- * $Id: EmbeddedMessageList.php 3550 2010-05-06 00:39:46Z ipso $
- * $Date: 2010-05-05 17:39:46 -0700 (Wed, 05 May 2010) $
+ * $Revision: 4335 $
+ * $Id: EmbeddedMessageList.php 4335 2011-03-05 00:33:51Z ipso $
+ * $Date: 2011-03-04 16:33:51 -0800 (Fri, 04 Mar 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -62,13 +62,14 @@ extract	(FormVariables::GetVariables(
 												'sort_order',
 												'object_type_id',
 												'object_id',
+												'object_user_id',
 												'parent_id',
 												'message_data',
 												'template',
 												'close'
 												) ) );
 
-$mcf = new MessageControlFactory();
+$mcf = TTnew( 'MessageControlFactory' );
 
 $action = Misc::findSubmitButton();
 switch ($action) {
@@ -88,7 +89,7 @@ switch ($action) {
 
 			$mcf->StartTransaction();
 
-			$mcf = new MessageControlFactory();
+			$mcf = TTnew( 'MessageControlFactory' );
 
 			$mcf->setObjectType( $object_type_id );
 			$mcf->setObject( $object_id );
@@ -98,8 +99,11 @@ switch ($action) {
 
 			//This needs to reply to all those involved in the object thread. As when the object (request) creator
 			//responds, we don't know who exactly they are responding to? Or should it be the last message sender only?
-			$mclf = new MessageControlListFactory();
+			$mclf = TTnew( 'MessageControlListFactory' );
 			$to_user_ids = $mclf->getByCompanyIdAndObjectTypeAndObjectAndNotUser( $current_user->getCompany(), $object_type_id, $object_id, $current_user->getId() );
+			if ( isset($object_user_id) AND $object_user_id > 0) {
+				$to_user_ids[] = $object_user_id;
+			}
 			$mcf->setToUserId( $to_user_ids );
 
 			$mcf->setSubject( $message_data['subject'] );
@@ -122,14 +126,14 @@ switch ($action) {
 		}
 	default:
 		if ( isset($object_type_id) AND isset($object_id) ) {
-			$mclf = new MessageControlListFactory();
+			$mclf = TTnew( 'MessageControlListFactory' );
 			$mclf->getByCompanyIDAndUserIdAndObjectTypeAndObject( $current_user->getCompany(), $current_user->getId(), $object_type_id, $object_id );
 
 			if ( $mclf->getRecordCount() > 0 ) {
 				$mark_read_message_ids = array();
 				$i=0;
 				foreach( $mclf as $message ) {
-					$ulf = new UserListFactory();
+					$ulf = TTnew( 'UserListFactory' );
 
 					$from_user_id = $message->getColumn('from_user_id');
 					$from_user_full_name = Misc::getFullName( $message->getColumn('from_first_name'), $message->getColumn('from_middle_name'), $message->getColumn('from_last_name') );
@@ -181,6 +185,7 @@ switch ($action) {
 			$smarty->assign_by_ref('parent_id', $parent_id);
 			$smarty->assign_by_ref('object_type_id', $object_type_id);
 			$smarty->assign_by_ref('object_id', $object_id);
+			$smarty->assign_by_ref('object_user_id', $object_user_id);
 		}
 
 		$smarty->assign_by_ref('template', $template);
