@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3507 $
- * $Id: UserMessageList.php 3507 2010-04-19 19:44:53Z ipso $
- * $Date: 2010-04-19 12:44:53 -0700 (Mon, 19 Apr 2010) $
+ * $Revision: 4104 $
+ * $Id: UserMessageList.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -69,7 +69,7 @@ if ( $sort_column != '' ) {
 	$sort_array = array($sort_column => $sort_order);
 }
 
-$mcf = new MessageFactory();
+$mcf = TTnew( 'MessageFactory' );
 
 $action = Misc::findSubmitButton();
 switch ($action) {
@@ -89,14 +89,14 @@ switch ($action) {
 
 			Debug::text('Filter Folder ID: '. $filter_folder_id, __FILE__, __LINE__, __METHOD__,9);
 			if ( $filter_folder_id == 10 ) { //Inbox
-				$mrlf = new MessageRecipientListFactory();
+				$mrlf = TTnew( 'MessageRecipientListFactory' );
 				$mrlf->getByCompanyIdAndUserIdAndMessageSenderId( $current_company->getId(), $current_user->getId(), $ids );
 				foreach ($mrlf as $m_obj) {
 					$m_obj->setDeleted($delete);
 					$m_obj->Save();
 				}
 			} else { //Sent
-				$mslf = new MessageSenderListFactory();
+				$mslf = TTnew( 'MessageSenderListFactory' );
 				$mslf->getByCompanyIdAndUserIdAndId( $current_company->getId(), $current_user->getId(), $ids );
 				foreach ($mslf as $m_obj) {
 					$m_obj->setDeleted($delete);
@@ -112,7 +112,7 @@ switch ($action) {
 
 		break;
 	default:
-		$mclf = new MessageControlListFactory();
+		$mclf = TTnew( 'MessageControlListFactory' );
 
 		$folder_options = $mclf->getOptions('folder');
 
