@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3507 $
- * $Id: ViewMessage.php 3507 2010-04-19 19:44:53Z ipso $
- * $Date: 2010-04-19 12:44:53 -0700 (Mon, 19 Apr 2010) $
+ * $Revision: 4104 $
+ * $Id: ViewMessage.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -68,7 +68,7 @@ extract	(FormVariables::GetVariables(
 												'message_data',
 												'ack_message_id',
 												) ) );
-$mcf = new MessageControlFactory();
+$mcf = TTnew( 'MessageControlFactory' );
 
 $action = Misc::findSubmitButton();
 switch ($action) {
@@ -95,7 +95,7 @@ switch ($action) {
 
 			$mcf->StartTransaction();
 
-			$mcf = new MessageControlFactory();
+			$mcf = TTnew( 'MessageControlFactory' );
 			$mcf->setFromUserId( $current_user->getId() );
 
 			//Get sender of the original message, as we only reply directly to them.
@@ -125,14 +125,14 @@ switch ($action) {
 
 			//If a supervisors sends a message to multiple recipients, we always treat it as individual messages,
 			//So we only display a message thread for a single from/to pair.
-			$mclf = new MessageControlListFactory();
+			$mclf = TTnew( 'MessageControlListFactory' );
 			$mclf->getByCompanyIDAndUserIdAndIdAndFolder( $current_user->getCompany(), $current_user->getID(), $id, $filter_folder_id, NULL, NULL, NULL, array( 'a.created_date' => 'asc' ) );
 			if ( $mclf->getRecordCount() > 0 ) {
 				$mark_read_message_ids = array();
 				$i=0;
 				foreach ($mclf as $message) {
 					//Get user info
-					$ulf = new UserListFactory();
+					$ulf = TTnew( 'UserListFactory' );
 
 					$from_user_id = $message->getColumn('from_user_id');
 					$from_user_full_name = Misc::getFullName( $message->getColumn('from_first_name'), $message->getColumn('from_middle_name'), $message->getColumn('from_last_name') );
