@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3764 $
- * $Id: PayStubEntryAccountList.php 3764 2010-08-13 18:07:55Z ipso $
- * $Date: 2010-08-13 11:07:55 -0700 (Fri, 13 Aug 2010) $
+ * $Revision: 4104 $
+ * $Id: PayStubEntryAccountList.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -96,7 +96,7 @@ switch ($action) {
 			$delete = FALSE;
 		}
 
-		$psealf = new PayStubEntryAccountListFactory();
+		$psealf = TTnew( 'PayStubEntryAccountListFactory' );
 
 		foreach ($ids as $id) {
 			$psealf->getByIdAndCompanyId($id, $current_company->getId() );
@@ -114,7 +114,7 @@ switch ($action) {
 	default:
 		BreadCrumb::setCrumb($title);
 
-		$psealf = new PayStubEntryAccountListFactory();
+		$psealf = TTnew( 'PayStubEntryAccountListFactory' );
 		$psealf->getByCompanyId( $current_company->getId() );
 
 		$pager = new Pager($psealf);
