@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3934 $
- * $Id: PayStubList.php 3934 2010-11-17 23:29:44Z ipso $
- * $Date: 2010-11-17 15:29:44 -0800 (Wed, 17 Nov 2010) $
+ * $Revision: 4600 $
+ * $Id: PayStubList.php 4600 2011-04-28 21:35:12Z ipso $
+ * $Date: 2011-04-28 14:35:12 -0700 (Thu, 28 Apr 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -105,12 +105,12 @@ if ( $saved_search_id == '' AND !isset($filter_data['columns']) ) {
 	}
 }
 
-$ugdlf = new UserGenericDataListFactory();
-$ugdf = new UserGenericDataFactory();
-$pplf = new PayPeriodListFactory();
+$ugdlf = TTnew( 'UserGenericDataListFactory' );
+$ugdf = TTnew( 'UserGenericDataFactory' );
+$pplf = TTnew( 'PayPeriodListFactory' );
 
 //Get Permission Hierarchy Children first, as this can be used for viewing, or editing.
-$hlf = new HierarchyListFactory();
+$hlf = TTnew( 'HierarchyListFactory' );
 $permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId() );
 Debug::Arr($permission_children_ids,'Permission Children Ids:', __FILE__, __LINE__, __METHOD__,10);
 
@@ -140,7 +140,7 @@ switch ($action) {
 		}
 
 		if ( count($ids) > 0 ) {
-			$pslf = new PayStubListFactory();
+			$pslf = TTnew( 'PayStubListFactory' );
 			if ( $permission->Check('pay_stub','view_child') ) {
 				$filter_data['permission_children_ids'] = $permission_children_ids;
 			}
@@ -159,7 +159,7 @@ switch ($action) {
 					} else {
 						//Include file creation number in the exported file name, so the user knows what it is without opening the file,
 						//and can generate multiple files if they need to match a specific number.
-						$ugdlf = new UserGenericDataListFactory();
+						$ugdlf = TTnew( 'UserGenericDataListFactory' );
 						$ugdlf->getByCompanyIdAndScriptAndDefault( $current_company->getId(), 'PayStubFactory', TRUE );
 						if ( $ugdlf->getRecordCount() > 0 ) {
 							$ugd_obj = $ugdlf->getCurrent();
@@ -198,7 +198,7 @@ switch ($action) {
 		}
 
 		if ( count($ids) > 0 ) {
-			$pslf = new PayStubListFactory();
+			$pslf = TTnew( 'PayStubListFactory' );
 
 			if ( $permission->Check('pay_stub','view') == FALSE ) {
 				if ( $permission->Check('pay_stub','view_child') ) {
@@ -242,17 +242,21 @@ switch ($action) {
 			exit;
 		}
 
-		$pslf = new PayStubListFactory();
+		$pslf = TTnew( 'PayStubListFactory' );
 
 		if ( is_array( $ids ) AND count($ids) > 0 ) {
 			foreach ($ids as $id) {
 				$pslf->getByCompanyIdAndId($current_company->getId(),$id);
 				foreach ($pslf as $pay_stub_obj) {
 					//Only delete pay stubs in OPEN/Post Adjustment pay periods.
-					if ( is_object($pay_stub_obj->getPayPeriodObject())
-							AND $pay_stub_obj->getPayPeriodObject()->getStatus() != 20 ) { //Closed
+					//Also allow deleting pay stubs attached to a pay period that has been deleted.
+					//Make sure pay stub is NOT marked PAID before deleting.
+					if ( ( $pay_stub_obj->getPayPeriodObject() == FALSE OR ( is_object( $pay_stub_obj->getPayPeriodObject() ) AND $pay_stub_obj->getPayPeriodObject()->getStatus() != 20 ) )
+							AND $pay_stub_obj->getStatus() != 40 ) { //Closed/Paid
 						$pay_stub_obj->setDeleted($delete);
 						$pay_stub_obj->Save();
+					} else {
+						Debug::Text('Not deleting pay stub: '. $pay_stub_obj->getId(), __FILE__, __LINE__, __METHOD__,10);
 					}
 				}
 			}
@@ -270,7 +274,7 @@ switch ($action) {
 			exit;
 		}
 
-		$pslf = new PayStubListFactory();
+		$pslf = TTnew( 'PayStubListFactory' );
 
 		if ( $permission->Check('pay_stub','edit') OR $permission->Check('pay_stub','edit_child') ) {
 			if ( is_array( $ids ) AND count($ids) > 0 ) {
@@ -278,9 +282,7 @@ switch ($action) {
 					$pslf->getById($id);
 					foreach ($pslf as $pay_stub_obj) {
 						//Only delete NEW pay stubs.!
-						//if ( $pay_stub_obj->getStatus() == 10 ) {
-						if ( is_object($pay_stub_obj->getPayPeriodObject())
-								AND $pay_stub_obj->getPayPeriodObject()->getStatus() != 20 //Open/Adjustment
+						if ( ( $pay_stub_obj->getPayPeriodObject() == FALSE OR ( is_object( $pay_stub_obj->getPayPeriodObject() ) AND $pay_stub_obj->getPayPeriodObject()->getStatus() != 20 ) ) //Open/Adjustment
 								AND ( $pay_stub_obj->getStatus() == 10 OR $pay_stub_obj->getStatus() == 25 ) ) {
 							$pay_stub_obj->setStatus( 40 ); //Paid
 							$pay_stub_obj->Save();
@@ -303,7 +305,7 @@ switch ($action) {
 			exit;
 		}
 
-		$pslf = new PayStubListFactory();
+		$pslf = TTnew( 'PayStubListFactory' );
 
 		if ( $permission->Check('pay_stub','edit') OR $permission->Check('pay_stub','edit_child') ) {
 			if ( is_array( $ids ) AND count($ids) > 0 ) {
@@ -311,8 +313,7 @@ switch ($action) {
 					$pslf->getById($id);
 					foreach ($pslf as $pay_stub_obj) {
 						//Only delete pay stubs in OPEN/Post Adjustment pay periods.
-						if ( is_object($pay_stub_obj->getPayPeriodObject())
-								AND $pay_stub_obj->getPayPeriodObject()->getStatus() != 20 //Open/Adjustment
+						if ( ( $pay_stub_obj->getPayPeriodObject() == FALSE OR ( is_object( $pay_stub_obj->getPayPeriodObject() ) AND $pay_stub_obj->getPayPeriodObject()->getStatus() != 20 ) ) //Open/Adjustment
 								AND $pay_stub_obj->getStatus() == 40 ) { //Paid/Closed
 							$pay_stub_obj->setStatus( 25 ); //Open
 							$pay_stub_obj->Save();
@@ -360,8 +361,8 @@ switch ($action) {
 															'saved_search_id' => $saved_search_id,
 															'page' => $page
 														) );
-		$pslf = new PayStubListFactory();
-		$ulf = new UserListFactory();
+		$pslf = TTnew( 'PayStubListFactory' );
+		$ulf = TTnew( 'UserListFactory' );
 
 		if ( $permission->Check('pay_stub','view') == FALSE ) {
 			if ( $permission->Check('pay_stub','view_child') ) {
@@ -372,7 +373,7 @@ switch ($action) {
 			}
 		}
 
-		$pplf = new PayPeriodListFactory();
+		$pplf = TTnew( 'PayPeriodListFactory' );
 		$pplf->getPayPeriodsWithPayStubsByCompanyId( $current_company->getId(), NULL, array('a.start_date' => 'desc') );
 		$pay_period_options = $pplf->getArrayByListFactory( $pplf, FALSE, FALSE );
 		$pay_period_ids = array_keys((array)$pay_period_options);
@@ -390,19 +391,19 @@ switch ($action) {
 
 		$pager = new Pager($pslf);
 
-		$utlf = new UserTitleListFactory();
+		$utlf = TTnew( 'UserTitleListFactory' );
 		$utlf->getByCompanyId( $current_company->getId() );
 		$title_options = $utlf->getArrayByListFactory( $utlf, FALSE, TRUE );
 
-		$blf = new BranchListFactory();
+		$blf = TTnew( 'BranchListFactory' );
 		$blf->getByCompanyId( $current_company->getId() );
 		$branch_options = $blf->getArrayByListFactory( $blf, FALSE, TRUE );
 
-		$dlf = new DepartmentListFactory();
+		$dlf = TTnew( 'DepartmentListFactory' );
 		$dlf->getByCompanyId( $current_company->getId() );
 		$department_options = $dlf->getArrayByListFactory( $dlf, FALSE, TRUE );
 
-		$uglf = new UserGroupListFactory();
+		$uglf = TTnew( 'UserGroupListFactory' );
 		$group_options = $uglf->getArrayByNodes( FastTree::FormatArray( $uglf->getByCompanyIdArray( $current_company->getId() ), 'TEXT', TRUE) );
 
 		foreach ($pslf as $pay_stub) {
@@ -431,7 +432,7 @@ switch ($action) {
 			unset($transaction_date);
 		}
 
-		$export_type_options = $pslf->getOptions('export_type');
+		$export_type_options = Misc::trimSortPrefix( $pslf->getOptions('export_type') );
 
 		$all_array_option = array('-1' => TTi18n::gettext('-- Any --'));
 
