@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 1246 $
- * $Id: EditRecurringPayStubAmendment.php 1246 2007-09-14 23:47:42Z ipso $
- * $Date: 2007-09-14 16:47:42 -0700 (Fri, 14 Sep 2007) $
+ * $Revision: 4104 $
+ * $Id: EditRecurringPayStubAmendment.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -72,14 +72,14 @@ if ( isset($pay_stub_amendment_data) ) {
 
 }
 
-$rpsaf = new RecurringPayStubAmendmentFactory();
+$rpsaf = TTnew( 'RecurringPayStubAmendmentFactory' );
 
 $action = Misc::findSubmitButton();
 $action = strtolower($action);
 switch ($action) {
 	case 'recalculate':
 		//Debug::setVerbosity(11);
-		$rpsalf = new RecurringPayStubAmendmentListFactory();
+		$rpsalf = TTnew( 'RecurringPayStubAmendmentListFactory' );
 		$rpsalf->getById( $pay_stub_amendment_data['id'] );
 		if ( $rpsalf->getRecordCount() > 0 ) {
 			$rpsa_obj = $rpsalf->getCurrent();
@@ -144,7 +144,7 @@ switch ($action) {
 		BreadCrumb::setCrumb($title);
 
 		if ( isset($id) ) {
-			$rpsalf = new RecurringPayStubAmendmentListFactory();
+			$rpsalf = TTnew( 'RecurringPayStubAmendmentListFactory' );
 
 			//$uwlf->GetByUserIdAndCompanyId($current_user->getId(), $current_company->getId() );
 			$rpsalf->GetById($id);
@@ -221,15 +221,15 @@ switch ($action) {
 
 		$pay_stub_amendment_data['type_options'] = $rpsaf->getOptions('type');
 
-		$pseallf = new PayStubEntryAccountLinkListFactory();
+		$pseallf = TTnew( 'PayStubEntryAccountLinkListFactory' );
 		$pseallf->getByCompanyId( $current_company->getId() );
 		if ( $pseallf->getRecordCount() > 0 ) {
 			$net_pay_psea_id = $pseal_obj = $pseallf->getCurrent()->getTotalNetPay();
 		}
 
-		//$psenlf = new PayStubEntryNameListFactory();
+		//$psenlf = TTnew( 'PayStubEntryNameListFactory' );
 
-		$psealf = new PayStubEntryAccountListFactory();
+		$psealf = TTnew( 'PayStubEntryAccountListFactory' );
 		$pay_stub_amendment_data['pay_stub_entry_name_options'] = $psealf->getByCompanyIdAndStatusIdAndTypeIdArray( $current_company->getId(), 10, array(10,20,30,50,60,65) );
 		$pay_stub_amendment_data['percent_amount_entry_name_options'] = $psealf->getByCompanyIdAndStatusIdAndTypeIdArray( $current_company->getId(), 10, array(10,20,30,40,50,60,65) );
 		if ( isset($net_pay_psea_id) ) {
