@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2095 $
- * $Id: PayStubAmendmentList.php 2095 2008-09-01 07:04:25Z ipso $
- * $Date: 2008-09-01 00:04:25 -0700 (Mon, 01 Sep 2008) $
+ * $Revision: 4104 $
+ * $Id: PayStubAmendmentList.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -100,12 +100,12 @@ if ( $saved_search_id == '' AND !isset($filter_data['columns']) ) {
 	}
 }
 
-$ugdlf = new UserGenericDataListFactory();
-$ugdf = new UserGenericDataFactory();
-$pplf = new PayPeriodListFactory();
+$ugdlf = TTnew( 'UserGenericDataListFactory' );
+$ugdf = TTnew( 'UserGenericDataFactory' );
+$pplf = TTnew( 'PayPeriodListFactory' );
 
 //Get Permission Hierarchy Children first, as this can be used for viewing, or editing.
-$hlf = new HierarchyListFactory();
+$hlf = TTnew( 'HierarchyListFactory' );
 $permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId() );
 Debug::Arr($permission_children_ids,'Permission Children Ids:', __FILE__, __LINE__, __METHOD__,10);
 
@@ -133,7 +133,7 @@ switch ($action) {
 			$delete = FALSE;
 		}
 
-		$psalf = new PayStubAmendmentListFactory();
+		$psalf = TTnew( 'PayStubAmendmentListFactory' );
 
 		foreach ($ids as $id) {
 			$psalf->getById( $id );
@@ -183,8 +183,8 @@ switch ($action) {
 															'page' => $page
 														) );
 
-		$ulf = new UserListFactory();
-		$psalf = new PayStubAmendmentListFactory();
+		$ulf = TTnew( 'UserListFactory' );
+		$psalf = TTnew( 'PayStubAmendmentListFactory' );
 
 		if ( $permission->Check('pay_stub_amendment','view') == FALSE ) {
 			if ( $permission->Check('pay_stub_amendment','view_child') ) {
@@ -210,30 +210,30 @@ switch ($action) {
 
 		$pager = new Pager($psalf);
 
-		$psealf = new PayStubEntryAccountListFactory();
+		$psealf = TTnew( 'PayStubEntryAccountListFactory' );
 		$pay_stub_entry_name_options = $psealf->getByCompanyIdAndStatusIdAndTypeIdArray( $current_company->getId(), 10, array(10,20,30,50,60,65) );
 
 		//Get pay periods
 		$pplf->getByCompanyId( $current_company->getId() );
 		$pay_period_options = $pplf->getArrayByListFactory( $pplf, FALSE, TRUE );
 
-		$utlf = new UserTitleListFactory();
+		$utlf = TTnew( 'UserTitleListFactory' );
 		$utlf->getByCompanyId( $current_company->getId() );
 		$title_options = $utlf->getArrayByListFactory( $utlf, FALSE, TRUE );
 
-		$blf = new BranchListFactory();
+		$blf = TTnew( 'BranchListFactory' );
 		$blf->getByCompanyId( $current_company->getId() );
 		$branch_options = $blf->getArrayByListFactory( $blf, FALSE, TRUE );
 
-		$dlf = new DepartmentListFactory();
+		$dlf = TTnew( 'DepartmentListFactory' );
 		$dlf->getByCompanyId( $current_company->getId() );
 		$department_options = $dlf->getArrayByListFactory( $dlf, FALSE, TRUE );
 
-		$rpsalf = new RecurringPayStubAmendmentListFactory();
+		$rpsalf = TTnew( 'RecurringPayStubAmendmentListFactory' );
 		$rpsalf->getByCompanyId( $current_company->getId() );
 		$recurring_ps_amendment_options = $rpsalf->getArrayByListFactory( $rpsalf, FALSE, TRUE );
 
-		$uglf = new UserGroupListFactory();
+		$uglf = TTnew( 'UserGroupListFactory' );
 		$group_options = $uglf->getArrayByNodes( FastTree::FormatArray( $uglf->getByCompanyIdArray( $current_company->getId() ), 'TEXT', TRUE) );
 
 		foreach ($psalf as $psa_obj) {
