@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 1246 $
- * $Id: RecurringPayStubAmendmentList.php 1246 2007-09-14 23:47:42Z ipso $
- * $Date: 2007-09-14 16:47:42 -0700 (Fri, 14 Sep 2007) $
+ * $Revision: 4104 $
+ * $Id: RecurringPayStubAmendmentList.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -91,7 +91,7 @@ switch ($action) {
 			$delete = FALSE;
 		}
 
-		$rpsalf = new RecurringPayStubAmendmentListFactory();
+		$rpsalf = TTnew( 'RecurringPayStubAmendmentListFactory' );
 
 		foreach ($ids as $id) {
 			$rpsalf->getById( $id );
@@ -108,13 +108,13 @@ switch ($action) {
 	default:
 		URLBuilder::setURL(NULL, array('sort_column' => $sort_column, 'sort_order' => $sort_order) );
 
-		$rpsalf = new RecurringPayStubAmendmentListFactory();
+		$rpsalf = TTnew( 'RecurringPayStubAmendmentListFactory' );
 
 		$rpsalf->getByCompanyId($current_company->getId(), $current_user_prefs->getItemsPerPage(), $page, NULL, $sort_array );
 
 		$pager = new Pager($rpsalf);
 
-		$psealf = new PayStubEntryAccountListFactory();
+		$psealf = TTnew( 'PayStubEntryAccountListFactory' );
 
 		foreach ($rpsalf as $recurring_pay_stub_amendment) {
 
