@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3508 $
- * $Id: ClosePayPeriod.php 3508 2010-04-19 19:46:03Z ipso $
- * $Date: 2010-04-19 12:46:03 -0700 (Mon, 19 Apr 2010) $
+ * $Revision: 4104 $
+ * $Id: ClosePayPeriod.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -81,7 +81,7 @@ switch ($action) {
 		//Lock selected pay periods
 		Debug::Text('Lock Selected Pay Periods... Action: '. $action, __FILE__, __LINE__, __METHOD__,10);
 
-		$pplf = new PayPeriodListFactory();
+		$pplf = TTnew( 'PayPeriodListFactory' );
 
 		$pplf->StartTransaction();
 		if ( isset($pay_period_ids) AND count($pay_period_ids) > 0 ) {
@@ -114,8 +114,8 @@ switch ($action) {
 		break;
 	default:
 		//Step 1, get all open pay periods that have ended and are before the transaction date.
-		$pplf = new PayPeriodListFactory();
-		$ppslf = new PayPeriodScheduleListFactory();
+		$pplf = TTnew( 'PayPeriodListFactory' );
+		$ppslf = TTnew( 'PayPeriodScheduleListFactory' );
 
 		$open_pay_periods = FALSE;
 
@@ -132,7 +132,7 @@ switch ($action) {
 							)
 							) {
 
-					$elf = new ExceptionListFactory();
+					$elf = TTnew( 'ExceptionListFactory' );
 					$elf->getSumExceptionsByPayPeriodIdAndBeforeDate($pay_period_obj->getId(), $pay_period_obj->getEndDate() );
 
 					$low_severity_exceptions = 0;
@@ -158,14 +158,14 @@ switch ($action) {
 
 					//Get all pending requests
 					$pending_requests = 0;
-					$rlf = new RequestListFactory();
+					$rlf = TTnew( 'RequestListFactory' );
 					$rlf->getSumByPayPeriodIdAndStatus( $pay_period_obj->getId(), 30 );
 					if ( $rlf->getRecordCount() > 0 ) {
 						$pending_requests = $rlf->getCurrent()->getColumn('total');
 					}
 
 					//Get PS Amendments.
-					$psalf = new PayStubAmendmentListFactory();
+					$psalf = TTnew( 'PayStubAmendmentListFactory' );
 					$psalf->getByUserIdAndAuthorizedAndStartDateAndEndDate( $pay_period_schedule->getUser(), TRUE, $pay_period_obj->getStartDate(), $pay_period_obj->getEndDate() );
 					$total_ps_amendments = 0;
 					if ( is_object($psalf) ) {
@@ -173,7 +173,7 @@ switch ($action) {
 					}
 
 					//Get verified timesheets
-					$pptsvlf = new PayPeriodTimeSheetVerifyListFactory();
+					$pptsvlf = TTnew( 'PayPeriodTimeSheetVerifyListFactory' );
 					$pptsvlf->getByPayPeriodIdAndCompanyId( $pay_period_obj->getId(), $current_company->getId() );
 					$verified_time_sheets = 0;
 					$pending_time_sheets = 0;
@@ -188,11 +188,11 @@ switch ($action) {
 					}
 
 					//Get total employees with time for this pay period.
-					$udtlf = new UserDateTotalListFactory();
+					$udtlf = TTnew( 'UserDateTotalListFactory' );
 					$total_worked_users = $udtlf->getWorkedUsersByPayPeriodId( $pay_period_obj->getId() );
 
 					//Count how many pay stubs for each pay period.
-					$pslf = new PayStubListFactory();
+					$pslf = TTnew( 'PayStubListFactory' );
 					$total_pay_stubs = $pslf->getByPayPeriodId( $pay_period_obj->getId() )->getRecordCount();
 
 					if ( $pay_period_obj->getStatus() != 20 ) {
