@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2120 $
- * $Id: EditPayPeriod.php 2120 2008-09-08 23:08:13Z ipso $
- * $Date: 2008-09-08 16:08:13 -0700 (Mon, 08 Sep 2008) $
+ * $Revision: 4104 $
+ * $Id: EditPayPeriod.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -79,7 +79,7 @@ if ( isset($data) ) {
 	}
 }
 
-$ppf = new PayPeriodFactory();
+$ppf = TTnew( 'PayPeriodFactory' );
 
 $action = Misc::findSubmitButton();
 $action = strtolower($action);
@@ -128,7 +128,7 @@ switch ($action) {
 		if ( isset($id) ) {
 			BreadCrumb::setCrumb($title);
 
-			$pplf = new PayPeriodListFactory();
+			$pplf = TTnew( 'PayPeriodListFactory' );
 			$pplf->getByIdAndCompanyId($id, $current_company->getId() );
 
 			foreach ($pplf as $pp_obj) {
@@ -155,7 +155,7 @@ switch ($action) {
 			}
 		} else {
 			if ( isset($pay_period_schedule_id) AND $pay_period_schedule_id != '') {
-				$ppslf = new PayPeriodScheduleListFactory();
+				$ppslf = TTnew( 'PayPeriodScheduleListFactory' );
 				$ppslf->getByIdAndCompanyId( $pay_period_schedule_id, $current_company->getId() );
 				if ( $ppslf->getRecordCount() > 0 ) {
 					$data['pay_period_schedule_type_id'] = $ppslf->getCurrent()->getType();
@@ -164,7 +164,7 @@ switch ($action) {
 				$data['pay_period_schedule_id'] = $pay_period_schedule_id;
 
 				//Get end date of previous pay period, and default the start date of the new pay period to that.
-				$pplf = new PayPeriodListFactory();
+				$pplf = TTnew( 'PayPeriodListFactory' );
 				$pplf->getByPayPeriodScheduleId( $pay_period_schedule_id, 1, NULL, NULL, array('start_date' => 'desc') );
 				if ( $pplf->getRecordCount() > 0 ) {
 					foreach( $pplf as $pp_obj) {
