@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3725 $
- * $Id: EditPayPeriodSchedule.php 3725 2010-07-28 21:16:05Z ipso $
- * $Date: 2010-07-28 14:16:05 -0700 (Wed, 28 Jul 2010) $
+ * $Revision: 4104 $
+ * $Id: EditPayPeriodSchedule.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -78,7 +78,7 @@ if ( isset($pay_period_schedule_data) ) {
 }
 
 //var_dump($pay_period_schedule_data);
-$ppsf = new PayPeriodScheduleFactory();
+$ppsf = TTnew( 'PayPeriodScheduleFactory' );
 
 $action = Misc::findSubmitButton();
 $action = strtolower($action);
@@ -168,7 +168,7 @@ switch ($action) {
 		if ( isset($id) ) {
 			BreadCrumb::setCrumb($title);
 
-			$ppslf = new PayPeriodScheduleListFactory();
+			$ppslf = TTnew( 'PayPeriodScheduleListFactory' );
 
 			$ppslf->GetByIdAndCompanyId($id, $current_company->getId() );
 
