@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 1315 $
- * $Id: PayPeriodList.php 1315 2007-10-17 23:40:14Z ipso $
- * $Date: 2007-10-17 16:40:14 -0700 (Wed, 17 Oct 2007) $
+ * $Revision: 4104 $
+ * $Id: PayPeriodList.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -81,7 +81,7 @@ if ( $sort_column != '' ) {
 	$sort_array = array($sort_column => $sort_order);
 }
 
-//$ppslf = new PayPeriodScheduleFactory();
+//$ppslf = TTnew( 'PayPeriodScheduleFactory' );
 
 Debug::Arr($ids,'Selected Objects', __FILE__, __LINE__, __METHOD__,10);
 
@@ -99,7 +99,7 @@ switch ($action) {
 			$delete = FALSE;
 		}
 
-		$pplf = new PayPeriodListFactory();
+		$pplf = TTnew( 'PayPeriodListFactory' );
 
 		$pplf->StartTransaction();
 
@@ -119,8 +119,8 @@ switch ($action) {
 		break;
 
 	default:
-		$pplf = new PayPeriodListFactory();
-		$ppslf = new PayPeriodScheduleListFactory();
+		$pplf = TTnew( 'PayPeriodListFactory' );
+		$ppslf = TTnew( 'PayPeriodScheduleListFactory' );
 
 		//$pplf->GetByCompanyId($current_company->getId(), $current_user_prefs->getItemsPerPage(), $page, NULL, array($sort_column => $sort_order) );
 		//$pplf->GetByPayPeriodScheduleId($id, $current_user_prefs->getItemsPerPage(), $page, NULL, array($sort_column => $sort_order) );
