@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 1246 $
- * $Id: PayPeriodScheduleList.php 1246 2007-09-14 23:47:42Z ipso $
- * $Date: 2007-09-14 16:47:42 -0700 (Fri, 14 Sep 2007) $
+ * $Revision: 4104 $
+ * $Id: PayPeriodScheduleList.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -72,7 +72,7 @@ URLBuilder::setURL($_SERVER['SCRIPT_NAME'],
 
 
 
-//$ppslf = new PayPeriodScheduleFactory();
+//$ppslf = TTnew( 'PayPeriodScheduleFactory' );
 
 Debug::Arr($ids,'Selected Objects', __FILE__, __LINE__, __METHOD__,10);
 
@@ -90,7 +90,7 @@ switch ($action) {
 			$delete = FALSE;
 		}
 
-		$ppslf = new PayPeriodScheduleListFactory();
+		$ppslf = TTnew( 'PayPeriodScheduleListFactory' );
 
 		foreach ($ids as $id) {
 			$ppslf->GetByIdAndCompanyId($id, $current_company->getId() );
@@ -105,7 +105,7 @@ switch ($action) {
 		break;
 
 	default:
-		$ppslf = new PayPeriodScheduleListFactory();
+		$ppslf = TTnew( 'PayPeriodScheduleListFactory' );
 
 		$ppslf->getByCompanyId($current_company->getId(), $current_user_prefs->getItemsPerPage(), $page, NULL, array($sort_column => $sort_order) );
 
