@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3928 $
- * $Id: PermissionControlList.php 3928 2010-11-11 20:29:54Z ipso $
- * $Date: 2010-11-11 12:29:54 -0800 (Thu, 11 Nov 2010) $
+ * $Revision: 4104 $
+ * $Id: PermissionControlList.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -85,7 +85,7 @@ switch ($action) {
 
 		break;
 	case 'copy':
-		$pclf = new PermissionControlListFactory();
+		$pclf = TTnew( 'PermissionControlListFactory' );
 
 		$pclf->StartTransaction();
 
@@ -118,7 +118,7 @@ switch ($action) {
 			$delete = FALSE;
 		}
 
-		$pclf = new PermissionControlListFactory();
+		$pclf = TTnew( 'PermissionControlListFactory' );
 
 		foreach ($ids as $id) {
 			$pclf->getByIdAndCompanyId($id, $current_company->getId() );
@@ -135,7 +135,7 @@ switch ($action) {
 		break;
 
 	default:
-		$pclf = new PermissionControlListFactory();
+		$pclf = TTnew( 'PermissionControlListFactory' );
 		$pclf->getByCompanyId( $current_company->getId(), $current_user_prefs->getItemsPerPage(), $page, NULL, $sort_array );
 
 		$pager = new Pager($pclf);
