@@ -91,7 +91,7 @@ switch ($action) {
 			$delete = FALSE;
 		}
 
-		$bplf = new BreakPolicyListFactory();
+		$bplf = TTnew( 'BreakPolicyListFactory' );
 
 		foreach ($ids as $id) {
 			$bplf->getByIdAndCompanyId($id, $current_company->getId() );
@@ -108,7 +108,7 @@ switch ($action) {
 		break;
 
 	default:
-		$bplf = new BreakPolicyListFactory();
+		$bplf = TTnew( 'BreakPolicyListFactory' );
 		$bplf->getByCompanyId( $current_company->getId() );
 
 		$pager = new Pager($bplf);
