@@ -69,7 +69,7 @@ if ( isset($data['trigger_time'] ) ) {
 	$data['maximum_punch_time'] = TTDate::parseTimeUnit($data['maximum_punch_time']);
 }
 
-$bpf = new BreakPolicyFactory();
+$bpf = TTnew( 'BreakPolicyFactory' );
 
 $action = Misc::findSubmitButton();
 $action = strtolower($action);
@@ -96,6 +96,12 @@ switch ($action) {
 			$bpf->setIncludeBreakPunchTime( FALSE );
 		}
 
+		if ( isset($data['include_multiple_breaks']) ) {
+			$bpf->setIncludeMultipleBreaks( TRUE );
+		} else {
+			$bpf->setIncludeMultipleBreaks( FALSE );
+		}
+
 		if ( $bpf->isValid() ) {
 			$bpf->Save();
 
@@ -108,7 +114,7 @@ switch ($action) {
 		if ( isset($id) ) {
 			BreadCrumb::setCrumb($title);
 
-			$mplf = new BreakPolicyListFactory();
+			$mplf = TTnew( 'BreakPolicyListFactory' );
 			$mplf->getByIdAndCompanyID( $id, $current_company->getId() );
 
 			foreach ($mplf as $mp_obj) {
@@ -126,6 +132,7 @@ switch ($action) {
 									'minimum_punch_time' => $mp_obj->getMinimumPunchTime(),
 									'maximum_punch_time' => $mp_obj->getMaximumPunchTime(),
 									'include_break_punch_time' => $mp_obj->getIncludeBreakPunchTime(),
+									'include_multiple_breaks' => $mp_obj->getIncludeMultipleBreaks(),
 									'created_date' => $mp_obj->getCreatedDate(),
 									'created_by' => $mp_obj->getCreatedBy(),
 									'updated_date' => $mp_obj->getUpdatedDate(),
