@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: EditExceptionPolicyControl.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4104 $
+ * $Id: EditExceptionPolicyControl.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -75,8 +75,8 @@ if ( isset($data['exceptions'])) {
 	}
 }
 
-$epf = new ExceptionPolicyFactory();
-$epcf = new ExceptionPolicyControlFactory();
+$epf = TTnew( 'ExceptionPolicyFactory' );
+$epcf = TTnew( 'ExceptionPolicyControlFactory' );
 
 $action = Misc::findSubmitButton();
 $action = strtolower($action);
@@ -142,13 +142,13 @@ switch ($action) {
 		if ( isset($id) AND $id != '' ) {
 			BreadCrumb::setCrumb($title);
 
-			$epclf = new ExceptionPolicyControlListFactory();
+			$epclf = TTnew( 'ExceptionPolicyControlListFactory' );
 			$epclf->getByIdAndCompanyID( $id, $current_company->getID() );
 
 			foreach ($epclf as $epc_obj) {
 				//Debug::Arr($station,'Department', __FILE__, __LINE__, __METHOD__,10);
 
-				$eplf = new ExceptionPolicyListFactory();
+				$eplf = TTnew( 'ExceptionPolicyListFactory' );
 				$eplf->getByExceptionPolicyControlID( $id );
 				if ( $eplf->getRecordCount() > 0 ) {
 					foreach( $eplf as $ep_obj ) {
