@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3019 $
- * $Id: EditHoliday.php 3019 2009-11-11 23:31:59Z ipso $
- * $Date: 2009-11-11 15:31:59 -0800 (Wed, 11 Nov 2009) $
+ * $Revision: 4104 $
+ * $Id: EditHoliday.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -65,7 +65,7 @@ if ( isset($data['date_stamp'] ) ) {
 	$data['date_stamp'] = TTDate::parseDateTime($data['date_stamp']);
 }
 
-$hf = new HolidayFactory();
+$hf = TTnew( 'HolidayFactory' );
 
 $action = Misc::findSubmitButton();
 $action = strtolower($action);
@@ -95,7 +95,7 @@ switch ($action) {
 		if ( isset($id) AND $id != '' ) {
 			BreadCrumb::setCrumb($title);
 
-			$hlf = new HolidayListFactory();
+			$hlf = TTnew( 'HolidayListFactory' );
 			$hlf->getByIdAndHolidayPolicyID( $id, $holiday_policy_id );
 			if ( $hlf->getRecordCount() > 0 ) {
 				foreach ($hlf as $h_obj) {
