@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2875 $
- * $Id: EditMealPolicy.php 2875 2009-10-07 20:27:06Z ipso $
- * $Date: 2009-10-07 13:27:06 -0700 (Wed, 07 Oct 2009) $
+ * $Revision: 4104 $
+ * $Id: EditMealPolicy.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -69,7 +69,7 @@ if ( isset($data['trigger_time'] ) ) {
 	$data['maximum_punch_time'] = TTDate::parseTimeUnit($data['maximum_punch_time']);
 }
 
-$mpf = new MealPolicyFactory();
+$mpf = TTnew( 'MealPolicyFactory' );
 
 $action = Misc::findSubmitButton();
 $action = strtolower($action);
@@ -108,7 +108,7 @@ switch ($action) {
 		if ( isset($id) ) {
 			BreadCrumb::setCrumb($title);
 
-			$mplf = new MealPolicyListFactory();
+			$mplf = TTnew( 'MealPolicyListFactory' );
 			$mplf->getByIdAndCompanyID( $id, $current_company->getID() );
 
 			foreach ($mplf as $mp_obj) {
