@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2875 $
- * $Id: EditPremiumPolicy.php 2875 2009-10-07 20:27:06Z ipso $
- * $Date: 2009-10-07 13:27:06 -0700 (Wed, 07 Oct 2009) $
+ * $Revision: 4562 $
+ * $Id: EditPremiumPolicy.php 4562 2011-04-22 16:47:34Z ipso $
+ * $Date: 2011-04-22 09:47:34 -0700 (Fri, 22 Apr 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -82,6 +82,17 @@ if ( isset($data)) {
 		$data['minimum_break_time'] = TTDate::parseTimeUnit($data['minimum_break_time']);
 	}
 
+	if ( isset($data['minimum_time_between_shift'] ) ) {
+		$data['minimum_time_between_shift'] = TTDate::parseTimeUnit($data['minimum_time_between_shift']);
+	}
+	if ( isset($data['minimum_first_shift_time'] ) ) {
+		$data['minimum_first_shift_time'] = TTDate::parseTimeUnit($data['minimum_first_shift_time']);
+	}
+
+	if ( isset($data['minimum_shift_time'] ) ) {
+		$data['minimum_shift_time'] = TTDate::parseTimeUnit($data['minimum_shift_time']);
+	}
+
 	if ( isset($data['minimum_time'] ) ) {
 		$data['minimum_time'] = TTDate::parseTimeUnit($data['minimum_time']);
 	}
@@ -104,7 +115,7 @@ if ( isset($data)) {
 	}
 }
 
-$ppf = new PremiumPolicyFactory();
+$ppf = TTnew( 'PremiumPolicyFactory' );
 
 $action = Misc::findSubmitButton();
 switch ($action) {
@@ -187,6 +198,17 @@ switch ($action) {
 			$ppf->setMinimumBreakTime( $data['minimum_break_time'] );
 		}
 
+		if ( isset($data['minimum_time_between_shift']) ) {
+			$ppf->setMinimumTimeBetweenShift( $data['minimum_time_between_shift'] );
+		}
+		if ( isset($data['minimum_first_shift_time']) ) {
+			$ppf->setMinimumFirstShiftTime( $data['minimum_first_shift_time'] );
+		}
+
+		if ( isset($data['minimum_shift_time']) ) {
+			$ppf->setMinimumShiftTime( $data['minimum_shift_time'] );
+		}
+
 		$ppf->setMinimumTime( $data['minimum_time'] );
 		$ppf->setMaximumTime( $data['maximum_time'] );
 		if ( isset($data['include_meal_policy']) ) {
@@ -290,12 +312,10 @@ switch ($action) {
 		if ( isset($id) ) {
 			BreadCrumb::setCrumb($title);
 
-			$pplf = new PremiumPolicyListFactory();
+			$pplf = TTnew( 'PremiumPolicyListFactory' );
 			$pplf->getByIdAndCompanyID( $id, $current_company->getID() );
 
 			foreach ($pplf as $pp_obj) {
-				//Debug::Arr($station,'Department', __FILE__, __LINE__, __METHOD__,10);
-
 				$data = array(
 									'id' => $pp_obj->getId(),
 									'name' => $pp_obj->getName(),
@@ -325,6 +345,11 @@ switch ($action) {
 									'maximum_no_break_time' => $pp_obj->getMaximumNoBreakTime(),
 									'minimum_break_time' => $pp_obj->getMinimumBreakTime(),
 
+									'minimum_time_between_shift' => $pp_obj->getMinimumTimeBetweenShift(),
+									'minimum_first_shift_time' => $pp_obj->getMinimumFirstShiftTime(),
+
+									'minimum_shift_time' => $pp_obj->getMinimumShiftTime(),
+
 									'minimum_time' => $pp_obj->getMinimumTime(),
 									'maximum_time' => $pp_obj->getMaximumTime(),
 
@@ -382,6 +407,9 @@ switch ($action) {
 								'weekly_trigger_time' => 0,
 								'maximum_no_break_time' => 0,
 								'minimum_break_time' => 0,
+								'minimum_time_between_shift' => 0,
+								'minimum_first_shift_time' => 0,
+								'minimum_shift_time' => 0,
 								'minimum_time' => 0,
 								'maximum_time' => 0,
 								'include_meal_policy' => TRUE,
@@ -391,21 +419,21 @@ switch ($action) {
 
 		$data = Misc::preSetArrayValues( $data, array('branch_ids', 'department_ids', 'job_group_ids', 'job_ids', 'job_item_group_ids', 'job_item_ids'), NULL);
 
-		$aplf = new AccrualPolicyListFactory();
+		$aplf = TTnew( 'AccrualPolicyListFactory' );
 		$accrual_options = $aplf->getByCompanyIDArray( $current_company->getId(), TRUE );
 
-		$psealf = new PayStubEntryAccountListFactory();
+		$psealf = TTnew( 'PayStubEntryAccountListFactory' );
 		$pay_stub_entry_options = $psealf->getByCompanyIdAndStatusIdAndTypeIdArray( $current_company->getId(), 10, array(10,20,30,50) );
 
 		//Get branches
-		$blf = new BranchListFactory();
+		$blf = TTnew( 'BranchListFactory' );
 		$blf->getByCompanyId( $current_company->getId() );
 		$branch_options = $blf->getArrayByListFactory( $blf, FALSE, TRUE );
 		$data['src_branch_options'] = Misc::arrayDiffByKey( (array)$data['branch_ids'], $branch_options );
 		$data['selected_branch_options'] = Misc::arrayIntersectByKey( (array)$data['branch_ids'], $branch_options );
 
 		//Get departments
-		$dlf = new DepartmentListFactory();
+		$dlf = TTnew( 'DepartmentListFactory' );
 		$dlf->getByCompanyId( $current_company->getId() );
 		$department_options = $dlf->getArrayByListFactory( $dlf, FALSE, TRUE );
 		$data['src_department_options'] = Misc::arrayDiffByKey( (array)$data['department_ids'], $department_options );
@@ -413,28 +441,28 @@ switch ($action) {
 
 		if ( $current_company->getProductEdition() == 20 ) {
 			//Get Job Groups
-			$jglf = new JobGroupListFactory();
+			$jglf = TTnew( 'JobGroupListFactory' );
 			$nodes = FastTree::FormatArray( $jglf->getByCompanyIdArray( $current_company->getId() ), 'TEXT', TRUE);
 			$job_group_options = $jglf->getArrayByNodes( $nodes, FALSE, FALSE );
 			$data['src_job_group_options'] = Misc::arrayDiffByKey( (array)$data['job_group_ids'], $job_group_options );
 			$data['selected_job_group_options'] = Misc::arrayIntersectByKey( (array)$data['job_group_ids'], $job_group_options );
 
 			//Get Jobs
-			$jlf = new JobListFactory();
+			$jlf = TTnew( 'JobListFactory' );
 			$jlf->getByCompanyId( $current_company->getId() );
 			$job_options = $jlf->getArrayByListFactory( $jlf, FALSE, TRUE );
 			$data['src_job_options'] = Misc::arrayDiffByKey( (array)$data['job_ids'], $job_options );
 			$data['selected_job_options'] = Misc::arrayIntersectByKey( (array)$data['job_ids'], $job_options );
 
 			//Get Job Item Groups
-			$jiglf = new JobItemGroupListFactory();
+			$jiglf = TTnew( 'JobItemGroupListFactory' );
 			$nodes = FastTree::FormatArray( $jiglf->getByCompanyIdArray( $current_company->getId() ), 'TEXT', TRUE);
 			$job_item_group_options = $jiglf->getArrayByNodes( $nodes, FALSE, FALSE );
 			$data['src_job_item_group_options'] = Misc::arrayDiffByKey( (array)$data['job_item_group_ids'], $job_item_group_options );
 			$data['selected_job_item_group_options'] = Misc::arrayIntersectByKey( (array)$data['job_item_group_ids'], $job_item_group_options );
 
 			//Get Job Items
-			$jilf = new JobItemListFactory();
+			$jilf = TTnew( 'JobItemListFactory' );
 			$jilf->getByCompanyId( $current_company->getId() );
 			$job_item_options = $jilf->getArrayByListFactory( $jilf, FALSE, TRUE );
 			$data['src_job_item_options'] = Misc::arrayDiffByKey( (array)$data['job_item_ids'], $job_item_options );
@@ -442,7 +470,7 @@ switch ($action) {
 		}
 
 		//Select box options;
-		$wglf = new WageGroupListFactory();
+		$wglf = TTnew( 'WageGroupListFactory' );
 		$data['wage_group_options'] = $wglf->getArrayByListFactory( $wglf->getByCompanyId( $current_company->getId() ), TRUE );
 
 		$data['type_options'] = $ppf->getOptions('type');
