@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2035 $
- * $Id: PremiumPolicyList.php 2035 2008-08-08 20:36:51Z ipso $
- * $Date: 2008-08-08 13:36:51 -0700 (Fri, 08 Aug 2008) $
+ * $Revision: 4104 $
+ * $Id: PremiumPolicyList.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -90,7 +90,7 @@ switch ($action) {
 			$delete = FALSE;
 		}
 
-		$pplf = new PremiumPolicyListFactory();
+		$pplf = TTnew( 'PremiumPolicyListFactory' );
 
 		foreach ($ids as $id) {
 			$pplf->getByIdAndCompanyId($id, $current_company->getId() );
@@ -109,7 +109,7 @@ switch ($action) {
 
 	default:
 		BreadCrumb::setCrumb($title);
-		$pplf = new PremiumPolicyListFactory();
+		$pplf = TTnew( 'PremiumPolicyListFactory' );
 		$pplf->getByCompanyId( $current_company->getId() );
 
 		$pager = new Pager($pplf);
