@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2035 $
- * $Id: RoundIntervalPolicyList.php 2035 2008-08-08 20:36:51Z ipso $
- * $Date: 2008-08-08 13:36:51 -0700 (Fri, 08 Aug 2008) $
+ * $Revision: 4104 $
+ * $Id: RoundIntervalPolicyList.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -91,7 +91,7 @@ switch ($action) {
 			$delete = FALSE;
 		}
 
-		$riplf = new RoundIntervalPolicyListFactory();
+		$riplf = TTnew( 'RoundIntervalPolicyListFactory' );
 
 		foreach ($ids as $id) {
 			$riplf->getByIdAndCompanyId($id, $current_company->getId() );
@@ -106,7 +106,7 @@ switch ($action) {
 		break;
 
 	default:
-		$riplf = new RoundIntervalPolicyListFactory();
+		$riplf = TTnew( 'RoundIntervalPolicyListFactory' );
 		$riplf->getByCompanyId( $current_company->getId() );
 
 		$pager = new Pager($riplf);
