@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3872 $
- * $Id: ProgressBar.php 3872 2010-09-20 17:18:20Z ipso $
- * $Date: 2010-09-20 10:18:20 -0700 (Mon, 20 Sep 2010) $
+ * $Revision: 4104 $
+ * $Id: ProgressBar.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -137,7 +137,7 @@ extract	(FormVariables::GetVariables(
 
 Debug::text('Next Page: '. $next_page, __FILE__, __LINE__, __METHOD__,10);
 
-$ppf = new PayPeriodFactory();
+$ppf = TTnew( 'PayPeriodFactory' );
 
 $action = strtolower($action);
 switch ($action) {
@@ -148,13 +148,13 @@ switch ($action) {
 
 		//Make sure pay period is not CLOSED.
 		//We can re-calc on locked though.
-		$pplf = new PayPeriodListFactory();
+		$pplf = TTnew( 'PayPeriodListFactory' );
 		$pplf->getById( $pay_period_ids );
 		if ( $pplf->getRecordCount() > 0 ) {
 			$pp_obj = $pplf->getCurrent();
 
 			if ( $pp_obj->getStatus() != 20 ) {
-				$udlf = new UserDateListFactory();
+				$udlf = TTnew( 'UserDateListFactory' );
 				if ( $action == 'recalculate_company' ) {
 					TTLog::addEntry( $current_company->getId(), TTi18n::gettext('Notice'), TTi18n::gettext(' Recalculating Company TimeSheet'), $current_user->getId(), 'user_date_total' );
 					$udlf->getByCompanyIdAndPayPeriodID( $current_company->getId(), $pay_period_ids );
@@ -218,7 +218,7 @@ switch ($action) {
 		foreach($pay_period_ids as $pay_period_id) {
 			Debug::text('Pay Period ID: '. $pay_period_id, __FILE__, __LINE__, __METHOD__,10);
 
-			$pplf = new PayPeriodListFactory();
+			$pplf = TTnew( 'PayPeriodListFactory' );
 			$pplf->getByIdAndCompanyId($pay_period_id, $current_company->getId() );
 
 			$epoch = TTDate::getTime();
@@ -227,7 +227,7 @@ switch ($action) {
 				Debug::text('Pay Period Schedule ID: '. $pay_period_obj->getPayPeriodSchedule(), __FILE__, __LINE__, __METHOD__,10);
 
 				//Grab all users for pay period
-				$ppsulf = new PayPeriodScheduleUserListFactory();
+				$ppsulf = TTnew( 'PayPeriodScheduleUserListFactory' );
 				$ppsulf->getByPayPeriodScheduleId( $pay_period_obj->getPayPeriodSchedule() );
 
 				$total_pay_stubs = $ppsulf->getRecordCount();
@@ -244,7 +244,7 @@ switch ($action) {
 
 				//Delete existing pay stub. Make sure we only
 				//delete pay stubs that are the same as what we're creating.
-				$pslf = new PayStubListFactory();
+				$pslf = TTnew( 'PayStubListFactory' );
 				$pslf->getByPayPeriodId( $pay_period_obj->getId() );
 				foreach ( $pslf as $pay_stub_obj ) {
 
@@ -285,7 +285,7 @@ switch ($action) {
 				}
 				unset($ppsulf);
 
-				$ugsf = new UserGenericStatusFactory();
+				$ugsf = TTnew( 'UserGenericStatusFactory' );
 				$ugsf->setUser( $current_user->getId() );
 				$ugsf->setBatchID( $ugsf->getNextBatchId() );
 				$ugsf->setQueue( UserGenericStatusFactory::getStaticQueue() );
@@ -306,7 +306,7 @@ switch ($action) {
 		$init_progress_bar = TRUE;
 
 		//Just need the pay_stub_id of the modified pay stub.
-		$pslf = new PayStubListFactory();
+		$pslf = TTnew( 'PayStubListFactory' );
 
 		$pslf->StartTransaction();
 		if ( is_array($pay_stub_ids) ) {
@@ -375,9 +375,9 @@ switch ($action) {
 			$total_punches = count($filter_user_id) * TTDate::getDays($data['end_punch_full_time_stamp'] - $data['start_punch_full_time_stamp']);
 			Debug::Text('Total Punches: '. $total_punches .' Users: '.  count($filter_user_id) .' Days: '.  TTDate::getDays($data['end_punch_full_time_stamp'] - $data['start_punch_full_time_stamp']), __FILE__, __LINE__, __METHOD__,10);
 
-			$pcf = new PunchControlFactory();
-			$pf = new PunchFactory();
-			$ulf = new UserListFactory();
+			$pcf = TTnew( 'PunchControlFactory' );
+			$pf = TTnew( 'PunchFactory' );
+			$ulf = TTnew( 'UserListFactory' );
 
 			$pf->StartTransaction();
 
@@ -399,8 +399,8 @@ switch ($action) {
 							$user_generic_status_label = 'N/A @ '. TTDate::getDate('DATE+TIME', $time_stamp);
 						}
 
-						$pcf = new PunchControlFactory();
-						$pf = new PunchFactory();
+						$pcf = TTnew( 'PunchControlFactory' );
+						$pf = TTnew( 'PunchFactory' );
 
 						Debug::Text('Punch Full Time Stamp: '. TTDate::getDate('DATE+TIME', $time_stamp), __FILE__, __LINE__, __METHOD__,10);
 
@@ -427,7 +427,7 @@ switch ($action) {
 
 						if ( $pf->isValid() == TRUE ) {
 							if ( $pf->Save( FALSE ) == TRUE ) {
-								$pcf = new PunchControlFactory();
+								$pcf = TTnew( 'PunchControlFactory' );
 								$pcf->setId( $pf->getPunchControlID() );
 								$pcf->setPunchObject( $pf );
 
@@ -524,7 +524,7 @@ switch ($action) {
 			//$pf->FailTransaction();
 			$pf->CommitTransaction();
 
-			$ugsf = new UserGenericStatusFactory();
+			$ugsf = TTnew( 'UserGenericStatusFactory' );
 			$ugsf->setUser( $current_user->getId() );
 			$ugsf->setBatchID( $ugsf->getNextBatchId() );
 			$ugsf->setQueue( UserGenericStatusFactory::getStaticQueue() );
@@ -553,8 +553,8 @@ switch ($action) {
 			$total_shifts = count($filter_user_id) * TTDate::getDays($data['end_full_time_stamp'] - $data['start_full_time_stamp']);
 			Debug::Text('Total Shifts: '. $total_shifts .' Users: '.  count($filter_user_id) .' Days: '.  TTDate::getDays($data['end_full_time_stamp'] - $data['start_full_time_stamp']), __FILE__, __LINE__, __METHOD__,10);
 
-			$sf = new ScheduleFactory();
-			$ulf = new UserListFactory();
+			$sf = TTnew( 'ScheduleFactory' );
+			$ulf = TTnew( 'UserListFactory' );
 
 			$sf->StartTransaction();
 
@@ -587,7 +587,7 @@ switch ($action) {
 						$conflicting_shifts = FALSE;
 						if ( isset($data['overwrite']) AND $data['overwrite'] == 1 ) {
 							Debug::Text('Overwriting Existing Shifts Enabled...', __FILE__, __LINE__, __METHOD__,10);
-							$slf = new ScheduleListFactory();
+							$slf = TTnew( 'ScheduleListFactory' );
 							//$slf->getConflictingByUserDateIdAndStartDateAndEndDate($user_date_id, $start_time, $end_time);
 							$slf->getConflictingByUserIdAndStartDateAndEndDate( $user_id, $start_time, $end_time );
 							if ( $slf->getRecordCount() > 0 ) {
@@ -620,7 +620,7 @@ switch ($action) {
 						}
 
 						//Re-initialize schedule factory here so we clear any errors preventing the next schedule from being inserted.
-						$sf = new ScheduleFactory();
+						$sf = TTnew( 'ScheduleFactory' );
 						//$sf->setUserDateId( $user_date_id  );
 						$sf->setUserDate($user_id, $time_stamp);
 						$sf->setStatus( $data['status_id'] );
@@ -683,7 +683,7 @@ switch ($action) {
 			//$sf->FailTransaction();
 			$sf->CommitTransaction();
 
-			$ugsf = new UserGenericStatusFactory();
+			$ugsf = TTnew( 'UserGenericStatusFactory' );
 			$ugsf->setUser( $current_user->getId() );
 			$ugsf->setBatchID( $ugsf->getNextBatchId() );
 			$ugsf->setQueue( UserGenericStatusFactory::getStaticQueue() );
@@ -715,8 +715,8 @@ switch ($action) {
 				$progress_bar->setValue(0);
 				$progress_bar->display();
 
-				$apf = new AccrualPolicyFactory();
-				$aplf = new AccrualPolicyListFactory();
+				$apf = TTnew( 'AccrualPolicyFactory' );
+				$aplf = TTnew( 'AccrualPolicyListFactory' );
 
 				$aplf->getByIdAndCompanyId( (int)$data['accrual_policy_id'], $current_company->getId() );
 				if ( $aplf->getRecordCount() > 0 ) {
