@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2698 $
- * $Id: EditPunch.php 2698 2009-07-31 20:50:37Z ipso $
- * $Date: 2009-07-31 13:50:37 -0700 (Fri, 31 Jul 2009) $
+ * $Revision: 4104 $
+ * $Id: EditPunch.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 
@@ -84,9 +84,9 @@ if ( isset($pc_data) ) {
 	}
 }
 
-$pcf = new PunchControlFactory();
-$pf = new PunchFactory();
-$ulf = new UserListFactory();
+$pcf = TTnew( 'PunchControlFactory' );
+$pf = TTnew( 'PunchFactory' );
+$ulf = TTnew( 'UserListFactory' );
 
 $action = Misc::findSubmitButton();
 switch ($action) {
@@ -94,7 +94,7 @@ switch ($action) {
 		//Debug::setVerbosity(11);
 		Debug::Text('Delete!', __FILE__, __LINE__, __METHOD__,10);
 
-		$plf = new PunchListFactory();
+		$plf = TTnew( 'PunchListFactory' );
 		$plf->getById( $pc_data['punch_id'] );
 		if ( $plf->getRecordCount() > 0 ) {
 			foreach($plf as $p_obj) {
@@ -130,7 +130,7 @@ switch ($action) {
 		Debug::Text('Repeating Punch For: '. $pc_data['repeat'] .' Days', __FILE__, __LINE__, __METHOD__,10);
 
 		for( $i=0; $i <= (int)$pc_data['repeat']; $i++ ) {
-			$pf = new PunchFactory();
+			$pf = TTnew( 'PunchFactory' );
 
 			Debug::Text('Punch Repeat: '. $i, __FILE__, __LINE__, __METHOD__,10);
 			if ( $i == 0 ) {
@@ -177,7 +177,7 @@ switch ($action) {
 			if ( $pf->isValid() == TRUE ) {
 
 				if ( $pf->Save( FALSE ) == TRUE ) {
-					$pcf = new PunchControlFactory();
+					$pcf = TTnew( 'PunchControlFactory' );
 					$pcf->setId( $pf->getPunchControlID() );
 					$pcf->setPunchObject( $pf );
 
@@ -272,14 +272,14 @@ switch ($action) {
 		if ( $id != '' AND $action != 'submit' ) {
 			Debug::Text(' ID was passed: '. $id, __FILE__, __LINE__, __METHOD__,10);
 
-			$pclf = new PunchControlListFactory();
+			$pclf = TTnew( 'PunchControlListFactory' );
 			$pclf->getByPunchId( $id );
 
 			foreach ($pclf as $pc_obj) {
 				//Debug::Arr($station,'Department', __FILE__, __LINE__, __METHOD__,10);
 
 				//Get punches
-				$plf = new PunchListFactory();
+				$plf = TTnew( 'PunchListFactory' );
 				//$plf->getByPunchControlId( $pc_obj->getId() );
 				$plf->getById( $id );
 				if ( $plf->getRecordCount() > 0 ) {
@@ -290,7 +290,7 @@ switch ($action) {
 
 				//Get Station data.
 				$station_data = FALSE;
-				$slf = new StationListFactory();
+				$slf = TTnew( 'StationListFactory' );
 				if ( $p_obj->getStation() != FALSE ) {
 					$slf->getById( $p_obj->getStation() );
 					if ( $slf->getRecordCount() > 0 ) {
@@ -363,7 +363,7 @@ switch ($action) {
 				Debug::Text(' Punch Control ID was passed: '. $punch_control_id, __FILE__, __LINE__, __METHOD__,10);
 
 				//Get previous punch, and default timestamp to that.
-				$plf = new PunchListFactory();
+				$plf = TTnew( 'PunchListFactory' );
 				$plf->getPreviousPunchByPunchControlID( $punch_control_id );
 				if ( $plf->getRecordCount() > 0 ) {
 					$prev_punch_obj = $plf->getCurrent();
@@ -374,7 +374,7 @@ switch ($action) {
 					$date_stamp = NULL;
 				}
 
-				$pclf = new PunchControlListFactory();
+				$pclf = TTnew( 'PunchControlListFactory' );
 				$pclf->getById( $punch_control_id );
 				if ( $pclf->getRecordCount() > 0 ) {
 					$pc_obj = $pclf->getCurrent();
@@ -424,7 +424,7 @@ switch ($action) {
 					$epoch = TTDate::getTime();
 				}
 				//Get previous punch, and default timestamp to that.
-				$plf = new PunchListFactory();
+				$plf = TTnew( 'PunchListFactory' );
 				$plf->getPreviousPunchByUserIDAndEpoch( $user_id, $epoch );
 				if ( $plf->getRecordCount() > 0 ) {
 					Debug::Text(' Found Previous punch: ', __FILE__, __LINE__, __METHOD__,10);
@@ -434,7 +434,7 @@ switch ($action) {
 					$time_stamp = $date_stamp;
 				}
 				*/
-				$ulf = new UserListFactory();
+				$ulf = TTnew( 'UserListFactory' );
 				$ulf->getByIdAndCompanyId( $user_id, $current_company->getId() );
 				if ( $ulf->getRecordCount() > 0 ) {
 					$user_obj = $ulf->getCurrent();
@@ -457,19 +457,19 @@ switch ($action) {
 		}
 
 
-		$blf = new BranchListFactory();
+		$blf = TTnew( 'BranchListFactory' );
 		$branch_options = $blf->getByCompanyIdArray( $current_company->getId() );
 
-		$dlf = new DepartmentListFactory();
+		$dlf = TTnew( 'DepartmentListFactory' );
 		$department_options = $dlf->getByCompanyIdArray( $current_company->getId() );
 
 		if ( $current_company->getProductEdition() == 20 ) {
-			$jlf = new JobListFactory();
+			$jlf = TTnew( 'JobListFactory' );
 			$jlf->getByCompanyIdAndUserIdAndStatus( $current_company->getId(), $pc_data['user_id'], array(10,20,30,40) );
 			$pc_data['job_options'] = $jlf->getArrayByListFactory( $jlf, TRUE, TRUE );
 			$pc_data['job_manual_id_options'] = $jlf->getManualIDArrayByListFactory($jlf, TRUE);
 
-			$jilf = new JobItemListFactory();
+			$jilf = TTnew( 'JobItemListFactory' );
 			$jilf->getByCompanyId( $current_company->getId() );
 			$pc_data['job_item_options'] = $jilf->getArrayByListFactory( $jilf, TRUE, TRUE );
 			$pc_data['job_item_manual_id_options'] = $jilf->getManualIdArrayByListFactory( $jilf, TRUE );
@@ -482,7 +482,7 @@ switch ($action) {
 		$pc_data['department_options'] = $department_options;
 
 		//Get other field names
-		$oflf = new OtherFieldListFactory();
+		$oflf = TTnew( 'OtherFieldListFactory' );
 		$pc_data['other_field_names'] = $oflf->getByCompanyIdAndTypeIdArray( $current_company->getId(), 15 );
 
 		//Debug::Text('pc_data[date_stamp]: '. TTDate::getDate('DATE+TIME', $pc_data['date_stamp']), __FILE__, __LINE__, __METHOD__,10);
