@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2391 $
- * $Id: EditUserAbsence.php 2391 2009-01-27 01:04:39Z ipso $
- * $Date: 2009-01-26 17:04:39 -0800 (Mon, 26 Jan 2009) $
+ * $Revision: 4104 $
+ * $Id: EditUserAbsence.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -70,7 +70,7 @@ if ( isset($udt_data) ) {
 	}
 }
 
-$udtf = new UserDateTotalFactory();
+$udtf = TTnew( 'UserDateTotalFactory' );
 
 $action = Misc::findSubmitButton();
 $action = strtolower($action);
@@ -79,7 +79,7 @@ switch ($action) {
 		Debug::Text('Delete!', __FILE__, __LINE__, __METHOD__,10);
 		//Debug::setVerbosity(11);
 
-		$udtlf = new UserDateTotalListFactory();
+		$udtlf = TTnew( 'UserDateTotalListFactory' );
 		$udtlf->getById( $udt_data['id'] );
 		if ( $udtlf->getRecordCount() > 0 ) {
 			foreach($udtlf as $udt_obj) {
@@ -128,7 +128,7 @@ switch ($action) {
 					$udtf->setId($udt_data['id']);
 				} else {
 					Debug::Text('Editing absence, absence policy changed, deleting old record ID: '. $udt_data['id'] , __FILE__, __LINE__, __METHOD__,10);
-					$udtlf = new UserDateTotalListFactory();
+					$udtlf = TTnew( 'UserDateTotalListFactory' );
 					$udtlf->getById( $udt_data['id'] );
 					if ( $udtlf->getRecordCount() == 1 ) {
 						$udt_obj = $udtlf->getCurrent();
@@ -193,7 +193,7 @@ switch ($action) {
 		if ( $id != '' ) {
 			Debug::Text(' ID was passed: '. $id, __FILE__, __LINE__, __METHOD__,10);
 
-			$udtlf = new UserDateTotalListFactory();
+			$udtlf = TTnew( 'UserDateTotalListFactory' );
 			$udtlf->getById( $id );
 
 			foreach ($udtlf as $udt_obj) {
@@ -224,7 +224,7 @@ switch ($action) {
 			Debug::Text(' ID was NOT passed: '. $id, __FILE__, __LINE__, __METHOD__,10);
 
 			//Get user full name
-			$ulf = new UserListFactory();
+			$ulf = TTnew( 'UserListFactory' );
 			$user_obj = $ulf->getById( $user_id )->getCurrent();
 			$user_date_id = UserDateFactory::getUserDateID($user_id, $date_stamp);
 
@@ -240,13 +240,13 @@ switch ($action) {
 							);
 		}
 
-		$aplf = new AbsencePolicyListFactory();
+		$aplf = TTnew( 'AbsencePolicyListFactory' );
 		$absence_policy_options = Misc::prependArray( array( 0 => TTi18n::gettext('-- Please Choose --') ), $aplf->getByCompanyIdArray( $current_company->getId() ) );
 
-		$blf = new BranchListFactory();
+		$blf = TTnew( 'BranchListFactory' );
 		$branch_options = $blf->getByCompanyIdArray( $current_company->getId() );
 
-		$dlf = new DepartmentListFactory();
+		$dlf = TTnew( 'DepartmentListFactory' );
 		$department_options = $dlf->getByCompanyIdArray( $current_company->getId() );
 
 		//Select box options;
