@@ -112,8 +112,8 @@ if ( $saved_search_id == '' AND !isset($filter_data['columns']) ) {
 	}
 }
 
-$ugdlf = new UserGenericDataListFactory();
-$ugdf = new UserGenericDataFactory();
+$ugdlf = TTnew( 'UserGenericDataListFactory' );
+$ugdf = TTnew( 'UserGenericDataFactory' );
 
 Debug::Text('Form: '. $form, __FILE__, __LINE__, __METHOD__,10);
 //Handle different actions for different forms.
@@ -136,7 +136,7 @@ switch ($action) {
 
 		if ( DEMO_MODE == FALSE
 			AND ( $permission->Check('punch','delete') OR $permission->Check('punch','delete_own') OR $permission->Check('punch','delete_child')  ) ) {
-			$plf = new PunchListFactory();
+			$plf = TTnew( 'PunchListFactory' );
 			$plf->StartTransaction();
 
 			$plf->getByCompanyIdAndId($current_company->getID(), $ids );
@@ -187,10 +187,10 @@ switch ($action) {
 															'page' => $page
 														) );
 
-		$ulf = new UserListFactory();
-		$plf = new PunchListFactory();
+		$ulf = TTnew( 'UserListFactory' );
+		$plf = TTnew( 'PunchListFactory' );
 
-		$hlf = new HierarchyListFactory();
+		$hlf = TTnew( 'HierarchyListFactory' );
 		$permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId() );
 		//Debug::Arr($permission_children_ids,'Permission Children Ids:', __FILE__, __LINE__, __METHOD__,10);
 		if ( $permission->Check('punch','view') == FALSE ) {
@@ -202,7 +202,7 @@ switch ($action) {
 			}
 		}
 
-		$pplf = new PayPeriodListFactory();
+		$pplf = TTnew( 'PayPeriodListFactory' );
 		$pplf->getByCompanyId( $current_company->getId() );
 		$pay_period_options = $pplf->getArrayByListFactory( $pplf, FALSE, FALSE );
 		$pay_period_ids = array_keys((array)$pay_period_options);
@@ -212,7 +212,7 @@ switch ($action) {
 		}
 
 		//If they aren't searching, limit to the last pay period by default for performance optimization when there are hundreds of thousands of punches.
-		if ( $action == '' AND isset($pay_period_ids[0]) AND isset($pay_period_ids[1]) ) {
+		if ( $action == '' AND isset($pay_period_ids[0]) AND isset($pay_period_ids[1]) AND !isset($filter_data['pay_period_ids']) ) {
 			$filter_data['pay_period_ids'] = array($pay_period_ids[0],$pay_period_ids[1]);
 		}
 
@@ -225,22 +225,22 @@ switch ($action) {
 		$punch_status_options = $plf->getOptions('status');
 		$punch_type_options = $plf->getOptions('type');
 
-		$utlf = new UserTitleListFactory();
+		$utlf = TTnew( 'UserTitleListFactory' );
 		$utlf->getByCompanyId( $current_company->getId() );
 		$title_options = $utlf->getArrayByListFactory( $utlf, FALSE, TRUE );
 
-		$blf = new BranchListFactory();
+		$blf = TTnew( 'BranchListFactory' );
 		$blf->getByCompanyId( $current_company->getId() );
 		$branch_options = $blf->getArrayByListFactory( $blf, FALSE, TRUE );
 
-		$dlf = new DepartmentListFactory();
+		$dlf = TTnew( 'DepartmentListFactory' );
 		$dlf->getByCompanyId( $current_company->getId() );
 		$department_options = $dlf->getArrayByListFactory( $dlf, FALSE, TRUE );
 
-		$uglf = new UserGroupListFactory();
+		$uglf = TTnew( 'UserGroupListFactory' );
 		$group_options = $uglf->getArrayByNodes( FastTree::FormatArray( $uglf->getByCompanyIdArray( $current_company->getId() ), 'TEXT', TRUE) );
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$user_options = $ulf->getByCompanyIdArray( $current_company->getID(), FALSE );
 
 		foreach ($plf as $p_obj) {
