@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 1549 $
- * $Id: UserExceptionList.php 1549 2007-12-14 21:41:35Z ipso $
- * $Date: 2007-12-14 13:41:35 -0800 (Fri, 14 Dec 2007) $
+ * $Revision: 4230 $
+ * $Id: UserExceptionList.php 4230 2011-02-11 21:36:14Z ipso $
+ * $Date: 2011-02-11 13:36:14 -0800 (Fri, 11 Feb 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -100,8 +100,8 @@ if ( $saved_search_id == '' AND !isset($filter_data['columns']) ) {
 	}
 }
 
-$ugdlf = new UserGenericDataListFactory();
-$ugdf = new UserGenericDataFactory();
+$ugdlf = TTnew( 'UserGenericDataListFactory' );
+$ugdf = TTnew( 'UserGenericDataFactory' );
 
 Debug::Text('Form: '. $form, __FILE__, __LINE__, __METHOD__,10);
 //Handle different actions for different forms.
@@ -140,10 +140,10 @@ switch ($action) {
 															'page' => $page
 														) );
 
-		$ulf = new UserListFactory();
-		$elf = new ExceptionListFactory();
+		$ulf = TTnew( 'UserListFactory' );
+		$elf = TTnew( 'ExceptionListFactory' );
 
-		$hlf = new HierarchyListFactory();
+		$hlf = TTnew( 'HierarchyListFactory' );
 		$permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId() );
 		Debug::Arr($permission_children_ids,'Permission Children Ids:', __FILE__, __LINE__, __METHOD__,10);
 		if ( $permission->Check('punch','view') == FALSE ) {
@@ -155,7 +155,7 @@ switch ($action) {
 			}
 		}
 
-		$pplf = new PayPeriodListFactory();
+		$pplf = TTnew( 'PayPeriodListFactory' );
 		$pplf->getByCompanyId( $current_company->getId() );
 		$pay_period_options = $pplf->getArrayByListFactory( $pplf, FALSE, FALSE );
 		$pay_period_ids = array_keys((array)$pay_period_options);
@@ -175,26 +175,26 @@ switch ($action) {
 
 		$pager = new Pager($elf);
 
-		$epf = new ExceptionPolicyFactory();
+		$epf = TTnew( 'ExceptionPolicyFactory' );
 		$exception_policy_type_options = $epf->getOptions('type');
 		$exception_policy_severity_options = $epf->getOptions('severity');
 
-		$utlf = new UserTitleListFactory();
+		$utlf = TTnew( 'UserTitleListFactory' );
 		$utlf->getByCompanyId( $current_company->getId() );
 		$title_options = $utlf->getArrayByListFactory( $utlf, FALSE, TRUE );
 
-		$blf = new BranchListFactory();
+		$blf = TTnew( 'BranchListFactory' );
 		$blf->getByCompanyId( $current_company->getId() );
 		$branch_options = $blf->getArrayByListFactory( $blf, FALSE, TRUE );
 
-		$dlf = new DepartmentListFactory();
+		$dlf = TTnew( 'DepartmentListFactory' );
 		$dlf->getByCompanyId( $current_company->getId() );
 		$department_options = $dlf->getArrayByListFactory( $dlf, FALSE, TRUE );
 
-		$uglf = new UserGroupListFactory();
+		$uglf = TTnew( 'UserGroupListFactory' );
 		$group_options = $uglf->getArrayByNodes( FastTree::FormatArray( $uglf->getByCompanyIdArray( $current_company->getId() ), 'TEXT', TRUE) );
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$user_options = $ulf->getByCompanyIdArray( $current_company->getID(), FALSE );
 
 		foreach ($elf as $e_obj) {
@@ -217,6 +217,7 @@ switch ($action) {
 								'last_name' => $user_obj->getLastName(),
 								'user_full_name' => Option::getByKey($e_obj->getColumn('user_id'), $user_options),
 								'date_stamp' => TTDate::getDate('DATE', TTDate::strtotime($e_obj->getColumn('user_date_stamp')) ),
+								'date_stamp_epoch' => TTDate::strtotime($e_obj->getColumn('user_date_stamp')),
 								'type_id' => $e_obj->getType(),
 								'severity_id' => $e_obj->getColumn('severity_id'),
 								'severity' => Option::getByKey($e_obj->getColumn('severity_id'), $exception_policy_severity_options),
