@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3807 $
- * $Id: Form1099Misc.php 3807 2010-08-24 23:14:34Z ipso $
- * $Date: 2010-08-24 16:14:34 -0700 (Tue, 24 Aug 2010) $
+ * $Revision: 4104 $
+ * $Id: Form1099Misc.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -67,7 +67,7 @@ URLBuilder::setURL($_SERVER['SCRIPT_NAME'],
 //													'sort_order' => $sort_order,
 												) );
 
-$pseallf = new PayStubEntryAccountLinkListFactory();
+$pseallf = TTnew( 'PayStubEntryAccountLinkListFactory' );
 $pseallf->getByCompanyId( $current_company->getId() );
 if ( $pseallf->getRecordCount() > 0 ) {
 	$pseal_obj = $pseallf->getCurrent();
@@ -109,8 +109,8 @@ if ( !isset($filter_data['user_title_ids']) ) {
 	$filter_data['user_title_ids'] = array();
 }
 
-$ugdlf = new UserGenericDataListFactory();
-$ugdf = new UserGenericDataFactory();
+$ugdlf = TTnew( 'UserGenericDataListFactory' );
+$ugdf = TTnew( 'UserGenericDataFactory' );
 
 $action = Misc::findSubmitButton();
 Debug::Text('Action: '. $action, __FILE__, __LINE__, __METHOD__,10);
@@ -142,7 +142,7 @@ switch ($action) {
 			$ugdf->Save();
 		}
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$ulf->getSearchByCompanyIdAndArrayCriteria( $current_company->getId(), $filter_data );
 
 		if ( $ulf->getRecordCount() > 0 ) {
@@ -151,7 +151,7 @@ switch ($action) {
 			}
 
 			if ( isset($filter_data['user_id']) ) {
-				$pseallf = new PayStubEntryAccountLinkListFactory();
+				$pseallf = TTnew( 'PayStubEntryAccountLinkListFactory' );
 				$pseallf->getByCompanyId( $current_company->getId() );
 				if ( $pseallf->getRecordCount() > 0 ) {
 					$pseal_obj = $pseallf->getCurrent();
@@ -165,7 +165,7 @@ switch ($action) {
 
 				//PS Account Amounts...
 				//Get employees who have recieved pay stubs.
-				$pself = new PayStubEntryListFactory();
+				$pself = TTnew( 'PayStubEntryListFactory' );
 				//$pself->getReportByCompanyIdAndUserIdAndPayPeriodId( $current_company->getId(), $filter_data['user_ids'], $pay_period_ids );
 				$pself->getReportByCompanyIdAndArrayCriteria( $current_company->getId(), $filter_data );
 				foreach( $pself as $pse_obj ) {
@@ -183,7 +183,7 @@ switch ($action) {
 				//
 				//Figure out state/locality wages/taxes.
 				//
-				$cdlf = new CompanyDeductionListFactory();
+				$cdlf = TTnew( 'CompanyDeductionListFactory' );
 				$cdlf->getByCompanyIdAndStatusIdAndTypeId( $current_company->getId(), array(10,20), 10 );
 				if ( $cdlf->getRecordCount() > 0 ) {
 					foreach( $cdlf as $cd_obj ) {
@@ -220,7 +220,7 @@ switch ($action) {
 				}
 
 				if ( isset($raw_rows) ) {
-					$ulf = new UserListFactory();
+					$ulf = TTnew( 'UserListFactory' );
 
 					$x=0;
 					foreach($raw_rows as $user_id => $raw_row) {
@@ -456,7 +456,7 @@ switch ($action) {
 			}
 		}
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$all_array_option = array('-1' => TTi18n::gettext('-- All --'));
 
 		//Get include employee list.
@@ -477,38 +477,38 @@ switch ($action) {
 		$filter_data['selected_user_status_options'] = Misc::arrayIntersectByKey( (array)$filter_data['user_status_ids'], $user_status_options );
 
 		//Get Employee Groups
-		$uglf = new UserGroupListFactory();
+		$uglf = TTnew( 'UserGroupListFactory' );
 		$group_options = Misc::prependArray( $all_array_option, $uglf->getArrayByNodes( FastTree::FormatArray( $uglf->getByCompanyIdArray( $current_company->getId() ), 'TEXT', TRUE) ) );
 		$filter_data['src_group_options'] = Misc::arrayDiffByKey( (array)$filter_data['group_ids'], $group_options );
 		$filter_data['selected_group_options'] = Misc::arrayIntersectByKey( (array)$filter_data['group_ids'], $group_options );
 
 		//Get branches
-		$blf = new BranchListFactory();
+		$blf = TTnew( 'BranchListFactory' );
 		$blf->getByCompanyId( $current_company->getId() );
 		$branch_options = Misc::prependArray( $all_array_option, $blf->getArrayByListFactory( $blf, FALSE, TRUE ) );
 		$filter_data['src_branch_options'] = Misc::arrayDiffByKey( (array)$filter_data['branch_ids'], $branch_options );
 		$filter_data['selected_branch_options'] = Misc::arrayIntersectByKey( (array)$filter_data['branch_ids'], $branch_options );
 
 		//Get departments
-		$dlf = new DepartmentListFactory();
+		$dlf = TTnew( 'DepartmentListFactory' );
 		$dlf->getByCompanyId( $current_company->getId() );
 		$department_options = Misc::prependArray( $all_array_option, $dlf->getArrayByListFactory( $dlf, FALSE, TRUE ) );
 		$filter_data['src_department_options'] = Misc::arrayDiffByKey( (array)$filter_data['department_ids'], $department_options );
 		$filter_data['selected_department_options'] = Misc::arrayIntersectByKey( (array)$filter_data['department_ids'], $department_options );
 
 		//Get employee titles
-		$utlf = new UserTitleListFactory();
+		$utlf = TTnew( 'UserTitleListFactory' );
 		$utlf->getByCompanyId( $current_company->getId() );
 		$user_title_options = Misc::prependArray( $all_array_option, $utlf->getArrayByListFactory( $utlf, FALSE, TRUE ) );
 		$filter_data['src_user_title_options'] = Misc::arrayDiffByKey( (array)$filter_data['user_title_ids'], $user_title_options );
 		$filter_data['selected_user_title_options'] = Misc::arrayIntersectByKey( (array)$filter_data['user_title_ids'], $user_title_options );
 
 		//PSEA accounts
-		$psealf = new PayStubEntryAccountListFactory();
+		$psealf = TTnew( 'PayStubEntryAccountListFactory' );
 		$filter_data['pay_stub_entry_account_options'] = $psealf->getByCompanyIdAndStatusIdAndTypeIdArray( $current_company->getId(), 10, array(10,20,30,40), TRUE );
 
 		//Get a unique list of states each employee belongs to
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$ulf->getByCompanyId( $current_company->getId() );
 		if ( $ulf->getRecordCount() > 0 ) {
 			foreach( $ulf as $u_obj ) {
