@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3928 $
- * $Id: Form941.php 3928 2010-11-11 20:29:54Z ipso $
- * $Date: 2010-11-11 12:29:54 -0800 (Thu, 11 Nov 2010) $
+ * $Revision: 4492 $
+ * $Id: Form941.php 4492 2011-04-02 18:42:31Z ipso $
+ * $Date: 2011-04-02 11:42:31 -0700 (Sat, 02 Apr 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -66,7 +66,7 @@ URLBuilder::setURL($_SERVER['SCRIPT_NAME'],
 //													'sort_order' => $sort_order,
 												) );
 
-$pseallf = new PayStubEntryAccountLinkListFactory();
+$pseallf = TTnew( 'PayStubEntryAccountLinkListFactory' );
 $pseallf->getByCompanyId( $current_company->getId() );
 if ( $pseallf->getRecordCount() > 0 ) {
 	$pseal_obj = $pseallf->getCurrent();
@@ -78,11 +78,12 @@ $column_ps_entry_name_map = array(
 								'5a' 	=> @array( $setup_data['5a_psea_ids'], $setup_data['5a_exclude_psea_ids'] ),
 								'5b' 	=> @array( $setup_data['5b_psea_ids'], $setup_data['5b_exclude_psea_ids'] ),
 								'5c' 	=> @array( $setup_data['5c_psea_ids'], $setup_data['5c_exclude_psea_ids'] ),
-								'7b'	=> @array( $setup_data['7b_psea_ids'], $setup_data['7b_exclude_psea_ids'] ),
+								'8'		=> @array( $setup_data['8_psea_ids'], $setup_data['8_exclude_psea_ids'] ),
 								'9' 	=> @array( $setup_data['9_psea_ids'], $setup_data['9_exclude_psea_ids'] ),
+								'12a' 	=> @array( $setup_data['12a_psea_ids'], $setup_data['12a_exclude_psea_ids'] ),
 								);
 
-$pplf = new PayPeriodListFactory();
+$pplf = TTnew( 'PayPeriodListFactory' );
 $year_options = $pplf->getYearsArrayByCompanyId( $current_company->getId() );
 
 $quarter_options = array(
@@ -117,8 +118,8 @@ $quarter_dates = array(
 
 $filter_data = Misc::preSetArrayValues( $filter_data, array('include_user_ids', 'exclude_user_ids', 'user_status_ids', 'group_ids', 'branch_ids', 'department_ids', 'user_title_ids', 'pay_period_ids', 'column_ids' ), array() );
 
-$ugdlf = new UserGenericDataListFactory();
-$ugdf = new UserGenericDataFactory();
+$ugdlf = TTnew( 'UserGenericDataListFactory' );
+$ugdf = TTnew( 'UserGenericDataFactory' );
 
 $action = Misc::findSubmitButton();
 Debug::Text('Action: '. $action, __FILE__, __LINE__, __METHOD__,10);
@@ -150,7 +151,7 @@ switch ($action) {
 			$ugdf->Save();
 		}
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$ulf->getSearchByCompanyIdAndArrayCriteria( $current_company->getId(), $filter_data );
 
 		if ( $ulf->getRecordCount() > 0 ) {
@@ -159,7 +160,7 @@ switch ($action) {
 			}
 
 			if ( isset($filter_data['user_ids']) AND isset($filter_data['quarter_id']) ) {
-				$pseallf = new PayStubEntryAccountLinkListFactory();
+				$pseallf = TTnew( 'PayStubEntryAccountLinkListFactory' );
 				$pseallf->getByCompanyId( $current_company->getId() );
 				if ( $pseallf->getRecordCount() > 0 ) {
 					$pseal_obj = $pseallf->getCurrent();
@@ -184,7 +185,7 @@ switch ($action) {
 					//Get Pay Periods in date range.
 					Debug::Text('Start Date: '. TTDate::getDate('DATE+TIME', $quarter_dates_arr['start']) .' End Date: '. TTDate::getDate('DATE+TIME', $quarter_dates_arr['end']), __FILE__, __LINE__, __METHOD__,10);
 
-					$pplf = new PayPeriodListFactory();
+					$pplf = TTnew( 'PayPeriodListFactory' );
 					$pplf->getByCompanyIdAndTransactionStartDateAndTransactionEndDate( $current_company->getId(), $quarter_dates_arr['start'], $quarter_dates_arr['end'] );
 					if ( $pplf->getRecordCount() > 0 ) {
 						foreach($pplf as $pp_obj) {
@@ -194,7 +195,7 @@ switch ($action) {
 					}
 
 					if ( isset($pay_period_ids) ) {
-						$pslf = new PayStubListFactory();
+						$pslf = TTnew( 'PayStubListFactory' );
 						$pslf->getByCompanyIdAndPayPeriodId( $current_company->getId(), $pay_period_ids );
 						if ( $pslf->getRecordCount() > 0 ) {
 							foreach( $pslf as $ps_obj ) {
@@ -214,7 +215,7 @@ switch ($action) {
 						foreach( $pay_period_ids as $pay_period_id ) {
 							//PS Account Amounts...
 							//Get employees who have recieved pay stubs.
-							$pself = new PayStubEntryListFactory();
+							$pself = TTnew( 'PayStubEntryListFactory' );
 							$pself->getReportByCompanyIdAndUserIdAndPayPeriodId( $current_company->getId(), $filter_data['user_ids'], $pay_period_id );
 							if ( $pself->getRecordCount() > 0 ) {
 								foreach( $pself as $pse_obj ) {
@@ -242,15 +243,18 @@ switch ($action) {
 								$pp_lines_arr[$month_id][$pay_period_id]['5c'] = Misc::calculateMultipleColumns( $ps_entries, $column_ps_entry_name_map['5c'][0], $column_ps_entry_name_map['5c'][1] );
 								$pp_lines_arr[$month_id][$pay_period_id]['5c2'] = bcmul( $pp_lines_arr[$month_id][$pay_period_id]['5c'], $f941->medicare_rate );
 								$pp_lines_arr[$month_id][$pay_period_id]['5d'] =  bcadd( bcadd( $pp_lines_arr[$month_id][$pay_period_id]['5a2'], $pp_lines_arr[$month_id][$pay_period_id]['5b2']), $pp_lines_arr[$month_id][$pay_period_id]['5c2']);
-								$pp_lines_arr[$month_id][$pay_period_id]['6'] = bcadd( $pp_lines_arr[$month_id][$pay_period_id]['3'], $pp_lines_arr[$month_id][$pay_period_id]['5d']);
 
-								$pp_lines_arr[$month_id][$pay_period_id]['7a'] = bcsub( Misc::MoneyFormat($pp_lines_arr[$month_id][$pay_period_id]['5d'], FALSE) , bcadd( bcadd($pp_lines_arr[$month_id][$pay_period_id]['5a2'], $pp_lines_arr[$month_id][$pay_period_id]['5b2']), $pp_lines_arr[$month_id][$pay_period_id]['5c2'] ) );
-								$pp_lines_arr[$month_id][$pay_period_id]['7b'] = Misc::calculateMultipleColumns( $ps_entries, $column_ps_entry_name_map['7b'][0], $column_ps_entry_name_map['7b'][1] );
+								$pp_lines_arr[$month_id][$pay_period_id]['6e'] =  bcadd( $pp_lines_arr[$month_id][$pay_period_id]['3'], $pp_lines_arr[$month_id][$pay_period_id]['5d']);
 
-								$pp_lines_arr[$month_id][$pay_period_id]['7d'] = bcadd($pp_lines_arr[$month_id][$pay_period_id]['7a'], $pp_lines_arr[$month_id][$pay_period_id]['7b']);
-								$pp_lines_arr[$month_id][$pay_period_id]['8'] = bcadd( $pp_lines_arr[$month_id][$pay_period_id]['6'], $pp_lines_arr[$month_id][$pay_period_id]['7d']);
-								$pp_lines_arr[$month_id][$pay_period_id]['9'] = abs(Misc::calculateMultipleColumns( $ps_entries, $column_ps_entry_name_map['9'][0], $column_ps_entry_name_map['9'][1] ) );
-								$pp_lines_arr[$month_id][$pay_period_id]['10'] = bcsub( $pp_lines_arr[$month_id][$pay_period_id]['8'], $pp_lines_arr[$month_id][$pay_period_id]['9']);
+								$pp_lines_arr[$month_id][$pay_period_id]['7'] = bcsub( Misc::MoneyFormat($pp_lines_arr[$month_id][$pay_period_id]['5d'], FALSE) , bcadd( bcadd($pp_lines_arr[$month_id][$pay_period_id]['5a2'], $pp_lines_arr[$month_id][$pay_period_id]['5b2']), $pp_lines_arr[$month_id][$pay_period_id]['5c2'] ) );
+
+								//Was 7b
+								$pp_lines_arr[$month_id][$pay_period_id]['8'] = Misc::calculateMultipleColumns( $ps_entries, $column_ps_entry_name_map['8'][0], $column_ps_entry_name_map['8'][1] );
+
+								$pp_lines_arr[$month_id][$pay_period_id]['9'] = Misc::calculateMultipleColumns( $ps_entries, $column_ps_entry_name_map['9'][0], $column_ps_entry_name_map['9'][1] );
+								$pp_lines_arr[$month_id][$pay_period_id]['12a'] = Misc::calculateMultipleColumns( $ps_entries, $column_ps_entry_name_map['12a'][0], $column_ps_entry_name_map['12a'][1] );
+
+								$pp_lines_arr[$month_id][$pay_period_id]['10'] = bcadd( bcadd( bcadd( $pp_lines_arr[$month_id][$pay_period_id]['6e'], $pp_lines_arr[$month_id][$pay_period_id]['7']), $pp_lines_arr[$month_id][$pay_period_id]['8']), $pp_lines_arr[$month_id][$pay_period_id]['9']);
 							}
 							unset($ps_entries);
 						}
@@ -297,13 +301,12 @@ switch ($action) {
 					$f941->l5b = $lines_arr['total']['5b'];
 					$f941->l5c = $lines_arr['total']['5c'];
 
-					$f941->l7a = $lines_arr['total']['7a'];
-					$f941->l7b = $lines_arr['total']['7b'];
-					//$f941->l7c = $lines_arr['total']['7c'];
-
+					$f941->l7 = $lines_arr['total']['7'];
+					$f941->l8 = $lines_arr['total']['8'];
 					$f941->l9 = $lines_arr['total']['9'];
 
 					$f941->l11 = $lines_arr['total']['11'];
+					$f941->l12a = $lines_arr['total']['12a'];
 
 					$f941->l15b = TRUE;
 
@@ -416,7 +419,7 @@ switch ($action) {
 		}
 		$filter_data = Misc::preSetArrayValues( $filter_data, array('include_user_ids', 'exclude_user_ids', 'user_status_ids', 'group_ids', 'branch_ids', 'department_ids', 'user_title_ids', 'pay_period_ids', 'column_ids' ), NULL );
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$all_array_option = array('-1' => TTi18n::gettext('-- All --'));
 
 		//Get include employee list.
@@ -437,34 +440,34 @@ switch ($action) {
 		$filter_data['selected_user_status_options'] = Misc::arrayIntersectByKey( (array)$filter_data['user_status_ids'], $user_status_options );
 
 		//Get Employee Groups
-		$uglf = new UserGroupListFactory();
+		$uglf = TTnew( 'UserGroupListFactory' );
 		$group_options = Misc::prependArray( $all_array_option, $uglf->getArrayByNodes( FastTree::FormatArray( $uglf->getByCompanyIdArray( $current_company->getId() ), 'TEXT', TRUE) ) );
 		$filter_data['src_group_options'] = Misc::arrayDiffByKey( (array)$filter_data['group_ids'], $group_options );
 		$filter_data['selected_group_options'] = Misc::arrayIntersectByKey( (array)$filter_data['group_ids'], $group_options );
 
 		//Get branches
-		$blf = new BranchListFactory();
+		$blf = TTnew( 'BranchListFactory' );
 		$blf->getByCompanyId( $current_company->getId() );
 		$branch_options = Misc::prependArray( $all_array_option, $blf->getArrayByListFactory( $blf, FALSE, TRUE ) );
 		$filter_data['src_branch_options'] = Misc::arrayDiffByKey( (array)$filter_data['branch_ids'], $branch_options );
 		$filter_data['selected_branch_options'] = Misc::arrayIntersectByKey( (array)$filter_data['branch_ids'], $branch_options );
 
 		//Get departments
-		$dlf = new DepartmentListFactory();
+		$dlf = TTnew( 'DepartmentListFactory' );
 		$dlf->getByCompanyId( $current_company->getId() );
 		$department_options = Misc::prependArray( $all_array_option, $dlf->getArrayByListFactory( $dlf, FALSE, TRUE ) );
 		$filter_data['src_department_options'] = Misc::arrayDiffByKey( (array)$filter_data['department_ids'], $department_options );
 		$filter_data['selected_department_options'] = Misc::arrayIntersectByKey( (array)$filter_data['department_ids'], $department_options );
 
 		//Get employee titles
-		$utlf = new UserTitleListFactory();
+		$utlf = TTnew( 'UserTitleListFactory' );
 		$utlf->getByCompanyId( $current_company->getId() );
 		$user_title_options = Misc::prependArray( $all_array_option, $utlf->getArrayByListFactory( $utlf, FALSE, TRUE ) );
 		$filter_data['src_user_title_options'] = Misc::arrayDiffByKey( (array)$filter_data['user_title_ids'], $user_title_options );
 		$filter_data['selected_user_title_options'] = Misc::arrayIntersectByKey( (array)$filter_data['user_title_ids'], $user_title_options );
 
 		//PSEA accounts
-		$psealf = new PayStubEntryAccountListFactory();
+		$psealf = TTnew( 'PayStubEntryAccountListFactory' );
 		$filter_data['pay_stub_entry_account_options'] = $psealf->getByCompanyIdAndStatusIdAndTypeIdArray( $current_company->getId(), 10, array(10,20,30,40), TRUE );
 
 		//Get employee list
