@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: FormW2.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4845 $
+ * $Id: FormW2.php 4845 2011-06-21 16:23:18Z ipso $
+ * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -100,7 +100,7 @@ $non_static_columns = array(
 											'-1610-district_tax_1' => TTi18n::gettext('1- Locality Income Tax (19)'),
 											);
 
-$pseallf = new PayStubEntryAccountLinkListFactory();
+$pseallf = TTnew( 'PayStubEntryAccountLinkListFactory' );
 $pseallf->getByCompanyId( $current_company->getId() );
 if ( $pseallf->getRecordCount() > 0 ) {
 	$pseal_obj = $pseallf->getCurrent();
@@ -129,13 +129,13 @@ $column_ps_entry_name_map = array(
 								'box_14c' 				=> @array( $setup_data['14c_psea_ids'], $setup_data['14c_exclude_psea_ids'] ),
 								);
 
-$pplf = new PayPeriodListFactory();
+$pplf = TTnew( 'PayPeriodListFactory' );
 $year_options = $pplf->getYearsArrayByCompanyId( $current_company->getId() );
 
 $filter_data = Misc::preSetArrayValues( $filter_data, array('include_user_ids', 'exclude_user_ids', 'user_status_ids', 'group_ids', 'branch_ids', 'department_ids', 'user_title_ids', 'pay_period_ids', 'column_ids' ), array() );
 
-$ugdlf = new UserGenericDataListFactory();
-$ugdf = new UserGenericDataFactory();
+$ugdlf = TTnew( 'UserGenericDataListFactory' );
+$ugdf = TTnew( 'UserGenericDataFactory' );
 
 $action = Misc::findSubmitButton();
 Debug::Text('Action: '. $action, __FILE__, __LINE__, __METHOD__,10);
@@ -167,7 +167,7 @@ switch ($action) {
 			$ugdf->Save();
 		}
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$ulf->getSearchByCompanyIdAndArrayCriteria( $current_company->getId(), $filter_data );
 
 		if ( $ulf->getRecordCount() > 0 ) {
@@ -181,7 +181,7 @@ switch ($action) {
 					Debug::Text(' Year: '. TTDate::getDate('DATE+TIME', $year_epoch) , __FILE__, __LINE__, __METHOD__,10);
 				}
 
-				$pseallf = new PayStubEntryAccountLinkListFactory();
+				$pseallf = TTnew( 'PayStubEntryAccountLinkListFactory' );
 				$pseallf->getByCompanyId( $current_company->getId() );
 				if ( $pseallf->getRecordCount() > 0 ) {
 					$pseal_obj = $pseallf->getCurrent();
@@ -192,7 +192,7 @@ switch ($action) {
 				//
 
 				//Get Pay Periods in date range.
-				$pplf = new PayPeriodListFactory();
+				$pplf = TTnew( 'PayPeriodListFactory' );
 				$pplf->getByCompanyIdAndTransactionStartDateAndTransactionEndDate( $current_company->getId(), TTDate::getBeginYearEpoch($year_epoch), TTDate::getEndYearEpoch($year_epoch) );
 				if ( $pplf->getRecordCount() > 0 ) {
 					foreach($pplf as $pp_obj) {
@@ -202,7 +202,7 @@ switch ($action) {
 
 				$report_columns = $static_columns;
 
-				$pself = new PayStubEntryListFactory();
+				$pself = TTnew( 'PayStubEntryListFactory' );
 				$pself->getReportByCompanyIdAndUserIdAndPayPeriodId( $current_company->getId(), $filter_data['user_ids'], $pay_period_ids );
 
 				foreach( $pself as $pse_obj ) {
@@ -216,25 +216,30 @@ switch ($action) {
 				//
 				//Figure out state/locality wages/taxes.
 				//
-				$cdlf = new CompanyDeductionListFactory();
+				$cdlf = TTnew( 'CompanyDeductionListFactory' );
 				$cdlf->getByCompanyIdAndStatusIdAndTypeId( $current_company->getId(), array(10,20), 10 );
 				if ( $cdlf->getRecordCount() > 0 ) {
 					foreach( $cdlf as $cd_obj ) {
 						$tax_deductions[] = array(
 													'id' => $cd_obj->getId(),
+													'name' => $cd_obj->getName(),
+													'calculation_id' => $cd_obj->getCalculation(),
 													'province' => $cd_obj->getProvince(),
 													'district' => $cd_obj->getDistrictName(),
 													'pay_stub_entry_account_id' => $cd_obj->getPayStubEntryAccount(),
 													'include' => $cd_obj->getIncludePayStubEntryAccount(),
 													'exclude' => $cd_obj->getExcludePayStubEntryAccount(),
 													'user_ids' => $cd_obj->getUser(),
+													'company_value1' => $cd_obj->getCompanyValue1(),
 													'user_value1' => $cd_obj->getUserValue1(),
+													'user_value5' => $cd_obj->getUserValue5(), //District
 												);
 					}
+					//Debug::Arr($tax_deductions, 'Tax Deductions: ', __FILE__, __LINE__, __METHOD__,10);
 				}
 
 				if ( isset($raw_rows) ) {
-					$ulf = new UserListFactory();
+					$ulf = TTnew( 'UserListFactory' );
 
 					$x=0;
 					foreach($raw_rows as $user_id => $raw_row) {
@@ -255,24 +260,34 @@ switch ($action) {
 						//FIXME: Loop through each raw_row pay stub account IDs, and match them to tax deductions
 						//that way if a user is removed from a tax deduction half way through the year it will
 						//still match up, assuming it isn't deleted.
+						//If an employee has worked in more than 2 states or localities, issue multiple W2's.
+						//**Need to make sure we split up the earnings proper between states/localities when the employees switch between them.
+						// Adam from DiscipleM??? requested this feature.
 						if ( isset($tax_deductions) ) {
 							foreach( $tax_deductions as $tax_deduction_arr ) {
 								if ( isset($tax_deduction_arr['user_ids']) AND is_array($tax_deduction_arr['user_ids']) AND in_array( $user_id, $tax_deduction_arr['user_ids'] ) ) {
 									//Debug::Arr($tax_deduction_arr, 'Tax / Deduction Data: ', __FILE__, __LINE__, __METHOD__,10);
 									Debug::Text('Found User ID: '. $user_id .' in Tax Deduction ID: '. $tax_deduction_arr['id'] .' Pay Stub Entry Account ID: '. $tax_deduction_arr['pay_stub_entry_account_id'], __FILE__, __LINE__, __METHOD__,10);
 
-									if ( $tax_deduction_arr['province'] != '' AND $tax_deduction_arr['district'] == '' ) {
+									//if ( $tax_deduction_arr['province'] != '' AND $tax_deduction_arr['district'] == '' AND $tax_deduction_arr['user_value5'] == '' ) {
+									if ( $tax_deduction_arr['calculation_id'] == 200 AND $tax_deduction_arr['province'] != '' ) {
 										//State Wages/Taxes
 										//Handle two states here, just check if $tmp_rows[$x]['state_1'] isset,
 										//if it is, move on to state 2.
 										$tmp_rows[$x]['state_1'] = $tax_deduction_arr['province'];
 										$tmp_rows[$x]['state_wage_1'] = Misc::MoneyFormat( Misc::sumMultipleColumns( $raw_rows[$user_id], $tax_deduction_arr['include'] ), FALSE );
 										$tmp_rows[$x]['state_tax_1'] = Misc::MoneyFormat( Misc::sumMultipleColumns( $raw_rows[$user_id], array($tax_deduction_arr['pay_stub_entry_account_id']) ), FALSE );
-									} elseif ( $tax_deduction_arr['province'] != '' AND $tax_deduction_arr['district'] != '' )  {
+									} elseif ( $tax_deduction_arr['calculation_id'] == 300 AND ( $tax_deduction_arr['district'] != '' OR $tax_deduction_arr['company_value1'] != '' ) )  {
 										//District Wages/Taxes
-										$tmp_rows[$x]['district_1'] = $tax_deduction_arr['district'];
+										if ( $tax_deduction_arr['district'] == '' AND $tax_deduction_arr['company_value1'] != '' ) {
+											$tmp_rows[$x]['district_1'] = $tax_deduction_arr['company_value1'];
+										} else {
+											$tmp_rows[$x]['district_1'] = $tax_deduction_arr['district'];
+										}
 										$tmp_rows[$x]['district_wage_1'] = Misc::MoneyFormat( Misc::sumMultipleColumns( $raw_rows[$user_id], $tax_deduction_arr['include'] ), FALSE );
 										$tmp_rows[$x]['district_tax_1'] = Misc::MoneyFormat( Misc::sumMultipleColumns( $raw_rows[$user_id], array($tax_deduction_arr['pay_stub_entry_account_id']) ), FALSE );
+									} else {
+										//Debug::Text('Not State or Local income tax: '. $tax_deduction_arr['id'] .' Calculation: '. $tax_deduction_arr['calculation_id'] .' District: '. $tax_deduction_arr['district'] .' UserValue5: '.$tax_deduction_arr['user_value5'] .' CompanyValue1: '. $tax_deduction_arr['company_value1'], __FILE__, __LINE__, __METHOD__,10);
 									}
 								} else {
 									Debug::Text('DID NOT Find user in Tax Deduction ID: '. $tax_deduction_arr['id'], __FILE__, __LINE__, __METHOD__,10);
@@ -315,7 +330,7 @@ switch ($action) {
 				Debug::Text('Generating PDF: ', __FILE__, __LINE__, __METHOD__,10);
 
 				//Get company information
-				$clf = new CompanyListFactory();
+				$clf = TTnew( 'CompanyListFactory' );
 				$company_obj = $clf->getById( $current_company->getId() )->getCurrent();
 
 				$border = 0;
@@ -338,9 +353,9 @@ switch ($action) {
 
 				//Form year
 				if ( $show_background == TRUE ) {
-					$pdf->SetFont('freeserif','', 22);
+					$pdf->SetFont('freeserif','', 18);
 					$pdf->setFillColor( 255,255,255 );
-					$pdf->setXY( 135, 155 );
+					$pdf->setXY( 135, 154 );
 					$pdf->Cell(20,7, $filter_data['year'], $border, 1, 'C', 1);
 
 					$pdf->SetFont('freeserif','', 10);
@@ -528,7 +543,7 @@ switch ($action) {
 						if ( $i == $last_row ) {
 							continue;
 						}
-						$ulf = new UserListFactory();
+						$ulf = TTnew( 'UserListFactory' );
 						$user_obj = $ulf->getById( $row['user_id'] )->getCurrent();
 
 						$pdf->AddPage();
@@ -861,7 +876,7 @@ switch ($action) {
 		}
 		$filter_data = Misc::preSetArrayValues( $filter_data, array('include_user_ids', 'exclude_user_ids', 'user_status_ids', 'group_ids', 'branch_ids', 'department_ids', 'user_title_ids', 'pay_period_ids', 'column_ids' ), NULL );
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$all_array_option = array('-1' => TTi18n::gettext('-- All --'));
 
 		//Get include employee list.
@@ -882,34 +897,34 @@ switch ($action) {
 		$filter_data['selected_user_status_options'] = Misc::arrayIntersectByKey( (array)$filter_data['user_status_ids'], $user_status_options );
 
 		//Get Employee Groups
-		$uglf = new UserGroupListFactory();
+		$uglf = TTnew( 'UserGroupListFactory' );
 		$group_options = Misc::prependArray( $all_array_option, $uglf->getArrayByNodes( FastTree::FormatArray( $uglf->getByCompanyIdArray( $current_company->getId() ), 'TEXT', TRUE) ) );
 		$filter_data['src_group_options'] = Misc::arrayDiffByKey( (array)$filter_data['group_ids'], $group_options );
 		$filter_data['selected_group_options'] = Misc::arrayIntersectByKey( (array)$filter_data['group_ids'], $group_options );
 
 		//Get branches
-		$blf = new BranchListFactory();
+		$blf = TTnew( 'BranchListFactory' );
 		$blf->getByCompanyId( $current_company->getId() );
 		$branch_options = Misc::prependArray( $all_array_option, $blf->getArrayByListFactory( $blf, FALSE, TRUE ) );
 		$filter_data['src_branch_options'] = Misc::arrayDiffByKey( (array)$filter_data['branch_ids'], $branch_options );
 		$filter_data['selected_branch_options'] = Misc::arrayIntersectByKey( (array)$filter_data['branch_ids'], $branch_options );
 
 		//Get departments
-		$dlf = new DepartmentListFactory();
+		$dlf = TTnew( 'DepartmentListFactory' );
 		$dlf->getByCompanyId( $current_company->getId() );
 		$department_options = Misc::prependArray( $all_array_option, $dlf->getArrayByListFactory( $dlf, FALSE, TRUE ) );
 		$filter_data['src_department_options'] = Misc::arrayDiffByKey( (array)$filter_data['department_ids'], $department_options );
 		$filter_data['selected_department_options'] = Misc::arrayIntersectByKey( (array)$filter_data['department_ids'], $department_options );
 
 		//Get employee titles
-		$utlf = new UserTitleListFactory();
+		$utlf = TTnew( 'UserTitleListFactory' );
 		$utlf->getByCompanyId( $current_company->getId() );
 		$user_title_options = Misc::prependArray( $all_array_option, $utlf->getArrayByListFactory( $utlf, FALSE, TRUE ) );
 		$filter_data['src_user_title_options'] = Misc::arrayDiffByKey( (array)$filter_data['user_title_ids'], $user_title_options );
 		$filter_data['selected_user_title_options'] = Misc::arrayIntersectByKey( (array)$filter_data['user_title_ids'], $user_title_options );
 
 		//PSEA accounts
-		$psealf = new PayStubEntryAccountListFactory();
+		$psealf = TTnew( 'PayStubEntryAccountListFactory' );
 		$filter_data['pay_stub_entry_account_options'] = $psealf->getByCompanyIdAndStatusIdAndTypeIdArray( $current_company->getId(), 10, array(10,20,30,40), TRUE );
 
 		//Get column list
@@ -924,7 +939,7 @@ switch ($action) {
 		$filter_data['sort_direction_options'] = Misc::getSortDirectionArray();
 
 		//Get a unique list of states each employee belongs to
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$ulf->getByCompanyId( $current_company->getId() );
 		if ( $ulf->getRecordCount() > 0 ) {
 			foreach( $ulf as $u_obj ) {
