@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3891 $
- * $Id: GeneralLedgerSummary.php 3891 2010-10-12 22:23:20Z ipso $
- * $Date: 2010-10-12 15:23:20 -0700 (Tue, 12 Oct 2010) $
+ * $Revision: 4104 $
+ * $Id: GeneralLedgerSummary.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -90,7 +90,7 @@ $static_columns = array(
 
 //$static_columns = array();
 
-$psealf = new PayStubEntryAccountListFactory();
+$psealf = TTnew( 'PayStubEntryAccountListFactory' );
 /*
 
 $psen_columns = $psealf->getByCompanyIdAndStatusIdAndTypeIdArray( $current_company->getId(), 10, array(10,20,30,40,50,60,65), FALSE );
@@ -103,20 +103,20 @@ $psen_columns = array();
 $columns = $static_columns;
 
 //Get all pay periods
-$pplf = new PayPeriodListFactory();
+$pplf = TTnew( 'PayPeriodListFactory' );
 $pplf->getByCompanyId( $current_company->getId() );
 if ( $pplf->getRecordCount() > 0 ) {
 	foreach ($pplf as $pay_period_obj) {
 		$pay_period_ids[] = $pay_period_obj->getId();
 	}
-	$pplf = new PayPeriodListFactory();
+	$pplf = TTnew( 'PayPeriodListFactory' );
 	$pay_period_options = $pplf->getByIdListArray($pay_period_ids, NULL, array('start_date' => 'desc'));
 }
 
 $filter_data = Misc::preSetArrayValues( $filter_data, array('include_user_ids', 'exclude_user_ids', 'user_status_ids', 'group_ids', 'branch_ids', 'department_ids', 'user_title_ids', 'pay_period_ids', 'currency_ids', 'column_ids' ), array() );
 
-$ugdlf = new UserGenericDataListFactory();
-$ugdf = new UserGenericDataFactory();
+$ugdlf = TTnew( 'UserGenericDataListFactory' );
+$ugdf = TTnew( 'UserGenericDataFactory' );
 
 $action = Misc::findSubmitButton();
 
@@ -128,7 +128,7 @@ switch ($action) {
 		Debug::Text('Submit!', __FILE__, __LINE__, __METHOD__,10);
 		//Debug::Arr($filter_data, 'aFilter Data', __FILE__, __LINE__, __METHOD__,10);
 /*
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$ulf->getSearchByCompanyIdAndArrayCriteria( $current_company->getId(), $filter_data );
 		if ( $ulf->getRecordCount() > 0 ) {
 			foreach( $ulf as $u_obj ) {
@@ -154,7 +154,7 @@ switch ($action) {
 				//var_dump($report_columns);
 				$report_columns = Misc::prependArray( $static_columns, $report_columns);
 
-				$psealf = new PayStubEntryAccountListFactory();
+				$psealf = TTnew( 'PayStubEntryAccountListFactory' );
 				$psealf->getByCompanyId( $current_company->getId() );
 				if ( $psealf->getRecordCount() > 0 ) {
 					foreach($psealf as $psea_obj) {
@@ -168,14 +168,14 @@ switch ($action) {
 				//var_dump($psea_arr);
 
 				//Get all pay stubs.
-				$pslf = new PayStubListFactory();
+				$pslf = TTnew( 'PayStubListFactory' );
 				//$pslf->getByUserIdAndCompanyIdAndPayPeriodId( $filter_data['user_ids'], $current_company->getId(), $filter_data['pay_period_ids'] );
 				$pslf->getSearchByCompanyIdAndArrayCriteria( $current_company->getId(), $filter_data );
 
 				if ( $pslf->getRecordCount() > 0 ) {
-					$ulf = new UserListFactory();
+					$ulf = TTnew( 'UserListFactory' );
 
-					$blf = new BranchListFactory();
+					$blf = TTnew( 'BranchListFactory' );
 					$branch_options = $blf->getByCompanyIdArray( $current_company->getId() );
 
 					//Get Branch ID to Branch Code mapping
@@ -187,7 +187,7 @@ switch ($action) {
 						}
 					}
 
-					$dlf = new DepartmentListFactory();
+					$dlf = TTnew( 'DepartmentListFactory' );
 					$department_options = $dlf->getByCompanyIdArray( $current_company->getId() );
 
 					//Get Department ID to Branch Code mapping
@@ -199,10 +199,10 @@ switch ($action) {
 						}
 					}
 
-					$utlf = new UserTitleListFactory();
+					$utlf = TTnew( 'UserTitleListFactory' );
 					$title_options = $utlf->getByCompanyIdArray( $current_company->getId() );
 
-					$crlf = new CurrencyListFactory();
+					$crlf = TTnew( 'CurrencyListFactory' );
 					$crlf->getByCompanyId( $current_company->getId() );
 					$currency_options = $crlf->getArrayByListFactory( $crlf, FALSE, TRUE );
 
@@ -226,7 +226,7 @@ switch ($action) {
 						$je_records = NULL;
 
 						//Get all PS Entries for this pay stub.
-						$pself = new PayStubEntryListFactory();
+						$pself = TTnew( 'PayStubEntryListFactory' );
 						//$pself->getByPayStubId( $ps_obj->getId() );
 						$pself->getByPayStubIdAndYTDAdjustment( $ps_obj->getId(), FALSE ); //Skip any YTD adjustments, as they aren't needed in the GL
 						if ( $pself->getRecordCount() > 0 ) {
@@ -532,7 +532,7 @@ switch ($action) {
 
 				$default_columns = array( 5 => '-1000-full_name' );
 
-				$pseallf = new PayStubEntryAccountLinkListFactory();
+				$pseallf = TTnew( 'PayStubEntryAccountLinkListFactory' );
 				$pseallf->getByCompanyId( $current_company->getId() );
 				if ( $pseallf->getRecordCount() > 0 ) {
 					$pseal_obj = $pseallf->getCurrent();
@@ -555,7 +555,7 @@ switch ($action) {
 		}
 		$filter_data = Misc::preSetArrayValues( $filter_data, array('include_user_ids', 'exclude_user_ids', 'user_status_ids', 'group_ids', 'branch_ids', 'department_ids', 'user_title_ids', 'pay_period_ids', 'currency_ids', 'column_ids' ), NULL );
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$all_array_option = array('-1' => TTi18n::gettext('-- All --'));
 
 		//Get include employee list.
@@ -576,41 +576,41 @@ switch ($action) {
 		$filter_data['selected_user_status_options'] = Misc::arrayIntersectByKey( (array)$filter_data['user_status_ids'], $user_status_options );
 
 		//Get Employee Groups
-		$uglf = new UserGroupListFactory();
+		$uglf = TTnew( 'UserGroupListFactory' );
 		$group_options = Misc::prependArray( $all_array_option, $uglf->getArrayByNodes( FastTree::FormatArray( $uglf->getByCompanyIdArray( $current_company->getId() ), 'TEXT', TRUE) ) );
 		$filter_data['src_group_options'] = Misc::arrayDiffByKey( (array)$filter_data['group_ids'], $group_options );
 		$filter_data['selected_group_options'] = Misc::arrayIntersectByKey( (array)$filter_data['group_ids'], $group_options );
 
 		//Get branches
-		$blf = new BranchListFactory();
+		$blf = TTnew( 'BranchListFactory' );
 		$blf->getByCompanyId( $current_company->getId() );
 		$branch_options = Misc::prependArray( $all_array_option, $blf->getArrayByListFactory( $blf, FALSE, TRUE ) );
 		$filter_data['src_branch_options'] = Misc::arrayDiffByKey( (array)$filter_data['branch_ids'], $branch_options );
 		$filter_data['selected_branch_options'] = Misc::arrayIntersectByKey( (array)$filter_data['branch_ids'], $branch_options );
 
 		//Get departments
-		$dlf = new DepartmentListFactory();
+		$dlf = TTnew( 'DepartmentListFactory' );
 		$dlf->getByCompanyId( $current_company->getId() );
 		$department_options = Misc::prependArray( $all_array_option, $dlf->getArrayByListFactory( $dlf, FALSE, TRUE ) );
 		$filter_data['src_department_options'] = Misc::arrayDiffByKey( (array)$filter_data['department_ids'], $department_options );
 		$filter_data['selected_department_options'] = Misc::arrayIntersectByKey( (array)$filter_data['department_ids'], $department_options );
 
 		//Get employee titles
-		$utlf = new UserTitleListFactory();
+		$utlf = TTnew( 'UserTitleListFactory' );
 		$utlf->getByCompanyId( $current_company->getId() );
 		$user_title_options = Misc::prependArray( $all_array_option, $utlf->getArrayByListFactory( $utlf, FALSE, TRUE ) );
 		$filter_data['src_user_title_options'] = Misc::arrayDiffByKey( (array)$filter_data['user_title_ids'], $user_title_options );
 		$filter_data['selected_user_title_options'] = Misc::arrayIntersectByKey( (array)$filter_data['user_title_ids'], $user_title_options );
 
 		//Get pay periods
-		$pplf = new PayPeriodListFactory();
+		$pplf = TTnew( 'PayPeriodListFactory' );
 		$pplf->getByCompanyId( $current_company->getId() );
 		$pay_period_options = Misc::prependArray( $all_array_option, $pplf->getArrayByListFactory( $pplf, FALSE, TRUE ) );
 		$filter_data['src_pay_period_options'] = Misc::arrayDiffByKey( (array)$filter_data['pay_period_ids'], $pay_period_options );
 		$filter_data['selected_pay_period_options'] = Misc::arrayIntersectByKey( (array)$filter_data['pay_period_ids'], $pay_period_options );
 
 		//Get currencies
-		$crlf = new CurrencyListFactory();
+		$crlf = TTnew( 'CurrencyListFactory' );
 		$crlf->getByCompanyId( $current_company->getId() );
 		$currency_options = Misc::prependArray( $all_array_option, $crlf->getArrayByListFactory( $crlf, FALSE, TRUE ) );
 		$filter_data['src_currency_options'] = Misc::arrayDiffByKey( (array)$filter_data['currency_ids'], $currency_options );
