@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2194 $
- * $Id: GenericTaxSummary.php 2194 2008-10-13 19:04:04Z ipso $
- * $Date: 2008-10-13 12:04:04 -0700 (Mon, 13 Oct 2008) $
+ * $Revision: 4258 $
+ * $Id: GenericTaxSummary.php 4258 2011-02-16 20:46:59Z ipso $
+ * $Date: 2011-02-16 12:46:59 -0800 (Wed, 16 Feb 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -81,7 +81,6 @@ $static_columns = array(
 											'-1040-default_branch' => TTi18n::gettext('Default Branch'),
 											'-1050-default_department' => TTi18n::gettext('Default Department'),
 											'-1060-transaction_date' => TTi18n::gettext('Transaction Date'),
-
 											);
 
 $columns = array(
@@ -102,8 +101,8 @@ if ( isset($filter_data['end_date']) ) {
 
 $filter_data = Misc::preSetArrayValues( $filter_data, array('company_deduction_ids', 'include_user_ids', 'exclude_user_ids', 'user_status_ids', 'group_ids', 'branch_ids', 'department_ids', 'user_title_ids', 'pay_period_ids', 'column_ids' ), array() );
 
-$ugdlf = new UserGenericDataListFactory();
-$ugdf = new UserGenericDataFactory();
+$ugdlf = TTnew( 'UserGenericDataListFactory' );
+$ugdf = TTnew( 'UserGenericDataFactory' );
 
 $action = Misc::findSubmitButton();
 
@@ -115,17 +114,17 @@ switch ($action) {
 		Debug::Text('Submit! Action: '. $action, __FILE__, __LINE__, __METHOD__,10);
 		//Debug::Arr($filter_data, 'aFilter Data', __FILE__, __LINE__, __METHOD__,10);
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$ulf->getSearchByCompanyIdAndArrayCriteria( $current_company->getId(), $filter_data );
 		if ( $ulf->getRecordCount() > 0 ) {
 			//Get total gross pay stub account IDs
-			$cdf = new CompanyDeductionFactory();
+			$cdf = TTnew( 'CompanyDeductionFactory' );
 			$cdf->setCompany( $current_company->getId() );
 			$total_gross_psea_ids = $cdf->getExpandedPayStubEntryAccountIDs( $cdf->getPayStubEntryAccountLinkObject()->getTotalGross() );
 			//var_dump($total_gross_psea_ids);
 
 			//Get include/exclude IDs for company deduction.
-			$cdlf = new CompanyDeductionListFactory();
+			$cdlf = TTnew( 'CompanyDeductionListFactory' );
 			$cdlf->getByCompanyIdAndId( $current_company->getId(), $filter_data['company_deduction_ids'] );
 			if ( $cdlf->getRecordCount() > 0 ) {
 				$taxable_wages_psea_ids = array();
@@ -146,7 +145,7 @@ switch ($action) {
 			}
 
 			//Get all pay periods by transaction start/end date
-			$pplf = new PayPeriodListFactory();
+			$pplf = TTnew( 'PayPeriodListFactory' );
 			$pplf->getByCompanyIdAndTransactionStartDateAndTransactionEndDate( $current_company->getId(), $filter_data['start_date'], $filter_data['end_date']);
 			if ( $pplf->getRecordCount() > 0 ) {
 				foreach( $pplf as $pp_obj ) {
@@ -158,7 +157,7 @@ switch ($action) {
 			if ( isset($pay_period_ids) AND isset($filter_data['user_ids']) ) {
 				//Get column headers
 				/*
-				$psealf = new PayStubEntryAccountListFactory();
+				$psealf = TTnew( 'PayStubEntryAccountListFactory' );
 				$psealf->getByCompanyId( $current_company->getId() );
 				foreach($psealf as $psea_obj) {
 					//$report_columns[$psen_obj->getId()] = $psen_obj->getDescription();
@@ -169,7 +168,7 @@ switch ($action) {
 				$report_columns = Misc::prependArray( $static_columns, $report_columns);
 				*/
 
-				$pself = new PayStubEntryListFactory();
+				$pself = TTnew( 'PayStubEntryListFactory' );
 				$pself->getDateReportByCompanyIdAndUserIdAndPayPeriodId( $current_company->getId(), $filter_data['user_ids'], $pay_period_ids );
 
 				//Prepare data for regular report.
@@ -184,18 +183,18 @@ switch ($action) {
 				//var_dump($raw_rows);
 
 				if ( isset($raw_rows) ) {
-					$ulf = new UserListFactory();
+					$ulf = TTnew( 'UserListFactory' );
 
-					$utlf = new UserTitleListFactory();
+					$utlf = TTnew( 'UserTitleListFactory' );
 					$title_options = $utlf->getByCompanyIdArray( $current_company->getId() );
 
-					$uglf = new UserGroupListFactory();
+					$uglf = TTnew( 'UserGroupListFactory' );
 					$group_options = $uglf->getArrayByNodes( FastTree::FormatArray( $uglf->getByCompanyIdArray( $current_company->getId() ), 'no_tree_text', TRUE) );
 
-					$blf = new BranchListFactory();
+					$blf = TTnew( 'BranchListFactory' );
 					$branch_options = $blf->getByCompanyIdArray( $current_company->getId() );
 
-					$dlf = new DepartmentListFactory();
+					$dlf = TTnew( 'DepartmentListFactory' );
 					$department_options = $dlf->getByCompanyIdArray( $current_company->getId() );
 
 
@@ -207,20 +206,15 @@ switch ($action) {
 
 							if ( $filter_data['transaction_date_format'] == 20 ) {
 								$transaction_date_display = date('m', $transaction_date).' - '.date('F', $transaction_date);
-								//$transaction_date_order = date('m', $transaction_date);
 							} elseif ( $filter_data['transaction_date_format'] == 30 ) { //Quarter
 								$transaction_date_display = 'Quarter '.ceil( date('m', $transaction_date) / 3);
-								//$transaction_date_order = $transaction_date_display;
 							} elseif ( $filter_data['transaction_date_format'] == 40 ) { //Year
 								$transaction_date_display = date('Y', $transaction_date);
-								//$transaction_date_order = $transaction_date_display;
 							} else {
 								$transaction_date_display = TTDate::getDate('DATE', $transaction_date);
-								//$transaction_date_order = $transaction_date;
 							}
 
 							$tmp_rows[$x]['transaction_date'] = $transaction_date_display;
-							//$tmp_rows[$x]['transaction_date_order'] = $transaction_date_order;
 							$tmp_rows[$x]['user_id'] = $user_id;
 							$tmp_rows[$x]['full_name'] = $user_obj->getFullName(TRUE);
 							//$tmp_rows[$x]['province'] = Option::getByKey($user_obj->getProvince(), $user_obj->getCompanyObject()->getOptions('province', $user_obj->getCountry() ) );
@@ -245,20 +239,20 @@ switch ($action) {
 							$tax_withheld_amount = 0;
 							foreach($raw_row_b as $pay_stub_entry_name_id => $amount ) {
 								if ( isset($total_gross_psea_ids) AND is_array($total_gross_psea_ids) AND in_array($pay_stub_entry_name_id, $total_gross_psea_ids ) ) {
-									//Debug::Text('Total Amount: '. $amount, __FILE__, __LINE__, __METHOD__,10);
+									//Debug::Text('Total Gross Amount: '. $amount, __FILE__, __LINE__, __METHOD__,10);
 									$total_gross_amount += $amount;
 								}
 
 								if ( isset($taxable_wages_psea_ids) AND is_array($taxable_wages_psea_ids) AND in_array($pay_stub_entry_name_id, $taxable_wages_psea_ids ) ) {
-									Debug::Text('Total Amount: '. $amount, __FILE__, __LINE__, __METHOD__,10);
+									//Debug::Text('Total Taxable Wages Amount: '. $amount, __FILE__, __LINE__, __METHOD__,10);
 									$taxable_wages_amount += $amount;
 								}
 
 								if ( isset($tax_withheld_psea_ids) AND is_array($tax_withheld_psea_ids) AND in_array($pay_stub_entry_name_id, $tax_withheld_psea_ids ) ) {
-									//Debug::Text('Total Amount: '. $amount, __FILE__, __LINE__, __METHOD__,10);
+									//Debug::Text('Total Tax Withheld Amount: '. $amount, __FILE__, __LINE__, __METHOD__,10);
 									$tax_withheld_amount += $amount;
 								}
-
+								//Debug::Text('Total: Gross: '. $total_gross_amount  .'  Taxable Wages: '. $taxable_wages_amount .' Tax Withheld: '. $tax_withheld_amount .' Amount: '. $amount, __FILE__, __LINE__, __METHOD__,10);
 								//$tmp_rows[$x][$pay_stub_entry_name_id] = $amount;
 							}
 							unset($$pay_stub_entry_name_id, $amount);
@@ -267,7 +261,6 @@ switch ($action) {
 							$tmp_rows[$x]['taxable_wages'] = Misc::MoneyFormat( $taxable_wages_amount, FALSE );
 							$tmp_rows[$x]['tax_withheld'] = Misc::MoneyFormat( $tax_withheld_amount, FALSE );
 
-
 							$x++;
 						}
 					}
@@ -394,7 +387,7 @@ switch ($action) {
 		}
 		$filter_data = Misc::preSetArrayValues( $filter_data, array('company_deduction_ids', 'include_user_ids', 'exclude_user_ids', 'user_status_ids', 'group_ids', 'branch_ids', 'department_ids', 'user_title_ids', 'pay_period_ids', 'column_ids' ), NULL );
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$all_array_option = array('-1' => TTi18n::gettext('-- All --'));
 
 		//Get include employee list.
@@ -415,34 +408,34 @@ switch ($action) {
 		$filter_data['selected_user_status_options'] = Misc::arrayIntersectByKey( (array)$filter_data['user_status_ids'], $user_status_options );
 
 		//Get Employee Groups
-		$uglf = new UserGroupListFactory();
+		$uglf = TTnew( 'UserGroupListFactory' );
 		$group_options = Misc::prependArray( $all_array_option, $uglf->getArrayByNodes( FastTree::FormatArray( $uglf->getByCompanyIdArray( $current_company->getId() ), 'TEXT', TRUE) ) );
 		$filter_data['src_group_options'] = Misc::arrayDiffByKey( (array)$filter_data['group_ids'], $group_options );
 		$filter_data['selected_group_options'] = Misc::arrayIntersectByKey( (array)$filter_data['group_ids'], $group_options );
 
 		//Get branches
-		$blf = new BranchListFactory();
+		$blf = TTnew( 'BranchListFactory' );
 		$blf->getByCompanyId( $current_company->getId() );
 		$branch_options = Misc::prependArray( $all_array_option, $blf->getArrayByListFactory( $blf, FALSE, TRUE ) );
 		$filter_data['src_branch_options'] = Misc::arrayDiffByKey( (array)$filter_data['branch_ids'], $branch_options );
 		$filter_data['selected_branch_options'] = Misc::arrayIntersectByKey( (array)$filter_data['branch_ids'], $branch_options );
 
 		//Get departments
-		$dlf = new DepartmentListFactory();
+		$dlf = TTnew( 'DepartmentListFactory' );
 		$dlf->getByCompanyId( $current_company->getId() );
 		$department_options = Misc::prependArray( $all_array_option, $dlf->getArrayByListFactory( $dlf, FALSE, TRUE ) );
 		$filter_data['src_department_options'] = Misc::arrayDiffByKey( (array)$filter_data['department_ids'], $department_options );
 		$filter_data['selected_department_options'] = Misc::arrayIntersectByKey( (array)$filter_data['department_ids'], $department_options );
 
 		//Get employee titles
-		$utlf = new UserTitleListFactory();
+		$utlf = TTnew( 'UserTitleListFactory' );
 		$utlf->getByCompanyId( $current_company->getId() );
 		$user_title_options = Misc::prependArray( $all_array_option, $utlf->getArrayByListFactory( $utlf, FALSE, TRUE ) );
 		$filter_data['src_user_title_options'] = Misc::arrayDiffByKey( (array)$filter_data['user_title_ids'], $user_title_options );
 		$filter_data['selected_user_title_options'] = Misc::arrayIntersectByKey( (array)$filter_data['user_title_ids'], $user_title_options );
 
 		//Get Company Tax Deductions
-		$cdlf = new CompanyDeductionListFactory();
+		$cdlf = TTnew( 'CompanyDeductionListFactory' );
 		$cdlf->getByCompanyIdAndTypeId( $current_company->getId(), 10 );
 		//$company_deduction_options = Misc::prependArray( $all_array_option, $cdlf->getArrayByListFactory( $cdlf, FALSE, TRUE ) );
 		$company_deduction_options = $cdlf->getArrayByListFactory( $cdlf, FALSE, TRUE );
