@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2838 $
- * $Id: PayStubSummary.php 2838 2009-09-18 20:57:41Z ipso $
- * $Date: 2009-09-18 13:57:41 -0700 (Fri, 18 Sep 2009) $
+ * $Revision: 4600 $
+ * $Id: PayStubSummary.php 4600 2011-04-28 21:35:12Z ipso $
+ * $Date: 2011-04-28 14:35:12 -0700 (Thu, 28 Apr 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -95,7 +95,7 @@ $static_columns = array(
 							'-1131-current_currency' => TTi18n::gettext('Current Currency'),
 							);
 
-$psealf = new PayStubEntryAccountListFactory();
+$psealf = TTnew( 'PayStubEntryAccountListFactory' );
 $psen_columns = $psealf->getByCompanyIdAndStatusIdAndTypeIdArray( $current_company->getId(), 10, array(10,20,30,40,50,60,65), FALSE );
 
 $columns = Misc::prependArray( $static_columns, $psen_columns);
@@ -104,7 +104,7 @@ $default_transaction_start_date = TTDate::getBeginMonthEpoch( time() );
 $default_transaction_end_date = TTDate::getEndMonthEpoch( time() );
 
 //Get all pay periods
-$pplf = new PayPeriodListFactory();
+$pplf = TTnew( 'PayPeriodListFactory' );
 $pplf->getPayPeriodsWithPayStubsByCompanyId( $current_company->getId() );
 $pay_period_options = array();
 if ( $pplf->getRecordCount() > 0 ) {
@@ -119,7 +119,7 @@ if ( $pplf->getRecordCount() > 0 ) {
 		}
 		$pp++;
 	}
-	$pplf = new PayPeriodListFactory();
+	$pplf = TTnew( 'PayPeriodListFactory' );
 	$pay_period_options = $pplf->getByIdListArray($pay_period_ids, NULL, array('start_date' => 'desc'));
 }
 
@@ -136,7 +136,7 @@ $filter_data = Misc::preSetArrayValues( $filter_data, array('include_user_ids',
 //Get Permission Hierarchy Children first, as this can be used for viewing, or editing.
 $permission_children_ids = array();
 if ( $permission->Check('pay_stub','view') == FALSE ) {
-	$hlf = new HierarchyListFactory();
+	$hlf = TTnew( 'HierarchyListFactory' );
 	$permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId() );
 	Debug::Arr($permission_children_ids,'Permission Children Ids:', __FILE__, __LINE__, __METHOD__,10);
 
@@ -150,8 +150,8 @@ if ( $permission->Check('pay_stub','view') == FALSE ) {
 	$filter_data['permission_children_ids'] = $permission_children_ids;
 }
 
-$ugdlf = new UserGenericDataListFactory();
-$ugdf = new UserGenericDataFactory();
+$ugdlf = TTnew( 'UserGenericDataListFactory' );
+$ugdf = TTnew( 'UserGenericDataFactory' );
 
 $action = Misc::findSubmitButton();
 switch ($action) {
@@ -163,7 +163,7 @@ switch ($action) {
 		Debug::Text('Submit! Action: '. $action, __FILE__, __LINE__, __METHOD__,10);
 		//Debug::Arr($filter_data, 'aFilter Data', __FILE__, __LINE__, __METHOD__,10);
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$ulf->getSearchByCompanyIdAndArrayCriteria( $current_company->getId(), $filter_data );
 		if ( $ulf->getRecordCount() > 0 ) {
 			if ( isset($filter_data['date_type']) AND $filter_data['date_type'] == 'pay_period_ids' ) {
@@ -192,7 +192,7 @@ switch ($action) {
 				if ( $action == 'view_pay_stubs' ) {
 					Debug::Text('View Pay Stubs!', __FILE__, __LINE__, __METHOD__,10);
 
-					$pslf = new PayStubListFactory();
+					$pslf = TTnew( 'PayStubListFactory' );
 					//$pslf->getByUserIdAndCompanyIdAndPayPeriodId( $filter_data['user_ids'], $current_company->getId(), $filter_data['pay_period_ids']);
 					$pslf->getSearchByCompanyIdAndArrayCriteria( $current_company->getId(), $filter_data );
 					if ( $pslf->getRecordCount() > 0 ) {
@@ -212,7 +212,7 @@ switch ($action) {
 				} elseif ( $action == 'export' AND $filter_data['export_type'] != 'csv' ) {
 					Debug::Text('Export NON-CSV', __FILE__, __LINE__, __METHOD__,10);
 
-					$pslf = new PayStubListFactory();
+					$pslf = TTnew( 'PayStubListFactory' );
 					//$pslf->getByUserIdAndCompanyIdAndPayPeriodId( $filter_data['user_ids'], $current_company->getId(), $filter_data['pay_period_ids']);
 					$pslf->getSearchByCompanyIdAndArrayCriteria( $current_company->getId(), $filter_data );
 					if ( $pslf->getRecordCount() > 0 AND strlen($filter_data['export_type']) >= 3) {
@@ -222,7 +222,22 @@ switch ($action) {
 							if ( stristr( $filter_data['export_type'], 'cheque') ) {
 								Misc::FileDownloadHeader('checks_'. str_replace(array('/',',',' '), '_', TTDate::getDate('DATE', time() ) ) .'.pdf', 'application/pdf', strlen($output));
 							} else {
-								Misc::FileDownloadHeader('eft_'. str_replace(array('/',',',' '), '_', TTDate::getDate('DATE', time() ) ) .'.txt', 'application/text', strlen($output));
+
+								//Include file creation number in the exported file name, so the user knows what it is without opening the file,
+								//and can generate multiple files if they need to match a specific number.
+								$ugdlf = TTnew( 'UserGenericDataListFactory' );
+								$ugdlf->getByCompanyIdAndScriptAndDefault( $current_company->getId(), 'PayStubFactory', TRUE );
+								if ( $ugdlf->getRecordCount() > 0 ) {
+									$ugd_obj = $ugdlf->getCurrent();
+									$setup_data = $ugd_obj->getData();
+								}
+
+								if ( isset($setup_data) ) {
+									$file_creation_number = $setup_data['file_creation_number']++;
+								} else {
+									$file_creation_number = 0;
+								}
+								Misc::FileDownloadHeader('eft_'. $file_creation_number .'_'. str_replace(array('/',',',' '), '_', TTDate::getDate('DATE', time() ) ) .'.txt', 'application/text', strlen($output));
 							}
 
 							if ( $output != FALSE ) {
@@ -250,7 +265,7 @@ switch ($action) {
 
 					$report_columns = Misc::prependArray( $static_columns, $report_columns);
 
-					$pself = new PayStubEntryListFactory();
+					$pself = TTnew( 'PayStubEntryListFactory' );
 					$pself->getReportByCompanyIdAndArrayCriteria( $current_company->getId(), $filter_data );
 					if ( $pself->getRecordCount() > 0 ) {
 						//Prepare data for regular report.
@@ -280,21 +295,21 @@ switch ($action) {
 					//var_dump($raw_rows);
 
 					if ( isset($raw_rows) ) {
-						$ulf = new UserListFactory();
+						$ulf = TTnew( 'UserListFactory' );
 
-						$utlf = new UserTitleListFactory();
+						$utlf = TTnew( 'UserTitleListFactory' );
 						$title_options = $utlf->getByCompanyIdArray( $current_company->getId() );
 
-						$uglf = new UserGroupListFactory();
+						$uglf = TTnew( 'UserGroupListFactory' );
 						$group_options = $uglf->getArrayByNodes( FastTree::FormatArray( $uglf->getByCompanyIdArray( $current_company->getId() ), 'no_tree_text', TRUE) );
 
-						$blf = new BranchListFactory();
+						$blf = TTnew( 'BranchListFactory' );
 						$branch_options = $blf->getByCompanyIdArray( $current_company->getId() );
 
-						$dlf = new DepartmentListFactory();
+						$dlf = TTnew( 'DepartmentListFactory' );
 						$department_options = $dlf->getByCompanyIdArray( $current_company->getId() );
 
-						$crlf = new CurrencyListFactory();
+						$crlf = TTnew( 'CurrencyListFactory' );
 						$crlf->getByCompanyId( $current_company->getId() );
 						$currency_options = $crlf->getArrayByListFactory( $crlf, FALSE, TRUE );
 
@@ -310,7 +325,7 @@ switch ($action) {
 							$currency_convert_to_base = TRUE;
 						}
 
-						$balf = new BankAccountListFactory();
+						$balf = TTnew( 'BankAccountListFactory' );
 
 						$x=0;
 						foreach($raw_rows as $user_id => $data_b) {
@@ -503,7 +518,7 @@ switch ($action) {
 
 				$default_columns = array( 5 => '-1000-full_name', 6 => '-1090-pay_period' );
 
-				$pseallf = new PayStubEntryAccountLinkListFactory();
+				$pseallf = TTnew( 'PayStubEntryAccountLinkListFactory' );
 				$pseallf->getByCompanyId( $current_company->getId() );
 				if ( $pseallf->getRecordCount() > 0 ) {
 					$pseal_obj = $pseallf->getCurrent();
@@ -525,7 +540,7 @@ switch ($action) {
 		}
 		$filter_data = Misc::preSetArrayValues( $filter_data, array('include_user_ids', 'exclude_user_ids', 'user_status_ids', 'group_ids', 'branch_ids', 'department_ids', 'user_title_ids', 'pay_period_ids', 'currency_ids', 'column_ids' ), NULL );
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$all_array_option = array('-1' => TTi18n::gettext('-- All --'));
 
 		//Get include employee list.
@@ -546,41 +561,41 @@ switch ($action) {
 		$filter_data['selected_user_status_options'] = Misc::arrayIntersectByKey( (array)$filter_data['user_status_ids'], $user_status_options );
 
 		//Get Employee Groups
-		$uglf = new UserGroupListFactory();
+		$uglf = TTnew( 'UserGroupListFactory' );
 		$group_options = Misc::prependArray( $all_array_option, $uglf->getArrayByNodes( FastTree::FormatArray( $uglf->getByCompanyIdArray( $current_company->getId() ), 'TEXT', TRUE) ) );
 		$filter_data['src_group_options'] = Misc::arrayDiffByKey( (array)$filter_data['group_ids'], $group_options );
 		$filter_data['selected_group_options'] = Misc::arrayIntersectByKey( (array)$filter_data['group_ids'], $group_options );
 
 		//Get branches
-		$blf = new BranchListFactory();
+		$blf = TTnew( 'BranchListFactory' );
 		$blf->getByCompanyId( $current_company->getId() );
 		$branch_options = Misc::prependArray( $all_array_option, $blf->getArrayByListFactory( $blf, FALSE, TRUE ) );
 		$filter_data['src_branch_options'] = Misc::arrayDiffByKey( (array)$filter_data['branch_ids'], $branch_options );
 		$filter_data['selected_branch_options'] = Misc::arrayIntersectByKey( (array)$filter_data['branch_ids'], $branch_options );
 
 		//Get departments
-		$dlf = new DepartmentListFactory();
+		$dlf = TTnew( 'DepartmentListFactory' );
 		$dlf->getByCompanyId( $current_company->getId() );
 		$department_options = Misc::prependArray( $all_array_option, $dlf->getArrayByListFactory( $dlf, FALSE, TRUE ) );
 		$filter_data['src_department_options'] = Misc::arrayDiffByKey( (array)$filter_data['department_ids'], $department_options );
 		$filter_data['selected_department_options'] = Misc::arrayIntersectByKey( (array)$filter_data['department_ids'], $department_options );
 
 		//Get employee titles
-		$utlf = new UserTitleListFactory();
+		$utlf = TTnew( 'UserTitleListFactory' );
 		$utlf->getByCompanyId( $current_company->getId() );
 		$user_title_options = Misc::prependArray( $all_array_option, $utlf->getArrayByListFactory( $utlf, FALSE, TRUE ) );
 		$filter_data['src_user_title_options'] = Misc::arrayDiffByKey( (array)$filter_data['user_title_ids'], $user_title_options );
 		$filter_data['selected_user_title_options'] = Misc::arrayIntersectByKey( (array)$filter_data['user_title_ids'], $user_title_options );
 
 		//Get pay periods
-		//$pplf = new PayPeriodListFactory();
+		//$pplf = TTnew( 'PayPeriodListFactory' );
 		//$pplf->getPayPeriodsWithPayStubsByCompanyId( $current_company->getId() );
 		$pay_period_options = Misc::prependArray( $all_array_option, $pplf->getArrayByListFactory( $pplf, FALSE, TRUE ) );
 		$filter_data['src_pay_period_options'] = Misc::arrayDiffByKey( (array)$filter_data['pay_period_ids'], $pay_period_options );
 		$filter_data['selected_pay_period_options'] = Misc::arrayIntersectByKey( (array)$filter_data['pay_period_ids'], $pay_period_options );
 
 		//Get currencies
-		$crlf = new CurrencyListFactory();
+		$crlf = TTnew( 'CurrencyListFactory' );
 		$crlf->getByCompanyId( $current_company->getId() );
 		$currency_options = Misc::prependArray( $all_array_option, $crlf->getArrayByListFactory( $crlf, FALSE, TRUE ) );
 		$filter_data['src_currency_options'] = Misc::arrayDiffByKey( (array)$filter_data['currency_ids'], $currency_options );
@@ -597,8 +612,8 @@ switch ($action) {
 
 		$filter_data['group_by_options'] = Misc::prependArray( array('0' => TTi18n::gettext('No Grouping')), $static_columns );
 
-		$psf = new PayStubFactory();
-		$filter_data['export_type_options'] = Misc::prependArray( array( 'csv' => TTi18n::gettext('CSV (Excel)') ), $psf->getOptions('export_type') );
+		$psf = TTnew( 'PayStubFactory' );
+		$filter_data['export_type_options'] = Misc::prependArray( array( 'csv' => TTi18n::gettext('CSV (Excel)') ), Misc::trimSortPrefix( $psf->getOptions('export_type') ) );
 
 		$saved_report_options = $ugdlf->getByUserIdAndScriptArray( $current_user->getId(), $_SERVER['SCRIPT_NAME']);
 		$generic_data['saved_report_options'] = $saved_report_options;
