@@ -73,7 +73,7 @@ $columns = array(					'-0010-regular_time' => TTi18n::gettext('Regular Time'),
 $columns = Misc::prependArray( $static_columns, $columns);
 
 //Get all Overtime policies.
-$otplf = new OverTimePolicyListFactory();
+$otplf = TTnew( 'OverTimePolicyListFactory' );
 $otplf->getByCompanyId($current_company->getId());
 if ( $otplf->getRecordCount() > 0 ) {
 	foreach ($otplf as $otp_obj ) {
@@ -84,7 +84,7 @@ if ( $otplf->getRecordCount() > 0 ) {
 }
 
 //Get all Premium policies.
-$pplf = new PremiumPolicyListFactory();
+$pplf = TTnew( 'PremiumPolicyListFactory' );
 $pplf->getByCompanyId($current_company->getId());
 if ( $pplf->getRecordCount() > 0 ) {
 	foreach ($pplf as $pp_obj ) {
@@ -96,7 +96,7 @@ if ( $pplf->getRecordCount() > 0 ) {
 
 
 //Get all Absence Policies.
-$aplf = new AbsencePolicyListFactory();
+$aplf = TTnew( 'AbsencePolicyListFactory' );
 $aplf->getByCompanyId($current_company->getId());
 if ( $aplf->getRecordCount() > 0 ) {
 	foreach ($aplf as $ap_obj ) {
@@ -111,7 +111,7 @@ $default_start_date = TTDate::getBeginMonthEpoch();
 $default_end_date = TTDate::getEndMonthEpoch();
 
 //Get all pay periods
-$pplf = new PayPeriodListFactory();
+$pplf = TTnew( 'PayPeriodListFactory' );
 $pplf->getByCompanyId( $current_company->getId() );
 if ( $pplf->getRecordCount() > 0 ) {
 	$pp=0;
@@ -126,7 +126,7 @@ if ( $pplf->getRecordCount() > 0 ) {
 		$pp++;
 	}
 
-	$pplf = new PayPeriodListFactory();
+	$pplf = TTnew( 'PayPeriodListFactory' );
 	$pay_period_options = $pplf->getByIdListArray($pay_period_ids, NULL, array('start_date' => 'desc'));
 } else {
 	$pay_period_options = array();
@@ -145,7 +145,7 @@ $filter_data = Misc::preSetArrayValues( $filter_data, array('include_user_ids',
 //Get Permission Hierarchy Children first, as this can be used for viewing, or editing.
 $permission_children_ids = array();
 if ( $permission->Check('punch','view') == FALSE ) {
-	$hlf = new HierarchyListFactory();
+	$hlf = TTnew( 'HierarchyListFactory' );
 	$permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId() );
 	Debug::Arr($permission_children_ids,'Permission Children Ids:', __FILE__, __LINE__, __METHOD__,10);
 
@@ -159,8 +159,8 @@ if ( $permission->Check('punch','view') == FALSE ) {
 	$filter_data['permission_children_ids'] = $permission_children_ids;
 }
 
-$ugdlf = new UserGenericDataListFactory();
-$ugdf = new UserGenericDataFactory();
+$ugdlf = TTnew( 'UserGenericDataListFactory' );
+$ugdf = TTnew( 'UserGenericDataFactory' );
 
 $action = Misc::findSubmitButton();
 switch ($action) {
@@ -198,7 +198,7 @@ switch ($action) {
 									);
 */
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$ulf->getSearchByCompanyIdAndArrayCriteria( $current_company->getId(), $filter_data );
 		if ( $ulf->getRecordCount() > 0 ) {
 			if ( isset($filter_data['date_type']) AND $filter_data['date_type'] == 'pay_period_ids' ) {
@@ -246,7 +246,7 @@ switch ($action) {
 				$end_date = $filter_data['end_date'];
 			}
 /*
-			$uwlf = new UserWageListFactory();
+			$uwlf = TTnew( 'UserWageListFactory' );
 			$uwlf->getLastWageByUserIdAndDate( $filter_data['user_id'], $end_date );
 			if ( $uwlf->getRecordCount() > 0 ) {
 				foreach($uwlf as $uw_obj) {
@@ -257,7 +257,7 @@ switch ($action) {
 			//var_dump($user_wage);
 */
 
-			$udtlf = new UserDateTotalListFactory();
+			$udtlf = TTnew( 'UserDateTotalListFactory' );
 			$udtlf->getReportByCompanyIdAndArrayCriteria( $current_company->getId(), $filter_data );
 			foreach ($udtlf as $udt_obj ) {
 				$user_id = $udt_obj->getColumn('id');
@@ -294,18 +294,18 @@ switch ($action) {
 			}
 			//print_r($tmp_rows);
 
-			$ulf = new UserListFactory();
+			$ulf = TTnew( 'UserListFactory' );
 
-			$utlf = new UserTitleListFactory();
+			$utlf = TTnew( 'UserTitleListFactory' );
 			$title_options = $utlf->getByCompanyIdArray( $current_company->getId() );
 
-			$uglf = new UserGroupListFactory();
+			$uglf = TTnew( 'UserGroupListFactory' );
 			$group_options = $uglf->getArrayByNodes( FastTree::FormatArray( $uglf->getByCompanyIdArray( $current_company->getId() ), 'no_tree_text', TRUE) );
 
-			$blf = new BranchListFactory();
+			$blf = TTnew( 'BranchListFactory' );
 			$branch_options = $blf->getByCompanyIdArray( $current_company->getId() );
 
-			$dlf = new DepartmentListFactory();
+			$dlf = TTnew( 'DepartmentListFactory' );
 			$department_options = $dlf->getByCompanyIdArray( $current_company->getId() );
 
 			if ( isset($tmp_rows) ) {
@@ -457,7 +457,63 @@ switch ($action) {
 								}
 							}
 						}
+						break;
+                    case 'paychex_online': //Paychex Online Payroll CSV
+                        $data = NULL;
+                        ksort($setup_data['paychex_online']['columns']);
+						$setup_data['paychex_online']['columns'] = Misc::trimSortPrefix( $setup_data['paychex_online']['columns'] );
 
+                        $earnings = array();
+                        //Find all the hours codes
+                        foreach( $setup_data['paychex_online']['columns'] as $column_id => $column_data ) {
+							$hour_code = $column_data['hour_code'];
+							$earnings[] = $hour_code;
+                        }
+
+						$export_column_map['employee_number'] = '';
+                        foreach($earnings as $key => $value) {
+                            $export_column_map[$value] = '';
+                        }
+
+                        $i=0;
+						foreach($rows as $row) {
+							if ( $i == 0 ) {
+								//Include header.
+								$tmp_row['employee_number'] = 'Employee Number';
+                                foreach($earnings as $key => $value) {
+                                    $tmp_row[$value] = $value . ' Hours';
+                                }
+								$tmp_rows[] = $tmp_row;
+								unset($tmp_row);
+							}
+
+							//Combine all hours from the same code together.
+							foreach( $setup_data['paychex_online']['columns'] as $column_id => $column_data ) {
+								$hour_code = trim($column_data['hour_code']);
+								if ( isset( $row[$column_id] ) AND $hour_code != '' ) {
+									if ( !isset($tmp_hour_codes[$hour_code]) ) {
+										$tmp_hour_codes[$hour_code] = 0;
+									}
+									$tmp_hour_codes[$hour_code] = bcadd( $tmp_hour_codes[$column_data['hour_code']], $row[$column_id] ); //Use seconds for math here.
+								}
+							}
+
+							if ( isset($tmp_hour_codes) ) {
+                                $tmp_row['employee_number'] = $row['employee_number'];
+								foreach($tmp_hour_codes as $hour_code => $hours ) {
+                                    $tmp_row[$hour_code] = TTDate::getTimeUnit($hours, 20);
+                                }
+                                $tmp_rows[] = $tmp_row;
+								unset($tmp_hour_codes, $hour_code, $hours, $tmp_row);
+							}
+
+							$i++;
+						}
+
+						if ( isset( $tmp_rows) ) {
+							$data = Misc::Array2CSV( $tmp_rows, $export_column_map, FALSE, FALSE );
+						}
+						unset($tmp_rows, $export_column_map, $column_id, $column_data, $rows, $row);
 						break;
 					case 'ceridian_insync': //Ceridian InSync export format.
 						$data = NULL;
@@ -517,7 +573,6 @@ switch ($action) {
 							$data = Misc::Array2CSV( $tmp_rows, $export_column_map, FALSE, FALSE );
 						}
 						unset($tmp_rows, $export_column_map, $column_id, $column_data, $rows, $row);
-
 						break;
 					case 'csv': //Generic CSV
 						$data = NULL;
@@ -578,6 +633,7 @@ switch ($action) {
 
 						break;
 
+
 					case 'quickbooks': //Quickbooks Pro export format.
 						$file_name = 'payroll_export.iif';
 
@@ -729,7 +785,7 @@ switch ($action) {
 		}
 		$filter_data = Misc::preSetArrayValues( $filter_data, array('include_user_ids', 'exclude_user_ids', 'user_status_ids', 'group_ids', 'branch_ids', 'department_ids', 'user_title_ids', 'pay_period_ids', 'column_ids' ), NULL);
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$all_array_option = array('-1' => TTi18n::gettext('-- All --'));
 
 		//Get include employee list.
@@ -749,34 +805,34 @@ switch ($action) {
 		$filter_data['selected_user_status_options'] = Misc::arrayIntersectByKey( (array)$filter_data['user_status_ids'], $user_status_options );
 
 		//Get Employee Groups
-		$uglf = new UserGroupListFactory();
+		$uglf = TTnew( 'UserGroupListFactory' );
 		$group_options = Misc::prependArray( $all_array_option, $uglf->getArrayByNodes( FastTree::FormatArray( $uglf->getByCompanyIdArray( $current_company->getId() ), 'TEXT', TRUE) ) );
 		$filter_data['src_group_options'] = Misc::arrayDiffByKey( (array)$filter_data['group_ids'], $group_options );
 		$filter_data['selected_group_options'] = Misc::arrayIntersectByKey( (array)$filter_data['group_ids'], $group_options );
 
 		//Get branches
-		$blf = new BranchListFactory();
+		$blf = TTnew( 'BranchListFactory' );
 		$blf->getByCompanyId( $current_company->getId() );
 		$branch_options = Misc::prependArray( $all_array_option, $blf->getArrayByListFactory( $blf, FALSE, TRUE ) );
 		$filter_data['src_branch_options'] = Misc::arrayDiffByKey( (array)$filter_data['branch_ids'], $branch_options );
 		$filter_data['selected_branch_options'] = Misc::arrayIntersectByKey( (array)$filter_data['branch_ids'], $branch_options );
 
 		//Get departments
-		$dlf = new DepartmentListFactory();
+		$dlf = TTnew( 'DepartmentListFactory' );
 		$dlf->getByCompanyId( $current_company->getId() );
 		$department_options = Misc::prependArray( $all_array_option, $dlf->getArrayByListFactory( $dlf, FALSE, TRUE ) );
 		$filter_data['src_department_options'] = Misc::arrayDiffByKey( (array)$filter_data['department_ids'], $department_options );
 		$filter_data['selected_department_options'] = Misc::arrayIntersectByKey( (array)$filter_data['department_ids'], $department_options );
 
 		//Get employee titles
-		$utlf = new UserTitleListFactory();
+		$utlf = TTnew( 'UserTitleListFactory' );
 		$utlf->getByCompanyId( $current_company->getId() );
 		$user_title_options = Misc::prependArray( $all_array_option, $utlf->getArrayByListFactory( $utlf, FALSE, TRUE ) );
 		$filter_data['src_user_title_options'] = Misc::arrayDiffByKey( (array)$filter_data['user_title_ids'], $user_title_options );
 		$filter_data['selected_user_title_options'] = Misc::arrayIntersectByKey( (array)$filter_data['user_title_ids'], $user_title_options );
 
 		//Get pay periods
-		$pplf = new PayPeriodListFactory();
+		$pplf = TTnew( 'PayPeriodListFactory' );
 		$pplf->getByCompanyId( $current_company->getId() );
 		$pay_period_options = Misc::prependArray( $all_array_option, $pplf->getArrayByListFactory( $pplf, FALSE, TRUE ) );
 		$filter_data['src_pay_period_options'] = Misc::arrayDiffByKey( (array)$filter_data['pay_period_ids'], $pay_period_options );
@@ -786,6 +842,7 @@ switch ($action) {
 													0 => TTi18n::gettext('-- Please Choose --'),
 													'adp' => TTi18n::gettext('ADP'),
 													'paychex_preview' => TTi18n::gettext('Paychex Preview'),
+                                                    'paychex_online' => TTi18n::gettext('Paychex Online Payroll'),
 													'ceridian_insync' => TTi18n::gettext('Ceridian Insync'),
 													'millenium' => TTi18n::gettext('Millenium'),
 													'quickbooks' => TTi18n::gettext('QuickBooks Pro'),
