@@ -88,7 +88,7 @@ $non_static_columns = array(		'-1100-pension' => TTi18n::gettext('Pension Or Sup
 									'-1180-charity' => TTi18n::gettext('Charity Donations (46)'),
 									);
 
-$pseallf = new PayStubEntryAccountLinkListFactory();
+$pseallf = TTnew( 'PayStubEntryAccountLinkListFactory' );
 $pseallf->getByCompanyId( $current_company->getId() );
 if ( $pseallf->getRecordCount() > 0 ) {
 	$pseal_obj = $pseallf->getCurrent();
@@ -108,11 +108,11 @@ $column_ps_entry_name_map = array(
 
 $columns = Misc::prependArray( $static_columns, $non_static_columns);
 
-$pplf = new PayPeriodListFactory();
+$pplf = TTnew( 'PayPeriodListFactory' );
 $year_options = $pplf->getYearsArrayByCompanyId( $current_company->getId() );
 
-$ugdlf = new UserGenericDataListFactory();
-$ugdf = new UserGenericDataFactory();
+$ugdlf = TTnew( 'UserGenericDataListFactory' );
+$ugdf = TTnew( 'UserGenericDataFactory' );
 
 $filter_data = Misc::preSetArrayValues( $filter_data, array('include_user_ids', 'exclude_user_ids', 'user_status_ids', 'group_ids', 'branch_ids', 'department_ids', 'user_title_ids', 'pay_period_ids', 'column_ids' ), array() );
 
@@ -140,7 +140,7 @@ switch ($action) {
 			$ugdf->Save();
 		}
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$ulf->getSearchByCompanyIdAndArrayCriteria( $current_company->getId(), $filter_data );
 		if ( $ulf->getRecordCount() > 0 ) {
 			foreach( $ulf as $u_obj ) {
@@ -154,7 +154,7 @@ switch ($action) {
 					Debug::Text(' Year: '. TTDate::getDate('DATE+TIME', $year_epoch) , __FILE__, __LINE__, __METHOD__,10);
 				}
 
-				$pself = new PayStubEntryListFactory();
+				$pself = TTnew( 'PayStubEntryListFactory' );
 				$pself->getReportByCompanyIdAndUserIdAndTransactionStartDateAndTransactionEndDate($current_company->getId(), $filter_data['user_ids'], TTDate::getBeginYearEpoch($year_epoch), TTDate::getEndYearEpoch($year_epoch) );
 
 				$report_columns = $static_columns;
@@ -168,18 +168,18 @@ switch ($action) {
 				//var_dump($raw_rows);
 
 				if ( isset($raw_rows) ) {
-					$ulf = new UserListFactory();
+					$ulf = TTnew( 'UserListFactory' );
 
-					$utlf = new UserTitleListFactory();
+					$utlf = TTnew( 'UserTitleListFactory' );
 					$title_options = $utlf->getByCompanyIdArray( $current_company->getId() );
 
-					$uglf = new UserGroupListFactory();
+					$uglf = TTnew( 'UserGroupListFactory' );
 					$group_options = $uglf->getArrayByNodes( FastTree::FormatArray( $uglf->getByCompanyIdArray( $current_company->getId() ), 'no_tree_text', TRUE) );
 
-					$blf = new BranchListFactory();
+					$blf = TTnew( 'BranchListFactory' );
 					$branch_options = $blf->getByCompanyIdArray( $current_company->getId() );
 
-					$dlf = new DepartmentListFactory();
+					$dlf = TTnew( 'DepartmentListFactory' );
 					$department_options = $dlf->getByCompanyIdArray( $current_company->getId() );
 
 					$x=0;
@@ -262,7 +262,7 @@ switch ($action) {
 			$total_row = $last_row+1;
 
 			//Get company information
-			$clf = new CompanyListFactory();
+			$clf = TTnew( 'CompanyListFactory' );
 			$company_obj = $clf->getById( $current_company->getId() )->getCurrent();
 
 			//Debug::setVerbosity(11);
@@ -295,7 +295,7 @@ switch ($action) {
 
 				//Only show T4A's with non-zero amounts, excluding income tax deducted.
 				if ( ($row['pension']+$row['lump_sum_payment']+$row['other_income']+$row['eligible_retiring_allowance']+$row['non_eligible_retiring_allowance']+$row['rpp']+$row['charity']+$row['pension_adjustment']) > 0 ) {
-					$ulf = new UserListFactory();
+					$ulf = TTnew( 'UserListFactory' );
 					$user_obj = $ulf->getById( $row['user_id'] )->getCurrent();
 
 					$t4aee = new T4AEmployee();
@@ -410,13 +410,13 @@ switch ($action) {
 		$filter_data = Misc::preSetArrayValues( $filter_data, array('include_user_ids', 'exclude_user_ids', 'user_status_ids', 'group_ids', 'branch_ids', 'department_ids', 'user_title_ids', 'pay_period_ids', 'column_ids' ), NULL );
 
 		//Deduction PSEA accounts
-		$psealf = new PayStubEntryAccountListFactory();
+		$psealf = TTnew( 'PayStubEntryAccountListFactory' );
 		$filter_data['pay_stub_entry_account_options'] = $psealf->getByCompanyIdAndStatusIdAndTypeIdArray( $current_company->getId(), 10, array(10,20,30,40,50), TRUE );
 
-		$psealf = new PayStubEntryAccountListFactory();
+		$psealf = TTnew( 'PayStubEntryAccountListFactory' );
 		$filter_data['deduction_pay_stub_entry_account_options'] = $psealf->getByCompanyIdAndStatusIdAndTypeIdArray( $current_company->getId(), 10, array(20,30), TRUE );
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$all_array_option = array('-1' => TTi18n::gettext('-- All --'));
 
 		//Get include employee list.
@@ -437,27 +437,27 @@ switch ($action) {
 		$filter_data['selected_user_status_options'] = Misc::arrayIntersectByKey( (array)$filter_data['user_status_ids'], $user_status_options );
 
 		//Get Employee Groups
-		$uglf = new UserGroupListFactory();
+		$uglf = TTnew( 'UserGroupListFactory' );
 		$group_options = Misc::prependArray( $all_array_option, $uglf->getArrayByNodes( FastTree::FormatArray( $uglf->getByCompanyIdArray( $current_company->getId() ), 'TEXT', TRUE) ) );
 		$filter_data['src_group_options'] = Misc::arrayDiffByKey( (array)$filter_data['group_ids'], $group_options );
 		$filter_data['selected_group_options'] = Misc::arrayIntersectByKey( (array)$filter_data['group_ids'], $group_options );
 
 		//Get branches
-		$blf = new BranchListFactory();
+		$blf = TTnew( 'BranchListFactory' );
 		$blf->getByCompanyId( $current_company->getId() );
 		$branch_options = Misc::prependArray( $all_array_option, $blf->getArrayByListFactory( $blf, FALSE, TRUE ) );
 		$filter_data['src_branch_options'] = Misc::arrayDiffByKey( (array)$filter_data['branch_ids'], $branch_options );
 		$filter_data['selected_branch_options'] = Misc::arrayIntersectByKey( (array)$filter_data['branch_ids'], $branch_options );
 
 		//Get departments
-		$dlf = new DepartmentListFactory();
+		$dlf = TTnew( 'DepartmentListFactory' );
 		$dlf->getByCompanyId( $current_company->getId() );
 		$department_options = Misc::prependArray( $all_array_option, $dlf->getArrayByListFactory( $dlf, FALSE, TRUE ) );
 		$filter_data['src_department_options'] = Misc::arrayDiffByKey( (array)$filter_data['department_ids'], $department_options );
 		$filter_data['selected_department_options'] = Misc::arrayIntersectByKey( (array)$filter_data['department_ids'], $department_options );
 
 		//Get employee titles
-		$utlf = new UserTitleListFactory();
+		$utlf = TTnew( 'UserTitleListFactory' );
 		$utlf->getByCompanyId( $current_company->getId() );
 		$user_title_options = Misc::prependArray( $all_array_option, $utlf->getArrayByListFactory( $utlf, FALSE, TRUE ) );
 		$filter_data['src_user_title_options'] = Misc::arrayDiffByKey( (array)$filter_data['user_title_ids'], $user_title_options );
