@@ -34,13 +34,12 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2906 $
- * $Id: T4Summary.php 2906 2009-10-16 21:41:04Z ipso $
- * $Date: 2009-10-16 14:41:04 -0700 (Fri, 16 Oct 2009) $
+ * $Revision: 4247 $
+ * $Id: T4Summary.php 4247 2011-02-15 21:40:19Z ipso $
+ * $Date: 2011-02-15 13:40:19 -0800 (Tue, 15 Feb 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
-require(Environment::getBasePath() .'/classes/fpdi/fpdi.php');
 
 if ( !$permission->Check('report','enabled')
 		OR !$permission->Check('report','view_t4_summary') ) {
@@ -97,7 +96,7 @@ $non_static_columns = array(		'-1100-income' => TTi18n::gettext('Income (14)'),
 									'-1220-other_box_5' => TTi18n::gettext('Other Box 6'),
 									);
 
-$pseallf = new PayStubEntryAccountLinkListFactory();
+$pseallf = TTnew( 'PayStubEntryAccountLinkListFactory' );
 $pseallf->getByCompanyId( $current_company->getId() );
 if ( $pseallf->getRecordCount() > 0 ) {
 	$pseal_obj = $pseallf->getCurrent();
@@ -126,11 +125,11 @@ $column_ps_entry_name_map = array(
 
 $columns = Misc::prependArray( $static_columns, $non_static_columns);
 
-$pplf = new PayPeriodListFactory();
+$pplf = TTnew( 'PayPeriodListFactory' );
 $year_options = $pplf->getYearsArrayByCompanyId( $current_company->getId() );
 
-$ugdlf = new UserGenericDataListFactory();
-$ugdf = new UserGenericDataFactory();
+$ugdlf = TTnew( 'UserGenericDataListFactory' );
+$ugdf = TTnew( 'UserGenericDataFactory' );
 
 $filter_data = Misc::preSetArrayValues( $filter_data, array('include_user_ids', 'exclude_user_ids', 'user_status_ids', 'group_ids', 'branch_ids', 'department_ids', 'user_title_ids', 'pay_period_ids', 'column_ids' ), array() );
 
@@ -138,7 +137,9 @@ $action = Misc::findSubmitButton();
 Debug::Text('Action: '. $action, __FILE__, __LINE__, __METHOD__,10);
 switch ($action) {
 	case 'display_t4s':
+	case 'export_xml':
 	case 'display_report':
+	case 'export':
 		//Debug::setVerbosity(11);
 
 		Debug::Text('Submit!: '. $action, __FILE__, __LINE__, __METHOD__,10);
@@ -158,7 +159,7 @@ switch ($action) {
 			$ugdf->Save();
 		}
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$ulf->getSearchByCompanyIdAndArrayCriteria( $current_company->getId(), $filter_data );
 		if ( $ulf->getRecordCount() > 0 ) {
 			foreach( $ulf as $u_obj ) {
@@ -172,7 +173,7 @@ switch ($action) {
 					Debug::Text(' Year: '. TTDate::getDate('DATE+TIME', $year_epoch) , __FILE__, __LINE__, __METHOD__,10);
 				}
 
-				$pself = new PayStubEntryListFactory();
+				$pself = TTnew( 'PayStubEntryListFactory' );
 				$pself->getReportByCompanyIdAndUserIdAndTransactionStartDateAndTransactionEndDate($current_company->getId(), $filter_data['user_ids'], TTDate::getBeginYearEpoch($year_epoch), TTDate::getEndYearEpoch($year_epoch) );
 
 				$report_columns = $static_columns;
@@ -186,18 +187,18 @@ switch ($action) {
 				//var_dump($raw_rows);
 
 				if ( isset($raw_rows) ) {
-					$ulf = new UserListFactory();
+					$ulf = TTnew( 'UserListFactory' );
 
-					$utlf = new UserTitleListFactory();
+					$utlf = TTnew( 'UserTitleListFactory' );
 					$title_options = $utlf->getByCompanyIdArray( $current_company->getId() );
 
-					$uglf = new UserGroupListFactory();
+					$uglf = TTnew( 'UserGroupListFactory' );
 					$group_options = $uglf->getArrayByNodes( FastTree::FormatArray( $uglf->getByCompanyIdArray( $current_company->getId() ), 'no_tree_text', TRUE) );
 
-					$blf = new BranchListFactory();
+					$blf = TTnew( 'BranchListFactory' );
 					$branch_options = $blf->getByCompanyIdArray( $current_company->getId() );
 
-					$dlf = new DepartmentListFactory();
+					$dlf = TTnew( 'DepartmentListFactory' );
 					$department_options = $dlf->getByCompanyIdArray( $current_company->getId() );
 
 					$x=0;
@@ -273,51 +274,45 @@ switch ($action) {
 			$filter_columns[Misc::trimSortPrefix($column_key)] = $columns[$column_key];
 		}
 
-		if ( $action == 'display_t4s' ) {
-			Debug::Text('Generating PDF: ', __FILE__, __LINE__, __METHOD__,10);
+		if ( isset($rows) AND ( $action == 'display_t4s' OR $action == 'export_xml' ) ) {
+			Debug::Text('Generating PDF/XML: '. $action, __FILE__, __LINE__, __METHOD__,10);
 
 			$last_row = count($rows)-1;
 			$total_row = $last_row+1;
 
 			//Get company information
-			$clf = new CompanyListFactory();
+			$clf = TTnew( 'CompanyListFactory' );
 			$company_obj = $clf->getById( $current_company->getId() )->getCurrent();
 
 			//Debug::setVerbosity(11);
-			$t4 = new T4;
+			require_once( Environment::getBasePath() .'/classes/GovernmentForms/GovernmentForms.class.php');
+			$gf = new GovernmentForms();
+			if ( $action == 'export_xml' ) {
+				$t619 = $gf->getFormObject( 'T619', 'CA' );
+				$t619->transmitter_number = $setup_data['transmitter_number'];
+				$t619->transmitter_name = $company_obj->getName();
+				$t619->transmitter_address1 = $company_obj->getAddress1();
+				$t619->transmitter_address2 = $company_obj->getAddress2();
+				$t619->transmitter_city = $company_obj->getCity();
+				$t619->transmitter_province = $company_obj->getProvince();
+				$t619->transmitter_postal_code = $company_obj->getPostalCode();
+				$t619->contact_name = $current_user->getFullName();
+				$t619->contact_phone = $company_obj->getWorkPhone();
+				$t619->contact_email = $current_user->getWorkEmail();
+				$gf->addForm( $t619 );
+			}
+
+			$t4 = $gf->getFormObject( 'T4', 'CA' );
+
 			if ( isset($filter_data['include_t4_back']) AND $filter_data['include_t4_back'] == 1 ) {
 				$t4->setShowInstructionPage(TRUE);
 			}
-			//$t4->setShowBackGround(FALSE);
-			$t4->setShowBorder(FALSE);
-			//$t4->setXOffset(10);
-			//$t4->setYOffset(10);
 
 			$t4->setType( $filter_data['type'] );
-			$t4->setYear( $filter_data['year'] );
-			$t4->setBusinessNumber( $company_obj->getBusinessNumber() );
+			$t4->year = $filter_data['year'];
+			$t4->payroll_account_number = $setup_data['payroll_account_number'];
 
-			$t4->setCompanyName( $company_obj->getName() );
-			$t4->setCompanyAddress1( $company_obj->getAddress1() );
-			$t4->setCompanyAddress2( $company_obj->getAddress2() );
-			$t4->setCompanyCity( $company_obj->getCity() );
-			$t4->setCompanyProvince( $company_obj->getProvince() );
-			$t4->setCompanyPostalCode( $company_obj->getPostalCode() );
-
-			$t4sum = new T4Summary();
-			$t4sum->setTotalT4s( count($rows)-1 );
-			$t4sum->setEmploymentIncome( $rows[$last_row]['income'] );
-			$t4sum->setIncomeTax( $rows[$last_row]['income_tax'] );
-			$t4sum->setEmployeeCPP( $rows[$last_row]['employee_cpp'] );
-			$t4sum->setEmployeeEI($rows[$last_row]['employee_ei'] );
-			$t4sum->setEmployerCPP(  $rows[$last_row]['employer_cpp'] );
-			$t4sum->setEmployerEI( $rows[$last_row]['employer_ei'] );
-			$t4sum->setEmployeeRPP( $rows[$last_row]['rpp'] );
-			$t4sum->setPensionAdjustment( $rows[$last_row]['pension_adjustment'] );
-
-			$total_deductions = Misc::MoneyFormat( $rows[$last_row]['employee_cpp'] + $rows[$last_row]['employer_cpp'] + $rows[$last_row]['employee_ei'] + $rows[$last_row]['employer_ei'] + $rows[$last_row]['income_tax'], FALSE );
-			$t4sum->setTotalDeductions( $total_deductions );
-			$t4->addT4Summary( $t4sum );
+			$t4->company_name = $setup_data['company_name'];
 
 			$i=0;
 			foreach($rows as $row) {
@@ -325,30 +320,55 @@ switch ($action) {
 					continue;
 				}
 
-				$ulf = new UserListFactory();
+				$ulf = TTnew( 'UserListFactory' );
 				$user_obj = $ulf->getById( $row['user_id'] )->getCurrent();
 
-
-				$t4ee = new T4Employee();
-				$t4ee->setSin( $row['sin'] );
-				$t4ee->setFirstName( $user_obj->getFirstName() );
-				$t4ee->setMiddleName( $user_obj->getMiddleName() );
-				$t4ee->setLastName( $user_obj->getLastName()  );
-				$t4ee->setAddress1( $user_obj->getAddress1() );
-				$t4ee->setAddress2( $user_obj->getAddress2() );
-				$t4ee->setCity( $user_obj->getCity() );
-				$t4ee->setProvince( $user_obj->getProvince() );
-				$t4ee->setPostalCode( $user_obj->getPostalCode() );
-				//$t4ee->setEmployementCode( );
+				$ee_data = array(
+							'first_name' => $user_obj->getFirstName(),
+							'middle_name' => $user_obj->getMiddleName(),
+							'last_name' => $user_obj->getLastName(),
+							'address1' => $user_obj->getAddress1(),
+							'address2' => $user_obj->getAddress2(),
+							'city' => $user_obj->getCity(),
+							'province' => $user_obj->getProvince(),
+							'employment_province' => $user_obj->getProvince(),
+							'postal_code' => $user_obj->getPostalCode(),
+							'sin' => $row['sin'],
+							'employee_number' => $user_obj->getEmployeeNumber(),
+							'l14' => $row['income'],
+							'l22' => $row['income_tax'],
+							'l16' => $row['employee_cpp'],
+							'l24' => $row['ei_earnings'],
+							'l26' => $row['cpp_earnings'],
+							'l18' => $row['employee_ei'],
+							'l44' => $row['union_dues'],
+							'l20' => $row['rpp'] ,
+							'l46' => $row['charity'],
+							'l52' => $row['pension_adjustment'],
+							'cpp_exempt' => FALSE,
+							'ei_exempt' => FALSE,
+							'other_box_0_code' => NULL,
+							'other_box_0' => NULL,
+							'other_box_1_code' => NULL,
+							'other_box_1' => NULL,
+							'other_box_2_code' => NULL,
+							'other_box_2' => NULL,
+							'other_box_3_code' => NULL,
+							'other_box_3' => NULL,
+							'other_box_4_code' => NULL,
+							'other_box_4' => NULL,
+							'other_box_5_code' => NULL,
+							'other_box_5' => NULL,
+							);
 
 				//Get User Tax / Deductions by Pay Stub Account.
-				$udlf = new UserDeductionListFactory();
+				$udlf = TTnew( 'UserDeductionListFactory' );
 				if ( isset($setup_data['employee_cpp_psea_id']) ) {
 					$udlf->getByUserIdAndPayStubEntryAccountID( $user_obj->getId(), $setup_data['employee_cpp_psea_id'] );
 					if ( $setup_data['employee_cpp_psea_id'] != 0
 							AND $udlf->getRecordCount() == 0 ) {
-						Debug::Text('CPP Exempt!', __FILE__, __LINE__, __METHOD__,10);
-						$t4ee->setExemptCPP( TRUE );
+						//Debug::Text('CPP Exempt!', __FILE__, __LINE__, __METHOD__,10);
+						$ee_data['cpp_exempt'] = TRUE;
 					}
 				}
 
@@ -356,70 +376,120 @@ switch ($action) {
 					$udlf->getByUserIdAndPayStubEntryAccountID( $user_obj->getId(), $setup_data['employee_ei_psea_id'] );
 					if ( $setup_data['employee_ei_psea_id'] != 0
 							AND $udlf->getRecordCount() == 0 ) {
-						Debug::Text('EI Exempt!', __FILE__, __LINE__, __METHOD__,10);
-						$t4ee->setExemptEI( TRUE );
+						//Debug::Text('EI Exempt!', __FILE__, __LINE__, __METHOD__,10);
+						$ee_data['ei_exempt'] = TRUE;
 					}
 				}
 
-				$t4ee->setEmploymentIncome( $row['income'] );
-				$t4ee->setIncomeTax( $row['income_tax'] );
-				$t4ee->setEmployeeCPP( $row['employee_cpp'] );
-				$t4ee->setEIEarnings( $row['ei_earnings'] );
-				$t4ee->setCPPEarnings( $row['cpp_earnings'] );
-				$t4ee->setEmployeeEI( $row['employee_ei'] );
-				$t4ee->setUnionDues( $row['union_dues']  );
-				$t4ee->setEmployeeRPP( $row['rpp'] );
-				$t4ee->setCharityDonations( $row['charity'] );
-				$t4ee->setPensionAdjustment( $row['pension_adjustment'] );
-
 				if ( $row['other_box_0'] > 0 AND isset($setup_data['other_box'][0]['box']) AND $setup_data['other_box'][0]['box'] !='') {
-					$t4ee->setOtherBox1Code( $setup_data['other_box'][0]['box'] );
-					$t4ee->setOtherBox1( $row['other_box_0'] );
+					$ee_data['other_box_0_code'] = $setup_data['other_box'][0]['box'];
+					$ee_data['other_box_0'] = $row['other_box_0'];
 				}
 
 				if ( $row['other_box_1'] > 0 AND isset($setup_data['other_box'][1]['box']) AND $setup_data['other_box'][1]['box'] !='') {
-					$t4ee->setOtherBox2Code( $setup_data['other_box'][1]['box'] );
-					$t4ee->setOtherBox2( $row['other_box_1'] );
+					$ee_data['other_box_1_code'] = $setup_data['other_box'][1]['box'];
+					$ee_data['other_box_1'] = $row['other_box_1'];
 				}
 
 				if ( $row['other_box_2'] > 0 AND isset($setup_data['other_box'][2]['box']) AND $setup_data['other_box'][2]['box'] !='') {
-					$t4ee->setOtherBox3Code( $setup_data['other_box'][2]['box'] );
-					$t4ee->setOtherBox3( $row['other_box_2'] );
+					$ee_data['other_box_2_code'] = $setup_data['other_box'][2]['box'];
+					$ee_data['other_box_2'] = $row['other_box_2'];
 				}
 
 				if ( $row['other_box_3'] > 0 AND isset($setup_data['other_box'][3]['box']) AND $setup_data['other_box'][3]['box'] !='') {
-					$t4ee->setOtherBox4Code( $setup_data['other_box'][3]['box'] );
-					$t4ee->setOtherBox4( $row['other_box_3'] );
+					$ee_data['other_box_3_code'] = $setup_data['other_box'][3]['box'];
+					$ee_data['other_box_3'] = $row['other_box_3'];
 				}
 
 				if ( $row['other_box_4'] > 0 AND isset($setup_data['other_box'][4]['box']) AND $setup_data['other_box'][4]['box'] !='') {
-					$t4ee->setOtherBox5Code( $setup_data['other_box'][4]['box'] );
-					$t4ee->setOtherBox5( $row['other_box_4'] );
+					$ee_data['other_box_4_code'] = $setup_data['other_box'][4]['box'];
+					$ee_data['other_box_4'] = $row['other_box_4'];
 				}
 				if ( $row['other_box_5'] > 0 AND isset($setup_data['other_box'][5]['box']) AND $setup_data['other_box'][5]['box'] !='') {
-					$t4ee->setOtherBox6Code( $setup_data['other_box'][5]['box'] );
-					$t4ee->setOtherBox6( $row['other_box_5'] );
+					$ee_data['other_box_5_code'] = $setup_data['other_box'][5]['box'];
+					$ee_data['other_box_5'] = $row['other_box_5'];
 				}
-				$t4->addT4Employee( $t4ee );
+				$t4->addRecord( $ee_data );
+				unset($ee_data);
 
 				$i++;
 			}
+			$gf->addForm( $t4 );
 
-			$t4->compileT4Summary();
-			$t4->compileT4();
+			//Handle T4Summary
+			$t4s = $gf->getFormObject( 'T4Sum', 'CA' );
+			$t4s->year = $t4->year;
+			$t4s->payroll_account_number = $t4->payroll_account_number;
+			$t4s->company_name = $t4->company_name;
 
-			$t4->displayPDF();
+			$t4s->company_address1 = $setup_data['company_address1'];
+			$t4s->company_address2 = $setup_data['company_address2'];
+			$t4s->company_city = $setup_data['company_city'];
+			$t4s->company_province = $setup_data['company_province'];
+			$t4s->company_postal_code = $setup_data['company_postal_code'];
+
+			$t4s->l76 = $current_user->getFullName(); //Contact name.
+			$t4s->l78 = $company_obj->getWorkPhone();
+
+			$t4s->l88 = count($rows)-1;
+			$t4s->l14 = $rows[$last_row]['income'];
+			$t4s->l22 = $rows[$last_row]['income_tax'];
+			$t4s->l16 = $rows[$last_row]['employee_cpp'];
+			$t4s->l18 = $rows[$last_row]['employee_ei'];
+			$t4s->l27 = $rows[$last_row]['employer_cpp'];
+			$t4s->l19 = $rows[$last_row]['employer_ei'];
+			$t4s->l20 = $rows[$last_row]['rpp'];
+			$t4s->l52 = $rows[$last_row]['pension_adjustment'];
+
+			$total_deductions = Misc::MoneyFormat( $rows[$last_row]['employee_cpp'] + $rows[$last_row]['employer_cpp'] + $rows[$last_row]['employee_ei'] + $rows[$last_row]['employer_ei'] + $rows[$last_row]['income_tax'], FALSE );
+			$t4s->l82 = $total_deductions;
+			$gf->addForm( $t4s );
+
+			if ( $action == 'display_t4s' ) {
+				$file_name = 't4_'.$filter_data['year'].'.pdf';
+				$mime_type = 'application/pdf';
+				$output = $gf->output( 'PDF' );
+			} elseif ( $action == 'export_xml' ) {
+				$file_name = 't4_'.$filter_data['year'].'.xml';
+				$mime_type = 'application/octetstream';
+				$output = $gf->output( 'XML' );
+			}
+			unset($t4, $t4s);
+
+			if ( Debug::getVerbosity() == 11 ) {
+				Debug::Display();
+			} elseif ( strlen($output) > 0 ) {
+				Misc::FileDownloadHeader( $file_name, $mime_type, strlen($output));
+				echo $output;
+				exit;
+			} else {
+				echo TTi18n::getText('Invalid data, unable to generate report.');
+				Debug::writeToLog();
+				exit;
+			}
 		} else {
 			Debug::Text('NOT Generating PDF: ', __FILE__, __LINE__, __METHOD__,10);
 		}
 
-		$smarty->assign_by_ref('generated_time', TTDate::getTime() );
-		//$smarty->assign_by_ref('pay_period_options', $pay_period_options );
-		$smarty->assign_by_ref('filter_data', $filter_data );
-		$smarty->assign_by_ref('columns', $filter_columns );
-		$smarty->assign_by_ref('rows', $rows);
+		if ( $action == 'export' ) {
+			if ( isset($rows) AND isset($filter_columns) ) {
+				Debug::Text('Exporting as CSV', __FILE__, __LINE__, __METHOD__,10);
+				$data = Misc::Array2CSV( $rows, $filter_columns, FALSE );
 
-		$smarty->display('report/T4SummaryReport.tpl');
+				Misc::FileDownloadHeader('report.csv', 'application/csv', strlen($data) );
+				echo $data;
+			} else {
+				echo TTi18n::gettext('No Data To Export!') ."<br>\n";
+			}
+		} else {
+			$smarty->assign_by_ref('generated_time', TTDate::getTime() );
+			//$smarty->assign_by_ref('pay_period_options', $pay_period_options );
+			$smarty->assign_by_ref('filter_data', $filter_data );
+			$smarty->assign_by_ref('columns', $filter_columns );
+			$smarty->assign_by_ref('rows', $rows);
+
+			$smarty->display('report/T4SummaryReport.tpl');
+		}
 
 		break;
 	case 'delete':
@@ -475,13 +545,13 @@ switch ($action) {
 		$filter_data = Misc::preSetArrayValues( $filter_data, array('include_user_ids', 'exclude_user_ids', 'user_status_ids', 'group_ids', 'branch_ids', 'department_ids', 'user_title_ids', 'pay_period_ids', 'column_ids' ), NULL );
 
 		//Deduction PSEA accounts
-		$psealf = new PayStubEntryAccountListFactory();
+		$psealf = TTnew( 'PayStubEntryAccountListFactory' );
 		$filter_data['pay_stub_entry_account_options'] = $psealf->getByCompanyIdAndStatusIdAndTypeIdArray( $current_company->getId(), 10, array(10,20,30,40,50), TRUE );
 
-		$psealf = new PayStubEntryAccountListFactory();
+		$psealf = TTnew( 'PayStubEntryAccountListFactory' );
 		$filter_data['deduction_pay_stub_entry_account_options'] = $psealf->getByCompanyIdAndStatusIdAndTypeIdArray( $current_company->getId(), 10, array(20,30), TRUE );
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$all_array_option = array('-1' => TTi18n::gettext('-- All --'));
 
 		//Get include employee list.
@@ -502,27 +572,27 @@ switch ($action) {
 		$filter_data['selected_user_status_options'] = Misc::arrayIntersectByKey( (array)$filter_data['user_status_ids'], $user_status_options );
 
 		//Get Employee Groups
-		$uglf = new UserGroupListFactory();
+		$uglf = TTnew( 'UserGroupListFactory' );
 		$group_options = Misc::prependArray( $all_array_option, $uglf->getArrayByNodes( FastTree::FormatArray( $uglf->getByCompanyIdArray( $current_company->getId() ), 'TEXT', TRUE) ) );
 		$filter_data['src_group_options'] = Misc::arrayDiffByKey( (array)$filter_data['group_ids'], $group_options );
 		$filter_data['selected_group_options'] = Misc::arrayIntersectByKey( (array)$filter_data['group_ids'], $group_options );
 
 		//Get branches
-		$blf = new BranchListFactory();
+		$blf = TTnew( 'BranchListFactory' );
 		$blf->getByCompanyId( $current_company->getId() );
 		$branch_options = Misc::prependArray( $all_array_option, $blf->getArrayByListFactory( $blf, FALSE, TRUE ) );
 		$filter_data['src_branch_options'] = Misc::arrayDiffByKey( (array)$filter_data['branch_ids'], $branch_options );
 		$filter_data['selected_branch_options'] = Misc::arrayIntersectByKey( (array)$filter_data['branch_ids'], $branch_options );
 
 		//Get departments
-		$dlf = new DepartmentListFactory();
+		$dlf = TTnew( 'DepartmentListFactory' );
 		$dlf->getByCompanyId( $current_company->getId() );
 		$department_options = Misc::prependArray( $all_array_option, $dlf->getArrayByListFactory( $dlf, FALSE, TRUE ) );
 		$filter_data['src_department_options'] = Misc::arrayDiffByKey( (array)$filter_data['department_ids'], $department_options );
 		$filter_data['selected_department_options'] = Misc::arrayIntersectByKey( (array)$filter_data['department_ids'], $department_options );
 
 		//Get employee titles
-		$utlf = new UserTitleListFactory();
+		$utlf = TTnew( 'UserTitleListFactory' );
 		$utlf->getByCompanyId( $current_company->getId() );
 		$user_title_options = Misc::prependArray( $all_array_option, $utlf->getArrayByListFactory( $utlf, FALSE, TRUE ) );
 		$filter_data['src_user_title_options'] = Misc::arrayDiffByKey( (array)$filter_data['user_title_ids'], $user_title_options );
