@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3580 $
- * $Id: TimesheetSummary.php 3580 2010-05-17 22:57:10Z ipso $
- * $Date: 2010-05-17 15:57:10 -0700 (Mon, 17 May 2010) $
+ * $Revision: 4104 $
+ * $Id: TimesheetSummary.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -95,7 +95,7 @@ $columns = array(					'-1070-schedule_working' => TTi18n::gettext('Scheduled Tim
 $columns = Misc::prependArray( $static_columns, $columns);
 
 //Get all Overtime policies.
-$otplf = new OverTimePolicyListFactory();
+$otplf = TTnew( 'OverTimePolicyListFactory' );
 $otplf->getByCompanyId($current_company->getId());
 if ( $otplf->getRecordCount() > 0 ) {
 	foreach ($otplf as $otp_obj ) {
@@ -106,7 +106,7 @@ if ( $otplf->getRecordCount() > 0 ) {
 }
 
 //Get all Premium policies.
-$pplf = new PremiumPolicyListFactory();
+$pplf = TTnew( 'PremiumPolicyListFactory' );
 $pplf->getByCompanyId($current_company->getId());
 if ( $pplf->getRecordCount() > 0 ) {
 	foreach ($pplf as $pp_obj ) {
@@ -118,7 +118,7 @@ if ( $pplf->getRecordCount() > 0 ) {
 
 
 //Get all Absence Policies.
-$aplf = new AbsencePolicyListFactory();
+$aplf = TTnew( 'AbsencePolicyListFactory' );
 $aplf->getByCompanyId($current_company->getId());
 if ( $aplf->getRecordCount() > 0 ) {
 	foreach ($aplf as $ap_obj ) {
@@ -133,7 +133,7 @@ $default_start_date = TTDate::getBeginMonthEpoch();
 $default_end_date = TTDate::getEndMonthEpoch();
 
 //Get all pay periods
-$pplf = new PayPeriodListFactory();
+$pplf = TTnew( 'PayPeriodListFactory' );
 $pplf->getByCompanyId( $current_company->getId() );
 if ( $pplf->getRecordCount() > 0 ) {
 	$pp=0;
@@ -148,7 +148,7 @@ if ( $pplf->getRecordCount() > 0 ) {
 		$pp++;
 	}
 
-	$pplf = new PayPeriodListFactory();
+	$pplf = TTnew( 'PayPeriodListFactory' );
 	$pay_period_options = $pplf->getByIdListArray($pay_period_ids, NULL, array('start_date' => 'desc'));
 } else {
 	$pay_period_options = array();
@@ -168,7 +168,7 @@ $filter_data = Misc::preSetArrayValues( $filter_data, array('include_user_ids',
 $permission_children_ids = array();
 $wage_permission_children_ids = array();
 if ( $permission->Check('punch','view') == FALSE ) {
-	$hlf = new HierarchyListFactory();
+	$hlf = TTnew( 'HierarchyListFactory' );
 	$permission_children_ids = $wage_permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId() );
 	Debug::Arr($permission_children_ids,'Permission Children Ids:', __FILE__, __LINE__, __METHOD__,10);
 
@@ -194,8 +194,8 @@ if ( $permission->Check('wage','view') == FALSE ) {
 	$wage_filter_data['permission_children_ids'] = $wage_permission_children_ids;
 }
 
-$ugdlf = new UserGenericDataListFactory();
-$ugdf = new UserGenericDataFactory();
+$ugdlf = TTnew( 'UserGenericDataListFactory' );
+$ugdf = TTnew( 'UserGenericDataFactory' );
 
 $action = Misc::findSubmitButton();
 switch ($action) {
@@ -219,7 +219,7 @@ switch ($action) {
 									);
 */
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$ulf->getSearchByCompanyIdAndArrayCriteria( $current_company->getId(), $filter_data );
 		if ( $ulf->getRecordCount() > 0 ) {
 			if ( isset($filter_data['date_type']) AND $filter_data['date_type'] == 'pay_period_ids' ) {
@@ -271,7 +271,7 @@ switch ($action) {
             if ( $permission->Check('wage','view') == TRUE ) {
                 $wage_filter_data['permission_children_ids'] = $filter_data['user_id'];
             }
-			$uwlf = new UserWageListFactory();
+			$uwlf = TTnew( 'UserWageListFactory' );
 			$uwlf->getLastWageByUserIdAndDate( $wage_filter_data['permission_children_ids'], $end_date );
 			if ( $uwlf->getRecordCount() > 0 ) {
 				foreach($uwlf as $uw_obj) {
@@ -284,7 +284,7 @@ switch ($action) {
 			$pending_requests = array();
 			if ( isset($filter_data['pay_period_ids']) AND count($filter_data['pay_period_ids']) > 0 ) {
 				//Get all pending requests
-				$rlf = new RequestListFactory();
+				$rlf = TTnew( 'RequestListFactory' );
 				$rlf->getSumByPayPeriodIdAndStatus( $filter_data['pay_period_ids'], 30 );
 				if ( $rlf->getRecordCount() > 0 ) {
 					$r_obj = $rlf->getCurrent();
@@ -292,7 +292,7 @@ switch ($action) {
 				}
 			}
 
-			$slf = new ScheduleListFactory();
+			$slf = TTnew( 'ScheduleListFactory' );
 			//$slf->getReportByPayPeriodIdAndUserId($filter_data['pay_period_ids'], $filter_data['user_ids']);
 			$slf->getReportByCompanyIdAndArrayCriteria( $current_company->getId(), $filter_data );
 			if ( $slf->getRecordCount() > 0 ) {
@@ -311,7 +311,7 @@ switch ($action) {
 
 			$pay_period_ids = array();
 
-			$udtlf = new UserDateTotalListFactory();
+			$udtlf = TTnew( 'UserDateTotalListFactory' );
 			//$udtlf->getReportByPayPeriodIDListAndUserIdList($filter_data['pay_period_ids'], $filter_data['user_ids'], array($filter_data['primary_sort'] => 'asc') );
 			$udtlf->getReportByCompanyIdAndArrayCriteria( $current_company->getId(), $filter_data );
 			foreach ($udtlf as $udt_obj ) {
@@ -396,25 +396,25 @@ switch ($action) {
 			}
 			//print_r($tmp_rows);
 
-			$ulf = new UserListFactory();
+			$ulf = TTnew( 'UserListFactory' );
 
-			$utlf = new UserTitleListFactory();
+			$utlf = TTnew( 'UserTitleListFactory' );
 			$title_options = $utlf->getByCompanyIdArray( $current_company->getId() );
 
-			$uglf = new UserGroupListFactory();
+			$uglf = TTnew( 'UserGroupListFactory' );
 			$group_options = $uglf->getArrayByNodes( FastTree::FormatArray( $uglf->getByCompanyIdArray( $current_company->getId() ), 'no_tree_text', TRUE) );
 
-			$blf = new BranchListFactory();
+			$blf = TTnew( 'BranchListFactory' );
 			$branch_options = $blf->getByCompanyIdArray( $current_company->getId() );
 
-			$dlf = new DepartmentListFactory();
+			$dlf = TTnew( 'DepartmentListFactory' );
 			$department_options = $dlf->getByCompanyIdArray( $current_company->getId() );
 
 			//Get verified timesheets
 			//Ignore if more then one pay period is selected
 			$verified_time_sheets = NULL;
 			if ( isset($pay_period_ids) AND count($pay_period_ids) > 0 ) {
-				$pptsvlf = new PayPeriodTimeSheetVerifyListFactory();
+				$pptsvlf = TTnew( 'PayPeriodTimeSheetVerifyListFactory' );
 				$pptsvlf->getByPayPeriodIdAndCompanyId( array_keys($pay_period_ids), $current_company->getId() );
 				if ( $pptsvlf->getRecordCount() > 0 ) {
 					foreach( $pptsvlf as $pptsv_obj ) {
@@ -620,7 +620,7 @@ switch ($action) {
 		}
 		$filter_data = Misc::preSetArrayValues( $filter_data, array('include_user_ids', 'exclude_user_ids', 'user_status_ids', 'group_ids', 'branch_ids', 'department_ids', 'punch_branch_ids', 'punch_department_ids', 'user_title_ids', 'pay_period_ids', 'column_ids' ), NULL);
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$all_array_option = array('-1' => TTi18n::gettext('-- All --'));
 
 		//Get include employee list.
@@ -640,13 +640,13 @@ switch ($action) {
 		$filter_data['selected_user_status_options'] = Misc::arrayIntersectByKey( (array)$filter_data['user_status_ids'], $user_status_options );
 
 		//Get Employee Groups
-		$uglf = new UserGroupListFactory();
+		$uglf = TTnew( 'UserGroupListFactory' );
 		$group_options = Misc::prependArray( $all_array_option, $uglf->getArrayByNodes( FastTree::FormatArray( $uglf->getByCompanyIdArray( $current_company->getId() ), 'TEXT', TRUE) ) );
 		$filter_data['src_group_options'] = Misc::arrayDiffByKey( (array)$filter_data['group_ids'], $group_options );
 		$filter_data['selected_group_options'] = Misc::arrayIntersectByKey( (array)$filter_data['group_ids'], $group_options );
 
 		//Get branches
-		$blf = new BranchListFactory();
+		$blf = TTnew( 'BranchListFactory' );
 		$blf->getByCompanyId( $current_company->getId() );
 		$branch_options = Misc::prependArray( $all_array_option, $blf->getArrayByListFactory( $blf, FALSE, TRUE ) );
 		$filter_data['src_branch_options'] = Misc::arrayDiffByKey( (array)$filter_data['branch_ids'], $branch_options );
@@ -656,7 +656,7 @@ switch ($action) {
 		$filter_data['selected_punch_branch_options'] = Misc::arrayIntersectByKey( (array)$filter_data['punch_branch_ids'], $branch_options );
 
 		//Get departments
-		$dlf = new DepartmentListFactory();
+		$dlf = TTnew( 'DepartmentListFactory' );
 		$dlf->getByCompanyId( $current_company->getId() );
 		$department_options = Misc::prependArray( $all_array_option, $dlf->getArrayByListFactory( $dlf, FALSE, TRUE ) );
 		$filter_data['src_department_options'] = Misc::arrayDiffByKey( (array)$filter_data['department_ids'], $department_options );
@@ -666,14 +666,14 @@ switch ($action) {
 		$filter_data['selected_punch_department_options'] = Misc::arrayIntersectByKey( (array)$filter_data['punch_department_ids'], $department_options );
 
 		//Get employee titles
-		$utlf = new UserTitleListFactory();
+		$utlf = TTnew( 'UserTitleListFactory' );
 		$utlf->getByCompanyId( $current_company->getId() );
 		$user_title_options = Misc::prependArray( $all_array_option, $utlf->getArrayByListFactory( $utlf, FALSE, TRUE ) );
 		$filter_data['src_user_title_options'] = Misc::arrayDiffByKey( (array)$filter_data['user_title_ids'], $user_title_options );
 		$filter_data['selected_user_title_options'] = Misc::arrayIntersectByKey( (array)$filter_data['user_title_ids'], $user_title_options );
 
 		//Get pay periods
-		$pplf = new PayPeriodListFactory();
+		$pplf = TTnew( 'PayPeriodListFactory' );
 		$pplf->getByCompanyId( $current_company->getId() );
 		$pay_period_options = Misc::prependArray( $all_array_option, $pplf->getArrayByListFactory( $pplf, FALSE, TRUE ) );
 		$filter_data['src_pay_period_options'] = Misc::arrayDiffByKey( (array)$filter_data['pay_period_ids'], $pay_period_options );
