@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3522 $
- * $Id: UserDetail.php 3522 2010-04-23 16:27:05Z ipso $
- * $Date: 2010-04-23 09:27:05 -0700 (Fri, 23 Apr 2010) $
+ * $Revision: 4104 $
+ * $Id: UserDetail.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -131,7 +131,7 @@ if ( !isset($filter_data['column_ids']) ) {
 $permission_children_ids = array();
 $wage_permission_children_ids = array();
 if ( $permission->Check('user','view') == FALSE ) {
-	$hlf = new HierarchyListFactory();
+	$hlf = TTnew( 'HierarchyListFactory' );
 	$permission_children_ids = $wage_permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId() );
 	Debug::Arr($permission_children_ids,'Permission Children Ids:', __FILE__, __LINE__, __METHOD__,10);
 
@@ -157,8 +157,8 @@ if ( $permission->Check('wage','view') == FALSE ) {
 	$wage_filter_data['permission_children_ids'] = $wage_permission_children_ids;
 }
 
-$ugdlf = new UserGenericDataListFactory();
-$ugdf = new UserGenericDataFactory();
+$ugdlf = TTnew( 'UserGenericDataListFactory' );
+$ugdf = TTnew( 'UserGenericDataFactory' );
 
 $action = Misc::findSubmitButton();
 
@@ -168,7 +168,7 @@ switch ($action) {
 		Debug::Text('Submit!', __FILE__, __LINE__, __METHOD__,10);
 		//Debug::Arr($filter_data, 'Filter Data', __FILE__, __LINE__, __METHOD__,10);
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$ulf->getSearchByCompanyIdAndArrayCriteria( $current_company->getId(), $filter_data );
 		if ( $ulf->getRecordCount() > 0 ) {
 			foreach( $ulf as $u_obj ) {
@@ -176,14 +176,14 @@ switch ($action) {
 			}
 
 			//Get title list,
-			$utlf = new UserTitleListFactory();
+			$utlf = TTnew( 'UserTitleListFactory' );
 			$user_titles = $utlf->getByCompanyIdArray( $current_company->getId() );
 
 			//Get default branch list
-			$blf = new BranchListFactory();
+			$blf = TTnew( 'BranchListFactory' );
 			$branch_options = $blf->getByCompanyIdArray( $current_company->getId() );
 
-			$dlf = new DepartmentListFactory();
+			$dlf = TTnew( 'DepartmentListFactory' );
 			$department_options = $dlf->getByCompanyIdArray( $current_company->getId() );
 
 			/*
@@ -195,7 +195,7 @@ switch ($action) {
 				if ( $permission->Check('wage','view') == TRUE ) {
 					$wage_filter_data['permission_children_ids'] = $filter_data['user_ids'];
 				}
-				$uwlf = new UserWageListFactory();
+				$uwlf = TTnew( 'UserWageListFactory' );
 				$uwlf->getByUserIdAndCompanyIdAndStartDateAndEndDate( $wage_filter_data['permission_children_ids'], $current_company->getId(), $filter_data['start_date'], $filter_data['end_date'] );
 				if ( $uwlf->getRecordCount() > 0 ) {
 					foreach( $uwlf as $uw_obj ) {
@@ -218,17 +218,17 @@ switch ($action) {
 			*/
 			if ( isset($columns['attendance']) ) {
 				//Get policy names.
-				$oplf = new OverTimePolicyListFactory();
+				$oplf = TTnew( 'OverTimePolicyListFactory' );
 				$over_time_policy_arr = $oplf->getByCompanyIdArray($current_company->getId(), FALSE);
 
-				$aplf = new AbsencePolicyListFactory();
+				$aplf = TTnew( 'AbsencePolicyListFactory' );
 				$absence_policy_arr = $aplf->getByCompanyIdArray($current_company->getId(), FALSE);
 
-				$pplf = new PremiumPolicyListFactory();
+				$pplf = TTnew( 'PremiumPolicyListFactory' );
 				$premium_policy_arr = $pplf->getByCompanyIdArray($current_company->getId(), FALSE);
 
 				//Get stats on number of days worked per month/week
-				$udlf = new UserDateListFactory();
+				$udlf = TTnew( 'UserDateListFactory' );
 				$udlf->getDaysWorkedByTimePeriodAndUserIdAndCompanyIdAndStartDateAndEndDate( 'month', $filter_data['user_ids'], $current_company->getId(), $filter_data['start_date'], $filter_data['end_date'] );
 				if ( $udlf->getRecordCount() > 0 ) {
 					foreach( $udlf as $ud_obj ) {
@@ -253,7 +253,7 @@ switch ($action) {
 				}
 				//var_dump($user_days_worked);
 
-				$udtlf = new UserDateTotalListFactory();
+				$udtlf = TTnew( 'UserDateTotalListFactory' );
 				$udtlf->getReportHoursByTimePeriodAndUserIdAndCompanyIdAndStartDateAndEndDate( 'day', $filter_data['user_ids'], $current_company->getId(), $filter_data['start_date'], $filter_data['end_date'] );
 				if ( $udtlf->getRecordCount() > 0 ) {
 					foreach( $udtlf as $udt_obj ) {
@@ -389,7 +389,7 @@ switch ($action) {
 			*/
 			if ( isset($columns['exception']) ) {
 				//Get exception types.
-				$eplf = new ExceptionPolicyListFactory();
+				$eplf = TTnew( 'ExceptionPolicyListFactory' );
 				$eplf->getByCompanyId( $current_company->getId() );
 				if ( $eplf->getRecordCount() > 0 ) {
 					foreach( $eplf as $ep_obj) {
@@ -402,7 +402,7 @@ switch ($action) {
 				}
 				//var_dump($exception_policy_arr);
 
-				$elf = new ExceptionListFactory();
+				$elf = TTnew( 'ExceptionListFactory' );
 				$elf->getReportByTimePeriodAndUserIdAndCompanyIdAndStartDateAndEndDate( 'week', $filter_data['user_ids'], $current_company->getId(), $filter_data['start_date'], $filter_data['end_date'] );
 				if ( $elf->getRecordCount() > 0 ) {
 					foreach( $elf as $e_obj ) {
@@ -460,7 +460,7 @@ switch ($action) {
 				Get Employee contact information.
 
 			*/
-			$ulf = new UserListFactory();
+			$ulf = TTnew( 'UserListFactory' );
 			$ulf->getReportByCompanyIdAndUserIDList( $current_company->getId(), $filter_data['user_ids'] );
 
 			foreach ($ulf as $u_obj ) {
@@ -598,7 +598,7 @@ switch ($action) {
 			}
 		}
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$all_array_option = array('-1' => TTi18n::gettext('-- All --'));
 
 		//Get include employee list.
@@ -631,7 +631,7 @@ switch ($action) {
 		if ( !isset($filter_data['group_ids']) ) {
 				$filter_data['group_ids'] = NULL;
 		}
-		$uglf = new UserGroupListFactory();
+		$uglf = TTnew( 'UserGroupListFactory' );
 		$group_options = Misc::prependArray( $all_array_option, $uglf->getArrayByNodes( FastTree::FormatArray( $uglf->getByCompanyIdArray( $current_company->getId() ), 'TEXT', TRUE) ) );
 		$filter_data['src_group_options'] = Misc::arrayDiffByKey( (array)$filter_data['group_ids'], $group_options );
 		$filter_data['selected_group_options'] = Misc::arrayIntersectByKey( (array)$filter_data['group_ids'], $group_options );
@@ -640,7 +640,7 @@ switch ($action) {
 		if ( !isset($filter_data['branch_ids']) ) {
 				$filter_data['branch_ids'] = NULL;
 		}
-		$blf = new BranchListFactory();
+		$blf = TTnew( 'BranchListFactory' );
 		$blf->getByCompanyId( $current_company->getId() );
 		$branch_options = Misc::prependArray( $all_array_option, $blf->getArrayByListFactory( $blf, FALSE, TRUE ) );
 		$filter_data['src_branch_options'] = Misc::arrayDiffByKey( (array)$filter_data['branch_ids'], $branch_options );
@@ -650,7 +650,7 @@ switch ($action) {
 		if ( !isset($filter_data['department_ids']) ) {
 				$filter_data['department_ids'] = NULL;
 		}
-		$dlf = new DepartmentListFactory();
+		$dlf = TTnew( 'DepartmentListFactory' );
 		$dlf->getByCompanyId( $current_company->getId() );
 		$department_options = Misc::prependArray( $all_array_option, $dlf->getArrayByListFactory( $dlf, FALSE, TRUE ) );
 		$filter_data['src_department_options'] = Misc::arrayDiffByKey( (array)$filter_data['department_ids'], $department_options );
@@ -660,7 +660,7 @@ switch ($action) {
 		if ( !isset($filter_data['user_title_ids']) ) {
 				$filter_data['user_title_ids'] = NULL;
 		}
-		$utlf = new UserTitleListFactory();
+		$utlf = TTnew( 'UserTitleListFactory' );
 		$utlf->getByCompanyId( $current_company->getId() );
 		$user_title_options = Misc::prependArray( $all_array_option, $utlf->getArrayByListFactory( $utlf, FALSE, TRUE ) );
 		$filter_data['src_user_title_options'] = Misc::arrayDiffByKey( (array)$filter_data['user_title_ids'], $user_title_options );
