@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: UserInformation.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4104 $
+ * $Id: UserInformation.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -140,7 +140,7 @@ $columns = array(						'-1010-employee_number' => TTi18n::gettext('Employee #'),
 										);
 
 //Get custom user fields
-$oflf = new OtherFieldListFactory();
+$oflf = TTnew( 'OtherFieldListFactory' );
 $other_field_names = $oflf->getByCompanyIdAndTypeIdArray( $current_company->getId(), 10 );
 if ( is_array($other_field_names) ) {
 	$columns = Misc::prependArray( $columns, $other_field_names);
@@ -172,7 +172,7 @@ if ( !isset($filter_data['column_ids']) ) {
 }
 
 //Company Deductions
-$cdlf = new CompanyDeductionListFactory();
+$cdlf = TTnew( 'CompanyDeductionListFactory' );
 $deduction_columns = $cdlf->getByCompanyIdAndStatusIdArray( $current_company->getId(), 10, FALSE);
 
 $columns = Misc::prependArray( $columns, $deduction_columns);
@@ -181,7 +181,7 @@ $columns = Misc::prependArray( $columns, $deduction_columns);
 $permission_children_ids = array();
 $wage_permission_children_ids = array();
 if ( $permission->Check('user','view') == FALSE ) {
-	$hlf = new HierarchyListFactory();
+	$hlf = TTnew( 'HierarchyListFactory' );
 	$permission_children_ids = $wage_permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId() );
 	Debug::Arr($permission_children_ids,'Permission Children Ids:', __FILE__, __LINE__, __METHOD__,10);
 
@@ -207,8 +207,8 @@ if ( $permission->Check('wage','view') == FALSE ) {
 	$wage_filter_data['permission_children_ids'] = $wage_permission_children_ids;
 }
 
-$ugdlf = new UserGenericDataListFactory();
-$ugdf = new UserGenericDataFactory();
+$ugdlf = TTnew( 'UserGenericDataListFactory' );
+$ugdf = TTnew( 'UserGenericDataFactory' );
 
 $action = Misc::findSubmitButton();
 switch ($action) {
@@ -218,7 +218,7 @@ switch ($action) {
 		//Debug::Arr($filter_data, 'Filter Data', __FILE__, __LINE__, __METHOD__,10);
 
 		//Get all employees that match the criteria:
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$ulf->getSearchByCompanyIdAndArrayCriteria( $current_company->getId(), $filter_data );
 		if ( $ulf->getRecordCount() > 0 ) {
 			foreach( $ulf as $u_obj ) {
@@ -228,46 +228,46 @@ switch ($action) {
 			$ulf->getReportByCompanyIdAndUserIDList( $current_company->getId(), $filter_data['user_ids'] );
 
 			//Get title list,
-			$utlf = new UserTitleListFactory();
+			$utlf = TTnew( 'UserTitleListFactory' );
 			$user_titles = $utlf->getByCompanyIdArray( $current_company->getId() );
 
-			$uglf = new UserGroupListFactory();
+			$uglf = TTnew( 'UserGroupListFactory' );
 			$group_options = $uglf->getArrayByNodes( FastTree::FormatArray( $uglf->getByCompanyIdArray( $current_company->getId() ), 'no_tree_text', TRUE) );
 
 			//Get default branch list
-			$blf = new BranchListFactory();
+			$blf = TTnew( 'BranchListFactory' );
 			$branch_options = $blf->getByCompanyIdArray( $current_company->getId() );
 
-			$dlf = new DepartmentListFactory();
+			$dlf = TTnew( 'DepartmentListFactory' );
 			$department_options = $dlf->getByCompanyIdArray( $current_company->getId() );
 
-			$pclf = new PermissionControlListFactory();
+			$pclf = TTnew( 'PermissionControlListFactory' );
 			$pclf->getByCompanyId( $current_company->getId() );
 			$permission_control_options = $pclf->getArrayByListFactory( $pclf, TRUE );
 
-			$ppslf = new PayPeriodScheduleListFactory();
+			$ppslf = TTnew( 'PayPeriodScheduleListFactory' );
 			$pay_period_schedule_options = $ppslf->getByCompanyIDArray( $current_company->getId() );
 
-			$pglf = new PolicyGroupListFactory();
+			$pglf = TTnew( 'PolicyGroupListFactory' );
 			$policy_group_options = $pglf->getByCompanyIDArray( $current_company->getId() );
 
-			$pclf = new PermissionControlListFactory();
+			$pclf = TTnew( 'PermissionControlListFactory' );
 			$pclf->getByCompanyIdAndUserId( $current_company->getId(), $filter_data['user_ids'] );
 			$permission_control_user_map = $pclf->getUserToPermissionControlMapArrayByListFactory( $pclf );
 
-			$ppslf = new PayPeriodScheduleListFactory();
+			$ppslf = TTnew( 'PayPeriodScheduleListFactory' );
 			$ppslf->getByCompanyIdAndUserId( $current_company->getId(), $filter_data['user_ids'] );
 			$pay_period_schedule_user_map = $ppslf->getUserToPayPeriodScheduleMapArrayByListFactory( $ppslf );
 
-			$pglf = new PolicyGroupListFactory();
+			$pglf = TTnew( 'PolicyGroupListFactory' );
 			$pglf->getByCompanyIdAndUserId( $current_company->getId(), $filter_data['user_ids'] );
 			$policy_group_user_map = $pglf->getUserToPolicyGroupMapArrayByListFactory( $pglf );
 
-			$crlf = new CurrencyListFactory();
+			$crlf = TTnew( 'CurrencyListFactory' );
 			$crlf->getByCompanyId( $current_company->getId() );
 			$currency_options = $crlf->getArrayByListFactory( $crlf, FALSE, TRUE );
 
-			$upf = new UserPreferenceFactory();
+			$upf = TTnew( 'UserPreferenceFactory' );
 			$language_options = TTi18n::getLanguageArray();
 			$date_format_options = $upf->getOptions('date_format');
 			$time_format_options = $upf->getOptions('time_format');
@@ -280,7 +280,7 @@ switch ($action) {
             if ( $permission->Check('wage','view') == TRUE ) {
                 $wage_filter_data['permission_children_ids'] = $filter_data['user_ids'];
             }
-			$uwlf = new UserWageListFactory();
+			$uwlf = TTnew( 'UserWageListFactory' );
 			$uwlf->getLastWageByUserIdAndDate( $wage_filter_data['permission_children_ids'], TTDate::getTime() );
 			if ( $uwlf->getRecordCount() > 0 ) {
 				foreach($uwlf as $uw_obj) {
@@ -293,7 +293,7 @@ switch ($action) {
 				}
 			}
 
-			$udlf = new UserDeductionListFactory();
+			$udlf = TTnew( 'UserDeductionListFactory' );
 			$udlf->getByCompanyIdAndUserId( $current_company->getId(), $filter_data['user_ids']);
 			if ( $udlf->getRecordCount() > 0 ) {
 				foreach( $udlf as $ud_obj ) {
@@ -358,7 +358,7 @@ switch ($action) {
 				}
 
 				//Get user preference data.
-				$uplf = new UserPreferenceListFactory();
+				$uplf = TTnew( 'UserPreferenceListFactory' );
 				$uplf->getByUserId( $u_obj->getId() );
 				if ( $uplf->getRecordCount() > 0 ) {
 					$up_obj = $uplf->getCurrent();
@@ -599,7 +599,7 @@ switch ($action) {
 			}
 		}
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$all_array_option = array('-1' => TTi18n::gettext('-- All --'));
 
 		//Get include employee list.
@@ -633,7 +633,7 @@ switch ($action) {
 		if ( !isset($filter_data['group_ids']) ) {
 			$filter_data['group_ids'] = NULL;
 		}
-		$uglf = new UserGroupListFactory();
+		$uglf = TTnew( 'UserGroupListFactory' );
 		$group_options = Misc::prependArray( $all_array_option, $uglf->getArrayByNodes( FastTree::FormatArray( $uglf->getByCompanyIdArray( $current_company->getId() ), 'TEXT', TRUE) ) );
 		$filter_data['src_group_options'] = Misc::arrayDiffByKey( (array)$filter_data['group_ids'], $group_options );
 		$filter_data['selected_group_options'] = Misc::arrayIntersectByKey( (array)$filter_data['group_ids'], $group_options );
@@ -643,7 +643,7 @@ switch ($action) {
 		if ( !isset($filter_data['branch_ids']) ) {
 			$filter_data['branch_ids'] = NULL;
 		}
-		$blf = new BranchListFactory();
+		$blf = TTnew( 'BranchListFactory' );
 		$blf->getByCompanyId( $current_company->getId() );
 		$branch_options = Misc::prependArray( $all_array_option, $blf->getArrayByListFactory( $blf, FALSE, TRUE ) );
 		$filter_data['src_branch_options'] = Misc::arrayDiffByKey( (array)$filter_data['branch_ids'], $branch_options );
@@ -653,7 +653,7 @@ switch ($action) {
 		if ( !isset($filter_data['department_ids']) ) {
 			$filter_data['department_ids'] = NULL;
 		}
-		$dlf = new DepartmentListFactory();
+		$dlf = TTnew( 'DepartmentListFactory' );
 		$dlf->getByCompanyId( $current_company->getId() );
 		$department_options = Misc::prependArray( $all_array_option, $dlf->getArrayByListFactory( $dlf, FALSE, TRUE ) );
 		$filter_data['src_department_options'] = Misc::arrayDiffByKey( (array)$filter_data['department_ids'], $department_options );
@@ -663,7 +663,7 @@ switch ($action) {
 		if ( !isset($filter_data['user_title_ids']) ) {
 			$filter_data['user_title_ids'] = NULL;
 		}
-		$utlf = new UserTitleListFactory();
+		$utlf = TTnew( 'UserTitleListFactory' );
 		$utlf->getByCompanyId( $current_company->getId() );
 		$user_title_options = Misc::prependArray( $all_array_option, $utlf->getArrayByListFactory( $utlf, FALSE, TRUE ) );
 		$filter_data['src_user_title_options'] = Misc::arrayDiffByKey( (array)$filter_data['user_title_ids'], $user_title_options );
