@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3937 $
- * $Id: WagesPayableSummary.php 3937 2010-11-19 19:54:51Z ipso $
- * $Date: 2010-11-19 11:54:51 -0800 (Fri, 19 Nov 2010) $
+ * $Revision: 4104 $
+ * $Id: WagesPayableSummary.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -56,7 +56,7 @@ function getUserWageObject( $user_wage_id, $user_id ) {
 		AND is_object($user_wage_obj[$user_wage_id]) ) {
 		return $user_wage_obj[$user_wage_id];
 	} else {
-		$uwlf = new UserWageListFactory();
+		$uwlf = TTnew( 'UserWageListFactory' );
 
 		//This handles future wage changes properly.
 		$uwlf->getByIDAndUserId( $user_wage_id, $user_id );
@@ -119,7 +119,7 @@ $append_columns = array(
 $columns = array_merge($static_columns, $append_columns);
 
 //Get all Overtime policies.
-$otplf = new OverTimePolicyListFactory();
+$otplf = TTnew( 'OverTimePolicyListFactory' );
 $otplf->getByCompanyId($current_company->getId());
 if ( $otplf->getRecordCount() > 0 ) {
 	foreach ($otplf as $otp_obj ) {
@@ -134,7 +134,7 @@ if ( $otplf->getRecordCount() > 0 ) {
 }
 
 //Get all Premium policies.
-$pplf = new PremiumPolicyListFactory();
+$pplf = TTnew( 'PremiumPolicyListFactory' );
 $pplf->getByCompanyId($current_company->getId());
 if ( $pplf->getRecordCount() > 0 ) {
 	foreach ($pplf as $pp_obj ) {
@@ -148,7 +148,7 @@ if ( $pplf->getRecordCount() > 0 ) {
 }
 
 //Get all Absence Policies.
-$aplf = new AbsencePolicyListFactory();
+$aplf = TTnew( 'AbsencePolicyListFactory' );
 $aplf->getByCompanyId($current_company->getId());
 if ( $aplf->getRecordCount() > 0 ) {
 	foreach ($aplf as $ap_obj ) {
@@ -165,7 +165,7 @@ if ( $aplf->getRecordCount() > 0 ) {
 }
 
 //Get all pay periods
-$pplf = new PayPeriodListFactory();
+$pplf = TTnew( 'PayPeriodListFactory' );
 $pplf->getByCompanyId( $current_company->getId() );
 if ( $pplf->getRecordCount() > 0 ) {
 	$pp=0;
@@ -180,7 +180,7 @@ if ( $pplf->getRecordCount() > 0 ) {
 		$pp++;
 	}
 
-	$pplf = new PayPeriodListFactory();
+	$pplf = TTnew( 'PayPeriodListFactory' );
 	$pay_period_options = $pplf->getByIdListArray($pay_period_ids, NULL, array('start_date' => 'desc'));
 } else {
 	$pay_period_options = array();
@@ -214,7 +214,7 @@ $filter_data = Misc::preSetArrayValues( $filter_data, array('include_user_ids',
 $permission_children_ids = array();
 $wage_permission_children_ids = array();
 if ( $permission->Check('punch','view') == FALSE ) {
-	$hlf = new HierarchyListFactory();
+	$hlf = TTnew( 'HierarchyListFactory' );
 	$permission_children_ids = $wage_permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId() );
 	Debug::Arr($permission_children_ids,'Permission Children Ids:', __FILE__, __LINE__, __METHOD__,10);
 
@@ -240,8 +240,8 @@ if ( $permission->Check('wage','view') == FALSE ) {
 	$wage_filter_data['permission_children_ids'] = $wage_permission_children_ids;
 }
 
-$ugdlf = new UserGenericDataListFactory();
-$ugdf = new UserGenericDataFactory();
+$ugdlf = TTnew( 'UserGenericDataListFactory' );
+$ugdf = TTnew( 'UserGenericDataFactory' );
 
 $action = Misc::findSubmitButton();
 switch ($action) {
@@ -252,7 +252,7 @@ switch ($action) {
 		Debug::Text('Submit!', __FILE__, __LINE__, __METHOD__,10);
 		//Debug::Arr($filter_data, 'Filter Data', __FILE__, __LINE__, __METHOD__,10);
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$ulf->getSearchByCompanyIdAndArrayCriteria( $current_company->getId(), $filter_data );
 		if ( $ulf->getRecordCount() > 0 ) {
 			if ( isset($filter_data['date_type']) AND $filter_data['date_type'] == 'pay_period_ids' ) {
@@ -276,19 +276,19 @@ switch ($action) {
 				unset($key, $tmp_filter_pay_period_ids, $filter_pay_period_id);
 			}
 
-			$utlf = new UserTitleListFactory();
+			$utlf = TTnew( 'UserTitleListFactory' );
 			$title_options = $utlf->getByCompanyIdArray( $current_company->getId() );
 
-			$uglf = new UserGroupListFactory();
+			$uglf = TTnew( 'UserGroupListFactory' );
 			$group_options = $uglf->getArrayByNodes( FastTree::FormatArray( $uglf->getByCompanyIdArray( $current_company->getId() ), 'no_tree_text', TRUE) );
 
-			$blf = new BranchListFactory();
+			$blf = TTnew( 'BranchListFactory' );
 			$branch_options = $blf->getByCompanyIdArray( $current_company->getId() );
 
-			$dlf = new DepartmentListFactory();
+			$dlf = TTnew( 'DepartmentListFactory' );
 			$department_options = $dlf->getByCompanyIdArray( $current_company->getId() );
 
-			$crlf = new CurrencyListFactory();
+			$crlf = TTnew( 'CurrencyListFactory' );
 			$crlf->getByCompanyId( $current_company->getId() );
 			$currency_options = $crlf->getArrayByListFactory( $crlf, FALSE, TRUE );
 
@@ -304,7 +304,7 @@ switch ($action) {
 				$currency_convert_to_base = TRUE;
 			}
 
-			$udtlf = new UserDateTotalListFactory();
+			$udtlf = TTnew( 'UserDateTotalListFactory' );
 			$udtlf->getDayReportByCompanyIdAndArrayCriteria( $current_company->getId(), $filter_data );
 			foreach ($udtlf as $udt_obj ) {
 				$user_id = $udt_obj->getColumn('id');
@@ -355,7 +355,7 @@ switch ($action) {
 			}
 			//print_r($raw_rows);
 
-			$ulf = new UserListFactory();
+			$ulf = TTnew( 'UserListFactory' );
 
 			if ( isset($raw_rows) ) {
 				$x=0;
@@ -631,7 +631,7 @@ switch ($action) {
 		}
 		$filter_data = Misc::preSetArrayValues( $filter_data, array('include_user_ids', 'exclude_user_ids', 'user_status_ids', 'group_ids', 'branch_ids', 'department_ids', 'user_title_ids', 'pay_period_ids', 'currency_ids', 'column_ids' ), NULL);
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$all_array_option = array('-1' => TTi18n::gettext('-- All --'));
 
 		//Get include employee list.
@@ -651,41 +651,41 @@ switch ($action) {
 		$filter_data['selected_user_status_options'] = Misc::arrayIntersectByKey( (array)$filter_data['user_status_ids'], $user_status_options );
 
 		//Get Employee Groups
-		$uglf = new UserGroupListFactory();
+		$uglf = TTnew( 'UserGroupListFactory' );
 		$group_options = Misc::prependArray( $all_array_option, $uglf->getArrayByNodes( FastTree::FormatArray( $uglf->getByCompanyIdArray( $current_company->getId() ), 'TEXT', TRUE) ) );
 		$filter_data['src_group_options'] = Misc::arrayDiffByKey( (array)$filter_data['group_ids'], $group_options );
 		$filter_data['selected_group_options'] = Misc::arrayIntersectByKey( (array)$filter_data['group_ids'], $group_options );
 
 		//Get branches
-		$blf = new BranchListFactory();
+		$blf = TTnew( 'BranchListFactory' );
 		$blf->getByCompanyId( $current_company->getId() );
 		$branch_options = Misc::prependArray( $all_array_option, $blf->getArrayByListFactory( $blf, FALSE, TRUE ) );
 		$filter_data['src_branch_options'] = Misc::arrayDiffByKey( (array)$filter_data['branch_ids'], $branch_options );
 		$filter_data['selected_branch_options'] = Misc::arrayIntersectByKey( (array)$filter_data['branch_ids'], $branch_options );
 
 		//Get departments
-		$dlf = new DepartmentListFactory();
+		$dlf = TTnew( 'DepartmentListFactory' );
 		$dlf->getByCompanyId( $current_company->getId() );
 		$department_options = Misc::prependArray( $all_array_option, $dlf->getArrayByListFactory( $dlf, FALSE, TRUE ) );
 		$filter_data['src_department_options'] = Misc::arrayDiffByKey( (array)$filter_data['department_ids'], $department_options );
 		$filter_data['selected_department_options'] = Misc::arrayIntersectByKey( (array)$filter_data['department_ids'], $department_options );
 
 		//Get employee titles
-		$utlf = new UserTitleListFactory();
+		$utlf = TTnew( 'UserTitleListFactory' );
 		$utlf->getByCompanyId( $current_company->getId() );
 		$user_title_options = Misc::prependArray( $all_array_option, $utlf->getArrayByListFactory( $utlf, FALSE, TRUE ) );
 		$filter_data['src_user_title_options'] = Misc::arrayDiffByKey( (array)$filter_data['user_title_ids'], $user_title_options );
 		$filter_data['selected_user_title_options'] = Misc::arrayIntersectByKey( (array)$filter_data['user_title_ids'], $user_title_options );
 
 		//Get currencies
-		$crlf = new CurrencyListFactory();
+		$crlf = TTnew( 'CurrencyListFactory' );
 		$crlf->getByCompanyId( $current_company->getId() );
 		$currency_options = Misc::prependArray( $all_array_option, $crlf->getArrayByListFactory( $crlf, FALSE, TRUE ) );
 		$filter_data['src_currency_options'] = Misc::arrayDiffByKey( (array)$filter_data['currency_ids'], $currency_options );
 		$filter_data['selected_currency_options'] = Misc::arrayIntersectByKey( (array)$filter_data['currency_ids'], $currency_options );
 
 		//Get pay periods
-		$pplf = new PayPeriodListFactory();
+		$pplf = TTnew( 'PayPeriodListFactory' );
 		$pplf->getByCompanyId( $current_company->getId() );
 		$pay_period_options = Misc::prependArray( $all_array_option, $pplf->getArrayByListFactory( $pplf, FALSE, TRUE ) );
 		$filter_data['src_pay_period_options'] = Misc::arrayDiffByKey( (array)$filter_data['pay_period_ids'], $pay_period_options );
