@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 1368 $
- * $Id: UserRequestList.php 1368 2007-10-29 21:27:14Z ipso $
- * $Date: 2007-10-29 14:27:14 -0700 (Mon, 29 Oct 2007) $
+ * $Revision: 4207 $
+ * $Id: UserRequestList.php 4207 2011-02-02 00:54:08Z ipso $
+ * $Date: 2011-02-01 16:54:08 -0800 (Tue, 01 Feb 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -83,7 +83,7 @@ $filter_data = array();
 //Get Permission Hierarchy Children first, as this can be used for viewing, or editing.
 $permission_children_ids = array();
 if ( $permission->Check('request','view') == FALSE ) {
-	$hlf = new HierarchyListFactory();
+	$hlf = TTnew( 'HierarchyListFactory' );
 	$permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId() );
 
 	if ( $permission->Check('request','view_child') == FALSE ) {
@@ -105,7 +105,8 @@ switch ($action) {
 		//Redirect::Page( URLBuilder::getURL( NULL, 'EditRequest.php', FALSE) );
 
 		break;
-	case 'delete' OR 'undelete':
+	case 'delete':
+	case 'undelete':
 		//Debug::setVerbosity(11);
 		if ( strtolower($action) == 'delete' ) {
 			$delete = TRUE;
@@ -113,7 +114,7 @@ switch ($action) {
 			$delete = FALSE;
 		}
 
-		$rlf = new RequestListFactory();
+		$rlf = TTnew( 'RequestListFactory' );
 
 		foreach ($ids as $id) {
 			$rlf->getByIdAndCompanyId( $id, $current_company->getId() );
@@ -141,7 +142,7 @@ switch ($action) {
 			$filter_data['end_date'] = $filter_end_date;
 		}
 
-		$rlf = new RequestListFactory();
+		$rlf = TTnew( 'RequestListFactory' );
 		$rlf->getByCompanyIdAndArrayCriteria( $current_company->getId(), $filter_data, $current_user_prefs->getItemsPerPage(), $page, NULL, $sort_array );
 
 		/*
@@ -173,7 +174,7 @@ switch ($action) {
 
 		}
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$ulf->getSearchByCompanyIdAndArrayCriteria( $current_company->getId(), $filter_data );
 		$user_options = UserListFactory::getArrayByListFactory( $ulf, FALSE, FALSE );
 
