@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3392 $
- * $Id: EditROE.php 3392 2010-03-05 19:31:18Z ipso $
- * $Date: 2010-03-05 11:31:18 -0800 (Fri, 05 Mar 2010) $
+ * $Revision: 4104 $
+ * $Id: EditROE.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -64,7 +64,7 @@ extract	(FormVariables::GetVariables(
 												'user_id'
 												) ) );
 
-$roef = new ROEFactory();
+$roef = TTnew( 'ROEFactory' );
 
 if ( isset($roe_data) ) {
 	if ( $roe_data['first_date'] != '' ) {
@@ -81,8 +81,8 @@ if ( isset($roe_data) ) {
 	}
 }
 
-$ugdlf = new UserGenericDataListFactory();
-$ugdf = new UserGenericDataFactory();
+$ugdlf = TTnew( 'UserGenericDataListFactory' );
+$ugdf = TTnew( 'UserGenericDataFactory' );
 
 $action = Misc::findSubmitButton();
 switch ($action) {
@@ -143,7 +143,7 @@ switch ($action) {
 
 			$roef->Save();
 
-			$ugsf = new UserGenericStatusFactory();
+			$ugsf = TTnew( 'UserGenericStatusFactory' );
 			$ugsf->setUser( $current_user->getId() );
 			$ugsf->setBatchID( $ugsf->getNextBatchId() );
 			$ugsf->setQueue( UserGenericStatusFactory::getStaticQueue() );
@@ -172,7 +172,7 @@ switch ($action) {
 		if ( isset($id) ) {
 			BreadCrumb::setCrumb($title);
 
-			$roelf = new ROEListFactory();
+			$roelf = TTnew( 'ROEListFactory' );
 
 			$roelf->getById( $id );
 
@@ -206,13 +206,13 @@ switch ($action) {
 			//Guess for end dates...
 
 			//get User data for hire date
-			$ulf = new UserListFactory();
+			$ulf = TTnew( 'UserListFactory' );
 			$user_obj = $ulf->getById($user_id)->getCurrent();
 
-			$plf = new PunchListFactory();
+			$plf = TTnew( 'PunchListFactory' );
 
 			//Is there a previous ROE? If so, find first shift back since ROE was issued.
-			$rlf = new ROEListFactory();
+			$rlf = TTnew( 'ROEListFactory' );
 			$rlf->getLastROEByUserId( $user_id );
 			if ( $rlf->getRecordCount() > 0 ) {
 				$roe_obj = $rlf->getCurrent();
@@ -242,7 +242,7 @@ switch ($action) {
 			Debug::Text('Last Punch Date: '. TTDate::getDate('DATE+TIME', $last_date) , __FILE__, __LINE__, __METHOD__,10);
 
 			//Get pay period of last shift workd
-			$plf = new PayPeriodListFactory();
+			$plf = TTnew( 'PayPeriodListFactory' );
 			$pay_period_obj = $plf->getByUserIdAndEndDate( $user_id, $last_date )->getCurrent();
 
 			$pay_period_type_id = FALSE;
@@ -261,7 +261,7 @@ switch ($action) {
 		//Select box options;
 		$roe_data['code_options'] = $roef->getOptions('code');
 
-		$ppsf = new PayPeriodScheduleFactory();
+		$ppsf = TTnew( 'PayPeriodScheduleFactory' );
 		$roe_data['pay_period_type_options'] = $ppsf->getOptions('type');
 		unset($roe_data['pay_period_type_options'][5]);
 
@@ -269,7 +269,7 @@ switch ($action) {
 		$smarty->assign_by_ref('user_options', $user_options);
 
 		//PSEA accounts
-		$psealf = new PayStubEntryAccountListFactory();
+		$psealf = TTnew( 'PayStubEntryAccountListFactory' );
 		$earning_pay_stub_entry_account_options = $psealf->getByCompanyIdAndStatusIdAndTypeIdArray( $current_company->getId(), 10, array(10,30,40), TRUE );
 		$smarty->assign_by_ref('earning_pay_stub_entry_account_options', $earning_pay_stub_entry_account_options);
 
