@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 1246 $
- * $Id: RoundPolicyList.php 1246 2007-09-14 23:47:42Z ipso $
- * $Date: 2007-09-14 16:47:42 -0700 (Fri, 14 Sep 2007) $
+ * $Revision: 4104 $
+ * $Id: RoundPolicyList.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -90,7 +90,7 @@ switch ($action) {
 			$delete = FALSE;
 		}
 
-		$rplf = new RoundPolicyListFactory();
+		$rplf = TTnew( 'RoundPolicyListFactory' );
 
 		foreach ($ids as $id) {
 			$rplf->getByIdAndCompanyId($id, $current_company->getId() );
@@ -105,7 +105,7 @@ switch ($action) {
 		break;
 
 	default:
-		$rplf = new RoundPolicyListFactory();
+		$rplf = TTnew( 'RoundPolicyListFactory' );
 
 		$rplf->getByCompanyId($current_company->getId(), $current_user_prefs->getItemsPerPage(),$page, NULL, $sort_array );
 
