@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3003 $
- * $Id: AddMassSchedule.php 3003 2009-11-10 21:47:39Z ipso $
- * $Date: 2009-11-10 13:47:39 -0800 (Tue, 10 Nov 2009) $
+ * $Revision: 4104 $
+ * $Id: AddMassSchedule.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 
@@ -104,7 +104,7 @@ if ( isset($data) ) {
 }
 
 //Get Permission Hierarchy Children first, as this can be used for viewing, or editing.
-$hlf = new HierarchyListFactory();
+$hlf = TTnew( 'HierarchyListFactory' );
 $permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId() );
 //Debug::Arr($permission_children_ids,'Permission Children Ids:', __FILE__, __LINE__, __METHOD__,10);
 $filter_data = array();
@@ -117,8 +117,8 @@ if ( $permission->Check('schedule','edit') == FALSE ) {
 	}
 }
 
-$sf = new ScheduleFactory();
-$ulf = new UserListFactory();
+$sf = TTnew( 'ScheduleFactory' );
+$ulf = TTnew( 'UserListFactory' );
 
 $action = Misc::findSubmitButton();
 $action = strtolower($action);
@@ -179,7 +179,7 @@ switch ($action) {
 		}
 		//var_dump($data);
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$ulf->getSearchByCompanyIdAndArrayCriteria( $current_company->getId(), $filter_data );
 		$src_user_options = UserListFactory::getArrayByListFactory( $ulf, FALSE, FALSE );
 
@@ -188,28 +188,28 @@ switch ($action) {
 
 		$prepend_array_option = array( 0 => '--', -1 => TTi18n::gettext('-- Default --') );
 
-		$splf = new SchedulePolicyListFactory();
+		$splf = TTnew( 'SchedulePolicyListFactory' );
 		$schedule_policy_options = $splf->getByCompanyIdArray( $current_company->getId() );
 
-		$aplf = new AbsencePolicyListFactory();
+		$aplf = TTnew( 'AbsencePolicyListFactory' );
 		$absence_policy_options = $aplf->getByCompanyIdArray( $current_company->getId() );
 
-		$blf = new BranchListFactory();
+		$blf = TTnew( 'BranchListFactory' );
 		$blf->getByCompanyId( $current_company->getId() );
 		$branch_options = Misc::prependArray( $prepend_array_option,  $blf->getArrayByListFactory( $blf, FALSE, TRUE ) );
 
-		$dlf = new DepartmentListFactory();
+		$dlf = TTnew( 'DepartmentListFactory' );
 		$dlf->getByCompanyId( $current_company->getId() );
 		$department_options = Misc::prependArray( $prepend_array_option,  $dlf->getArrayByListFactory( $dlf, FALSE, TRUE ) );
 
 		if ( $current_company->getProductEdition() == 20 ) {
-			$jlf = new JobListFactory();
+			$jlf = TTnew( 'JobListFactory' );
 			$jlf->getByStatusIdAndCompanyId( array(10,20,30,40), $current_company->getId() );
 			//$jlf->getByCompanyIdAndUserIdAndStatus( $current_company->getId(),  $data['user_id'], array(10,20,30,40) );
 			$data['job_options'] = $jlf->getArrayByListFactory( $jlf, TRUE, TRUE );
 			$data['job_manual_id_options'] = $jlf->getManualIDArrayByListFactory($jlf, TRUE);
 
-			$jilf = new JobItemListFactory();
+			$jilf = TTnew( 'JobItemListFactory' );
 			$jilf->getByCompanyId( $current_company->getId() );
 			$data['job_item_options'] = $jilf->getArrayByListFactory( $jilf, TRUE );
 			$data['job_item_manual_id_options'] = $jilf->getManualIdArrayByListFactory( $jilf, TRUE );
