@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3567 $
- * $Id: RecurringScheduleTemplateControlList.php 3567 2010-05-12 17:35:29Z ipso $
- * $Date: 2010-05-12 10:35:29 -0700 (Wed, 12 May 2010) $
+ * $Revision: 4104 $
+ * $Id: RecurringScheduleTemplateControlList.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -82,9 +82,9 @@ switch ($action) {
 
 		break;
 	case 'copy':
-		$rstf = new RecurringScheduleTemplateFactory();
-		$rstlf = new RecurringScheduleTemplateListFactory();
-		$rstclf = new RecurringScheduleTemplateControlListFactory();
+		$rstf = TTnew( 'RecurringScheduleTemplateFactory' );
+		$rstlf = TTnew( 'RecurringScheduleTemplateListFactory' );
+		$rstclf = TTnew( 'RecurringScheduleTemplateControlListFactory' );
 
 		foreach ($ids as $id) {
 			$rstclf->getByIdAndCompanyId($id, $current_company->getId() );
@@ -179,7 +179,7 @@ switch ($action) {
 			$delete = FALSE;
 		}
 
-		$rstclf = new RecurringScheduleTemplateControlListFactory();
+		$rstclf = TTnew( 'RecurringScheduleTemplateControlListFactory' );
 
 		foreach ($ids as $id) {
 			$rstclf->getByIdAndCompanyId($id, $current_company->getId() );
@@ -196,7 +196,7 @@ switch ($action) {
 		break;
 
 	default:
-		$rstclf = new RecurringScheduleTemplateControlListFactory();
+		$rstclf = TTnew( 'RecurringScheduleTemplateControlListFactory' );
 
 		$filter_data = NULL;
 		if ( $permission->Check('recurring_schedule_template','view') == FALSE ) {
