@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3491 $
- * $Id: ViewSchedule.php 3491 2010-04-13 23:38:13Z ipso $
- * $Date: 2010-04-13 16:38:13 -0700 (Tue, 13 Apr 2010) $
+ * $Revision: 4104 $
+ * $Id: ViewSchedule.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -80,7 +80,7 @@ if ( isset( $filter_data['start_date'] ) AND $filter_data['start_date'] != '' )
 //Get Permission Hierarchy Children first, as this can be used for viewing, or editing.
 $permission_children_ids = array();
 if ( $permission->Check('schedule','view') == FALSE ) {
-	$hlf = new HierarchyListFactory();
+	$hlf = TTnew( 'HierarchyListFactory' );
 	$permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId() );
 
 	if ( $permission->Check('schedule','view_child') == FALSE ) {
@@ -93,8 +93,8 @@ if ( $permission->Check('schedule','view') == FALSE ) {
 	$filter_data['permission_children_ids'] = $permission_children_ids;
 }
 
-$ugdlf = new UserGenericDataListFactory();
-$ugdf = new UserGenericDataFactory();
+$ugdlf = TTnew( 'UserGenericDataListFactory' );
+$ugdf = TTnew( 'UserGenericDataFactory' );
 
 //Debug::setVerbosity(11);
 $action = Misc::findSubmitButton('do');
@@ -114,7 +114,7 @@ switch ($action) {
 		Debug::Text('Start Date: '. TTDate::getDate('DATE+TIME', $filter_data['start_date']), __FILE__, __LINE__, __METHOD__,10);
 		$filter_data['end_date'] = $filter_data['start_date'] + (($filter_data['show_days']*7)*86400-3601);
 
-		$sf = new ScheduleFactory();
+		$sf = TTnew( 'ScheduleFactory' );
 		$output = $sf->getSchedule( $filter_data, $current_user_prefs->getStartWeekDay(), $filter_data['group_schedule'] );
 
 		//print_r($output);
@@ -169,7 +169,7 @@ switch ($action) {
 			}
 		}
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$all_array_option = array('-1' => TTi18n::gettext('-- All --'));
 
 		if ( !isset($filter_data['show_days']) OR ( isset($filter_data['show_days']) AND $filter_data['show_days'] == '' ) ) {
@@ -202,7 +202,7 @@ switch ($action) {
 		if ( !isset($filter_data['group_ids']) ) {
 			$filter_data['group_ids'] = NULL;
 		}
-		$uglf = new UserGroupListFactory();
+		$uglf = TTnew( 'UserGroupListFactory' );
 		$group_options = Misc::prependArray( $all_array_option, $uglf->getArrayByNodes( FastTree::FormatArray( $uglf->getByCompanyIdArray( $current_company->getId() ), 'TEXT', TRUE) ) );
 		$filter_data['src_group_options'] = Misc::arrayDiffByKey( (array)$filter_data['group_ids'], $group_options );
 		$filter_data['selected_group_options'] = Misc::arrayIntersectByKey( (array)$filter_data['group_ids'], $group_options );
@@ -214,7 +214,7 @@ switch ($action) {
 		if ( !isset($filter_data['default_branch_ids']) ) {
 			$filter_data['default_branch_ids'] = NULL;
 		}
-		$blf = new BranchListFactory();
+		$blf = TTnew( 'BranchListFactory' );
 		$blf->getByCompanyId( $current_company->getId() );
 		$branch_options = Misc::prependArray( $all_array_option, $blf->getArrayByListFactory( $blf, FALSE, TRUE ) );
 		$filter_data['src_schedule_branch_options'] = Misc::arrayDiffByKey( (array)$filter_data['schedule_branch_ids'], $branch_options );
@@ -229,7 +229,7 @@ switch ($action) {
 		if ( !isset($filter_data['default_department_ids']) ) {
 			$filter_data['default_department_ids'] = NULL;
 		}
-		$dlf = new DepartmentListFactory();
+		$dlf = TTnew( 'DepartmentListFactory' );
 		$dlf->getByCompanyId( $current_company->getId() );
 		$department_options = Misc::prependArray( $all_array_option, $dlf->getArrayByListFactory( $dlf, FALSE, TRUE ) );
 		$filter_data['src_schedule_department_options'] = Misc::arrayDiffByKey( (array)$filter_data['schedule_department_ids'], $department_options );
@@ -241,7 +241,7 @@ switch ($action) {
 		if ( !isset($filter_data['user_title_ids']) ) {
 			$filter_data['user_title_ids'] = NULL;
 		}
-		$utlf = new UserTitleListFactory();
+		$utlf = TTnew( 'UserTitleListFactory' );
 		$utlf->getByCompanyId( $current_company->getId() );
 		$user_title_options = Misc::prependArray( $all_array_option, $utlf->getArrayByListFactory( $utlf, FALSE, TRUE ) );
 		$filter_data['src_user_title_options'] = Misc::arrayDiffByKey( (array)$filter_data['user_title_ids'], $user_title_options );
