@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 1246 $
- * $Id: ViewScheduleCalendar.php 1246 2007-09-14 23:47:42Z ipso $
- * $Date: 2007-09-14 16:47:42 -0700 (Fri, 14 Sep 2007) $
+ * $Revision: 4104 $
+ * $Id: ViewScheduleCalendar.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -110,7 +110,7 @@ switch ($action) {
 
 		Debug::text(' Start Date: '. TTDate::getDate('DATE+TIME', $start_date) .' End Date: '. TTDate::getDate('DATE+TIME', $end_date) , __FILE__, __LINE__, __METHOD__,10);
 
-		$sf = new ScheduleFactory();
+		$sf = TTnew( 'ScheduleFactory' );
 		$default_schedule_shifts = $sf->getScheduleArray( $user_id, $start_date, $end_date);
 		//var_dump($default_schedule_shifts);
 
@@ -119,14 +119,14 @@ switch ($action) {
 		$smarty->assign_by_ref('calendar_array', $calendar_array);
 		//$smarty->assign_by_ref('pay_period_locked_rows', $pay_period_locked_rows);
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$user_obj = $ulf->getById( $user_id )->getCurrent();
 
 		/*
 		$holiday = new Holiday();
 		$holiday->GetByCountryAndProvince($user_obj->getCountry(), $user_obj->getProvince() );
 		*/
-		$hlf = new HolidayListFactory();
+		$hlf = TTnew( 'HolidayListFactory' );
 		$holiday_array = $hlf->getArrayByPolicyGroupUserId( $user_id, $start_date, $end_date );
 		//var_dump($holiday_array);
 
