@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3252 $
- * $Id: ViewScheduleLinear.php 3252 2010-01-07 22:35:06Z ipso $
- * $Date: 2010-01-07 14:35:06 -0800 (Thu, 07 Jan 2010) $
+ * $Revision: 4104 $
+ * $Id: ViewScheduleLinear.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -86,7 +86,7 @@ if ( !isset($filter_data['show_days']) OR ( isset($filter_data['show_days']) AND
 $filter_data['show_days'] = $filter_data['show_days'] * 7;
 
 //Get Permission Hierarchy Children first, as this can be used for viewing, or editing.
-$hlf = new HierarchyListFactory();
+$hlf = TTnew( 'HierarchyListFactory' );
 $permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId() );
 if ( $permission->Check('schedule','view') == FALSE ) {
 	if ( $permission->Check('schedule','view_child') == FALSE ) {
@@ -119,7 +119,7 @@ switch ($do) {
 		$min_hour = 0;
 		$max_hour = 0;
 
-		$sf = new ScheduleFactory();
+		$sf = TTnew( 'ScheduleFactory' );
 		$raw_schedule_shifts = $sf->getScheduleArray(  $filter_data );
 		if ( is_array($raw_schedule_shifts) ) {
 			foreach( $raw_schedule_shifts as $day_epoch => $day_schedule_shifts ) {
@@ -317,7 +317,7 @@ switch ($do) {
 		//var_dump($calendar_array);
 		$smarty->assign_by_ref('calendar_array', $calendar_array);
 
-		$hlf = new HolidayListFactory();
+		$hlf = TTnew( 'HolidayListFactory' );
 		$holiday_array = $hlf->getArrayByPolicyGroupUserId( $user_ids, $start_date, $end_date );
 		//var_dump($holiday_array);
 
