@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2681 $
- * $Id: ViewScheduleMonth.php 2681 2009-07-23 22:30:39Z ipso $
- * $Date: 2009-07-23 15:30:39 -0700 (Thu, 23 Jul 2009) $
+ * $Revision: 4104 $
+ * $Id: ViewScheduleMonth.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -83,7 +83,7 @@ if ( !isset($filter_data['show_days']) OR ( isset($filter_data['show_days']) AND
 $filter_data['show_days'] = $filter_data['show_days'] * 7;
 
 //Get Permission Hierarchy Children first, as this can be used for viewing, or editing.
-$hlf = new HierarchyListFactory();
+$hlf = TTnew( 'HierarchyListFactory' );
 $permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId() );
 if ( $permission->Check('schedule','view') == FALSE ) {
 	if ( $permission->Check('schedule','view_child') == FALSE ) {
@@ -113,7 +113,7 @@ switch (strtolower($do)) {
 		Debug::text(' Start Date: '. TTDate::getDate('DATE+TIME', $start_date) .' End Date: '. TTDate::getDate('DATE+TIME', $end_date) , __FILE__, __LINE__, __METHOD__,10);
 
 		//var_dump( $filter_data);
-		$sf = new ScheduleFactory();
+		$sf = TTnew( 'ScheduleFactory' );
 		$raw_schedule_shifts = $sf->getScheduleArray( $filter_data );
 		//Debug::Arr($raw_schedule_shifts, 'Raw Schedule Shifts1: ', __FILE__, __LINE__, __METHOD__, 10);
 		if ( is_array($raw_schedule_shifts) ) {
@@ -176,7 +176,7 @@ switch (strtolower($do)) {
 		}
 		$smarty->assign_by_ref('calendar_column_headers', $calendar_column_headers);
 
-		$hlf = new HolidayListFactory();
+		$hlf = TTnew( 'HolidayListFactory' );
 		$holiday_array = $hlf->getArrayByPolicyGroupUserId( $user_ids, $start_date, $end_date );
 		//var_dump($holiday_array);
 		$smarty->assign_by_ref('holidays', $holiday_array);
