@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3405 $
- * $Id: EditStation.php 3405 2010-03-10 23:55:01Z ipso $
- * $Date: 2010-03-10 15:55:01 -0800 (Wed, 10 Mar 2010) $
+ * $Revision: 4104 $
+ * $Id: EditStation.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -60,7 +60,7 @@ extract	(FormVariables::GetVariables(
 												'data'
 												) ) );
 
-$sf = new StationFactory();
+$sf = TTnew( 'StationFactory' );
 
 $action = Misc::findSubmitButton();
 switch ($action) {
@@ -185,7 +185,7 @@ switch ($action) {
 				//$tc->setUsername( $data['user_name'] );
 				$tc->setPassword( $data['password'] );
 
-				$slf = new StationListFactory();
+				$slf = TTnew( 'StationListFactory' );
 				$slf->getByIdAndCompanyId( $data['id'], $current_company->getId() );
 				if ( $slf->getRecordCount() == 1 ) {
 					$s_obj = $slf->getCurrent();
@@ -295,7 +295,7 @@ switch ($action) {
 		if ( isset($id) ) {
 			BreadCrumb::setCrumb($title);
 
-			$slf = new StationListFactory();
+			$slf = TTnew( 'StationListFactory' );
 
 			$slf->GetByIdAndCompanyId($id, $current_company->getId() );
 
@@ -373,35 +373,35 @@ switch ($action) {
 		$data['mode_flag_options'] = $sf->getOptions('mode_flag');
 
 		if ( $current_company->getProductEdition() == 20 ) {
-			$jlf = new JobListFactory();
+			$jlf = TTnew( 'JobListFactory' );
 			$jlf->getByCompanyId( $current_company->getId() );
 			$data['job_options'] = Misc::prependArray( array(0 => '-- None --'), $jlf->getArrayByListFactory( $jlf, FALSE, TRUE ) );
 
-			$jilf = new JobItemListFactory();
+			$jilf = TTnew( 'JobItemListFactory' );
 			$jilf->getByCompanyIdAndStatus( $current_company->getId(), 10 );
 			$data['job_item_options'] = Misc::prependArray( array(0 => '-- None --'), $jilf->getArrayByListFactory( $jilf, TRUE, FALSE ) );
 		}
 
 		//Get branches
-		$blf = new BranchListFactory();
+		$blf = TTnew( 'BranchListFactory' );
 		$blf->getByCompanyId( $current_company->getId() );
 		$branch_options = $blf->getArrayByListFactory( $blf, FALSE, TRUE );
 		$data['src_branch_options'] = Misc::arrayDiffByKey( (array)$data['branch_ids'], $branch_options );
 		$data['selected_branch_options'] = Misc::arrayIntersectByKey( (array)$data['branch_ids'], $branch_options );
 
 		//Get departments
-		$dlf = new DepartmentListFactory();
+		$dlf = TTnew( 'DepartmentListFactory' );
 		$dlf->getByCompanyId( $current_company->getId() );
 		$department_options = $dlf->getArrayByListFactory( $dlf, FALSE, TRUE );
 		$data['src_department_options'] = Misc::arrayDiffByKey( (array)$data['department_ids'], $department_options );
 		$data['selected_department_options'] = Misc::arrayIntersectByKey( (array)$data['department_ids'], $department_options );
 
-		$uglf = new UserGroupListFactory();
+		$uglf = TTnew( 'UserGroupListFactory' );
 		$group_options = $uglf->getArrayByNodes( FastTree::FormatArray( $uglf->getByCompanyIdArray( $current_company->getId() ), 'TEXT', TRUE) );
 		$data['src_group_options'] = Misc::arrayDiffByKey( (array)$data['group_ids'], $group_options );
 		$data['selected_group_options'] = Misc::arrayIntersectByKey( (array)$data['group_ids'], $group_options );
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$ulf->getSearchByCompanyIdAndArrayCriteria( $current_company->getId(), NULL );
 		$user_options = $ulf->getArrayByListFactory( $ulf, FALSE, TRUE );
 
@@ -418,7 +418,7 @@ switch ($action) {
 		$data['branch_options'] = Misc::prependArray( array(0 => '-- None --'), $branch_options );
 		$data['department_options'] = Misc::prependArray( array(0 => '-- None --'), $department_options );
 
-		$upf = new UserPreferenceFactory();
+		$upf = TTnew( 'UserPreferenceFactory' );
 		$timezone_options = Misc::prependArray( array(0 => '-- None --'), $upf->getOptions('time_zone') );
 		$data['time_zone_options'] = $timezone_options;
 
