@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 1246 $
- * $Id: EditStationUser.php 1246 2007-09-14 23:47:42Z ipso $
- * $Date: 2007-09-14 16:47:42 -0700 (Fri, 14 Sep 2007) $
+ * $Revision: 4104 $
+ * $Id: EditStationUser.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -60,7 +60,7 @@ extract	(FormVariables::GetVariables(
 												'station_data'
 												) ) );
 
-$sf = new StationFactory();
+$sf = TTnew( 'StationFactory' );
 
 $action = Misc::findSubmitButton();
 switch ($action) {
@@ -88,8 +88,8 @@ switch ($action) {
 		if ( isset($id) ) {
 			BreadCrumb::setCrumb($title);
 
-			$slf = new StationListFactory();
-			$sulf = new StationUserListFactory();
+			$slf = TTnew( 'StationListFactory' );
+			$sulf = TTnew( 'StationUserListFactory' );
 
 			$slf->GetByIdAndCompanyId($id, $current_company->getId() );
 
