@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3928 $
- * $Id: ViewUserTimeSheet.php 3928 2010-11-11 20:29:54Z ipso $
- * $Date: 2010-11-11 12:29:54 -0800 (Thu, 11 Nov 2010) $
+ * $Revision: 4104 $
+ * $Id: ViewUserTimeSheet.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -127,7 +127,7 @@ extract	(FormVariables::GetVariables(
 												) ) );
 
 //Load default filter settings, if other filter settings aren't set.
-$ugdlf = new UserGenericDataListFactory();
+$ugdlf = TTnew( 'UserGenericDataListFactory' );
 
 $ugdlf->getByUserIdAndScriptAndDefault( $current_user->getId(), $_SERVER['SCRIPT_NAME'], TRUE );
 if ( $ugdlf->getRecordCount() > 0 ) {
@@ -157,20 +157,20 @@ if ( !isset($filter_data['department_ids']) ) {
 	$filter_data['department_ids'] = -1;
 }
 
-$uglf = new UserGroupListFactory();
+$uglf = TTnew( 'UserGroupListFactory' );
 $group_options = $uglf->getArrayByNodes( FastTree::FormatArray( $uglf->getByCompanyIdArray( $current_company->getId() ), 'TEXT', TRUE) );
 
-$blf = new BranchListFactory();
+$blf = TTnew( 'BranchListFactory' );
 $blf->getByCompanyId( $current_company->getId() );
 $branch_options = $blf->getArrayByListFactory( $blf, FALSE, TRUE );
 
-$dlf = new DepartmentListFactory();
+$dlf = TTnew( 'DepartmentListFactory' );
 $dlf->getByCompanyId( $current_company->getId() );
 $department_options = $dlf->getArrayByListFactory( $dlf, FALSE, TRUE );
 
-$ulf = new UserListFactory();
+$ulf = TTnew( 'UserListFactory' );
 
-$hlf = new HierarchyListFactory();
+$hlf = TTnew( 'HierarchyListFactory' );
 $permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId() );
 //Debug::Arr($permission_children_ids,'Permission Children Ids:', __FILE__, __LINE__, __METHOD__,10);
 if ( $permission->Check('punch','view') == FALSE ) {
@@ -230,7 +230,7 @@ if ( isset($prev_week) ) {
 
 //Get current PP info
 if ( isset($prev_pp) OR isset($next_pp) ) {
-	$pplf = new PayPeriodListFactory();
+	$pplf = TTnew( 'PayPeriodListFactory' );
 	$pplf->getByUserIdAndEndDate( $user_id, $filter_data['date'] );
 	if ( $pplf->getRecordCount() > 0 ) {
 		//Debug::setVerbosity(11);
@@ -260,7 +260,7 @@ if ( $filter_data['date'] == '' OR $filter_data['date'] <= 0 ) {
 }
 
 //Save current filter settings, so when we come back to the timesheet they are loaded.
-$ugdf = new UserGenericDataFactory();
+$ugdf = TTnew( 'UserGenericDataFactory' );
 if ( isset($generic_data) AND $generic_data['id'] != '' AND $generic_data['id'] != 0 ) {
 	Debug::text('Passed ID: ', __FILE__, __LINE__, __METHOD__,10);
 	$ugdf->setID( $generic_data['id'] );
@@ -283,7 +283,7 @@ if ( $ugdf->isValid() ) {
 }
 
 //Get pay period info from filter date.
-$udlf = new UserDateListFactory();
+$udlf = TTnew( 'UserDateListFactory' );
 $udlf->getByUserIdAndDate( $user_id, $filter_data['date'] );
 if ( $udlf->getRecordCount() > 0 ) {
 	$pay_period_id = $udlf->getCurrent()->getPayPeriod();
@@ -295,7 +295,7 @@ if ( $udlf->getRecordCount() > 0 ) {
 	//This will guess they belong to the new pay period schedule.
 	//Only real fix I see for this is to make sure we have a user_date row for EVERY day, for EVERY
 	//user, regardless if they work or not.
-	$pplf = new PayPeriodListFactory();
+	$pplf = TTnew( 'PayPeriodListFactory' );
 	$pplf->getByUserIdAndEndDate( $user_id, $filter_data['date'] );
 	if ( $pplf->getRecordCount() > 0 ) {
 		$pay_period_obj = $pplf->getCurrent();
@@ -304,7 +304,7 @@ if ( $udlf->getRecordCount() > 0 ) {
 		$pay_period_id = FALSE;
 	}
 }
-$pplf = new PayPeriodListFactory();
+$pplf = TTnew( 'PayPeriodListFactory' );
 $pplf->getById( $pay_period_id );
 if ( $pplf->getRecordCount() > 0 ) {
 	$pay_period_obj = $pplf->getCurrent();
@@ -329,12 +329,12 @@ switch ($action) {
 		//Debug::setVerbosity(11);
 		Debug::text('Verifying Pay Period TimeSheet ', __FILE__, __LINE__, __METHOD__,10);
 
-		$pptsvlf = new PayPeriodTimeSheetVerifyListFactory();
+		$pptsvlf = TTnew( 'PayPeriodTimeSheetVerifyListFactory' );
 		$pptsvlf->StartTransaction();
 		$pptsvlf->getByPayPeriodIdAndUserId( $pay_period_obj->getId(), $user_id );
 		if ( $pptsvlf->getRecordCount() == 0 ) {
 			Debug::text('Timesheet NOT verified by employee yet.', __FILE__, __LINE__, __METHOD__,10);
-			$pptsvf = new PayPeriodTimeSheetVerifyFactory();
+			$pptsvf = TTnew( 'PayPeriodTimeSheetVerifyFactory' );
 		} else {
 			Debug::text('Timesheet re-verified by employee, or superior...', __FILE__, __LINE__, __METHOD__,10);
 			$pptsvf = $pptsvlf->getCurrent();
@@ -358,10 +358,10 @@ switch ($action) {
 
 		//Find out if a pay stub is already generated for the pay period we are currently in.
 		//If it is, delete it so we can start from fresh
-		$pplf = new PayPeriodListFactory();
+		$pplf = TTnew( 'PayPeriodListFactory' );
 		$pplf->getByIdAndCompanyId($pay_period_id, $current_company->getId() );
 
-		$pslf = new PayStubListFactory();
+		$pslf = TTnew( 'PayStubListFactory' );
 		$pslf->getByUserIdAndPayPeriodId( $filter_data['user_id'], $pay_period_id );
 
 		foreach ($pslf as $pay_stub) {
@@ -442,7 +442,7 @@ switch ($action) {
 		//var_dump($calendar_array);
 
 		//Get all punches, put in array by date epoch.
-		$plf = new PunchListFactory();
+		$plf = TTnew( 'PunchListFactory' );
 		$plf->getByCompanyIDAndUserIdAndStartDateAndEndDate( $current_company->getId(), $user_id, $start_date, $end_date);
 		if ( $plf->getRecordCount() > 0 ) {
 			foreach($plf as $punch_obj) {
@@ -659,9 +659,9 @@ switch ($action) {
 		unset($punches);
 
 		//Get date total rows.
-		$udtlf = new UserDateTotalListFactory();
+		$udtlf = TTnew( 'UserDateTotalListFactory' );
 
-		$mplf = new MealPolicyListFactory();
+		$mplf = TTnew( 'MealPolicyListFactory' );
 		$meal_policy_options = $mplf->getByCompanyIdArray( $current_company->getId() );
 		unset($mplf);
 
@@ -718,7 +718,7 @@ switch ($action) {
 		}
 
 
-		$bplf = new BreakPolicyListFactory();
+		$bplf = TTnew( 'BreakPolicyListFactory' );
 		$break_policy_options = $bplf->getByCompanyIdArray( $current_company->getId() );
 		unset($bplf);
 
@@ -852,14 +852,14 @@ switch ($action) {
 		$job_options = array();
 		$job_item_options = array();
 		if ( $current_company->getProductEdition() == 20 ) {
-			$jlf = new JobListFactory();
+			$jlf = TTnew( 'JobListFactory' );
 			$job_options = $jlf->getByCompanyIdArray( $current_company->getId(), FALSE );
 
-			$jilf = new JobItemListFactory();
+			$jilf = TTnew( 'JobItemListFactory' );
 			$job_item_options = $jilf->getByCompanyIdArray( $current_company->getId(), FALSE );
 		}
 
-		$udtlf = new UserDateTotalListFactory();
+		$udtlf = TTnew( 'UserDateTotalListFactory' );
 		//Get only worked/paid absence totals.
 		$udtlf->getPaidTimeByCompanyIDAndUserIdAndStatusAndStartDateAndEndDate( $current_company->getId(), $user_id, array(10,30) , $start_date, $end_date);
 		if ( $udtlf->getRecordCount() > 0 ) {
@@ -1017,11 +1017,11 @@ switch ($action) {
 
 
 		*/
-		$pplf_b = new PremiumPolicyListFactory();
+		$pplf_b = TTnew( 'PremiumPolicyListFactory' );
 		$premium_policy_options = $pplf_b->getByCompanyIdArray( $current_company->getId() );
 		unset($pplf_b);
 
-		$udtlf = new UserDateTotalListFactory();
+		$udtlf = TTnew( 'UserDateTotalListFactory' );
 		//Get only worked totals.
 		$udtlf->getByCompanyIDAndUserIdAndStatusAndTypeAndStartDateAndEndDate( $current_company->getId(), $user_id, 10, 40, $start_date, $end_date);
 		if ( $udtlf->getRecordCount() > 0 ) {
@@ -1082,10 +1082,10 @@ switch ($action) {
 
 
 		*/
-		$aplf = new AbsencePolicyListFactory();
+		$aplf = TTnew( 'AbsencePolicyListFactory' );
 		$absence_policy_options = $aplf->getByCompanyIdArray( $current_company->getId() );
 
-		$udtlf = new UserDateTotalListFactory();
+		$udtlf = TTnew( 'UserDateTotalListFactory' );
 		//Get only worked totals.
 		$udtlf->getByCompanyIDAndUserIdAndStatusAndStartDateAndEndDate( $current_company->getId(), $user_id, 30, $start_date, $end_date);
 		if ( $udtlf->getRecordCount() > 0 ) {
@@ -1154,7 +1154,7 @@ switch ($action) {
 
 
 		*/
-		$elf = new ExceptionListFactory();
+		$elf = TTnew( 'ExceptionListFactory' );
 		$elf->getByCompanyIDAndUserIdAndStartDateAndEndDate( $current_company->getID(), $user_id, $start_date, $end_date);
 		$punch_exceptions = array();
 		if ( $elf->getRecordCount() > 0 ) {
@@ -1200,7 +1200,7 @@ switch ($action) {
 
 		//Get exception names for legend.
 		if ( isset($unique_exceptions) ) {
-			$epf = new ExceptionPolicyFactory();
+			$epf = TTnew( 'ExceptionPolicyFactory' );
 			$exception_options = $epf->getOptions('type');
 			foreach( $unique_exceptions as $unique_exception ) {
 				$unique_exceptions[$unique_exception['exception_policy_type_id']]['name'] = $exception_options[$unique_exception['exception_policy_type_id']];
@@ -1216,7 +1216,7 @@ switch ($action) {
 
 
 		*/
-		$rlf = new RequestListFactory();
+		$rlf = TTnew( 'RequestListFactory' );
 		$rlf->getByCompanyIDAndUserIdAndStatusAndStartDateAndEndDate( $current_company->getID(), $user_id, 30, $start_date, $end_date);
 		if ( $rlf->getRecordCount() > 0 ) {
 			Debug::text('Found Requests!!: ', __FILE__, __LINE__, __METHOD__,10);
@@ -1251,7 +1251,7 @@ switch ($action) {
 
 		*/
 
-		$hlf = new HolidayListFactory();
+		$hlf = TTnew( 'HolidayListFactory' );
 		$holiday_array = $hlf->getArrayByPolicyGroupUserId( $user_id, $start_date, $end_date );
 		//var_dump($holiday_array);
 
@@ -1292,7 +1292,7 @@ switch ($action) {
 		*/
 		if ( isset($pay_period_obj) AND is_object($pay_period_obj) ) {
 			$is_timesheet_superior = FALSE;
-			$pptsvlf = new PayPeriodTimeSheetVerifyListFactory();
+			$pptsvlf = TTnew( 'PayPeriodTimeSheetVerifyListFactory' );
 			$pptsvlf->getByPayPeriodIdAndUserId( $pay_period_obj->getId(), $user_id );
 
 			if ( $pptsvlf->getRecordCount() > 0 ) {
@@ -1335,7 +1335,7 @@ switch ($action) {
 		//Sum all Paid Absences
 		//Sum all Dock Absences
 		//Sum all Regular/OverTime hours
-		$udtlf = new UserDateTotalListFactory();
+		$udtlf = TTnew( 'UserDateTotalListFactory' );
 		$worked_total_time = (int)$udtlf->getWorkedTimeSumByUserIDAndPayPeriodId( $user_id, $pay_period_id );
 		Debug::text('Worked Total Time: '. $worked_total_time, __FILE__, __LINE__, __METHOD__,10);
 
@@ -1348,7 +1348,7 @@ switch ($action) {
 		$udtlf->getRegularAndOverTimeSumByUserIDAndPayPeriodId( $user_id, $pay_period_id );
 		if ( $udtlf->getRecordCount() > 0 ) {
 			//Get overtime policy names
-			$otplf = new OverTimePolicyListFactory();
+			$otplf = TTnew( 'OverTimePolicyListFactory' );
 			$over_time_policy_options = $otplf->getByCompanyIdArray( $current_company->getId(), FALSE );
 
 			foreach($udtlf as $udt_obj ) {
@@ -1420,7 +1420,7 @@ switch ($action) {
 		} else {
 			Debug::text('Pay Period Object NOT Found!', __FILE__, __LINE__, __METHOD__,10);
 			//Check to see if employee is even assigned to pay period schedule.
-			$ppslf = new PayPeriodScheduleListFactory();
+			$ppslf = TTnew( 'PayPeriodScheduleListFactory' );
 			$ppslf->getByCompanyIdAndUserId( $current_company->getId(), $user_id );
 			if ( $ppslf->getRecordCount() > 0 ) {
 				Debug::text('Pay Period Schedule Found!', __FILE__, __LINE__, __METHOD__,10);
