@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3928 $
- * $Id: EditUser.php 3928 2010-11-11 20:29:54Z ipso $
- * $Date: 2010-11-11 12:29:54 -0800 (Thu, 11 Nov 2010) $
+ * $Revision: 4845 $
+ * $Id: EditUser.php 4845 2011-06-21 16:23:18Z ipso $
+ * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -83,10 +83,10 @@ if ( isset($user_data) ) {
 	$user_data['birth_date'] = TTDate::getTimeStampFromSmarty('birth_', $user_data);
 }
 
-$ulf = new UserListFactory();
-$uf = new UserFactory();
+$ulf = TTnew( 'UserListFactory' );
+$uf = TTnew( 'UserFactory' );
 
-$hlf = new HierarchyListFactory();
+$hlf = TTnew( 'HierarchyListFactory' );
 $permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeId( $current_company->getId(), $current_user->getId() );
 //Include current user in list.
 if ( $permission->Check('user','edit_own') ) {
@@ -94,7 +94,7 @@ if ( $permission->Check('user','edit_own') ) {
 }
 //Debug::Arr($permission_children_ids,'Permission Children Ids:', __FILE__, __LINE__, __METHOD__,10);
 
-Debug::Text('aCompany ID: '. $company_id, __FILE__, __LINE__, __METHOD__,10);
+//Debug::Text('aCompany ID: '. $company_id, __FILE__, __LINE__, __METHOD__,10);
 
 $action = Misc::findSubmitButton();
 switch ($action) {
@@ -154,7 +154,7 @@ switch ($action) {
 		}
 
         //Get New Hire Defaults.
-        $udlf = new UserDefaultListFactory();
+        $udlf = TTnew( 'UserDefaultListFactory' );
         $udlf->getByCompanyId( $uf->getCompany() );
         if ( $udlf->getRecordCount() > 0 ) {
             Debug::Text('Using User Defaults', __FILE__, __LINE__, __METHOD__,10);
@@ -187,14 +187,8 @@ switch ($action) {
 				}
 			}
 
-			if ( !empty($user_data['phone_password']) OR !empty($user_data['phone_password2']) ) {
-				if ( $user_data['phone_password'] == $user_data['phone_password2'] ) {
-					$uf->setPhonePassword($user_data['phone_password']);
-				} else {
-					$uf->Validator->isTrue( 'phone_password',
-											FALSE,
-											TTi18n::gettext('Passwords don\'t match') );
-				}
+			if ( isset( $user_data['phone_password'] ) ) {
+				$uf->setPhonePassword($user_data['phone_password']);
 			}
 		}
 
@@ -397,14 +391,14 @@ switch ($action) {
 			break;
 		}
 	default:
-		Debug::Text('bCompany ID: '. $company_id, __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Text('bCompany ID: '. $company_id, __FILE__, __LINE__, __METHOD__,10);
 		if ( $permission->Check('company','view') == FALSE OR $company_id == '' OR $company_id == '-1' ) {
 			$company_id = $current_company->getId();
 		}
-		Debug::Text('cCompany ID: '. $company_id, __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Text('cCompany ID: '. $company_id, __FILE__, __LINE__, __METHOD__,10);
 
 		if ( isset($id) AND $action !== 'submit' ) {
-			Debug::Text('ID IS set', __FILE__, __LINE__, __METHOD__,10);
+			//Debug::Text('ID IS set', __FILE__, __LINE__, __METHOD__,10);
 
 			BreadCrumb::setCrumb($title);
 
@@ -493,25 +487,25 @@ switch ($action) {
 										'deleted_by' => $user->getDeletedBy()
 									);
 
-					$pclfb = new PermissionControlListFactory();
+					$pclfb = TTnew( 'PermissionControlListFactory' );
 					$pclfb->getByCompanyIdAndUserId( $user->getCompany(), $id );
 					if ( $pclfb->getRecordCount() > 0 ) {
 						$user_data['permission_control_id'] = $pclfb->getCurrent()->getId();
 					}
 
-					$ppslfb = new PayPeriodScheduleListFactory();
+					$ppslfb = TTnew( 'PayPeriodScheduleListFactory' );
 					$ppslfb->getByUserId( $id );
 					if ( $ppslfb->getRecordCount() > 0 ) {
 						$user_data['pay_period_schedule_id'] = $ppslfb->getCurrent()->getId();
 					}
 
-					$pglf = new PolicyGroupListFactory();
+					$pglf = TTnew( 'PolicyGroupListFactory' );
 					$pglf->getByUserIds( $id );
 					if ( $pglf->getRecordCount() > 0 ) {
 						$user_data['policy_group_id'] = $pglf->getCurrent()->getId();
 					}
 
-					$hclf = new HierarchyControlListFactory();
+					$hclf = TTnew( 'HierarchyControlListFactory' );
 					$hclf->getObjectTypeAppendedListByCompanyIDAndUserID( $user->getCompany(), $user->getID() );
 					$user_data['hierarchy_control'] = $hclf->getArrayByListFactory( $hclf, FALSE, TRUE, FALSE );
 					unset($hclf);
@@ -576,7 +570,7 @@ switch ($action) {
 			Debug::Text('Adding new User.', __FILE__, __LINE__, __METHOD__,10);
 
 			//Get New Hire Defaults.
-			$udlf = new UserDefaultListFactory();
+			$udlf = TTnew( 'UserDefaultListFactory' );
 			$udlf->getByCompanyId( $company_id );
 			if ( $udlf->getRecordCount() > 0 ) {
 				Debug::Text('Using User Defaults', __FILE__, __LINE__, __METHOD__,10);
@@ -634,20 +628,20 @@ switch ($action) {
 		//var_dump($user_data);
 
 		//Select box options;
-		$blf = new BranchListFactory();
+		$blf = TTnew( 'BranchListFactory' );
 		$branch_options = $blf->getByCompanyIdArray( $company_id );
 
-		$dlf = new DepartmentListFactory();
+		$dlf = TTnew( 'DepartmentListFactory' );
 		$department_options = $dlf->getByCompanyIdArray( $company_id );
 
-		$culf = new CurrencyListFactory();
+		$culf = TTnew( 'CurrencyListFactory' );
         $culf->getByCompanyId( $company_id );
 		$currency_options = $culf->getArrayByListFactory( $culf, FALSE, TRUE );
 
-		$hotf = new HierarchyObjectTypeFactory();
+		$hotf = TTnew( 'HierarchyObjectTypeFactory' );
 		$hierarchy_object_type_options = $hotf->getOptions('object_type');
 
-		$hclf = new HierarchyControlListFactory();
+		$hclf = TTnew( 'HierarchyControlListFactory' );
 		$hclf->getObjectTypeAppendedListByCompanyID( $company_id );
 		$hierarchy_control_options = $hclf->getArrayByListFactory( $hclf, TRUE, TRUE );
 
@@ -659,33 +653,33 @@ switch ($action) {
 		$user_data['sex_options'] = $uf->getOptions('sex');
 		$user_data['status_options'] = $uf->getOptions('status');
 
-		$clf = new CompanyListFactory();
+		$clf = TTnew( 'CompanyListFactory' );
 		$user_data['country_options'] = $clf->getOptions('country');
 		$user_data['province_options'] = $clf->getOptions('province', $user_data['country'] );
 
-		$utlf = new UserTitleListFactory();
+		$utlf = TTnew( 'UserTitleListFactory' );
 		$user_titles = $utlf->getByCompanyIdArray( $company_id );
 		$user_data['title_options'] = $user_titles;
 
 		//Get Permission Groups
-		$pclf = new PermissionControlListFactory();
+		$pclf = TTnew( 'PermissionControlListFactory' );
 		$pclf->getByCompanyIdAndLevel( $company_id, $permission->getLevel() );
 		$user_data['permission_control_options'] = $pclf->getArrayByListFactory( $pclf, FALSE );
 
 		//Get pay period schedules
-		$ppslf = new PayPeriodScheduleListFactory();
+		$ppslf = TTnew( 'PayPeriodScheduleListFactory' );
 		$pay_period_schedules = $ppslf->getByCompanyIDArray( $company_id );
 		$user_data['pay_period_schedule_options'] = $pay_period_schedules;
 
-		$pglf = new PolicyGroupListFactory();
+		$pglf = TTnew( 'PolicyGroupListFactory' );
 		$policy_groups = $pglf->getByCompanyIDArray( $company_id );
 		$user_data['policy_group_options'] = $policy_groups;
 
-		$uglf = new UserGroupListFactory();
+		$uglf = TTnew( 'UserGroupListFactory' );
 		$user_data['group_options'] = $uglf->getArrayByNodes( FastTree::FormatArray( $uglf->getByCompanyIdArray( $company_id ), 'TEXT', TRUE) );
 
 		//Get other field names
-		$oflf = new OtherFieldListFactory();
+		$oflf = TTnew( 'OtherFieldListFactory' );
 		$user_data['other_field_names'] = $oflf->getByCompanyIdAndTypeIdArray( $company_id, 10 );
 
 		$user_data['hierarchy_object_type_options'] = $hierarchy_object_type_options;
