@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3193 $
- * $Id: EditUserDeduction.php 3193 2009-12-18 23:17:53Z ipso $
- * $Date: 2009-12-18 15:17:53 -0800 (Fri, 18 Dec 2009) $
+ * $Revision: 4104 $
+ * $Id: EditUserDeduction.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -61,9 +61,9 @@ extract	(FormVariables::GetVariables(
 												'data'
 												) ) );
 
-$udf = new UserDeductionFactory();
-$cdf = new CompanyDeductionFactory();
-$ulf = new UserListFactory();
+$udf = TTnew( 'UserDeductionFactory' );
+$cdf = TTnew( 'CompanyDeductionFactory' );
+$ulf = TTnew( 'UserListFactory' );
 
 $action = Misc::findSubmitButton();
 $action = strtolower($action);
@@ -140,7 +140,7 @@ switch ($action) {
 				Debug::Text('Adding Deductions', __FILE__, __LINE__, __METHOD__,10);
 				if ( isset($data['deduction_ids']) AND count($data['deduction_ids']) > 0 ) {
 					foreach( $data['deduction_ids'] as $deduction_id ) {
-						$udf = new UserDeductionFactory();
+						$udf = TTnew( 'UserDeductionFactory' );
 						$udf->setUser( $data['user_id'] );
 						$udf->setCompanyDeduction( $deduction_id );
 						if ( $udf->isValid() ) {
@@ -201,13 +201,13 @@ switch ($action) {
 		}
 		$udf->FailTransaction();
 	default:
-		$cf = new CompanyFactory();
+		$cf = TTnew( 'CompanyFactory' );
 
 		if ( isset($company_deduction_id) AND $company_deduction_id != '' ) {
 			Debug::Text('Mass User Deduction Edit!', __FILE__, __LINE__, __METHOD__,10);
 
 			//Get all employees assigned to this company deduction.
-			$cdlf = new CompanyDeductionListFactory();
+			$cdlf = TTnew( 'CompanyDeductionListFactory' );
 			$cdlf->getByCompanyIdAndId( $current_company->getId(), $company_deduction_id );
 			Debug::Text('Company Deduction Records: '. $cdlf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
 			if ( $cdlf->getRecordCount() > 0 ) {
@@ -273,7 +273,7 @@ switch ($action) {
 						Debug::Text('Assigned Users: '. count($user_ids), __FILE__, __LINE__, __METHOD__,10);
 						if ( is_array($user_ids) AND count($user_ids) > 0 ) {
 							//Get User deduction data for each user.
-							$udlf = new UserDeductionListFactory();
+							$udlf = TTnew( 'UserDeductionListFactory' );
 							$udlf->getByUserIdAndCompanyDeductionId( $user_ids, $cd_obj->getId() );
 							if ( $udlf->getRecordCount() > 0 ) {
 								//Get deduction data for each user.
@@ -336,10 +336,10 @@ switch ($action) {
 				BreadCrumb::setCrumb($title);
 
 				//Get Permission Hierarchy Children first, as this can be used for viewing, or editing.
-				$hlf = new HierarchyListFactory();
+				$hlf = TTnew( 'HierarchyListFactory' );
 				$permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId() );
 
-				$udlf = new UserDeductionListFactory();
+				$udlf = TTnew( 'UserDeductionListFactory' );
 				$udlf->getByCompanyIdAndId( $current_company->getID(), $id );
 
 				foreach ($udlf as $ud_obj) {
@@ -462,10 +462,10 @@ switch ($action) {
 				$data['user_id'] = $user_id;
 
 				//Get all Company Deductions for drop down box.
-				$cdlf = new CompanyDeductionListFactory();
+				$cdlf = TTnew( 'CompanyDeductionListFactory' );
 				$data['deduction_options'] = $cdlf->getByCompanyIdAndStatusIdArray( $current_company->getId(), 10, FALSE);
 
-				$udlf = new UserDeductionListFactory();
+				$udlf = TTnew( 'UserDeductionListFactory' );
 				$udlf->getByCompanyIdAndUserId( $current_company->getId(), $user_id );
 				if ($udlf->getRecordCount() > 0 ) {
 					//Remove deductions from select box that are already assigned to user.
@@ -479,7 +479,7 @@ switch ($action) {
 			}
 
 			//Get user full name
-			$ulf = new UserListFactory();
+			$ulf = TTnew( 'UserListFactory' );
 			$ulf->getByIdAndCompanyId( $data['user_id'], $current_company->getId() );
 			if ( $ulf->getRecordCount() > 0 ) {
 				$data['user_full_name'] = $ulf->getCurrent()->getFullName();
