@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 1246 $
- * $Id: EditUserGroup.php 1246 2007-09-14 23:47:42Z ipso $
- * $Date: 2007-09-14 16:47:42 -0700 (Fri, 14 Sep 2007) $
+ * $Revision: 4104 $
+ * $Id: EditUserGroup.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -61,7 +61,7 @@ extract	(FormVariables::GetVariables(
 												'data'
 												) ) );
 
-$ugf = new UserGroupFactory();
+$ugf = TTnew( 'UserGroupFactory' );
 
 $action = Misc::findSubmitButton();
 switch ($action) {
@@ -82,7 +82,7 @@ switch ($action) {
 			break;
 		}
 	default:
-		$uglf = new UserGroupListFactory();
+		$uglf = TTnew( 'UserGroupListFactory' );
 
 		$nodes = FastTree::FormatArray( $uglf->getByCompanyIdArray( $current_company->getId() ), 'TEXT', TRUE);
 
