@@ -35,9 +35,9 @@
  ********************************************************************************/
 /*
 
- * $Revision: 1246 $
- * $Id: EditUserTax.php 1246 2007-09-14 23:47:42Z ipso $
- * $Date: 2007-09-14 16:47:42 -0700 (Fri, 14 Sep 2007) $
+ * $Revision: 4104 $
+ * $Id: EditUserTax.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -64,7 +64,7 @@ extract	(FormVariables::GetVariables(
 												'data_saved'
 												) ) );
 
-$utf = new UserTaxFactory();
+$utf = TTnew( 'UserTaxFactory' );
 
 $action = Misc::findSubmitButton();
 switch ($action) {
@@ -191,13 +191,13 @@ switch ($action) {
 
 			Debug::Text('User ID: '. $user_id, __FILE__, __LINE__, __METHOD__,10);
 
-			$ulf = new UserListFactory();
+			$ulf = TTnew( 'UserListFactory' );
 			$ulf->getByIdAndCompanyId( $user_id, $current_company->getId() );
 			if ($ulf->getRecordCount() > 0 ) {
 				$user_obj = $ulf->getCurrent();
 			}
 
-			$utlf = new UserTaxListFactory();
+			$utlf = TTnew( 'UserTaxListFactory' );
 
 			//$uwlf->GetByUserIdAndCompanyId($current_user->getId(), $current_company->getId() );
 			$utlf->GetByUserId($user_id);
@@ -277,7 +277,7 @@ switch ($action) {
 		$smarty->assign_by_ref('tax_data', $tax_data);
 		$smarty->assign_by_ref('user_id', $user_id);
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$ulf->getByIdAndCompanyId( $user_id, $current_company->getId() );
 		$user_data = $ulf->getCurrent();
 
