@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2740 $
- * $Id: EditUserWage.php 2740 2009-08-19 20:21:50Z ipso $
- * $Date: 2009-08-19 13:21:50 -0700 (Wed, 19 Aug 2009) $
+ * $Revision: 4104 $
+ * $Id: EditUserWage.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -69,12 +69,12 @@ if ( isset($wage_data) ) {
 }
 
 //Get Permission Hierarchy Children first, as this can be used for viewing, or editing.
-$hlf = new HierarchyListFactory();
+$hlf = TTnew( 'HierarchyListFactory' );
 $permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId() );
 
-$uwf = new UserWageFactory();
+$uwf = TTnew( 'UserWageFactory' );
 
-$ulf = new UserListFactory();
+$ulf = TTnew( 'UserListFactory' );
 
 $action = Misc::findSubmitButton();
 $action = strtolower($action);
@@ -118,7 +118,7 @@ switch ($action) {
 		if ( isset($id) ) {
 			BreadCrumb::setCrumb($title);
 
-			$uwlf = new UserWageListFactory();
+			$uwlf = TTnew( 'UserWageListFactory' );
 			$uwlf->getByIdAndCompanyId($id, $current_company->getId() );
 
 			foreach ($uwlf as $wage) {
@@ -168,14 +168,14 @@ switch ($action) {
 		//Select box options;
 		$wage_data['type_options'] = $uwf->getOptions('type');
 
-		$wglf = new WageGroupListFactory();
+		$wglf = TTnew( 'WageGroupListFactory' );
 		$wage_data['wage_group_options'] = $wglf->getArrayByListFactory( $wglf->getByCompanyId( $current_company->getId() ), TRUE );
 
-		$crlf = new CurrencyListFactory();
+		$crlf = TTnew( 'CurrencyListFactory' );
 		$crlf->getByCompanyId( $current_company->getId() );
 		$currency_options = $crlf->getArrayByListFactory( $crlf, FALSE, TRUE );
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 		$ulf->getByIdAndCompanyId( $user_id, $current_company->getId() );
 		$user_data = $ulf->getCurrent();
 		if ( is_object( $user_data->getCurrencyObject() ) ) {
@@ -188,14 +188,14 @@ switch ($action) {
 		$pay_period_boundary_dates[TTDate::getDate('DATE', $user_data->getHireDate() )] = TTi18n::gettext('(Hire Date)').' '. TTDate::getDate('DATE', $user_data->getHireDate() );
 		$pay_period_boundary_dates = Misc::prependArray( array(-1 => TTi18n::gettext('(Choose Date)')), $pay_period_boundary_dates);
 
-		$ppslf = new PayPeriodScheduleListFactory();
+		$ppslf = TTnew( 'PayPeriodScheduleListFactory' );
 		$ppslf->getByUserId( $user_id );
 		if ( $ppslf->getRecordCount() > 0 ) {
 			$pay_period_schedule_id = $ppslf->getCurrent()->getId();
 			$pay_period_schedule_name = $ppslf->getCurrent()->getName();
 			Debug::Text('Pay Period Schedule ID: '. $pay_period_schedule_id, __FILE__, __LINE__, __METHOD__,10);
 
-			$pplf = new PayPeriodListFactory();
+			$pplf = TTnew( 'PayPeriodListFactory' );
 			$pplf->getByPayPeriodScheduleId( $pay_period_schedule_id, 10, NULL, NULL, array('transaction_date' => 'desc') );
 			$pay_period_dates = NULL;
 			foreach($pplf as $pay_period_obj) {
