@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 1934 $
- * $Id: UserDeductionList.php 1934 2008-06-23 22:22:17Z ipso $
- * $Date: 2008-06-23 15:22:17 -0700 (Mon, 23 Jun 2008) $
+ * $Revision: 4104 $
+ * $Id: UserDeductionList.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -79,7 +79,7 @@ if ( $sort_column != '' ) {
 Debug::Arr($ids,'Selected Objects', __FILE__, __LINE__, __METHOD__,10);
 
 
-$ulf = new UserListFactory();
+$ulf = TTnew( 'UserListFactory' );
 
 $action = Misc::findSubmitButton();
 switch ($action) {
@@ -95,7 +95,7 @@ switch ($action) {
 			$delete = FALSE;
 		}
 
-		$udlf = new UserDeductionListFactory();
+		$udlf = TTnew( 'UserDeductionListFactory' );
 
 		if ( isset($ids) AND is_array($ids) ) {
 			foreach ($ids as $id) {
@@ -116,10 +116,10 @@ switch ($action) {
 		BreadCrumb::setCrumb($title);
 
 		//Get Permission Hierarchy Children first, as this can be used for viewing, or editing.
-		$hlf = new HierarchyListFactory();
+		$hlf = TTnew( 'HierarchyListFactory' );
 		$permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId() );
 
-		$udlf = new UserDeductionListFactory();
+		$udlf = TTnew( 'UserDeductionListFactory' );
 		$udlf->getByCompanyIdAndUserId( $current_company->getId(), $user_id );
 
 		$pager = new Pager($udlf);
@@ -159,7 +159,7 @@ switch ($action) {
 		$smarty->assign_by_ref('rows', $rows);
 		$smarty->assign_by_ref('user_id', $user_id);
 
-		$ulf = new UserListFactory();
+		$ulf = TTnew( 'UserListFactory' );
 
 		$filter_data = NULL;
 		extract( UserGenericDataFactory::getSearchFormData( $saved_search_id, NULL ) );
