@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 842 $
- * $Id: UserGenericStatusList.php 842 2007-05-04 00:24:43Z ipso $
- * $Date: 2007-05-03 17:24:43 -0700 (Thu, 03 May 2007) $
+ * $Revision: 4104 $
+ * $Id: UserGenericStatusList.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -86,7 +86,7 @@ switch ($action) {
 	default:
 		Debug::Text('Next Page: '. urldecode( $batch_next_page ) , __FILE__, __LINE__, __METHOD__,10);
 		if ( $batch_id != '' ) {
-			$ugslf = new UserGenericStatusListFactory();
+			$ugslf = TTnew( 'UserGenericStatusListFactory' );
 			$ugslf->getByUserIdAndBatchId( $current_user->getId(), $batch_id,  $current_user_prefs->getItemsPerPage(), $page, NULL, $sort_array );
 			//var_dump($ugslf);
 			Debug::Text('Record Count: '. $ugslf->getRecordCount(), __FILE__, __LINE__, __METHOD__,10);
