@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3463 $
- * $Id: UserList.php 3463 2010-03-29 20:26:17Z ipso $
- * $Date: 2010-03-29 13:26:17 -0700 (Mon, 29 Mar 2010) $
+ * $Revision: 4845 $
+ * $Id: UserList.php 4845 2011-06-21 16:23:18Z ipso $
+ * $Date: 2011-06-21 09:23:18 -0700 (Tue, 21 Jun 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -118,11 +118,11 @@ if ( $saved_search_id == '' AND !isset($filter_data['columns']) ) {
 }
 Debug::Text('Action: '. $action, __FILE__, __LINE__, __METHOD__,10);
 
-$ugdlf = new UserGenericDataListFactory();
-$ugdf = new UserGenericDataFactory();
+$ugdlf = TTnew( 'UserGenericDataListFactory' );
+$ugdf = TTnew( 'UserGenericDataFactory' );
 
 //Get Permission Hierarchy Children first, as this can be used for viewing, or editing.
-$hlf = new HierarchyListFactory();
+$hlf = TTnew( 'HierarchyListFactory' );
 $permission_children_ids = $hlf->getHierarchyChildrenByCompanyIdAndUserIdAndObjectTypeID( $current_company->getId(), $current_user->getId() );
 Debug::Arr($permission_children_ids,'Permission Children Ids:', __FILE__, __LINE__, __METHOD__,10);
 
@@ -154,7 +154,7 @@ switch ($action) {
 			AND ( $permission->Check('user','delete') OR $permission->Check('user','delete_own') OR $permission->Check('user','delete_child')  ) ) {
 
 			if ( is_array($ids) ) {
-				$ulf = new UserListFactory();
+				$ulf = TTnew( 'UserListFactory' );
 				$ulf->StartTransaction();
 
 				foreach ($ids as $id) {
@@ -212,8 +212,8 @@ switch ($action) {
 															'page' => $page
 														) );
 
-		$ulf = new UserListFactory();
-		$clf = new CompanyListFactory();
+		$ulf = TTnew( 'UserListFactory' );
+		$clf = TTnew( 'CompanyListFactory' );
 
 		if ( $permission->Check('company','view') ) {
 			$ulf->getSearchByArrayCriteria( $filter_data, $current_user_prefs->getItemsPerPage(), $page, NULL, $sort_array );
@@ -234,25 +234,25 @@ switch ($action) {
 		$pager = new Pager($ulf);
 
 		if ( $permission->Check('company','view') ) {
-			$clf = new CompanyListFactory();
-			$clf->getAll( $current_company->getId() );
+			$clf = TTnew( 'CompanyListFactory' );
+			$clf->getAll();
 			$company_options = $clf->getArrayByListFactory( $clf, FALSE, TRUE );
 		}
 
 		//Get title list,
-		$utlf = new UserTitleListFactory();
+		$utlf = TTnew( 'UserTitleListFactory' );
 		$utlf->getByCompanyId( $current_company->getId() );
 		$title_options = $utlf->getArrayByListFactory( $utlf, FALSE, TRUE );
 
-		$blf = new BranchListFactory();
+		$blf = TTnew( 'BranchListFactory' );
 		$blf->getByCompanyId( $current_company->getId() );
 		$branch_options = $blf->getArrayByListFactory( $blf, FALSE, TRUE );
 
-		$dlf = new DepartmentListFactory();
+		$dlf = TTnew( 'DepartmentListFactory' );
 		$dlf->getByCompanyId( $current_company->getId() );
 		$department_options = $dlf->getArrayByListFactory( $dlf, FALSE, TRUE );
 
-		$uglf = new UserGroupListFactory();
+		$uglf = TTnew( 'UserGroupListFactory' );
 		$group_options = $uglf->getArrayByNodes( FastTree::FormatArray( $uglf->getByCompanyIdArray( $current_company->getId() ), 'TEXT', TRUE) );
 
 		foreach ($ulf as $u_obj) {
@@ -299,6 +299,8 @@ switch ($action) {
 									'hire_date' => TTDate::getDate('DATE', $u_obj->getHireDate() ),
 									'termination_date' => TTDate::getDate('DATE', $u_obj->getTerminationDate() ),
 
+									'map_url' => $u_obj->getMapURL(),
+									
 									'is_owner' => $permission->isOwner( $u_obj->getCreatedBy(), $u_obj->getId() ),
 									'is_child' => $permission->isChild( $u_obj->getId(), $permission_children_ids ),
 									'deleted' => $u_obj->getDeleted(),
@@ -321,7 +323,7 @@ switch ($action) {
 		$filter_data['sex_options'] = Misc::prependArray( $all_array_option, $ulf->getOptions('sex') );
 		$filter_data['status_options'] = Misc::prependArray( $all_array_option, $ulf->getOptions('status') );
 
-		$cf = new CompanyFactory();
+		$cf = TTnew( 'CompanyFactory' );
 		$filter_data['country_options'] = Misc::prependArray( $all_array_option, $cf->getOptions('country') );
 		if ( isset($filter_data['country']) ) {
 			$filter_data['province_options'] = Misc::prependArray( $all_array_option, $cf->getOptions('province', $filter_data['country'] ) );
@@ -329,10 +331,10 @@ switch ($action) {
 			$filter_data['province_options'] = $all_array_option;
 		}
 
-		$ppslf = new PayPeriodScheduleListFactory();
+		$ppslf = TTnew( 'PayPeriodScheduleListFactory' );
 		$filter_data['pay_period_schedule_options'] = Misc::prependArray( $all_array_option, $ppslf->getByCompanyIDArray( $current_company->getId() ) );
 
-		$pglf = new PolicyGroupListFactory();
+		$pglf = TTnew( 'PolicyGroupListFactory' );
 		$filter_data['policy_group_options'] = Misc::prependArray( $all_array_option, $pglf->getByCompanyIDArray( $current_company->getId() ) );
 
 		$filter_data['saved_search_options'] = $ugdlf->getArrayByListFactory( $ugdlf->getByUserIdAndScript( $current_user->getId(), $_SERVER['SCRIPT_NAME']), FALSE );
