@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 1919 $
- * $Id: UserTitleList.php 1919 2008-06-13 18:17:17Z ipso $
- * $Date: 2008-06-13 11:17:17 -0700 (Fri, 13 Jun 2008) $
+ * $Revision: 4104 $
+ * $Id: UserTitleList.php 4104 2011-01-04 19:04:05Z ipso $
+ * $Date: 2011-01-04 11:04:05 -0800 (Tue, 04 Jan 2011) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -84,7 +84,7 @@ switch ($action) {
 			$delete = FALSE;
 		}
 
-		$utlf = new UserTitleListFactory();
+		$utlf = TTnew( 'UserTitleListFactory' );
 
 		foreach ($ids as $id) {
 			$utlf->GetByIdAndCompanyId($id, $current_company->getId() );
@@ -104,7 +104,7 @@ switch ($action) {
 			$sort_array = array(Misc::trimSortPrefix($sort_column) => $sort_order);
 		}
 
-		$utlf = new UserTitleListFactory();
+		$utlf = TTnew( 'UserTitleListFactory' );
 		$utlf->getByCompanyId($current_company->getId(), $current_user_prefs->getItemsPerPage(),$page, NULL, $sort_array );
 
 		$pager = new Pager($utlf);
