@@ -44,7 +44,7 @@
  */
 require_once( dirname(__FILE__) . DIRECTORY_SEPARATOR .'..'. DIRECTORY_SEPARATOR .'includes'. DIRECTORY_SEPARATOR .'global.inc.php');
 require_once( dirname(__FILE__) . DIRECTORY_SEPARATOR .'..'. DIRECTORY_SEPARATOR .'includes'. DIRECTORY_SEPARATOR .'CLI.inc.php');
-
+/*
 //
 // Backup database if script exists.
 // Always backup the database first before doing anything else like purging tables.
@@ -76,16 +76,19 @@ if ( !isset($config_vars['other']['disable_backup'])
 				$filepath = $backup_dir . DIRECTORY_SEPARATOR . $file;
 				if ( !is_dir( $filepath ) ) {
 					if ( preg_match( '/timetrex_database.*\.sql/i', $file) == 1 ) {
-						$backup_history_files[] = $filepath;
+		                $backup_history_files[filemtime($filepath)] = $filepath;
 					}
 				}
 			}
 		}
-		sort($backup_history_files);
+		ksort($backup_history_files);
 
 		if ( is_array( $backup_history_files ) AND count($backup_history_files) > 7 ) {
-			Debug::Text('Deleting oldest backup: '. $backup_history_files[0] .' Of Total: '. count($backup_history_files), __FILE__, __LINE__, __METHOD__,10);
-			unlink( $backup_history_files[0] );
+			reset($backup_history_files);
+			$delete_backup_file = current($backup_history_files);
+			Debug::Text('Deleting oldest backup: '. $delete_backup_file .' Of Total: '. count($backup_history_files), __FILE__, __LINE__, __METHOD__,10);
+			unlink( $delete_backup_file );
+			unset($delete_backup_file);
 		}
 	}
 	unset($backup_script, $output, $retcode, $backup_dir, $fh, $file, $filepath, $backup_history_files);
@@ -113,6 +116,46 @@ if ( !isset($config_vars['other']['disable_log_rotate'])
 	$lr = new LogRotate( $log_rotate_config );
 	$lr->Rotate();
 }
+*/
+
+//
+// Check cache file directories and permissions.
+//
+if ( !isset($config_vars['other']['disable_cache_permission_check'])
+		OR isset($config_vars['other']['disable_cache_permission_check']) AND $config_vars['other']['disable_cache_permission_check'] != TRUE ) {
+	if ( isset($config_vars['cache']['enable']) AND $config_vars['cache']['enable'] == TRUE AND isset($config_vars['cache']['dir']) AND $config_vars['cache']['dir'] != '' ) {
+		Debug::Text('Validating Cache Files/Directory: '. $config_vars['cache']['dir'], __FILE__, __LINE__, __METHOD__,10);
+
+		//Just as a precaution, confirm that cache directory exists, if not try to create it.
+		if ( file_exists($config_vars['cache']['dir']) == FALSE ) {
+			//Try to create cache directory
+			Debug::Text( 'Cache directory does not exist, attempting to create it: '. $config_vars['cache']['dir'], __FILE__, __LINE__, __METHOD__,10);
+			$mkdir_result = @mkdir( $config_vars['cache']['dir'], 0777, TRUE );
+			if ( $mkdir_result == FALSE ) {
+				Debug::Text( 'ERROR: Unable to create cache directory: '. $config_vars['cache']['dir'], __FILE__, __LINE__, __METHOD__,10);
+				Misc::disableCaching();
+			} else {
+				Debug::Text( 'Cache directory created successfully: '. $config_vars['cache']['dir'], __FILE__, __LINE__, __METHOD__,10);
+			}
+			unset($mkdir_result);
+		}
+
+		//Check all cache files and make sure they are owned by the same users.
+		$cache_files = Misc::getFileList( $config_vars['cache']['dir'], NULL, TRUE );
+		if ( is_array($cache_files) AND count($cache_files) > 0 ) {
+			foreach( $cache_files as $cache_file ) {
+				$cache_file_owners[] = @fileowner($cache_file);
+			}
+
+			$cache_file_owners = array_unique($cache_file_owners);
+			if ( count($cache_file_owners) > 1 ) {
+				Debug::Text( 'ERROR: Cache directory contains files from several different owners. Its likely that their permission conflict.', __FILE__, __LINE__, __METHOD__,10);
+				Debug::Arr( $cache_file_owners, 'Cache File Owner UIDs: ', __FILE__, __LINE__, __METHOD__,10);
+				Misc::disableCaching();
+			}
+		}
+	}
+}
 
 Debug::writeToLog();
 Debug::Display();
