@@ -65,7 +65,7 @@ if ( !isset($config_vars['other']['disable_database_purging'])
 							// 'accrual_balance' => 30, //Doesnt have updated_date column
 							'accrual_policy' => 30,
 							'accrual_policy_milestone' => 30,
-							'authorizations' => 30,
+							'authorizations' => 30, //Must go before requests.
 							'bank_account' => 30,
 							'branch' => 30,
 							'break_policy' => 30,
@@ -82,6 +82,9 @@ if ( !isset($config_vars['other']['disable_database_purging'])
 							'holidays' => 30,
 							'meal_policy' => 30,
 							'message' => 30,
+							'message_sender' => 30,
+							'message_recipient' => 30,
+							'message_control' => 30,
 							'other_field' => 30,
 							'over_time_policy' => 30,
 							'pay_period' => 30,
@@ -156,52 +159,90 @@ if ( !isset($config_vars['other']['disable_database_purging'])
 		$db->StartTrans();
 		foreach( $purge_tables as $table => $expire_days ) {
 			if ( in_array($table, $current_tables) ) {
-
 				switch ( $table ) {
 					case 'user_generic_status':
 						//Treat the user_generic_status table differently, as rows are never marked as deleted in it.
-						$query = 'delete from '. $table .' where updated_date <= '. (time()-(86400*($expire_days)));
+						$query[] = 'delete from '. $table .' where updated_date <= '. (time()-(86400*($expire_days)));
 						break;
 					case 'system_log':
 						//Only delete system_log rows from deleted users, or deleted/cancelled companies
-						$query = 'delete from '. $table .' as a USING users as b, company as c WHERE a.user_id = b.id AND b.company_id = c.id AND ( b.deleted = 1 OR c.deleted = 1 OR c.status_id = 30 ) AND ( a.date <= '. (time()-(86400*($expire_days))) .' AND b.updated_date <= '. (time()-(86400*($expire_days))) .' AND c.updated_date <= '. (time()-(86400*($expire_days))) .')';
+						$query[] = 'delete from '. $table .' as a USING users as b, company as c WHERE a.user_id = b.id AND b.company_id = c.id AND ( b.deleted = 1 OR c.deleted = 1 OR c.status_id = 30 ) AND ( a.date <= '. (time()-(86400*($expire_days))) .' AND b.updated_date <= '. (time()-(86400*($expire_days))) .' AND c.updated_date <= '. (time()-(86400*($expire_days))) .')';
+
+						//Quite a few system_log rows are created by user_id=0 (system), they aren't shown on the audit log anyways and don't need to be kept around for long.
+						//This also deletes logs that can't be matches to any user, or those that have already been deleted.
+						$query[] = 'delete from '. $table .' where id in ( select a.id from '. $table .' as a LEFT JOIN users as b ON a.user_id = b.id WHERE b.id is NULL AND ( a.date <= '. (time()-(86400*($expire_days))) .' ) )';
 						break;
 					case 'system_log_detail':
 						//Only delete system_log_detail rows when the corresponding system_log rows are already deleted
-						$query = 'delete from '. $table .' where id in ( select a.id from '. $table .' as a LEFT JOIN system_log as b ON a.system_log_id = b.id WHERE b.id is NULL )';
+						$query[] = 'delete from '. $table .' where id in ( select a.id from '. $table .' as a LEFT JOIN system_log as b ON a.system_log_id = b.id WHERE b.id is NULL )';
 						break;
 					case 'punch':
 						//Delete punch rows from deleted users, or deleted/cancelled companies
-						$query = 'delete from '. $table .' as a USING punch_control as b, user_date as c, users as d, company as e WHERE a.punch_control_id = b.id AND b.user_date_id = c.id AND c.user_id = d.id AND d.company_id = e.id AND ( a.deleted = 1 OR b.deleted = 1 OR c.deleted = 1 OR d.deleted = 1 OR e.deleted = 1 OR e.status_id = 30 ) AND ( a.updated_date <= '. (time()-(86400*($expire_days))) .' AND d.updated_date <= '. (time()-(86400*($expire_days))) .' AND e.updated_date <= '. (time()-(86400*($expire_days))) .')';
+						$query[] = 'delete from '. $table .' as a USING punch_control as b, user_date as c, users as d, company as e WHERE a.punch_control_id = b.id AND b.user_date_id = c.id AND c.user_id = d.id AND d.company_id = e.id AND ( a.deleted = 1 OR b.deleted = 1 OR c.deleted = 1 OR d.deleted = 1 OR e.deleted = 1 OR e.status_id = 30 ) AND ( a.updated_date <= '. (time()-(86400*($expire_days))) .' AND d.updated_date <= '. (time()-(86400*($expire_days))) .' AND e.updated_date <= '. (time()-(86400*($expire_days))) .')';
 						break;
 					case 'punch_control':
 					case 'user_date_total':
 					case 'schedule':
+					case 'exception':
+					case 'request':
 						//Delete punch_control/user_date rows from deleted users, or deleted/cancelled companies
-						$query = 'delete from '. $table .' as a USING user_date as c, users as d, company as e WHERE a.user_date_id = c.id AND c.user_id = d.id AND d.company_id = e.id AND ( a.deleted = 1 OR c.deleted = 1 OR d.deleted = 1 OR e.deleted = 1 OR e.status_id = 30 ) AND ( a.updated_date <= '. (time()-(86400*($expire_days))) .' AND d.updated_date <= '. (time()-(86400*($expire_days))) .' AND e.updated_date <= '. (time()-(86400*($expire_days))) .')';
+						$query[] = 'delete from '. $table .' as a USING user_date as c, users as d, company as e WHERE a.user_date_id = c.id AND c.user_id = d.id AND d.company_id = e.id AND ( a.deleted = 1 OR c.deleted = 1 OR d.deleted = 1 OR e.deleted = 1 OR e.status_id = 30 ) AND ( a.updated_date <= '. (time()-(86400*($expire_days))) .' AND d.updated_date <= '. (time()-(86400*($expire_days))) .' AND e.updated_date <= '. (time()-(86400*($expire_days))) .')';
 						break;
 					case 'user_date':
-						//Delete user_date rows from deleted users, or deleted/cancelled companies
-						$query = 'delete from '. $table .' as a USING users as d, company as e WHERE a.user_id = d.id AND d.company_id = e.id AND ( a.deleted = 1 OR d.deleted = 1 OR e.deleted = 1 OR e.status_id = 30 ) AND ( a.updated_date <= '. (time()-(86400*($expire_days))) .' AND d.updated_date <= '. (time()-(86400*($expire_days))) .' AND e.updated_date <= '. (time()-(86400*($expire_days))) .')';
+					case 'user_identification':
+					case 'user_generic_data':
+					case 'pay_period_time_sheet_verify':
+					case 'message_sender':
+					case 'message_recipient':
+						//Delete rows from deleted users, or deleted/cancelled companies
+						$query[] = 'delete from '. $table .' as a USING users as d, company as e WHERE a.user_id = d.id AND d.company_id = e.id AND ( a.deleted = 1 OR d.deleted = 1 OR e.deleted = 1 OR e.status_id = 30 ) AND ( a.updated_date <= '. (time()-(86400*($expire_days))) .' AND d.updated_date <= '. (time()-(86400*($expire_days))) .' AND e.updated_date <= '. (time()-(86400*($expire_days))) .')';
 						break;
 					case 'pay_stub_entry':
 						//Only delete pay_stub_entry rows from deleted users, or deleted/cancelled companies
-						$query = 'delete from '. $table .' as a USING pay_stub as b WHERE a.pay_stub_id = b.id AND ( a.deleted = 1 OR b.deleted = 1 ) AND a.updated_date <= '. (time()-(86400*($expire_days)));
+						$query[] = 'delete from '. $table .' as a USING pay_stub as b WHERE a.pay_stub_id = b.id AND ( a.deleted = 1 OR b.deleted = 1 ) AND a.updated_date <= '. (time()-(86400*($expire_days)));
+						break;
+					case 'authorizations':
+						//Only delete authorization rows from deleted requests.
+						$query[] = 'delete from '. $table .' as a USING request as b WHERE a.object_type_id in (50,1010,1020,1030,1040,1100) AND a.object_id = b.id AND ( b.deleted = 1 ) AND ( b.updated_date <= '. (time()-(86400*($expire_days))) .' AND a.updated_date <= '. (time()-(86400*($expire_days))) .' AND b.updated_date <= '. (time()-(86400*($expire_days))) .')';
+
+						//FIXME: Need to handle authorizations for deleted timesheet verifications.
+						break;
+					case 'station':
+						//Delete station rows from deleted/cancelled companies
+						$query[] = 'delete from '. $table .' as a USING company as e WHERE a.company_id = e.id AND ( a.deleted = 1 OR e.deleted = 1 OR e.status_id = 30 ) AND ( a.updated_date <= '. (time()-(86400*($expire_days))) .' AND e.updated_date <= '. (time()-(86400*($expire_days))) .')';
+						break;
+					case 'permission_control':
+						//Only delete system_log rows from deleted users, or deleted/cancelled companies
+						$query[] = 'delete from '. $table .' as a USING company as c WHERE a.company_id = c.id AND ( c.deleted = 1 OR c.status_id = 30 ) AND ( a.updated_date <= '. (time()-(86400*($expire_days))) .' AND c.updated_date <= '. (time()-(86400*($expire_days))) .')';
+						break;
+					case 'permission':
+						//Only delete system_log_detail rows when the corresponding system_log rows are already deleted
+						$query[] = 'delete from '. $table .' where id in ( select a.id from '. $table .' as a LEFT JOIN permission_control as b ON a.permission_control_id = b.id WHERE b.id is NULL )';
+						break;
+					case 'message_control':
+						//Only delete system_log_detail rows when the corresponding system_log rows are already deleted
+						$query[] = 'delete from '. $table .' where id in ( select a.id from '. $table .' as a LEFT JOIN message_sender as b ON a.id = b.message_control_id WHERE b.id is NULL )';
 						break;
 					default:
-						$query = 'delete from '. $table .' where deleted = 1 AND updated_date <= '. (time()-(86400*($expire_days)));
+						$query[] = 'delete from '. $table .' where deleted = 1 AND updated_date <= '. (time()-(86400*($expire_days)));
 						break;
 				}
 
 				//FIXME: With new punch method in v3.0 add query to make sure orphaned punches without punch_control rows are cleaned out
 				//select a.id,a.deleted,b.id,b.deleted from punch as a LEFT JOIN punch_control as b ON (a.punch_control_id = b.id) WHERE b.id is NULL AND a.deleted = 0;
-
-				$db->Execute( $query );
-				Debug::Text('Table found for purging: '. $table .' Expire Days: '. $expire_days .' Purged Rows: '. $db->Affected_Rows(), __FILE__, __LINE__, __METHOD__,10);
+				if ( isset($query) AND is_array($query) ) {
+					$i=0;
+					foreach( $query as $q ) {
+						$db->Execute( $q );
+						//Debug::Text('Query: '. $q, __FILE__, __LINE__, __METHOD__,10);
+						Debug::Text('Table found for purging: '. $table .'('.$i.') Expire Days: '. $expire_days .' Purged Rows: '. $db->Affected_Rows(), __FILE__, __LINE__, __METHOD__,10);
+						$i++;
+					}
+				}
+				unset($query);
 			} else {
 				Debug::Text('Table not found for purging: '. $table, __FILE__, __LINE__, __METHOD__,10);
 			}
-
 		}
 		$db->CompleteTrans();
 	}
