@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2116 $
- * $Id: calcExceptions.php 2116 2008-09-05 18:49:48Z ipso $
- * $Date: 2008-09-05 11:49:48 -0700 (Fri, 05 Sep 2008) $
+ * $Revision: 4418 $
+ * $Id: calcExceptions.php 4418 2011-03-23 22:50:51Z ipso $
+ * $Date: 2011-03-23 15:50:51 -0700 (Wed, 23 Mar 2011) $
  */
 /*
  * Calculate Exceptions for the previous day. This helps especially for
@@ -148,56 +148,6 @@ if ( $clf->getRecordCount() > 0 ) {
 	}
 }
 
-
-/*
-//Two days ago.
-$date = TTDate::getMiddleDayEpoch( time() ) - (86400*2);
-//$date = TTDate::getBeginDayEpoch( time() );
-
-$udlf = new UserDateListFactory();
-$udlf->getByDate( $date );
-if ( $udlf->getRecordCount() > 0 ) {
-	$i=0;
-	foreach ($udlf as $ud_obj) {
-		Debug::text($i .'. User: '. $ud_obj->getUser() .' Date: '. TTDate::getDate('DATE+TIME', $ud_obj->getDateStamp() ) .' User Date ID: '. $ud_obj->getId() , __FILE__, __LINE__, __METHOD__,5);
-
-		//ExceptionPolicyFactory::calcExceptions( $ud_obj->getId() );
-
-		//Recalculate system time, and exceptions for the day.
-		//Because if its a Monday, it will also recalculate the rest of the days in the week.
-		//Shouldn't be a big deal though.
-		//This isn't needed, since we now do it in AddRecurringScheduleShift, so dock time is
-		//applied at the beginning of the day.
-		//The problem is that AddRecurringScheduleShift does it, then for the entire day someone with
-		//a dock policy shows up as dock time. Some users have complained about this a few times.
-
-		//Reason for doing two days ago is that if someone starts a shift at 11pm, but doesn't end it in
-		//time, it still needs to be re-calculated a day later.
-		//Could maybe get around this by getting all punches of yesterday, and getting their date_ids
-		//and just recalculating those.
-		UserDateTotalFactory::reCalculateDay( $ud_obj->getId(), TRUE );
-
-		$i++;
-	}
-}
-
-//One day ago
-$date = TTDate::getMiddleDayEpoch( time() ) - (86400);
-
-$udlf = new UserDateListFactory();
-$udlf->getByDate( $date );
-if ( $udlf->getRecordCount() > 0 ) {
-	$i=0;
-	foreach ($udlf as $ud_obj) {
-		Debug::text($i .'. User: '. $ud_obj->getUser() .' Date: '. TTDate::getDate('DATE+TIME', $ud_obj->getDateStamp() ) .' User Date ID: '. $ud_obj->getId(), __FILE__, __LINE__, __METHOD__,5);
-
-		//ExceptionPolicyFactory::calcExceptions( $ud_obj->getId() );
-		UserDateTotalFactory::reCalculateDay( $ud_obj->getId(), TRUE, TRUE );
-
-		$i++;
-	}
-}
-*/
 Debug::writeToLog();
 Debug::Display();
 ?>
\ No newline at end of file
