@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 4073 $
- * $Id: import_users.php 4073 2010-12-27 23:35:24Z ipso $
- * $Date: 2010-12-27 15:35:24 -0800 (Mon, 27 Dec 2010) $
+ * $Revision: 4495 $
+ * $Id: import_users.php 4495 2011-04-04 23:23:53Z ipso $
+ * $Date: 2011-04-04 16:23:53 -0700 (Mon, 04 Apr 2011) $
  */
 require_once( dirname(__FILE__) . DIRECTORY_SEPARATOR .'..'. DIRECTORY_SEPARATOR .'..'. DIRECTORY_SEPARATOR .'includes'. DIRECTORY_SEPARATOR .'global.inc.php');
 require_once( dirname(__FILE__) . DIRECTORY_SEPARATOR .'..'. DIRECTORY_SEPARATOR .'..'. DIRECTORY_SEPARATOR .'includes'. DIRECTORY_SEPARATOR .'CLI.inc.php');
@@ -357,7 +357,7 @@ if ( $argc < 3 OR in_array ($argv[1], array('--help', '-help', '-h', '-?') ) ) {
 	//FIXME: Use Pears Console_GetArgs package to handle these better.
 
 	//Set timezone to your system timezone, otherwise dates can be off by the difference.
-	TTDate::setTimeZone( 'GMT' );
+	TTDate::setTimeZone();
 
 	//Handle command line arguments
 	$last_arg = count($argv)-1;
@@ -1151,5 +1151,6 @@ if ( $argc < 3 OR in_array ($argv[1], array('--help', '-help', '-h', '-?') ) ) {
 
 echo "WARNING: Clear TimeTrex cache after running this.\n";
 
+//Debug::writeToLog();
 //Debug::Display();
 ?>
