@@ -42,7 +42,7 @@ require_once('PHPUnit/Framework/TestCase.php');
 
 class CAPayrollDeductionTest2007 extends PHPUnit_Framework_TestCase {
 
-    public $company_id = 1;
+    public $company_id = NULL;
 
     public function __construct() {
         global $db, $cache;
@@ -50,6 +50,8 @@ class CAPayrollDeductionTest2007 extends PHPUnit_Framework_TestCase {
         require_once('../includes/global.inc.php');
 		require_once( Environment::getBasePath().'/classes/payroll_deduction/PayrollDeduction.class.php');
 
+		$this->company_id = PRIMARY_COMPANY_ID;
+
         $profiler = new Profiler( true );
         Debug::setBufferOutput(FALSE);
         Debug::setEnable(TRUE);
