@@ -42,7 +42,7 @@ require_once('PHPUnit/Framework/TestCase.php');
 
 class CAPayrollDeductionTest2010 extends PHPUnit_Framework_TestCase {
 
-    public $company_id = 1;
+    public $company_id = NULL;
 	public $tax_table_file = 'CAPayrollDeductionTest2010.csv';
 
     public function __construct() {
@@ -51,6 +51,8 @@ class CAPayrollDeductionTest2010 extends PHPUnit_Framework_TestCase {
         require_once('../includes/global.inc.php');
 		require_once( Environment::getBasePath().'/classes/payroll_deduction/PayrollDeduction.class.php');
 
+		$this->company_id = PRIMARY_COMPANY_ID;
+
         $profiler = new Profiler( true );
         Debug::setBufferOutput(FALSE);
         Debug::setEnable(TRUE);
