@@ -1,7 +1,7 @@
 <?php
 /*********************************************************************************
  * TimeTrex is a Payroll and Time Management program developed by
- * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2011 TimeTrex Payroll Services.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Affero General Public License version 3 as published by
@@ -34,9 +34,9 @@
  * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 3298 $
- * $Id: DateTimeTest.php 3298 2010-01-20 18:52:46Z ipso $
- * $Date: 2010-01-20 10:52:46 -0800 (Wed, 20 Jan 2010) $
+ * $Revision: 3928 $
+ * $Id: DateTimeTest.php 3928 2010-11-11 20:29:54Z ipso $
+ * $Date: 2010-11-11 12:29:54 -0800 (Thu, 11 Nov 2010) $
  */
 require_once('PHPUnit/Framework/TestCase.php');
 
@@ -618,18 +618,16 @@ class DateTimeTest extends PHPUnit_Framework_TestCase {
 	}
 
 	function test_getNearestWeekDay() {
-/*
-				case 0: //No adjustment
-					break 2;
-				case 1: //Previous day
-					$epoch -= 86400;
-					break;
-				case 2: //Next day
-					$epoch += 86400;
-					break;
-				case 3: //Closest day
+		//case 0: //No adjustment
+		//	break 2;
+		//case 1: //Previous day
+		//	$epoch -= 86400;
+		//	break;
+		//case 2: //Next day
+		//	$epoch += 86400;
+		//	break;
+		//case 3: //Closest day
 
-*/
 
 		$date1 = strtotime('16-Jan-2010 12:00PM');
 		$this->assertEquals( TTDate::getNearestWeekDay( $date1, 0 ), strtotime('16-Jan-2010 12:00PM') );
@@ -673,5 +671,126 @@ class DateTimeTest extends PHPUnit_Framework_TestCase {
 		$this->assertEquals( TTDate::getNearestWeekDay( $date1, 1, $holidays ), strtotime('12-Jan-2010 12:00PM') );
 		$this->assertEquals( TTDate::getNearestWeekDay( $date1, 3, $holidays ), strtotime('19-Jan-2010 12:00PM') );
 	}
+
+	function test_timePeriodDates() {
+		Debug::text('Testing Time Period Dates!', __FILE__, __LINE__, __METHOD__,10);
+		TTDate::setTimeZone('PST');
+
+		$dates = TTDate::getTimePeriodDates('custom_date', strtotime('15-Jul-10 12:00 PM'), NULL, array('start_date' => strtotime('10-Jul-10 12:43 PM'), 'end_date' => strtotime('12-Jul-10 12:43 PM') ) );
+		$this->assertEquals( $dates['start_date'], (int)1278745200 );
+		$this->assertEquals( $dates['end_date'], (int)1279004399 );
+
+		$dates = TTDate::getTimePeriodDates('custom_time', strtotime('15-Jul-10 12:00 PM'), NULL, array('start_date' => strtotime('10-Jul-10 12:43 PM'), 'end_date' => strtotime('12-Jul-10 12:53 PM') ) );
+		$this->assertEquals( $dates['start_date'], (int)1278790980 );
+		$this->assertEquals( $dates['end_date'], (int)1278964380 );
+
+		$dates = TTDate::getTimePeriodDates('today', strtotime('15-Jul-10 12:00 PM') );
+		$this->assertEquals( $dates['start_date'], (int)1279177200 );
+		$this->assertEquals( $dates['end_date'], (int)1279263599 );
+
+		$dates = TTDate::getTimePeriodDates('yesterday', strtotime('15-Jul-10 12:00 PM') );
+		$this->assertEquals( $dates['start_date'], (int)1279090800 );
+		$this->assertEquals( $dates['end_date'], (int)1279177199 );
+
+		$dates = TTDate::getTimePeriodDates('last_24_hours', strtotime('15-Jul-10 12:43 PM') );
+		$this->assertEquals( $dates['start_date'], (int)1279136580 );
+		$this->assertEquals( $dates['end_date'], (int)1279222980 );
+
+		$dates = TTDate::getTimePeriodDates('this_week', strtotime('15-Jul-10 12:00 PM') );
+		$this->assertEquals( $dates['start_date'], (int)1278831600 );
+		$this->assertEquals( $dates['end_date'], (int)1279436399 );
+
+		$dates = TTDate::getTimePeriodDates('last_week', strtotime('15-Jul-10 12:00 PM') );
+		$this->assertEquals( $dates['start_date'], (int)1278226800 );
+		$this->assertEquals( $dates['end_date'], (int)1278831599 );
+
+		$dates = TTDate::getTimePeriodDates('last_7_days', strtotime('15-Jul-10 12:43 PM') );
+		$this->assertEquals( $dates['start_date'], (int)1278572400 );
+		$this->assertEquals( $dates['end_date'], (int)1279177199 );
+
+		$dates = TTDate::getTimePeriodDates('this_month', strtotime('15-Jul-10 12:00 PM') );
+		$this->assertEquals( $dates['start_date'], (int)1277967600 );
+		$this->assertEquals( $dates['end_date'], (int)1280645999 );
+
+		$dates = TTDate::getTimePeriodDates('last_month', strtotime('15-Jul-10 12:00 PM') );
+		$this->assertEquals( $dates['start_date'], (int)1275375600 );
+		$this->assertEquals( $dates['end_date'], (int)1277967599 );
+
+		$dates = TTDate::getTimePeriodDates('last_month', strtotime('15-Mar-10 12:00 PM') );
+		$this->assertEquals( $dates['start_date'], (int)1265011200 );
+		$this->assertEquals( $dates['end_date'], (int)1267430399 );
+
+		$dates = TTDate::getTimePeriodDates('last_30_days', strtotime('15-Jul-10 12:00 PM') );
+		$this->assertEquals( $dates['start_date'], (int)1276585200 );
+		$this->assertEquals( $dates['end_date'], (int)1279177199 );
+
+		$dates = TTDate::getTimePeriodDates('this_quarter', strtotime('15-Jul-10 12:00 PM') );
+		$this->assertEquals( $dates['start_date'], (int)1277967600 );
+		$this->assertEquals( $dates['end_date'], (int)1285916399 );
+
+		$dates = TTDate::getTimePeriodDates('last_quarter', strtotime('15-Jul-10 12:00 PM') );
+		$this->assertEquals( $dates['start_date'], (int)1270105200 );
+		$this->assertEquals( $dates['end_date'], (int)1277967599 );
+
+		$dates = TTDate::getTimePeriodDates('last_90_days', strtotime('15-Jul-10 12:00 PM') );
+		$this->assertEquals( $dates['start_date'], (int)1271401200 );
+		$this->assertEquals( $dates['end_date'], (int)1279177199 );
+
+		$dates = TTDate::getTimePeriodDates('this_year_1st_quarter', strtotime('15-Jul-10 12:00 PM') );
+		$this->assertEquals( $dates['start_date'], (int)1262332800 );
+		$this->assertEquals( $dates['end_date'], (int)1270105199 );
+
+		$dates = TTDate::getTimePeriodDates('this_year_2nd_quarter', strtotime('15-Jul-10 12:00 PM') );
+		$this->assertEquals( $dates['start_date'], (int)1270105200 );
+		$this->assertEquals( $dates['end_date'], (int)1277967599 );
+
+		$dates = TTDate::getTimePeriodDates('this_year_3rd_quarter', strtotime('15-Jul-10 12:00 PM') );
+		$this->assertEquals( $dates['start_date'], (int)1277967600 );
+		$this->assertEquals( $dates['end_date'], (int)1285916399 );
+
+		$dates = TTDate::getTimePeriodDates('this_year_4th_quarter', strtotime('15-Jul-10 12:00 PM') );
+		$this->assertEquals( $dates['start_date'], (int)1285916400 );
+		$this->assertEquals( $dates['end_date'], (int)1293868799 );
+
+		$dates = TTDate::getTimePeriodDates('last_year_1st_quarter', strtotime('15-Jul-10 12:00 PM') );
+		$this->assertEquals( $dates['start_date'], (int)1230796800 );
+		$this->assertEquals( $dates['end_date'], (int)1238569199 );
+
+		$dates = TTDate::getTimePeriodDates('last_year_2nd_quarter', strtotime('15-Jul-10 12:00 PM') );
+		$this->assertEquals( $dates['start_date'], (int)1238569200 );
+		$this->assertEquals( $dates['end_date'], (int)1246431599 );
+
+		$dates = TTDate::getTimePeriodDates('last_year_3rd_quarter', strtotime('15-Jul-10 12:00 PM') );
+		$this->assertEquals( $dates['start_date'], (int)1246431600 );
+		$this->assertEquals( $dates['end_date'], (int)1254380399 );
+
+		$dates = TTDate::getTimePeriodDates('last_year_4th_quarter', strtotime('15-Jul-10 12:00 PM') );
+		$this->assertEquals( $dates['start_date'], (int)1254380400 );
+		$this->assertEquals( $dates['end_date'], (int)1262332799 );
+
+		$dates = TTDate::getTimePeriodDates('last_3_months', strtotime('15-May-10 12:00 PM') );
+		$this->assertEquals( $dates['start_date'], (int)1266134400 );
+		$this->assertEquals( $dates['end_date'], (int)1273906799 );
+
+		$dates = TTDate::getTimePeriodDates('last_6_months', strtotime('15-May-10 12:00 PM') );
+		$this->assertEquals( $dates['start_date'], (int)1258185600 );
+		$this->assertEquals( $dates['end_date'], (int)1273906799 );
+
+		$dates = TTDate::getTimePeriodDates('last_9_months', strtotime('15-May-10 12:00 PM') );
+		$this->assertEquals( $dates['start_date'], (int)1250233200 );
+		$this->assertEquals( $dates['end_date'], (int)1273906799 );
+
+		$dates = TTDate::getTimePeriodDates('last_12_months', strtotime('15-Jul-10 12:00 PM') );
+		$this->assertEquals( $dates['start_date'], (int)1247554800 );
+		$this->assertEquals( $dates['end_date'], (int)1279177199 );
+
+		$dates = TTDate::getTimePeriodDates('this_year', strtotime('15-Jul-10 12:00 PM') );
+		$this->assertEquals( $dates['start_date'], (int)1262332800 );
+		$this->assertEquals( $dates['end_date'], (int)1293868799 );
+
+		$dates = TTDate::getTimePeriodDates('last_year', strtotime('15-Jul-10 12:00 PM') );
+		$this->assertEquals( $dates['start_date'], (int)1230796800 );
+		$this->assertEquals( $dates['end_date'], (int)1262332799 );
+	}
 }
 ?>
\ No newline at end of file
